@@ -2,7 +2,7 @@
 //
 // Export a Rivendell Cut Report.
 //
-//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,11 +22,15 @@
 
 #include <qfile.h>
 #include <qmessagebox.h>
-#include <rddb.h>
-#include <rdlog_line.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+
 #include <rdairplay_conf.h>
 #include <rdconf.h>
 #include <rddatedecode.h>
+#include <rddb.h>
+#include <rdescape_string.h>
+#include <rdlog_line.h>
 #include <rdreport.h>
 
 bool RDReport::ExportCutLog(const QString &filename,const QDate &startdate,
@@ -34,17 +38,19 @@ bool RDReport::ExportCutLog(const QString &filename,const QDate &startdate,
 {
   QString sql;
   RDSqlQuery *q;
-  FILE *f;
   QString cut;
   QString str;
   QString cart_fmt;
   QString cart_num;
 
-  QFile file(filename);
-  if((f=fopen((const char *)filename,"w"))==NULL) {
+  QFile *file=new QFile(filename);
+  if(!file->open(QIODevice::WriteOnly|QIODevice::Truncate)) {
     report_error_code=RDReport::ErrorCantOpen;
+    delete file;
     return false;
   }
+  Q3TextStream *strm=new Q3TextStream(file);
+  strm->setEncoding(Q3TextStream::UnicodeUTF8);
   if(useLeadingZeros()) {
     cart_fmt=QString().sprintf("%%0%uu",cartDigits());
   }
@@ -52,22 +58,23 @@ bool RDReport::ExportCutLog(const QString &filename,const QDate &startdate,
     cart_fmt="%6u";
   }
   sql=QString("select ")+
-    "`"+mixtable+"_SRT`.LENGTH,"+          // 00
-    "`"+mixtable+"_SRT`.CART_NUMBER,"+     // 01
-    "`"+mixtable+"_SRT`.EVENT_DATETIME,"+  // 02
-    "`"+mixtable+"_SRT`.EVENT_TYPE,"+      // 03
-    "`"+mixtable+"_SRT`.EXT_START_TIME,"+  // 04
-    "`"+mixtable+"_SRT`.EXT_LENGTH,"+      // 05
-    "`"+mixtable+"_SRT`.EXT_DATA,"+        // 06
-    "`"+mixtable+"_SRT`.EXT_EVENT_ID,"+    // 07
-    "`"+mixtable+"_SRT`.TITLE,"+           // 08
-    "CART.FORCED_LENGTH,"+                 // 09
-    "`"+mixtable+"_SRT`.STATION_NAME,"+    // 10
-    "`"+mixtable+"_SRT`.PLAY_SOURCE,"+     // 11
-    "`"+mixtable+"_SRT`.CUT_NUMBER,"+      // 12
-    "`"+mixtable+"_SRT`.DESCRIPTION "+     // 13
-    "from `"+mixtable+"_SRT` left join CART "+
-    "on `"+mixtable+"_SRT`.CART_NUMBER=CART.NUMBER "+
+    "ELR_LINES.LENGTH,"+          // 00
+    "ELR_LINES.CART_NUMBER,"+     // 01
+    "ELR_LINES.EVENT_DATETIME,"+  // 02
+    "ELR_LINES.EVENT_TYPE,"+      // 03
+    "ELR_LINES.EXT_START_TIME,"+  // 04
+    "ELR_LINES.EXT_LENGTH,"+      // 05
+    "ELR_LINES.EXT_DATA,"+        // 06
+    "ELR_LINES.EXT_EVENT_ID,"+    // 07
+    "ELR_LINES.TITLE,"+           // 08
+    "CART.FORCED_LENGTH,"+        // 09
+    "ELR_LINES.STATION_NAME,"+    // 10
+    "ELR_LINES.PLAY_SOURCE,"+     // 11
+    "ELR_LINES.CUT_NUMBER,"+      // 12
+    "ELR_LINES.DESCRIPTION "+     // 13
+    "from ELR_LINES left join CART "+
+    "on ELR_LINES.CART_NUMBER=CART.NUMBER where "+
+    "SERVICE_NAME=\""+RDEscapeString(mixtable)+"\" "+
     "order by EVENT_DATETIME";
   q=new RDSqlQuery(sql);
 
@@ -75,21 +82,16 @@ bool RDReport::ExportCutLog(const QString &filename,const QDate &startdate,
   // Write File Header
   //
   if(startdate==enddate) {
-    fprintf(f,"                  Rivendell RDAirPlay Cut Report for %s\n",
-	    (const char *)startdate.toString("MM/dd/yyyy"));
+    *strm << RDReport::center(QString("Rivendell RDAirPlay Cut Report for ")+
+		    startdate.toString("MM/dd/yyyy"),75);
   }
   else {
-    fprintf(f,"             Rivendell RDAirPlay Cut Report for %s - %s\n",
-	    (const char *)startdate.toString("MM/dd/yyyy"),
-	    (const char *)enddate.toString("MM/dd/yyyy"));
+    *strm << RDReport::center(QString("Rivendell RDAirPlay Cut Report for ")+
+		    startdate.toString("MM/dd/yyyy")+" - "+
+		    enddate.toString("MM/dd/yyyy"),75)+"\n";
   }
-  str=QString().sprintf("%s -- %s\n",(const char *)name(),
-			(const char *)description());
-  for(unsigned i=0;i<(80-str.length())/2;i++) {
-    fprintf(f," ");
-  }
-  fprintf(f,"%s\n",(const char *)str);
-  fprintf(f,"--Time--  -Cart-  --Title----------------  Cut  --Description-------  -Len-\n");
+  *strm << RDReport::center(name()+" -- "+description(),75)+"\n";
+  *strm << "--Time--  -Cart-  --Title----------------  Cut  --Description-------  -Len-\n";
 
   //
   // Write Data Rows
@@ -112,18 +114,17 @@ bool RDReport::ExportCutLog(const QString &filename,const QDate &startdate,
     if(desc.isEmpty()) {
       desc="                    ";
     }
-    fprintf(f,"%8s  %6s  %-23s  %3s  %-20s  %5s",
-	    (const char *)q->value(2).toTime().toString("hh:mm:ss"),
-	    (const char *)cart_num,
-	    (const char *)q->value(8).toString().left(23),
-	    (const char *)cut,
-	    (const char *)desc.left(20),
-	    (const char *)RDGetTimeLength(q->value(9).toInt(),true,false).
-	    right(5));
-    fprintf(f,"\n");
+    *strm << q->value(2).toTime().toString("hh:mm:ss")+"  ";
+    *strm << cart_num+"  ";
+    *strm << RDReport::leftJustify(q->value(8).toString(),23)+"  ";
+    *strm << cut+"  ";
+    *strm << RDReport::leftJustify(desc,20)+"  ";
+    *strm << RDGetTimeLength(q->value(9).toInt(),true,false).right(5);
+    *strm << "\n";
   }
   delete q;
-  fclose(f);
+  delete strm;
+  delete file;
   report_error_code=RDReport::ErrorOk;
   return true;
 }
