@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name></name>
     <message>
@@ -17,11 +19,11 @@
     <name>QObject</name>
     <message>
         <source>Couldn&apos;t initialize QSql driver!</source>
-        <translation>Nepodařilo se inicializovat ovladač QSql!</translation>
+        <translation type="obsolete">Nepodařilo se inicializovat ovladač QSql!</translation>
     </message>
     <message>
         <source>Couldn&apos;t open mySQL connection!</source>
-        <translation>Nepodařilo se vytvořit žádné spojení se serverem mySQL-Server!</translation>
+        <translation type="obsolete">Nepodařilo se vytvořit žádné spojení se serverem mySQL-Server!</translation>
     </message>
     <message>
         <source>Sequentially</source>
@@ -539,6 +541,230 @@
         <source>No free cart available in group</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to open database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Database version mismatch, should be</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Max. in a Row/Min. Wait for </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>after</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is overscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is underscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is not playable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t initialize MySql driver!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t open MySQL connection on</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB connection re-established</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Could not re-establish DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid arguments specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Specified configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more Rivendell modules are active</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No running as root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service shutdown failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store unmount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store mount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service startup failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Synlink creation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid configuration name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>mount(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not have a Hosts entry in the database.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to update automounter configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PCM8</source>
+        <translation type="unfinished">PCM8</translation>
+    </message>
+    <message>
+        <source>PCM16</source>
+        <translation type="unfinished">PCM16</translation>
+    </message>
+    <message>
+        <source>Float32</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer I</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer II (MP2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer III (MP3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OggVorbis</source>
+        <translation type="unfinished">OggVorbis</translation>
+    </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
+    <message>
+        <source>RIFF/WAVE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw MPEG Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ogg Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ATX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TMC</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw FLAC Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM-BOS Hybrid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AIFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MP4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Title separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> with sched code(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Artist separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No carts found in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>-- End of List --</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -622,6 +848,10 @@
         <source>The cart title must be unique!</source>
         <translation>Název vozíku musí být jedinečný!</translation>
     </message>
+    <message>
+        <source>Add Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddLog</name>
@@ -658,51 +888,70 @@
         <translation>Služba je neplatná!</translation>
     </message>
 </context>
+<context>
+    <name>RDApplication</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>systemctl(1) crashed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(1) returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service is not active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDAudioSettingsDialog</name>
     <message>
         <source>Edit Settings</source>
-        <translation>Upravit nastavení</translation>
+        <translation type="obsolete">Upravit nastavení</translation>
     </message>
     <message>
         <source>Default &amp;Format:</source>
-        <translation>Výchozí &amp;formát:</translation>
+        <translation type="obsolete">Výchozí &amp;formát:</translation>
     </message>
     <message>
         <source>Default &amp;Channels:</source>
-        <translation>Výchozí &amp;kanály:</translation>
+        <translation type="obsolete">Výchozí &amp;kanály:</translation>
     </message>
     <message>
         <source>Default &amp;Sample Rate:</source>
-        <translation>Výchozí &amp;vzorkovací kmitočet:</translation>
+        <translation type="obsolete">Výchozí &amp;vzorkovací kmitočet:</translation>
     </message>
     <message>
         <source>Default &amp;Bitrate:</source>
-        <translation>Výchozí &amp;datový tok:</translation>
+        <translation type="obsolete">Výchozí &amp;datový tok:</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Zrušit</translation>
+        <translation type="obsolete">&amp;Zrušit</translation>
     </message>
     <message>
         <source>PCM16</source>
-        <translation>PCM16</translation>
+        <translation type="obsolete">PCM16</translation>
     </message>
     <message>
         <source>OggVorbis</source>
-        <translation>OggVorbis</translation>
+        <translation type="obsolete">OggVorbis</translation>
     </message>
     <message>
         <source>MPEG Layer 2</source>
-        <translation>MPEG Layer 2</translation>
+        <translation type="obsolete">MPEG Layer 2</translation>
     </message>
     <message>
         <source>MPEG Layer 3</source>
-        <translation>MPEG Layer 3</translation>
+        <translation type="obsolete">MPEG Layer 3</translation>
     </message>
 </context>
 <context>
@@ -826,43 +1075,43 @@ barvu</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>ČÍSLO</translation>
+        <translation type="obsolete">ČÍSLO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>UMĚLEC</translation>
+        <translation type="obsolete">UMĚLEC</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>ZÁKAZNÍK</translation>
+        <translation type="obsolete">ZÁKAZNÍK</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTURA</translation>
+        <translation type="obsolete">AGENTURA</translation>
     </message>
     <message>
         <source>USER DEF</source>
-        <translation>DEF UŽIVATELE</translation>
+        <translation type="obsolete">DEF UŽIVATELE</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>ZAČÁTEK</translation>
+        <translation type="obsolete">ZAČÁTEK</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>KONEC</translation>
+        <translation type="obsolete">KONEC</translation>
     </message>
     <message>
         <source>Send to
@@ -929,28 +1178,75 @@ ze &amp;souboru</translation>
         <translation>Zavádí se</translation>
     </message>
     <message>
-        <source>COMPOSER</source>
+        <source>Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>CONDUCTOR</source>
+        <source>Length</source>
+        <translation type="unfinished">Délka</translation>
+    </message>
+    <message>
+        <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Def</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Konec</translation>
+    </message>
+</context>
+<context>
+    <name>RDCddbLookup</name>
+    <message>
+        <source>CDDB Query</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Multiple Matches Found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Zrušit</translation>
+    </message>
 </context>
 <context>
     <name>RDCueEdit</name>
-    <message>
-        <source>&amp;Audition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Pause</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Stop</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Start</source>
         <translation type="unfinished"></translation>
@@ -1011,15 +1307,15 @@ ze &amp;souboru</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>ČÍSLO</translation>
+        <translation type="obsolete">ČÍSLO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -1027,7 +1323,7 @@ ze &amp;souboru</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>POPIS</translation>
+        <translation type="obsolete">POPIS</translation>
     </message>
     <message>
         <source>&amp;Add New
@@ -1063,6 +1359,22 @@ vozík</translation>
         <source>Scheduler Code:</source>
         <translation>Kódy rozvrhovače:</translation>
     </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -1127,12 +1439,12 @@ vozík</translation>
     <message>
         <source>Zoom
 In</source>
-        <translation>Přiblížit</translation>
+        <translation type="obsolete">Přiblížit</translation>
     </message>
     <message>
         <source>Zoom
 Out</source>
-        <translation>Oddálit</translation>
+        <translation type="obsolete">Oddálit</translation>
     </message>
     <message>
         <source>Time</source>
@@ -1369,51 +1681,51 @@ Opravdu chcete uložit?</translation>
     <name>RDExceptionDialog</name>
     <message>
         <source>Rivendell Exception Report</source>
-        <translation>Zpráva o chybě Rivendellu</translation>
+        <translation type="obsolete">Zpráva o chybě Rivendellu</translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation>&amp;Uložit</translation>
+        <translation type="obsolete">&amp;Uložit</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation>&amp;Zavřít</translation>
+        <translation type="obsolete">&amp;Zavřít</translation>
     </message>
     <message>
         <source>Text (*.txt *.TXT)
 All Files (*.*)</source>
-        <translation>Text (*.txt *.TXT)
+        <translation type="obsolete">Text (*.txt *.TXT)
 Všechny soubory (*.*)</translation>
     </message>
     <message>
         <source>Export File</source>
-        <translation>Vyvést soubor</translation>
+        <translation type="obsolete">Vyvést soubor</translation>
     </message>
     <message>
         <source>The file</source>
-        <translation>Soubor</translation>
+        <translation type="obsolete">Soubor</translation>
     </message>
     <message>
         <source>already exists!
 Overwrite?</source>
-        <translation>Již existuje!
+        <translation type="obsolete">Již existuje!
 Přepsat?</translation>
     </message>
     <message>
         <source>File Exists</source>
-        <translation>Soubor již existuje</translation>
+        <translation type="obsolete">Soubor již existuje</translation>
     </message>
     <message>
         <source>Unable to open file</source>
-        <translation>Nelze otevřít soubor</translation>
+        <translation type="obsolete">Nelze otevřít soubor</translation>
     </message>
     <message>
         <source>for writing!</source>
-        <translation>pro zápis!</translation>
+        <translation type="obsolete">pro zápis!</translation>
     </message>
     <message>
         <source>File Error</source>
-        <translation>Chyba souboru</translation>
+        <translation type="obsolete">Chyba souboru</translation>
     </message>
 </context>
 <context>
@@ -1841,41 +2153,41 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
     <name>RDIntegerDialog</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Zrušit</translation>
+        <translation type="obsolete">&amp;Zrušit</translation>
     </message>
     <message>
         <source>Set Value</source>
-        <translation>Nastavit hodnotu</translation>
+        <translation type="obsolete">Nastavit hodnotu</translation>
     </message>
 </context>
 <context>
     <name>RDIntegerEdit</name>
     <message>
         <source>Add</source>
-        <translation>Přidat</translation>
+        <translation type="obsolete">Přidat</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Smazat</translation>
+        <translation type="obsolete">Smazat</translation>
     </message>
     <message>
         <source>Set Value</source>
-        <translation>Nastavit hodnotu</translation>
+        <translation type="obsolete">Nastavit hodnotu</translation>
     </message>
 </context>
 <context>
     <name>RDLicense</name>
     <message>
         <source>&amp;Close</source>
-        <translation>&amp;Zavřít</translation>
+        <translation type="obsolete">&amp;Zavřít</translation>
     </message>
     <message>
         <source>GNU Public License v2</source>
-        <translation>GNU Public License v2</translation>
+        <translation type="obsolete">GNU Public License v2</translation>
     </message>
 </context>
 <context>
@@ -1913,15 +2225,15 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>POPIS</translation>
+        <translation type="obsolete">POPIS</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SLUŽBA</translation>
+        <translation type="obsolete">SLUŽBA</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1931,6 +2243,18 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
         <source>Cancel</source>
         <translation>Zrušit</translation>
     </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -2109,6 +2433,25 @@ Zkuste to, prosím, znovu!</translation>
         <translation>OK</translation>
     </message>
 </context>
+<context>
+    <name>RDProcess</name>
+    <message>
+        <source>no such program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDRecording</name>
     <message>
@@ -2408,11 +2751,11 @@ Zkuste to, prosím, znovu!</translation>
     <name>RDSqlDatabaseStatus</name>
     <message>
         <source>Database connection restored.</source>
-        <translation>Databázové spojení obnoveno.</translation>
+        <translation type="obsolete">Databázové spojení obnoveno.</translation>
     </message>
     <message>
         <source>Database connection failed : </source>
-        <translation>Databázové spojení se nezdařilo:</translation>
+        <translation type="obsolete">Databázové spojení se nezdařilo:</translation>
     </message>
 </context>
 <context>
