@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name></name>
     <message>
@@ -17,11 +19,11 @@
     <name>QObject</name>
     <message>
         <source>Couldn&apos;t initialize QSql driver!</source>
-        <translation>Qsql-Treiber konnte nicht initialisiert werden!</translation>
+        <translation type="obsolete">Qsql-Treiber konnte nicht initialisiert werden!</translation>
     </message>
     <message>
         <source>Couldn&apos;t open mySQL connection!</source>
-        <translation>Konnte keine Verbindung zum mySQL-Server herstellen!</translation>
+        <translation type="obsolete">Konnte keine Verbindung zum mySQL-Server herstellen!</translation>
     </message>
     <message>
         <source>Sequentially</source>
@@ -527,6 +529,238 @@
         <source>No such service!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No such group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No free cart available in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Database version mismatch, should be</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Max. in a Row/Min. Wait for </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>after</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is overscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is underscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is not playable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t initialize MySql driver!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t open MySQL connection on</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB connection re-established</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Could not re-establish DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid arguments specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Specified configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more Rivendell modules are active</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No running as root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service shutdown failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store unmount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store mount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service startup failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Synlink creation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid configuration name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>mount(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not have a Hosts entry in the database.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to update automounter configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PCM8</source>
+        <translation type="unfinished">PCM8</translation>
+    </message>
+    <message>
+        <source>PCM16</source>
+        <translation type="unfinished">PCM16</translation>
+    </message>
+    <message>
+        <source>Float32</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer I</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer II (MP2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer III (MP3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OggVorbis</source>
+        <translation type="unfinished">OggVorbis</translation>
+    </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
+    <message>
+        <source>RIFF/WAVE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw MPEG Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ogg Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ATX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TMC</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw FLAC Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM-BOS Hybrid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AIFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MP4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Title separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> with sched code(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Artist separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No carts found in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>-- End of List --</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -610,6 +844,10 @@
         <source>The cart title must be unique!</source>
         <translation>Der Cart-Titel muss einzigartig sein!</translation>
     </message>
+    <message>
+        <source>Add Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddLog</name>
@@ -646,51 +884,70 @@
         <translation>Der Service ist ungültig!</translation>
     </message>
 </context>
+<context>
+    <name>RDApplication</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>systemctl(1) crashed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(1) returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service is not active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDAudioSettingsDialog</name>
     <message>
         <source>Edit Settings</source>
-        <translation>Einstellungen editieren</translation>
+        <translation type="obsolete">Einstellungen editieren</translation>
     </message>
     <message>
         <source>Default &amp;Format:</source>
-        <translation>Standard &amp;Format:</translation>
+        <translation type="obsolete">Standard &amp;Format:</translation>
     </message>
     <message>
         <source>Default &amp;Channels:</source>
-        <translation>Standard &amp;Kanäle:</translation>
+        <translation type="obsolete">Standard &amp;Kanäle:</translation>
     </message>
     <message>
         <source>Default &amp;Sample Rate:</source>
-        <translation>Standard &amp;Sample Rate:</translation>
+        <translation type="obsolete">Standard &amp;Sample Rate:</translation>
     </message>
     <message>
         <source>Default &amp;Bitrate:</source>
-        <translation>Standard &amp;Bitrate:</translation>
+        <translation type="obsolete">Standard &amp;Bitrate:</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
     <message>
         <source>PCM16</source>
-        <translation>PCM16</translation>
+        <translation type="obsolete">PCM16</translation>
     </message>
     <message>
         <source>OggVorbis</source>
-        <translation>OggVorbis</translation>
+        <translation type="obsolete">OggVorbis</translation>
     </message>
     <message>
         <source>MPEG Layer 2</source>
-        <translation>MPEG Layer 2</translation>
+        <translation type="obsolete">MPEG Layer 2</translation>
     </message>
     <message>
         <source>MPEG Layer 3</source>
-        <translation>MPEG Layer 3</translation>
+        <translation type="obsolete">MPEG Layer 3</translation>
     </message>
 </context>
 <context>
@@ -814,43 +1071,43 @@ setzen</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NUMMER</translation>
+        <translation type="obsolete">NUMMER</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>KÜNSTLER</translation>
+        <translation type="obsolete">KÜNSTLER</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KUNDE</translation>
+        <translation type="obsolete">KUNDE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTUR</translation>
+        <translation type="obsolete">AGENTUR</translation>
     </message>
     <message>
         <source>USER DEF</source>
-        <translation>BENUTZER DEF</translation>
+        <translation type="obsolete">BENUTZER DEF</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>END</translation>
+        <translation type="obsolete">END</translation>
     </message>
     <message>
         <source>Send to
@@ -895,10 +1152,6 @@ senden</translation>
         <source>Unable to create temporary cart for import!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to get temporary cart number for import!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import Error</source>
         <translation type="unfinished">Importfehler</translation>
@@ -916,28 +1169,75 @@ senden</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>COMPOSER</source>
+        <source>Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>CONDUCTOR</source>
+        <source>Length</source>
+        <translation type="unfinished">Länge</translation>
+    </message>
+    <message>
+        <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Def</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Ende</translation>
+    </message>
+</context>
+<context>
+    <name>RDCddbLookup</name>
+    <message>
+        <source>CDDB Query</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Multiple Matches Found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Abbrechen</translation>
+    </message>
 </context>
 <context>
     <name>RDCueEdit</name>
-    <message>
-        <source>&amp;Audition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Pause</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Stop</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Start</source>
         <translation type="unfinished"></translation>
@@ -998,15 +1298,15 @@ senden</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NUMMER</translation>
+        <translation type="obsolete">NUMMER</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -1014,7 +1314,7 @@ senden</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>BESCHREIBUNG</translation>
+        <translation type="obsolete">BESCHREIBUNG</translation>
     </message>
     <message>
         <source>&amp;Add New
@@ -1049,6 +1349,22 @@ Cart</source>
         <source>Scheduler Code:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -1113,12 +1429,12 @@ Cart</source>
     <message>
         <source>Zoom
 In</source>
-        <translation>hineinzoomen</translation>
+        <translation type="obsolete">hineinzoomen</translation>
     </message>
     <message>
         <source>Zoom
 Out</source>
-        <translation>herauszoomen</translation>
+        <translation type="obsolete">herauszoomen</translation>
     </message>
     <message>
         <source>Time</source>
@@ -1352,51 +1668,51 @@ Are you sure you want to save?</source>
     <name>RDExceptionDialog</name>
     <message>
         <source>Rivendell Exception Report</source>
-        <translation>Rivendell Fehlerreport</translation>
+        <translation type="obsolete">Rivendell Fehlerreport</translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation>&amp;Speichern</translation>
+        <translation type="obsolete">&amp;Speichern</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation>&amp;Schliessen</translation>
+        <translation type="obsolete">&amp;Schliessen</translation>
     </message>
     <message>
         <source>Text (*.txt *.TXT)
 All Files (*.*)</source>
-        <translation>Text (*.txt *.TXT)
+        <translation type="obsolete">Text (*.txt *.TXT)
 Alle Dateien (*.*)</translation>
     </message>
     <message>
         <source>Export File</source>
-        <translation>Datei Exportieren</translation>
+        <translation type="obsolete">Datei Exportieren</translation>
     </message>
     <message>
         <source>The file</source>
-        <translation>Die Datei</translation>
+        <translation type="obsolete">Die Datei</translation>
     </message>
     <message>
         <source>already exists!
 Overwrite?</source>
-        <translation>existiert bereits!
+        <translation type="obsolete">existiert bereits!
 Überschreiben?</translation>
     </message>
     <message>
         <source>File Exists</source>
-        <translation>Datei existiert</translation>
+        <translation type="obsolete">Datei existiert</translation>
     </message>
     <message>
         <source>Unable to open file</source>
-        <translation>Kann die Datei nicht öffnen</translation>
+        <translation type="obsolete">Kann die Datei nicht öffnen</translation>
     </message>
     <message>
         <source>for writing!</source>
-        <translation>zum schreiben!</translation>
+        <translation type="obsolete">zum schreiben!</translation>
     </message>
     <message>
         <source>File Error</source>
-        <translation>Dateifehler</translation>
+        <translation type="obsolete">Dateifehler</translation>
     </message>
 </context>
 <context>
@@ -1824,41 +2140,41 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
     <name>RDIntegerDialog</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Abbrechen</translation>
+        <translation type="obsolete">&amp;Abbrechen</translation>
     </message>
     <message>
         <source>Set Value</source>
-        <translation>Wert setzen</translation>
+        <translation type="obsolete">Wert setzen</translation>
     </message>
 </context>
 <context>
     <name>RDIntegerEdit</name>
     <message>
         <source>Add</source>
-        <translation>Hinzufügen</translation>
+        <translation type="obsolete">Hinzufügen</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Löschen</translation>
+        <translation type="obsolete">Löschen</translation>
     </message>
     <message>
         <source>Set Value</source>
-        <translation>Wert setzen</translation>
+        <translation type="obsolete">Wert setzen</translation>
     </message>
 </context>
 <context>
     <name>RDLicense</name>
     <message>
         <source>&amp;Close</source>
-        <translation>&amp;Schliessen</translation>
+        <translation type="obsolete">&amp;Schliessen</translation>
     </message>
     <message>
         <source>GNU Public License v2</source>
-        <translation>GNU Public License v2</translation>
+        <translation type="obsolete">GNU Public License v2</translation>
     </message>
 </context>
 <context>
@@ -1896,15 +2212,15 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAME</translation>
+        <translation type="obsolete">NAME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>BESCHREIBUNG</translation>
+        <translation type="obsolete">BESCHREIBUNG</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICE</translation>
+        <translation type="obsolete">SERVICE</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1918,6 +2234,18 @@ Bitte Kofiguration prüfen und erneut versuchen.</translation>
         <source>ALL</source>
         <translation type="obsolete">ALLE</translation>
     </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -2096,6 +2424,25 @@ bitte erneut versuchen!</translation>
         <translation>OK</translation>
     </message>
 </context>
+<context>
+    <name>RDProcess</name>
+    <message>
+        <source>no such program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDRecording</name>
     <message>
@@ -2395,11 +2742,11 @@ bitte erneut versuchen!</translation>
     <name>RDSqlDatabaseStatus</name>
     <message>
         <source>Database connection restored.</source>
-        <translation>Datenbankverbindung wiederhergestellt.</translation>
+        <translation type="obsolete">Datenbankverbindung wiederhergestellt.</translation>
     </message>
     <message>
         <source>Database connection failed : </source>
-        <translation>Datenbankverbindung fehlgeschlagen:</translation>
+        <translation type="obsolete">Datenbankverbindung fehlgeschlagen:</translation>
     </message>
 </context>
 <context>
@@ -2433,5 +2780,13 @@ bitte erneut versuchen!</translation>
 </source>
         <translation>Event-Füllfehler</translation>
     </message>
+    <message>
+        <source>Log in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import failed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
