@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name></name>
     <message>
@@ -17,11 +19,11 @@
     <name>QObject</name>
     <message>
         <source>Couldn&apos;t initialize QSql driver!</source>
-        <translation>Greidde ikkje setja opp QSql-drivaren!</translation>
+        <translation type="obsolete">Greidde ikkje setja opp QSql-drivaren!</translation>
     </message>
     <message>
         <source>Couldn&apos;t open mySQL connection!</source>
-        <translation>Greidde ikkje kopla til mySQL-databasen!</translation>
+        <translation type="obsolete">Greidde ikkje kopla til mySQL-databasen!</translation>
     </message>
     <message>
         <source>Sequentially</source>
@@ -121,7 +123,7 @@
     </message>
     <message>
         <source>ChainTo</source>
-        <translation type="unfinished">LenkTil</translation>
+        <translation type="obsolete">LenkTil</translation>
     </message>
     <message>
         <source>Track</source>
@@ -129,7 +131,7 @@
     </message>
     <message>
         <source>Link</source>
-        <translation type="unfinished">Lenkje</translation>
+        <translation type="obsolete">Lenkje</translation>
     </message>
     <message>
         <source>Traffic</source>
@@ -287,10 +289,6 @@
         <source>Unable to open report file!</source>
         <translation type="unfinished">Greidde ikkje opna rapportfil!</translation>
     </message>
-    <message>
-        <source>invalid SQL or failed DB connection:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Music Summary</source>
         <translation type="unfinished"></translation>
@@ -379,6 +377,390 @@
         <source>Sound Panel Fifth and Later Play Output</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>invalid SQL or failed DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">Alle</translation>
+    </message>
+    <message>
+        <source>Relative</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NaturalLog Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LiveAssist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Classical Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>reserved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mr. Master Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Spin Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>feature</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>background</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>promo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fade</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NoTime</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MusicLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TrafficLink</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Chain</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>new cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Host already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>host already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>service already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>template host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished">Klypp</translation>
+    </message>
+    <message>
+        <source>Log already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>No such service!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No such group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No free cart available in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Database version mismatch, should be</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Max. in a Row/Min. Wait for </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>after</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is overscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is underscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is not playable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t initialize MySql driver!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t open MySQL connection on</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB connection re-established</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Could not re-establish DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid arguments specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Specified configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more Rivendell modules are active</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No running as root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service shutdown failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store unmount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store mount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service startup failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Synlink creation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid configuration name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>mount(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not have a Hosts entry in the database.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to update automounter configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PCM8</source>
+        <translation type="unfinished">PCM8</translation>
+    </message>
+    <message>
+        <source>PCM16</source>
+        <translation type="unfinished">PCM16</translation>
+    </message>
+    <message>
+        <source>Float32</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer I</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer II (MP2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer III (MP3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OggVorbis</source>
+        <translation type="unfinished">Ogg Vorbis</translation>
+    </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
+    <message>
+        <source>RIFF/WAVE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw MPEG Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ogg Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ATX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TMC</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw FLAC Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM-BOS Hybrid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AIFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MP4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Title separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> with sched code(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Artist separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No carts found in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>-- End of List --</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -462,6 +844,10 @@
         <source>The cart title must be unique!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Add Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddLog</name>
@@ -491,58 +877,77 @@
     </message>
     <message>
         <source>The name is invalid!</source>
-        <translation>Namnet er ikkje gyldig!</translation>
+        <translation type="obsolete">Namnet er ikkje gyldig!</translation>
     </message>
     <message>
         <source>The service is invalid!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDApplication</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>systemctl(1) crashed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(1) returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service is not active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDAudioSettingsDialog</name>
     <message>
         <source>Edit Settings</source>
-        <translation>Rediger innstillingar</translation>
+        <translation type="obsolete">Rediger innstillingar</translation>
     </message>
     <message>
         <source>Default &amp;Format:</source>
-        <translation>Standard&amp;format:</translation>
+        <translation type="obsolete">Standard&amp;format:</translation>
     </message>
     <message>
         <source>Default &amp;Channels:</source>
-        <translation>Standard tal på &amp;kanalar:</translation>
+        <translation type="obsolete">Standard tal på &amp;kanalar:</translation>
     </message>
     <message>
         <source>Default &amp;Sample Rate:</source>
-        <translation>Standard &amp;punktprøverate:</translation>
+        <translation type="obsolete">Standard &amp;punktprøverate:</translation>
     </message>
     <message>
         <source>Default &amp;Bitrate:</source>
-        <translation>Standard &amp;bitrate:</translation>
+        <translation type="obsolete">Standard &amp;bitrate:</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>PCM16</source>
-        <translation>PCM16</translation>
+        <translation type="obsolete">PCM16</translation>
     </message>
     <message>
         <source>OggVorbis</source>
-        <translation>Ogg Vorbis</translation>
+        <translation type="obsolete">Ogg Vorbis</translation>
     </message>
     <message>
         <source>MPEG Layer 2</source>
-        <translation>MPEG lag 2</translation>
+        <translation type="obsolete">MPEG lag 2</translation>
     </message>
     <message>
         <source>MPEG Layer 3</source>
-        <translation>MPEG lag 3</translation>
+        <translation type="obsolete">MPEG lag 3</translation>
     </message>
 </context>
 <context>
@@ -666,43 +1071,43 @@ farge</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NUMMER</translation>
+        <translation type="obsolete">NUMMER</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KLIENT</translation>
+        <translation type="obsolete">KLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENT</translation>
+        <translation type="obsolete">AGENT</translation>
     </message>
     <message>
         <source>USER DEF</source>
-        <translation>BRUKARDEFINERT</translation>
+        <translation type="obsolete">BRUKARDEFINERT</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>SLUTT</translation>
+        <translation type="obsolete">SLUTT</translation>
     </message>
     <message>
         <source>Send to
@@ -746,10 +1151,6 @@ farge</translation>
         <source>Unable to create temporary cart for import!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to get temporary cart number for import!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Import Error</source>
         <translation type="unfinished"></translation>
@@ -766,6 +1167,103 @@ farge</translation>
         <source>Importing</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Lengd</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Def</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Slutten</translation>
+    </message>
+</context>
+<context>
+    <name>RDCddbLookup</name>
+    <message>
+        <source>CDDB Query</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Multiple Matches Found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEdit</name>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Slutten</translation>
+    </message>
+    <message>
+        <source>&amp;Recue</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDCueEditDialog</name>
+    <message>
+        <source>Set Cue Point</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Avbryt</translation>
+    </message>
 </context>
 <context>
     <name>RDCutDialog</name>
@@ -799,15 +1297,15 @@ farge</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NUMMER</translation>
+        <translation type="obsolete">NUMMER</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -815,7 +1313,7 @@ farge</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>&amp;Add New
@@ -850,6 +1348,22 @@ Cart</source>
         <source>Scheduler Code:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -914,13 +1428,13 @@ Cart</source>
     <message>
         <source>Zoom
 In</source>
-        <translation>Zoom
+        <translation type="obsolete">Zoom
 inn</translation>
     </message>
     <message>
         <source>Zoom
 Out</source>
-        <translation>Zoom
+        <translation type="obsolete">Zoom
 ut</translation>
     </message>
     <message>
@@ -1156,51 +1670,51 @@ Are you sure you want to save?</source>
     <name>RDExceptionDialog</name>
     <message>
         <source>Rivendell Exception Report</source>
-        <translation>Unntaksrapport frå Rivendell</translation>
+        <translation type="obsolete">Unntaksrapport frå Rivendell</translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation>&amp;Lagre</translation>
+        <translation type="obsolete">&amp;Lagre</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation>Lu&amp;kk</translation>
+        <translation type="obsolete">Lu&amp;kk</translation>
     </message>
     <message>
         <source>Text (*.txt *.TXT)
 All Files (*.*)</source>
-        <translation>Tekst (*.txt *.TXT)
+        <translation type="obsolete">Tekst (*.txt *.TXT)
 Alle filer (*.*)</translation>
     </message>
     <message>
         <source>Export File</source>
-        <translation>Eksporter fil</translation>
+        <translation type="obsolete">Eksporter fil</translation>
     </message>
     <message>
         <source>The file</source>
-        <translation>Fila</translation>
+        <translation type="obsolete">Fila</translation>
     </message>
     <message>
         <source>already exists!
 Overwrite?</source>
-        <translation>finst frå før!
+        <translation type="obsolete">finst frå før!
 Skriv over?</translation>
     </message>
     <message>
         <source>File Exists</source>
-        <translation>Fila finst</translation>
+        <translation type="obsolete">Fila finst</translation>
     </message>
     <message>
         <source>Unable to open file</source>
-        <translation>Greier ikkje opna fila</translation>
+        <translation type="obsolete">Greier ikkje opna fila</translation>
     </message>
     <message>
         <source>for writing!</source>
-        <translation>for skriving!</translation>
+        <translation type="obsolete">for skriving!</translation>
     </message>
     <message>
         <source>File Error</source>
-        <translation>Filfeil</translation>
+        <translation type="obsolete">Filfeil</translation>
     </message>
 </context>
 <context>
@@ -1349,6 +1863,10 @@ Skriv over?</translation>
         <source>144 kbps</source>
         <translation>144 kbps</translation>
     </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
 </context>
 <context>
     <name>RDGetAth</name>
@@ -1622,43 +2140,24 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
 </context>
 <context>
     <name>RDIntegerDialog</name>
-    <message>
-        <source>Set Value</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished">&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished">&amp;Avbryt</translation>
-    </message>
-</context>
-<context>
-    <name>RDIntegerEdit</name>
-    <message>
-        <source>Set Value</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Add</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
 </context>
 <context>
     <name>RDLicense</name>
     <message>
         <source>&amp;Close</source>
-        <translation>Lu&amp;kk</translation>
+        <translation type="obsolete">Lu&amp;kk</translation>
     </message>
     <message>
         <source>GNU Public License v2</source>
-        <translation>GNU Public-lisensen, versjon 2</translation>
+        <translation type="obsolete">GNU Public-lisensen, versjon 2</translation>
     </message>
 </context>
 <context>
@@ -1686,25 +2185,9 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
 </context>
 <context>
     <name>RDListLogs</name>
-    <message>
-        <source>Select Log - User: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Select Log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>NAME</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation type="unfinished">SKILDRING</translation>
-    </message>
-    <message>
-        <source>SERVICE</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1714,6 +2197,26 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="obsolete">ALLE</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -1734,6 +2237,29 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <translation>Aktive tenester</translation>
     </message>
 </context>
+<context>
+    <name>RDLogFilter</name>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear</source>
+        <translation type="unfinished">Tøm</translation>
+    </message>
+    <message>
+        <source>Show Only Recent Logs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished">ALLE</translation>
+    </message>
+</context>
 <context>
     <name>RDLogLine</name>
     <message>
@@ -1829,6 +2355,13 @@ Sjekk eksportoppsettet ditt og prøv att.</translation>
         <translation type="obsolete">Sporleggjar</translation>
     </message>
 </context>
+<context>
+    <name>RDPanelButton</name>
+    <message>
+        <source>No Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPasswd</name>
     <message>
@@ -1866,6 +2399,25 @@ prøv ein gong til!</translation>
         <translation>OK</translation>
     </message>
 </context>
+<context>
+    <name>RDProcess</name>
+    <message>
+        <source>no such program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDRecording</name>
     <message>
@@ -1893,6 +2445,120 @@ prøv ein gong til!</translation>
         <translation type="obsolete">Last opp</translation>
     </message>
 </context>
+<context>
+    <name>RDRehash</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Internal Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RDXport service returned an error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid user or password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RDRenderer</name>
+    <message>
+        <source>no such cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Using temporary file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 2 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Writing output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pass 1 of 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>first-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>last-time event not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP</source>
+        <translation type="unfinished">STOPP</translation>
+    </message>
+    <message>
+        <source>FAIL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NO AUDIO AVAILABLE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SKIP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- end of log ---</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to open output file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log render halted at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>due to STOP</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>at line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>failed to play (NO AUDIO AVAILABLE)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendered log is too long!</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDReport</name>
     <message>
@@ -1979,11 +2645,11 @@ prøv ein gong til!</translation>
     <name>RDSqlDatabaseStatus</name>
     <message>
         <source>Database connection restored.</source>
-        <translation>Databasetilkoplinga er gjenoppretta.</translation>
+        <translation type="obsolete">Databasetilkoplinga er gjenoppretta.</translation>
     </message>
     <message>
         <source>Database connection failed : </source>
-        <translation>Feil med databasetilkoplinga: </translation>
+        <translation type="obsolete">Feil med databasetilkoplinga: </translation>
     </message>
 </context>
 <context>
@@ -2024,5 +2690,13 @@ prøv ein gong til!</translation>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log in use by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import failed</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
