@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name></name>
     <message>
@@ -17,11 +19,11 @@
     <name>QObject</name>
     <message>
         <source>Couldn&apos;t initialize QSql driver!</source>
-        <translation>Não foi possível inicializar driver QSql !</translation>
+        <translation type="obsolete">Não foi possível inicializar driver QSql !</translation>
     </message>
     <message>
         <source>Couldn&apos;t open mySQL connection!</source>
-        <translation>Não foi possível conetar ao mySQL !</translation>
+        <translation type="obsolete">Não foi possível conetar ao mySQL !</translation>
     </message>
     <message>
         <source>Sequentially</source>
@@ -89,7 +91,7 @@
     </message>
     <message>
         <source>PLAY</source>
-        <translation type="unfinished">SIMPLES<byte value="x9"/></translation>
+        <translation type="unfinished">SIMPLES	</translation>
     </message>
     <message>
         <source>SEGUE</source>
@@ -535,6 +537,230 @@
         <source>No free cart available in group</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to open database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Database version mismatch, should be</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Max. in a Row/Min. Wait for </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>after</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Do not schedule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is overscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is underscheduled by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is not playable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t initialize MySql driver!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Couldn&apos;t open MySQL connection on</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB connection re-established</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Could not re-establish DB connection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid arguments specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Specified configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>One or more Rivendell modules are active</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No running as root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service shutdown failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store unmount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audio store mount failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service startup failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Current configuration was not found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Synlink creation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid configuration name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>mount(8) crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>does not have a Hosts entry in the database.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to update automounter configuration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PCM8</source>
+        <translation type="unfinished">PCM8</translation>
+    </message>
+    <message>
+        <source>PCM16</source>
+        <translation type="unfinished">PCM16</translation>
+    </message>
+    <message>
+        <source>Float32</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer I</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer II (MP2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MPEG Layer III (MP3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Dolby AC3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OggVorbis</source>
+        <translation type="unfinished">OggVorbis</translation>
+    </message>
+    <message>
+        <source>PCM24</source>
+        <translation type="unfinished">PCM24</translation>
+    </message>
+    <message>
+        <source>RIFF/WAVE</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw MPEG Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ogg Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ATX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TMC</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Raw FLAC Bitstream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM-BOS Hybrid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AIFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MP4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Title separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> with sched code(s): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rule broken: Artist separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No carts found in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>-- End of List --</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -618,6 +844,10 @@
         <source>This cart already exists.</source>
         <translation>Este Cartão já Existe.</translation>
     </message>
+    <message>
+        <source>Add Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddLog</name>
@@ -654,51 +884,70 @@
         <translation>O Serviço é Inválido!</translation>
     </message>
 </context>
+<context>
+    <name>RDApplication</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>systemctl(1) crashed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>systemctl(1) returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rivendell service is not active.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDAudioSettingsDialog</name>
     <message>
         <source>Edit Settings</source>
-        <translation>Editar Configurações</translation>
+        <translation type="obsolete">Editar Configurações</translation>
     </message>
     <message>
         <source>Default &amp;Format:</source>
-        <translation>&amp;Formato Padrão:</translation>
+        <translation type="obsolete">&amp;Formato Padrão:</translation>
     </message>
     <message>
         <source>Default &amp;Channels:</source>
-        <translation>&amp;Canais Padrão:</translation>
+        <translation type="obsolete">&amp;Canais Padrão:</translation>
     </message>
     <message>
         <source>Default &amp;Sample Rate:</source>
-        <translation>&amp;Taxa de Amostragem Padrão:</translation>
+        <translation type="obsolete">&amp;Taxa de Amostragem Padrão:</translation>
     </message>
     <message>
         <source>Default &amp;Bitrate:</source>
-        <translation>&amp;Taxa de Bits Padrão:</translation>
+        <translation type="obsolete">&amp;Taxa de Bits Padrão:</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>PCM16</source>
-        <translation>PCM16</translation>
+        <translation type="obsolete">PCM16</translation>
     </message>
     <message>
         <source>OggVorbis</source>
-        <translation>OggVorbis</translation>
+        <translation type="obsolete">OggVorbis</translation>
     </message>
     <message>
         <source>MPEG Layer 2</source>
-        <translation>MPEG Layer 2</translation>
+        <translation type="obsolete">MPEG Layer 2</translation>
     </message>
     <message>
         <source>MPEG Layer 3</source>
-        <translation>MPEG Layer 3</translation>
+        <translation type="obsolete">MPEG Layer 3</translation>
     </message>
 </context>
 <context>
@@ -822,43 +1071,43 @@ Cor</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NÚMERO</translation>
+        <translation type="obsolete">NÚMERO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURAÇÃO</translation>
+        <translation type="obsolete">DURAÇÃO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENTE</translation>
+        <translation type="obsolete">CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGÊNCIA</translation>
+        <translation type="obsolete">AGÊNCIA</translation>
     </message>
     <message>
         <source>USER DEF</source>
-        <translation>USO GENERICO</translation>
+        <translation type="obsolete">USO GENERICO</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>INÍCIO</translation>
+        <translation type="obsolete">INÍCIO</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>FINAL</translation>
+        <translation type="obsolete">FINAL</translation>
     </message>
     <message>
         <source>Send to
@@ -920,28 +1169,75 @@ Cor</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>COMPOSER</source>
+        <source>Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>CONDUCTOR</source>
+        <source>Length</source>
+        <translation type="unfinished">Duração</translation>
+    </message>
+    <message>
+        <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Def</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Fim</translation>
+    </message>
+</context>
+<context>
+    <name>RDCddbLookup</name>
+    <message>
+        <source>CDDB Query</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Multiple Matches Found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
 </context>
 <context>
     <name>RDCueEdit</name>
-    <message>
-        <source>&amp;Audition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Pause</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Stop</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Start</source>
         <translation type="unfinished"></translation>
@@ -1002,15 +1298,15 @@ Cor</translation>
     </message>
     <message>
         <source>NUMBER</source>
-        <translation>NÚMERO</translation>
+        <translation type="obsolete">NÚMERO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -1018,7 +1314,7 @@ Cor</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIÇÃO</translation>
+        <translation type="obsolete">DESCRIÇÃO</translation>
     </message>
     <message>
         <source>&amp;Add New
@@ -1054,6 +1350,22 @@ Cartão</translation>
         <source>Scheduler Code:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -1118,13 +1430,13 @@ Cartão</translation>
     <message>
         <source>Zoom
 In</source>
-        <translation>Zoom
+        <translation type="obsolete">Zoom
 In</translation>
     </message>
     <message>
         <source>Zoom
 Out</source>
-        <translation>Zoom
+        <translation type="obsolete">Zoom
 Out</translation>
     </message>
     <message>
@@ -1360,51 +1672,51 @@ Are you sure you want to save?</source>
     <name>RDExceptionDialog</name>
     <message>
         <source>Rivendell Exception Report</source>
-        <translation>Relatório de Exceções do Rivendell</translation>
+        <translation type="obsolete">Relatório de Exceções do Rivendell</translation>
     </message>
     <message>
         <source>&amp;Save</source>
-        <translation>&amp;Salvar</translation>
+        <translation type="obsolete">&amp;Salvar</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation>&amp;Fechar</translation>
+        <translation type="obsolete">&amp;Fechar</translation>
     </message>
     <message>
         <source>Text (*.txt *.TXT)
 All Files (*.*)</source>
-        <translation>Textos (*.txt *.TXT)
+        <translation type="obsolete">Textos (*.txt *.TXT)
 Todos os Arquivos (*.*)</translation>
     </message>
     <message>
         <source>Export File</source>
-        <translation>Exportar Arquivo</translation>
+        <translation type="obsolete">Exportar Arquivo</translation>
     </message>
     <message>
         <source>The file</source>
-        <translation>O Arquivo</translation>
+        <translation type="obsolete">O Arquivo</translation>
     </message>
     <message>
         <source>already exists!
 Overwrite?</source>
-        <translation>já Existe! 
+        <translation type="obsolete">já Existe! 
 Sobreescrever?</translation>
     </message>
     <message>
         <source>File Exists</source>
-        <translation>Arquivo Existente</translation>
+        <translation type="obsolete">Arquivo Existente</translation>
     </message>
     <message>
         <source>Unable to open file</source>
-        <translation>Não foi Possível abrir o arquivo</translation>
+        <translation type="obsolete">Não foi Possível abrir o arquivo</translation>
     </message>
     <message>
         <source>for writing!</source>
-        <translation>para escrita!</translation>
+        <translation type="obsolete">para escrita!</translation>
     </message>
     <message>
         <source>File Error</source>
-        <translation>Erro no Arquivo</translation>
+        <translation type="obsolete">Erro no Arquivo</translation>
     </message>
 </context>
 <context>
@@ -1832,41 +2144,41 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
     <name>RDIntegerDialog</name>
     <message>
         <source>Set Value</source>
-        <translation>Selecionar Valor</translation>
+        <translation type="obsolete">Selecionar Valor</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
 </context>
 <context>
     <name>RDIntegerEdit</name>
     <message>
         <source>Set Value</source>
-        <translation>Selecionar Valor</translation>
+        <translation type="obsolete">Selecionar Valor</translation>
     </message>
     <message>
         <source>Add</source>
-        <translation>Adicionar</translation>
+        <translation type="obsolete">Adicionar</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Deletar</translation>
+        <translation type="obsolete">Deletar</translation>
     </message>
 </context>
 <context>
     <name>RDLicense</name>
     <message>
         <source>&amp;Close</source>
-        <translation>&amp;Fechar</translation>
+        <translation type="obsolete">&amp;Fechar</translation>
     </message>
     <message>
         <source>GNU Public License v2</source>
-        <translation>GNU Public License v2</translation>
+        <translation type="obsolete">GNU Public License v2</translation>
     </message>
 </context>
 <context>
@@ -1904,15 +2216,15 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOME</translation>
+        <translation type="obsolete">NOME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIÇÃO</translation>
+        <translation type="obsolete">DESCRIÇÃO</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVIÇO</translation>
+        <translation type="obsolete">SERVIÇO</translation>
     </message>
     <message>
         <source>OK</source>
@@ -1926,6 +2238,18 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
         <source>ALL</source>
         <translation type="obsolete">TODOS</translation>
     </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDListSelector</name>
@@ -2002,7 +2326,7 @@ Por Favor, cheque suas configurações e tenbte outra vez.</translation>
     </message>
     <message>
         <source>PLAY</source>
-        <translation type="obsolete">SIMPLES<byte value="x9"/></translation>
+        <translation type="obsolete">SIMPLES	</translation>
     </message>
     <message>
         <source>SEGUE</source>
@@ -2105,6 +2429,25 @@ por favor, tente novamente!</translation>
         <translation>OK</translation>
     </message>
 </context>
+<context>
+    <name>RDProcess</name>
+    <message>
+        <source>no such program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>process returned exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDRecording</name>
     <message>
@@ -2348,11 +2691,11 @@ por favor, tente novamente!</translation>
     <name>RDSqlDatabaseStatus</name>
     <message>
         <source>Database connection restored.</source>
-        <translation>Conexão à Base de Daods reestabelecido.</translation>
+        <translation type="obsolete">Conexão à Base de Daods reestabelecido.</translation>
     </message>
     <message>
         <source>Database connection failed : </source>
-        <translation>Conexão à Base de Daods falhou: </translation>
+        <translation type="obsolete">Conexão à Base de Daods falhou: </translation>
     </message>
 </context>
 <context>
