@@ -2,9 +2,7 @@
 //
 // Abstract RDAirPlay Configuration
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdairplay_conf.h,v 1.36.8.5 2014/02/10 20:45:09 cvs Exp $
+//   (C) Copyright 2002-2003,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,7 +26,6 @@
 
 #include <rdlog_line.h>         
 
-
 class RDAirPlayConf
 {
  public:
@@ -59,6 +56,14 @@ class RDAirPlayConf
   void setStartRml(Channel chan,QString str) const;
   QString stopRml(Channel chan) const;
   void setStopRml(Channel chan,QString str) const;
+  int virtualCard(int mach) const;
+  void setVirtualCard(int mach,int card) const;
+  int virtualPort(int mach) const;
+  void setVirtualPort(int mach,int port) const;
+  QString virtualStartRml(int mach) const;
+  void setVirtualStartRml(int mach,QString str) const;
+  QString virtualStopRml(int mach) const;
+  void setVirtualStopRml(int mach,QString str) const;
   RDAirPlayConf::GpioType gpioType(RDAirPlayConf::Channel chan) const;
   void setGpioType(RDAirPlayConf::Channel chan,RDAirPlayConf::GpioType type) 
     const;
@@ -124,16 +129,10 @@ class RDAirPlayConf
   void setDescriptionTemplate(const QString &str);
   bool hourSelectorEnabled() const;
   void setHourSelectorEnabled(bool state) const;
-  QHostAddress udpAddress(int logno) const;
-  void setUdpAddress(int logno,QHostAddress addr) const;
-  Q_UINT16 udpPort(int logno) const;
-  void setUdpPort(int logno,Q_UINT16 port) const;
-  QString udpString(int logno) const;
-  void setUdpString(int logno,const QString &str) const;
-  QString logRml(int logno) const;
-  void setLogRml(int logno,const QString &str) const;
   RDAirPlayConf::ExitCode exitCode() const;
   void setExitCode(RDAirPlayConf::ExitCode code) const;
+  RDAirPlayConf::ExitCode virtualExitCode() const;
+  void setVirtualExitCode(RDAirPlayConf::ExitCode code) const;
   bool exitPasswordValid(const QString &passwd) const;
   void setExitPassword(const QString &passwd) const;
   QString skinPath() const;
