@@ -2,7 +2,7 @@
 //
 // Convert Audio File Formats
 //
-//   (C) Copyright 2010-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,7 @@
 
 #include <stdint.h>
 #include <stdlib.h>
+#include <syslog.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
@@ -30,6 +31,13 @@
 #include <errno.h>
 #include <unistd.h>
 
+#include <rdapplication.h>
+#include <rdaudioconvert.h>
+#include <rdcart.h>
+#include <rdconf.h>
+#include <rd.h>
+#include <rdtempdirectory.h>
+
 #include <sndfile.h>
 #include <samplerate.h>
 #include <soundtouch/SoundTouch.h>
@@ -45,19 +53,16 @@
 #include <mp4v2/mp4v2.h>
 #include <neaacdec.h>
 #endif // HAVE_MP4_LIBS
-#include <id3/tag.h>
+//#include <id3/tag.h>
+#include <id3v2tag.h>
+#include <textidentificationframe.h>
+#include <mpegfile.h>
 #include <qfile.h>
 
-#include <rd.h>
-#include <rdaudioconvert.h>
-#include <rdlibrary_conf.h>
-#include <rdcart.h>
-#include <rdconf.h>
-
 #define STAGE2_XFER_SIZE 2048
 #define STAGE2_BUFFER_SIZE 49152
 
-RDAudioConvert::RDAudioConvert(const QString &station_name,QObject *parent)
+RDAudioConvert::RDAudioConvert(QObject *parent)
   : QObject(parent)
 {
   conv_start_point=-1;
@@ -67,16 +72,15 @@ RDAudioConvert::RDAudioConvert(const QString &station_name,QObject *parent)
   conv_settings=NULL;
   conv_src_wavedata=new RDWaveData();
   conv_dst_wavedata=NULL;
-  RDLibraryConf *conf=new RDLibraryConf(station_name,0);
-  conv_src_converter=conf->srcConverter();
-  delete conf;
+  conv_src_converter=rda->libraryConf()->srcConverter();
+  conv_transcoding_delay=rda->config()->transcodingDelay();
 
   //
   // Load MPEG Libraries
   //
-  conv_mad_handle=dlopen("libmad.so",RTLD_LAZY);
-  conv_lame_handle=dlopen("libmp3lame.so",RTLD_LAZY);
-  conv_twolame_handle=dlopen("libtwolame.so",RTLD_LAZY);
+  conv_mad_handle=dlopen("libmad.so.0",RTLD_LAZY);
+  conv_lame_handle=dlopen("libmp3lame.so.0",RTLD_LAZY);
+  conv_twolame_handle=dlopen("libtwolame.so.0",RTLD_LAZY);
 }
 
 
@@ -143,10 +147,10 @@ void RDAudioConvert::setSpeedRatio(float ratio)
 
 RDAudioConvert::ErrorCode RDAudioConvert::convert()
 {
-  char tmpdir[PATH_MAX];
   RDAudioConvert::ErrorCode err;
   QString tmpfile1;
   QString tmpfile2;
+  RDTempDirectory *temp_dir=NULL;
 
   //
   // Make sure we're all set to go...
@@ -157,7 +161,9 @@ RDAudioConvert::ErrorCode RDAudioConvert::convert()
   if(!RDAudioConvert::settingsValid(conv_settings)) {
     return RDAudioConvert::ErrorInvalidSettings;
   }
-  if(!QFile::exists(conv_src_filename)) {
+  struct stat stats;
+  memset(&stats,0,sizeof(stats));
+  if(stat((const char *)conv_src_filename.toUtf8(),&stats)!=0) {
     return RDAudioConvert::ErrorNoSource;
   }
   if(conv_dst_filename.isEmpty()) {
@@ -170,21 +176,23 @@ RDAudioConvert::ErrorCode RDAudioConvert::convert()
   //
   // Generate Temporary Filenames
   //
-  strcpy(tmpdir,RDTempDir());
-  strcat(tmpdir,"/rdaudioconvertXXXXXX");
-  if(mkdtemp(tmpdir)==NULL) {
+  temp_dir=new RDTempDirectory("rdaudioconvert");
+  QString err_msg;
+  if(!temp_dir->create(&err_msg)) {
+    delete temp_dir;
+    rda->syslog(LOG_WARNING,"Could not create %s",
+		(const char *)err_msg.toUtf8());
     return RDAudioConvert::ErrorInternal;
   }
-  tmpfile1=QString(tmpdir)+"/signed32_1.wav";
-  tmpfile2=QString(tmpdir)+"/signed32_2.wav";
+  tmpfile1=QString(temp_dir->path())+"/signed32_1.wav";
+  tmpfile2=QString(temp_dir->path())+"/signed32_2.wav";
 
   //
   // Stage One -- Convert Source Format to Signed 32 Bit Integer
   //
   if((err=Stage1Convert(conv_src_filename,tmpfile1))!=
      RDAudioConvert::ErrorOk) {
-    unlink(tmpfile1);
-    rmdir(tmpdir);
+    delete temp_dir;
     return err;
   }
 
@@ -193,9 +201,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::convert()
   //
   if((err=Stage2Convert(tmpfile1,tmpfile2))!=
      RDAudioConvert::ErrorOk) {
-    unlink(tmpfile1);
-    unlink(tmpfile2);
-    rmdir(tmpdir);
+    delete temp_dir;
     return err;
   }
 
@@ -204,18 +210,14 @@ RDAudioConvert::ErrorCode RDAudioConvert::convert()
   //
   if((err=Stage3Convert(tmpfile2,conv_dst_filename))!=
      RDAudioConvert::ErrorOk) {
-    unlink(tmpfile1);
-    unlink(tmpfile2);
-    rmdir(tmpdir);
+    delete temp_dir;
     return err;
   }
 
   //
   // Clean Up
   //
-  unlink(tmpfile1);
-  unlink(tmpfile2);
-  rmdir(tmpdir);
+  delete temp_dir;
 
   return RDAudioConvert::ErrorOk;
 }
@@ -340,7 +342,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Convert(const QString &srcfile,
   // Try Libsndfile
   //
   memset(&sf_src_info,0,sizeof(sf_src_info));
-  if((sf_src=sf_open(srcfile,SFM_READ,&sf_src_info))!=NULL) {
+  if((sf_src=sf_open(srcfile.toUtf8(),SFM_READ,&sf_src_info))!=NULL) {
     err=Stage1SndFile(dstfile,sf_src,&sf_src_info);
     sf_close(sf_src);
     return RDAudioConvert::ErrorOk;
@@ -427,7 +429,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Vorbis(const QString &dstfile,
   //
   // Initialize Decoder
   //
-  if((fd=open(wave->getName(),O_RDONLY))<0) {
+  if((fd=open(wave->getName().toUtf8(),O_RDONLY))<0) {
     sf_close(sf_dst);
     return RDAudioConvert::ErrorNoSource;
   }
@@ -558,7 +560,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
   unsigned char buffer[STAGE1BUFSIZE];
   float sf_buffer[1152*2];
   sf_count_t start=0;
-  sf_count_t end=wave->getSampleLength();
+  int64_t end=-1;
   sf_count_t frames=0;
 
   //
@@ -607,13 +609,13 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
 
       int thiserr=mad_frame_decode(&mad_frame,&mad_stream);
       if(thiserr!=0) {
-	if(!MAD_RECOVERABLE(mad_stream.error))
+	if(!MAD_RECOVERABLE(mad_stream.error)) {
 	  break;
-	else
+	}
+	else {
 	  continue;
+	}
       }
-
-      //printf("decoding...\n");
       mad_synth_frame(&mad_synth,&mad_frame);
       for(int i=0;i<mad_synth.pcm.length;i++) {
 	for(int j=0;j<mad_synth.pcm.channels;j++) {
@@ -622,7 +624,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
 	}
       }
       if(frames>=start) {
-	if((frames+mad_synth.pcm.length)<end) {    // Write entire buffer 
+	if((end<0)||((frames+mad_synth.pcm.length)<end)) { // Write full buffer 
 	  UpdatePeak(sf_buffer,mad_synth.pcm.length*wave->getChannels());
 	  sf_writef_float(sf_dst,sf_buffer,mad_synth.pcm.length);
 	}
@@ -659,11 +661,11 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
     // Prevent buffer overflow on malformed files.
     // The amount checked for should match the maximum amount that may be read
     // by the next top-of-loop wave->readWave call.
-    if(left_over + fsize + 1 > STAGE1BUFSIZE)
+    if(left_over + fsize + 1 > STAGE1BUFSIZE) {
       return RDAudioConvert::ErrorFormatError;
-
+    }
     memmove(buffer,mad_stream.next_frame,left_over);
-
+    usleep(conv_transcoding_delay);
   }
   memset(buffer+left_over,0,MAD_BUFFER_GUARD);
   mad_stream_buffer(&mad_stream,buffer,MAD_BUFFER_GUARD+left_over);
@@ -720,7 +722,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1M4A(const QString &dstfile,
   //
   // Open source
   //
-  f = dlmp4.MP4Read(wave->getName());
+  f = dlmp4.MP4Read(wave->getName().toUtf8());
   if(f == MP4_INVALID_FILE_HANDLE)
     return RDAudioConvert::ErrorNoSource;
 
@@ -827,6 +829,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1M4A(const QString &dstfile,
     UpdatePeak((const float*)sample_buffer, frameInfo.samples);
     
     if(sf_write_float(sf_dst, (const float*)sample_buffer, frameInfo.samples) != (sf_count_t)frameInfo.samples) {
+      rda->syslog(LOG_WARNING,"%s",sf_strerror(sf_dst));
       ret = RDAudioConvert::ErrorInternal;
       break;
     }
@@ -893,6 +896,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1SndFile(const QString &dstfile,
     if((end-start)<buffer_size) {
       buffer_size=end-start;
     }
+    usleep(conv_transcoding_delay);
   }
   delete buffer;
   sf_close(sf_dst);
@@ -922,6 +926,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
   //
   memset(&src_info,0,sizeof(src_info));
   if((src_sf=sf_open(srcfile,SFM_READ,&src_info))==NULL) {
+    rda->syslog(LOG_WARNING,"Could not open %s",(const char *)srcfile.toUtf8());
     return RDAudioConvert::ErrorInternal;
   }
   sf_command(src_sf,SFC_SET_NORM_FLOAT,NULL,SF_FALSE);
@@ -932,6 +937,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
   dst_info.samplerate=conv_settings->sampleRate();
   if((dst_sf=sf_open(dstfile,SFM_WRITE,&dst_info))==NULL) {
     sf_close(src_sf);
+    rda->syslog(LOG_WARNING,"Could not open %s",(const char *)dstfile.toUtf8());
     return RDAudioConvert::ErrorInternal;
   }
 
@@ -970,6 +976,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     if((src_state=src_new(conv_src_converter,src_info.channels,&err))==NULL) {
       sf_close(src_sf);
       sf_close(dst_sf);
+      rda->syslog(LOG_WARNING,"%s",src_strerror(err));
       return RDAudioConvert::ErrorInternal;
     }
     memset(&src_data,0,sizeof(src_data));
@@ -1019,8 +1026,9 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     if(src_state!=NULL) {
       src_data.input_frames=n;
       if((err=src_process(src_state,&src_data))!=0) {
-	fprintf(stderr,"SRC Error: %s\n",src_strerror(err));
-	return RDAudioConvert::ErrorInternal;
+        fprintf(stderr,"SRC Error: %s\n",src_strerror(err));
+        rda->syslog(LOG_WARNING,"%s",src_strerror(err));
+        return RDAudioConvert::ErrorInternal;
       }
       n=src_data.output_frames_gen;
     }
@@ -1081,6 +1089,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
       sf_close(dst_sf);
       return RDAudioConvert::ErrorNoSpace;
     }
+    usleep(conv_transcoding_delay);
   }
 
   //
@@ -1104,6 +1113,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
 	sf_close(dst_sf);
 	return RDAudioConvert::ErrorNoSpace;
       }
+      usleep(conv_transcoding_delay);
     }
     delete st_conv;
   }
@@ -1137,6 +1147,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Convert(const QString &srcfile,
   // Open Source File
   //
   if((src_sf=sf_open(srcfile,SFM_READ,&src_sf_info))==NULL) {
+    rda->syslog(LOG_WARNING,"%s",sf_strerror(NULL));
     return RDAudioConvert::ErrorInternal;
   }
 
@@ -1202,12 +1213,13 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Flac(SNDFILE *src_sf,
    *
   flac->set_filename(dstfile.ascii());
   switch(flac->init()) {
-  case 0:
-  break;
+    case 0:
+      break;
 
-  default:
-  delete flac;
-  return RDAudioConvert::ErrorInternal;
+    default:
+      delete flac;
+      rda->log(RDConfig::LogWarning,QString("flac->init() failure"));
+      return RDAudioConvert::ErrorInternal;
   }
   */
   /*
@@ -1232,6 +1244,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Flac(SNDFILE *src_sf,
   case FLAC__STREAM_ENCODER_INIT_STATUS_INVALID_METADATA:
   default:
     delete flac;
+    rda->syslog(LOG_WARNING,"flac->init() failure");
     return RDAudioConvert::ErrorInternal;
   }
 
@@ -1299,6 +1312,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Vorbis(SNDFILE *src_sf,
 				conv_settings->quality())) {
   case OV_EFAULT:
   default:
+    rda->syslog(LOG_WARNING,"vorbis_encode_init_vbr() failure");
     return RDAudioConvert::ErrorInternal;
 
   case OV_EINVAL:
@@ -1490,6 +1504,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer3(SNDFILE *src_sf,
   if((lameopts=lame_init())==NULL) {
     lame_close(lameopts);
     ::close(dst_fd);
+    rda->syslog(LOG_WARNING,"lame_init() failure");
     return RDAudioConvert::ErrorInternal;
   }
   lame_set_mode(lameopts,mpeg_mode);
@@ -1516,6 +1531,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer3(SNDFILE *src_sf,
 	  return RDAudioConvert::ErrorNoSpace;
 	}
       }
+      usleep(conv_transcoding_delay);
     }
   }
   else {
@@ -1526,6 +1542,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer3(SNDFILE *src_sf,
 	  ::close(dst_fd);
 	  return RDAudioConvert::ErrorNoSpace;
 	}
+	usleep(conv_transcoding_delay);
       }
     }
   }
@@ -1626,6 +1643,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2Wav(SNDFILE *src_sf,
   //
   if((lameopts=twolame_init())==NULL) {
     wave->closeWave();
+    rda->syslog(LOG_WARNING,"twolame_init() failure");
     return RDAudioConvert::ErrorInternal;
   }
   twolame_set_mode(lameopts,mpeg_mode);
@@ -1655,6 +1673,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2Wav(SNDFILE *src_sf,
     else {
       fprintf(stderr,"TwoLAME encode error\n");
     }
+    usleep(conv_transcoding_delay);
   }
   if((s=twolame_encode_flush(lameopts,mpeg,2048))>=0) {
     if(wave->writeWave(mpeg,s)!=s) {
@@ -1729,6 +1748,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2(SNDFILE *src_sf,
   //
   if((lameopts=twolame_init())==NULL) {
     ::close(dst_fd);
+    rda->syslog(LOG_WARNING,"twolame_init() failure");
     return RDAudioConvert::ErrorInternal;
   }
   twolame_set_mode(lameopts,mpeg_mode);
@@ -1757,6 +1777,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2(SNDFILE *src_sf,
     else {
       fprintf(stderr,"TwoLAME encode error\n");
     }
+    usleep(conv_transcoding_delay);
   }
   if((s=twolame_encode_flush(lameopts,mpeg,2048))>=0) {
     if(write(dst_fd,mpeg,s)!=s) {
@@ -1823,6 +1844,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Pcm16(SNDFILE *src_sf,
       delete wave;
       return RDAudioConvert::ErrorNoSpace;
     }
+    usleep(conv_transcoding_delay);
   }
   delete sf_buffer;
   wave->closeWave();
@@ -1872,6 +1894,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Pcm24(SNDFILE *src_sf,
       delete wave;
       return RDAudioConvert::ErrorNoSpace;
     }
+    usleep(conv_transcoding_delay);
   }
   delete sf_buffer;
   delete pcm24;
@@ -1883,71 +1906,71 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Pcm24(SNDFILE *src_sf,
 
 void RDAudioConvert::ApplyId3Tag(const QString &filename,RDWaveData *wavedata)
 {
-  ID3_Tag *tag=new ID3_Tag(filename);
-  ID3_Frame *frame=new ID3_Frame(ID3FID_TITLE);
-  frame->GetField(ID3FN_TEXT)->Set(wavedata->title());
-  tag->AddNewFrame(frame);
+  TagLib::MPEG::File *file=new TagLib::MPEG::File(filename.toUtf8(),false);
+  TagLib::PropertyMap *map=new TagLib::PropertyMap();
+  TagLib::ID3v2::Tag *tag=file->ID3v2Tag();
 
-  if(wavedata->beatsPerMinute()>0) {
-    frame=new ID3_Frame(ID3FID_BPM);
-    frame->GetField(ID3FN_TEXT)->
-      Set(QString().sprintf("%d",wavedata->beatsPerMinute()));
-    tag->AddNewFrame(frame);
+  AddId3Property(map,"TITLE",wavedata->title());
+  if(!wavedata->artist().isEmpty()) {
+    AddId3Property(map,"ARTIST",wavedata->artist());
   }
   if(!wavedata->album().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_ALBUM);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->album());
-    tag->AddNewFrame(frame);
+    AddId3Property(map,"ALBUM",wavedata->album());
   }
-  if(!wavedata->composer().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_COMPOSER);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->composer());
-    tag->AddNewFrame(frame);
-  }
-  if(!wavedata->copyrightNotice().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_COPYRIGHT);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->copyrightNotice());
-    tag->AddNewFrame(frame);
-  }
-  if(!wavedata->artist().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_LEADARTIST);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->artist());
-    tag->AddNewFrame(frame);
-  }
-  if(!wavedata->publisher().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_PUBLISHER);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->publisher());
-    tag->AddNewFrame(frame);
+  if(!wavedata->label().isEmpty()) {
+    AddId3Property(map,"LABEL",wavedata->label());
   }
   if(!wavedata->conductor().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_CONDUCTOR);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->conductor());
-    tag->AddNewFrame(frame);
+    AddId3Property(map,"CONDUCTOR",wavedata->conductor());
+  }
+  if(!wavedata->composer().isEmpty()) {
+    AddId3Property(map,"COMPOSER",wavedata->composer());
+  }
+  if(!wavedata->publisher().isEmpty()) {
+    AddId3Property(map,"PUBLISHER",wavedata->publisher());
+  }
+  if(!wavedata->copyrightNotice().isEmpty()) {
+    AddId3Property(map,"COPYRIGHT",wavedata->copyrightNotice());
   }
   if(!wavedata->isrc().isEmpty()) {
-    frame=new ID3_Frame(ID3FID_ISRC);
-    frame->GetField(ID3FN_TEXT)->Set(wavedata->isrc());
-    tag->AddNewFrame(frame);
+    AddId3Property(map,"ISRC",wavedata->isrc());
   }
   if(wavedata->releaseYear()>0) {
-    frame=new ID3_Frame(ID3FID_YEAR);
-    frame->GetField(ID3FN_TEXT)->
-      Set(QString().sprintf("%d",wavedata->releaseYear()));
-    tag->AddNewFrame(frame);
+    AddId3Property(map,"YEAR",QString().sprintf("%d",wavedata->releaseYear()));
   }
+  if(wavedata->beatsPerMinute()>0) {
+    AddId3Property(map,"BPM",
+		   QString().sprintf("%d",wavedata->beatsPerMinute()));
+  }
+  tag->setProperties(*map);
+
   RDCart *cart=new RDCart(wavedata->cartNumber());
   if(cart->exists()) {
     QString xml=
       cart->xml(true,conv_start_point<0,conv_settings,wavedata->cutNumber());
-    frame=new ID3_Frame(ID3FID_USERTEXT);
-    frame->GetField(ID3FN_DESCRIPTION)->Set("rdxl");
-    frame->GetField(ID3FN_TEXTENC)->Set(ID3TE_NONE);
-    frame->GetField(ID3FN_TEXT)->Set(xml);
-    tag->AddNewFrame(frame);
-    delete cart;
+    TagLib::ID3v2::UserTextIdentificationFrame *frame=
+      new TagLib::ID3v2::UserTextIdentificationFrame(TagLib::String::UTF8);
+    frame->setDescription("rdxl");
+    frame->setText(TagLib::String((const char *)xml.toUtf8(),
+    				  TagLib::String::UTF8));
+    tag->addFrame(frame);
   }
-  tag->Update();
-  delete tag;
+  delete cart;
+
+  file->save();
+  delete map;
+  delete file;
+}
+
+
+void RDAudioConvert::AddId3Property(TagLib::PropertyMap *map,const QString &key,
+				    const QString &value) const
+{
+  TagLib::StringList args;
+
+  args.
+    append(TagLib::String((const char *)value.toUtf8(),TagLib::String::UTF8));
+  map->insert((const char *)key.toUtf8(),args);
 }
 
 
