@@ -2,7 +2,7 @@
 //
 // Connection to the Rivendell Core Audio Engine
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,18 +26,18 @@
 #include <qobject.h>
 #include <ctype.h>
 
-#include <qsocketdevice.h>
+#include <q3socketdevice.h>
 #include <qtimer.h>
 #include <qstringlist.h>
 
+#include <rdapplication.h>
 #include <rddb.h>
 #include <rdcae.h>
 #include <rddebug.h>
 #include <rdescape_string.h>
 
-RDCae::RDCae(RDStation *station,RDConfig *config,
-	     QObject *parent,const char *name)
-  : QObject(parent,name)
+RDCae::RDCae(RDStation *station,RDConfig *config,QObject *parent)
+  : QObject(parent)
 {
   cae_station=station;
   cae_config=config;
@@ -48,13 +48,13 @@ RDCae::RDCae(RDStation *station,RDConfig *config,
   //
   // TCP Connection
   //
-  cae_socket=new QSocketDevice(QSocketDevice::Stream);
+  cae_socket=new Q3SocketDevice(Q3SocketDevice::Stream);
   cae_socket->setBlocking(false);
 
   //
   // Meter Connection
   //
-  cae_meter_socket=new QSocketDevice(QSocketDevice::Datagram);
+  cae_meter_socket=new Q3SocketDevice(Q3SocketDevice::Datagram);
   cae_meter_socket->setBlocking(false);
   for(Q_INT16 i=30000;i<30100;i++) {
     if(cae_meter_socket->bind(QHostAddress(),i)) {
@@ -119,10 +119,30 @@ void RDCae::connectHost()
 	SendCommand(QString().sprintf("IS %d %d!",i,j));
       }
     }
-    SendCommand(QString().sprintf("ME %u!",cae_meter_socket->port()));
   }
 }
 
+
+void RDCae::enableMetering(QList<int> *cards)
+{
+  QString cmd=QString().sprintf("ME %u",cae_meter_socket->port());
+  for(int i=0;i<cards->size();i++) {
+    if(cards->at(i)>=0) {
+      bool found=false;
+      for(unsigned j=0;j<i;j++) {
+	if(cards->at(i)==cards->at(j)) {
+	  found=true;
+	}
+      }
+      if(!found) {
+	cmd+=QString().sprintf(" %d",cards->at(i));
+      }
+    }
+  }
+  SendCommand(cmd+"!");
+}
+
+
 bool RDCae::loadPlay(int card,QString name,int *stream,int *handle)
 {
   int count=0;
@@ -142,7 +162,8 @@ bool RDCae::loadPlay(int card,QString name,int *stream,int *handle)
     count++;
   }
   if(count>1000) {
-    syslog(LOG_ERR,"*** LoadPlay: CAE took %d mS to return stream for %s ***",
+    rda->syslog(LOG_ERR,
+		"*** LoadPlay: CAE took %d mS to return stream for %s ***",
 	   count,(const char *)name);
   }
   cae_handle[card][*stream]=*handle;
@@ -356,18 +377,6 @@ void RDCae::setPlayPortActive(int card,int port,int stream)
 }
 
 
-void RDCae::connectJackPorts(const QString &out,const QString &in)
-{
-  SendCommand(QString("JC ")+out+" | "+in+"!");
-}
-
-
-void RDCae::disconnectJackPorts(const QString &out,const QString &in)
-{
-  SendCommand(QString("JD ")+out+" | "+in+"!");
-}
-
-
 void RDCae::readyData()
 {
   readyData(0,0,"");
@@ -469,7 +478,6 @@ void RDCae::clockData()
 
 void RDCae::SendCommand(QString cmd)
 {
-  //printf("RDCae: SendCommand(%s)\n",(const char *)cmd);
   cae_socket->writeBlock((const char *)cmd,cmd.length());
 }
 
@@ -492,8 +500,8 @@ void RDCae::DispatchCommand(RDCmdCache *cmd)
     int handle=GetHandle(cmd->arg(4));
     int card=CardNumber(cmd->arg(1));
     int stream=StreamNumber(cmd->arg(3));
-    syslog(LOG_ERR,"*** RDCae::DispatchCommand: received unhandled play stream from CAE, handle=%d, card=%d, stream=%d, name=\"%s\" ***",
-	   handle,card,stream,cmd->arg(2));
+    rda->syslog(LOG_ERR,"*** RDCae::DispatchCommand: received unhandled play stream from CAE, handle=%d, card=%d, stream=%d, name=\"%s\" ***",
+		handle,card,stream,cmd->arg(2));
     
     unloadPlay(handle);
   }
@@ -522,7 +530,6 @@ void RDCae::DispatchCommand(RDCmdCache *cmd)
       for(int i=0;i<RD_MAX_CARDS;i++) {
 	for(int j=0;j<RD_MAX_STREAMS;j++) {
 	  if(cae_handle[i][j]==handle) {
-	    //emit playPositionChanged(handle,cae_output_positions[i][j]);
 	    emit playPositionChanged(handle,pos);
 	  }
 	}
@@ -637,7 +644,7 @@ void RDCae::UpdateMeters()
 
   while((n=cae_meter_socket->readBlock(msg,1500))>0) {
     msg[n]=0;
-    args=args.split(" ",msg);
+    args=QString(msg).split(" ");
     if(args[0]=="ML") {
       if(args.size()==6) {
 	if(args[1]=="I") {
