@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Cart.
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,12 +18,10 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef WIN32
 #include <sys/types.h>
 #include <unistd.h>
 #include <syslog.h>
 #include <curl/curl.h>
-#endif  // WIN32
 
 #include <vector>
 
@@ -31,16 +29,19 @@
 #include <qobject.h>
 
 #include <rd.h>
+#include <rdapplication.h>
 #include <rdconf.h>
+#include <rdconfig.h>
 #include <rdcart.h>
 #include <rdcut.h>
-#include <rdtextvalidator.h>
 #include <rdescape_string.h>
-#include <rdsystem.h>
-#include <rdxport_interface.h>
 #include <rdformpost.h>
-#include <rdweb.h>
+#include <rdgroup.h>
 #include <rdstation.h>
+#include <rdsystem.h>
+#include <rdtextvalidator.h>
+#include <rdxport_interface.h>
+#include <rdweb.h>
 
 //
 // CURL Callbacks
@@ -89,11 +90,8 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
   if(!exists()) {
     ret=(*cut=="");
     *cut="";
-#ifndef WIN32
-    syslog(LOG_USER|LOG_WARNING,
-	   "RDCart::selectCut(): cart doesn't exist, CUT=%s",
-	   (const char *)cut);
-#endif  // WIN32
+    rda->syslog(LOG_DEBUG,
+	   "RDCart::selectCut(): cart doesn't exist, CUT=%s",(const char *)cut);
     return ret;
   }
 
@@ -133,7 +131,7 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
              LAST_PLAY_DATETIME ASC";
     }
     else {
-      sql+=" order by LAST_PLAY_DATETIME desc";
+      sql+=" order by LAST_PLAY_DATETIME desc, PLAY_ORDER desc";
     }
     q=new RDSqlQuery(sql);
     cutname=GetNextCut(q);
@@ -145,9 +143,6 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
     break;
   }
   if(cutname.isEmpty()) {   // No valid cuts, try the evergreen
-#ifndef WIN32
-    // syslog(LOG_USER|LOG_WARNING,"RDCart::selectCut(): no valid cuts, trying evergreen, SQL=%s",(const char *)sql);
-#endif  // WIN32
     sql=QString("select ")+
       "CUT_NAME,"+
       "PLAY_ORDER,"+
@@ -169,9 +164,6 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
     delete q;
   }
   if(cutname.isEmpty()) {
-#ifndef WIN32
-    // syslog(LOG_USER|LOG_WARNING,"RDCart::selectCut(): no valid evergreen cuts, SQL=%s",(const char *)sql);
-#endif  // WIN32
   }
   *cut=cutname;
   return true;
@@ -253,37 +245,41 @@ void RDCart::setAlbum(const QString &album)
 
 int RDCart::year() const
 {
-  QString value;
-  value=RDGetSqlValue("CART","NUMBER",cart_number,"YEAR").toString();
-  QStringList f0=f0.split("-",value);
+  QStringList f0=
+    RDGetSqlValue("CART","NUMBER",cart_number,"YEAR").toString().split("-");
   return f0[0].toInt();
 }
 
 
 void RDCart::setYear(int year)
 {
-  SetRow("YEAR",QString().sprintf("%04d-01-01",year));
+  if((year>0)&&(year<10000)) {
+    SetRow("YEAR",QString().sprintf("%04d-01-01",year));
+  }
+  else {
+    SetRow("YEAR");
+  }
   metadata_changed=true;
 }
 
 
 QString RDCart::schedCodes() const
 {
-  return RDGetSqlValue("CART","NUMBER",cart_number,"SCHED_CODES").toString();
+  QString sched_codes="";
+
+  QStringList list = schedCodesList();
+
+  for(int i=0;i<list.size();i++) {
+    sched_codes+=QString().sprintf("%-11s",(const char *)list.at(i));
+  }
+  sched_codes+=".";
+  return sched_codes;
 }
 
 
 void RDCart::setSchedCodes(const QString &sched_codes) const
-{
-  SetRow("SCHED_CODES",sched_codes);
-}
-
-
-QStringList RDCart::schedCodesList() const
 {
   QStringList list;
-  QString sched_codes=
-    RDGetSqlValue("CART","NUMBER",cart_number,"SCHED_CODES").toString();
 
   for(int i=0;i<255;i+=11) {
     QString code=sched_codes.mid(i,11);
@@ -291,6 +287,20 @@ QStringList RDCart::schedCodesList() const
       list.push_back(code.stripWhiteSpace());
     }
   }
+  setSchedCodesList(list);
+}
+
+
+QStringList RDCart::schedCodesList() const
+{
+  QStringList list;
+  RDSqlQuery *q;
+
+  QString sql=QString().sprintf("select SCHED_CODE from CART_SCHED_CODES where CART_NUMBER=%u", cart_number);
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    list.push_back(q->value(0).toString());
+  }
 
   return list;
 }
@@ -298,13 +308,19 @@ QStringList RDCart::schedCodesList() const
 
 void RDCart::setSchedCodesList(const QStringList &codes) const
 {
+  RDSqlQuery *q;
+  QString sql;
   QString sched_codes="";
+  
+  sql=QString().sprintf("delete from CART_SCHED_CODES where CART_NUMBER=%u",cart_number);
+  q=new RDSqlQuery(sql);
+  delete q;
 
-  for(unsigned i=0;i<codes.size();i++) {
-    sched_codes+=QString().sprintf("%-11s",(const char *)codes[i].left(11));
+  for(int i=0;i<codes.size();i++) {
+    sql=QString().sprintf("insert into CART_SCHED_CODES set CART_NUMBER=%u,SCHED_CODE='%s'",cart_number,(const char *)codes.at(i));
+    q=new RDSqlQuery(sql);
+    delete q;
   }
-  sched_codes+=".";
-  SetRow("SCHED_CODES",sched_codes);  
 }
 
 
@@ -321,7 +337,7 @@ void RDCart::removeSchedCode(const QString &code) const
   QStringList codes=schedCodesList();
   QStringList new_codes;
 
-  for(unsigned i=0;i<codes.size();i++) {
+  for(int i=0;i<codes.size();i++) {
     if(codes[i].lower()!=code.lower()) {
       new_codes.push_back(codes[i]);
     }
@@ -333,7 +349,7 @@ void RDCart::removeSchedCode(const QString &code) const
 void RDCart::updateSchedCodes(const QString &add_codes,const QString &remove_codes) const
 {
   QString sched_codes;
-  QString save_codes="";
+  QStringList save_codes;
   QString sql;
   RDSqlQuery *q;
   QString str;
@@ -345,15 +361,13 @@ void RDCart::updateSchedCodes(const QString &add_codes,const QString &remove_cod
   while(q->next()) {
   	QString wstr=q->value(0).toString();
   	wstr+="          ";
-    wstr=wstr.left(11);
+        wstr=wstr.left(11);
   	if((sched_codes.contains(wstr)>0||add_codes.contains(wstr)>0)&&remove_codes.contains(wstr)==0) {
-  	  save_codes+=wstr;
+          save_codes.push_back(wstr.stripWhiteSpace());
   	}
   }
   delete q;
-
-  save_codes+=".";
-  SetRow("SCHED_CODES",save_codes);
+  setSchedCodesList(save_codes);
 }	
 
 
@@ -605,6 +619,32 @@ void RDCart::setAverageLength(unsigned length) const
 }
 
 
+unsigned RDCart::minimumTalkLength() const
+{
+  return RDGetSqlValue("CART","NUMBER",cart_number,
+		      "MINIMUM_TALK_LENGTH").toUInt();
+}
+
+
+void RDCart::setMinimumTalkLength(unsigned length) const
+{
+  SetRow("MINIMUM_TALK_LENGTH",length);
+}
+
+
+unsigned RDCart::maximumTalkLength() const
+{
+  return RDGetSqlValue("CART","NUMBER",cart_number,
+		      "MAXIMUM_TALK_LENGTH").toUInt();
+}
+
+
+void RDCart::setMaximumTalkLength(unsigned length) const
+{
+  SetRow("MAXIMUM_TALK_LENGTH",length);
+}
+
+
 unsigned RDCart::averageSegueLength() const
 {
   return RDGetSqlValue("CART","NUMBER",cart_number,
@@ -816,7 +856,6 @@ void RDCart::setUseEventLength(bool state) const
 
 void RDCart::setPending(const QString &station_name)
 {
-#ifndef WIN32
   QString sql;
   RDSqlQuery *q;
 
@@ -827,7 +866,6 @@ void RDCart::setPending(const QString &station_name)
     QString().sprintf("where NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   delete q;
-#endif  // WIN32
 }
 
 
@@ -905,51 +943,40 @@ void RDCart::setMetadata(const RDWaveData *data)
 {
   QString sql="update CART set ";
   if(!data->title().isEmpty()) {
-    sql+=QString().sprintf("TITLE=\"%s\",",(const char *)
-			   RDEscapeString(VerifyTitle(data->title())).utf8());
+    sql+=QString("TITLE=\"")+RDEscapeString(VerifyTitle(data->title()))+"\",";
   }
   if(!data->artist().isEmpty()) {
-    sql+=QString().sprintf("ARTIST=\"%s\",",(const char *)
-			   RDEscapeString(data->artist()).utf8());
+    sql+=QString("ARTIST=\"")+RDEscapeString(data->artist())+"\",";
   }
   if(!data->album().isEmpty()) {
-    sql+=QString().sprintf("ALBUM=\"%s\",",(const char *)
-			   RDEscapeString(data->album()).utf8());
+    sql+=QString("ALBUM=\"")+RDEscapeString(data->album())+"\",";
   }
   if(data->releaseYear()>0) {
     sql+=QString().sprintf("YEAR=\"%04d-01-01\",",data->releaseYear());
   }
   if(!data->label().isEmpty()) {
-    sql+=QString().sprintf("LABEL=\"%s\",",(const char *)
-			   RDEscapeString(data->label()).utf8());
+    sql+=QString("LABEL=\"")+RDEscapeString(data->label())+"\",";
   }
   if(!data->conductor().isEmpty()) {
-    sql+=QString().sprintf("CONDUCTOR=\"%s\",",(const char *)
-			   RDEscapeString(data->conductor()).utf8());
+    sql+=QString("CONDUCTOR=\"")+RDEscapeString(data->conductor())+"\",";
   }
   if(!data->client().isEmpty()) {
-    sql+=QString().sprintf("CLIENT=\"%s\",",(const char *)
-			   RDEscapeString(data->client()).utf8());
+    sql+=QString("CLIENT=\"")+RDEscapeString(data->client())+"\",";
   }
   if(!data->agency().isEmpty()) {
-    sql+=QString().sprintf("AGENCY=\"%s\",",(const char *)
-			   RDEscapeString(data->agency()).utf8());
+    sql+=QString("AGENCY=\"")+RDEscapeString(data->agency())+"\",";
   }
   if(!data->publisher().isEmpty()) {
-    sql+=QString().sprintf("PUBLISHER=\"%s\",",(const char *)
-			   RDEscapeString(data->publisher()).utf8());
+    sql+=QString("PUBLISHER=\"")+RDEscapeString(data->publisher())+"\",";
   }
   if(!data->composer().isEmpty()) {
-    sql+=QString().sprintf("COMPOSER=\"%s\",",(const char *)
-			   RDEscapeString(data->composer()).utf8());
+    sql+=QString("COMPOSER=\"")+RDEscapeString(data->composer())+"\",";
   }
   if(!data->userDefined().isEmpty()) {
-    sql+=QString().sprintf("USER_DEFINED=\"%s\",",(const char *)
-			   RDEscapeString(data->userDefined()).utf8());
+    sql+=QString("USER_DEFINED=\"")+RDEscapeString(data->userDefined())+"\",";
   }
   if(!data->tmciSongId().isEmpty()) {
-    sql+=QString().sprintf("SONG_ID=\"%s\",",(const char *)
-			   RDEscapeString(data->tmciSongId()).utf8());
+    sql+=QString("SONG_ID=\"")+RDEscapeString(data->tmciSongId())+"\",";
   }
   if(data->beatsPerMinute()>0) {
     sql+=QString().sprintf("BPM=%u,",data->beatsPerMinute());
@@ -988,9 +1015,6 @@ bool RDCart::validateLengths(int len) const
 QString RDCart::xml(bool include_cuts,bool absolute,
 		    RDSettings *settings,int cutnum) const
 {
-#ifdef WIN32
-  return QString();
-#else
   QString sql=RDCart::xmlSql(include_cuts)+
     QString().sprintf(" where (CART.NUMBER=%u)",cart_number);
   if(cutnum>=0) {
@@ -1001,7 +1025,6 @@ QString RDCart::xml(bool include_cuts,bool absolute,
   delete q;
 
   return xml;
-#endif  // WIN32
 }
 
 
@@ -1019,6 +1042,8 @@ void RDCart::updateLength(bool enforce_length,unsigned length)
   long long total=0;
   long long segue_total=0;
   long long hook_total=0;
+  long long min_talk_len=LLONG_MAX;
+  long long max_talk_len=0;
   unsigned weight_total=0;
   unsigned weight = 0;
   QDateTime end_date;
@@ -1028,7 +1053,8 @@ void RDCart::updateLength(bool enforce_length,unsigned length)
   QString sql=QString().
     sprintf("select LENGTH,SEGUE_START_POINT,SEGUE_END_POINT,START_POINT,\
              SUN,MON,TUE,WED,THU,FRI,SAT,START_DAYPART,END_DAYPART,\
-             HOOK_START_POINT,HOOK_END_POINT,WEIGHT,END_DATETIME \
+             HOOK_START_POINT,HOOK_END_POINT,WEIGHT,END_DATETIME,\
+             TALK_START_POINT,TALK_END_POINT \
              from CUTS where (CUT_NAME like \"%06d%%\")&&(LENGTH>0)",
 	    cart_number);
   RDSqlQuery *q=new RDSqlQuery(sql);
@@ -1050,6 +1076,12 @@ void RDCart::updateLength(bool enforce_length,unsigned length)
       segue_total+=(q->value(1).toInt()-q->value(3).toInt()) * weight;
     }
     hook_total+=(q->value(14).toUInt()-q->value(13).toUInt()) * weight;
+    if(min_talk_len>q->value(18).toUInt()-q->value(17).toUInt()) {
+      min_talk_len=q->value(18).toUInt()-q->value(17).toUInt();
+    }
+    if(max_talk_len<q->value(18).toUInt()-q->value(17).toUInt()) {
+      max_talk_len=q->value(18).toUInt()-q->value(17).toUInt();
+    }
     weight_total += weight;
   }
   if(weight_total>0) {
@@ -1068,6 +1100,8 @@ void RDCart::updateLength(bool enforce_length,unsigned length)
       setForcedLength(0);
     }
   }
+  setMinimumTalkLength(min_talk_len);
+  setMaximumTalkLength(max_talk_len);
   setCutQuantity(q->size());
   delete q;
 
@@ -1083,16 +1117,28 @@ void RDCart::updateLength(bool enforce_length,unsigned length)
   QDateTime valid_until;
   bool dates_valid=true;
 
-  sql=QString().sprintf("select CUT_NAME,START_DAYPART,END_DAYPART,LENGTH,\
-                         SUN,MON,TUE,WED,THU,FRI,SAT,EVERGREEN,\
-                         START_DATETIME,END_DATETIME from CUTS\
-                         where CART_NUMBER=%u",
-			cart_number);
+  sql=QString("select ")+
+    "CUT_NAME,"+        // 00
+    "START_DAYPART,"+   // 01
+    "END_DAYPART,"+     // 02
+    "LENGTH,"+          // 03
+    "SUN,"+             // 04
+    "MON,"+             // 05
+    "TUE,"+             // 06
+    "WED,"+             // 07
+    "THU,"+             // 08
+    "FRI,"+             // 09
+    "SAT,"+             // 10
+    "EVERGREEN,"+       // 11
+    "START_DATETIME,"+  // 12
+    "END_DATETIME "+    // 13
+    "from CUTS where "+
+    QString().sprintf("CART_NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   while(q->next()) {
     cut_validity=ValidateCut(q,enforce_length,length,&time_ok);
-    sql=QString().sprintf("update CUTS set VALIDITY=%u where CUT_NAME=\"%s\"",
-			  cut_validity,(const char *)q->value(0).toString());
+    sql=QString().sprintf("update CUTS set VALIDITY=%u where ",cut_validity)+
+      "CUT_NAME=\""+RDEscapeString(q->value(0).toString())+"\"";
     q1=new RDSqlQuery(sql);
     delete q1;
     evergreen&=RDBool(q->value(11).toString());
@@ -1137,15 +1183,15 @@ void RDCart::updateLength(bool enforce_length,unsigned length)
     sql+="START_DATETIME=NULL,";
   }
   else {
-    sql+=QString().sprintf("START_DATETIME=%s,",
-		(const char *)RDCheckDateTime(start_datetime,"yyyy-MM-dd hh:mm:ss"));
+    sql+=QString("START_DATETIME=")+
+      RDCheckDateTime(start_datetime,"yyyy-MM-dd hh:mm:ss")+",";
   }
   if(end_datetime.isNull()||(!dates_valid)) {
     sql+="END_DATETIME=NULL,";
   }
   else {
-    sql+=QString().sprintf("END_DATETIME=%s,",
-		(const char *)RDCheckDateTime(end_datetime,"yyyy-MM-dd hh:mm:ss"));
+    sql+=QString("END_DATETIME=")+
+      RDCheckDateTime(end_datetime,"yyyy-MM-dd hh:mm:ss")+",";
   }
   sql+=QString().sprintf("VALIDITY=%u where NUMBER=%u",
 			 cart_validity,cart_number);
@@ -1190,15 +1236,18 @@ int RDCart::addCut(unsigned format,unsigned bitrate,unsigned chans,
   if(desc.isEmpty()) {
     desc=QString().sprintf("Cut %03d",next);
   }
-  sql=QString("insert into CUTS set CUT_NAME=\"")+next_name+"\","+
-    QString().sprintf("CART_NUMBER=%d,",cart_number)+
+  if(!RDCut::create(next_name)) {
+    return -1;
+  }
+  sql=QString("update CUTS set ")+
     "ISCI=\""+RDEscapeString(isci)+"\","+
     "DESCRIPTION=\""+RDEscapeString(desc)+"\","+
     "LENGTH=0,"+
     QString().sprintf("CODING_FORMAT=%d,",format)+
     QString().sprintf("BIT_RATE=%d,",bitrate)+
     QString().sprintf("CHANNELS=%d,",chans)+
-    QString().sprintf("PLAY_ORDER=%d",next);
+    QString().sprintf("PLAY_ORDER=%d where ",next)+
+    "CUT_NAME=\""+next_name+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 
@@ -1245,12 +1294,12 @@ bool RDCart::removeCut(RDStation *station,RDUser *user,const QString &cutname,
   if(!RDCart::removeCutAudio(station,user,cart_number,cutname,config)) {
     return false;
   }
-  sql=QString().sprintf("delete from REPL_CUT_STATE where CUT_NAME=\"%s\"",
-			(const char *)cutname);
+  sql=QString("delete from REPL_CUT_STATE where ")+
+    "CUT_NAME=\""+RDEscapeString(cutname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
-  sql=QString().sprintf("delete from CUTS where CUT_NAME=\"%s\"",
-			(const char *)cutname);
+  sql=QString("delete from CUTS where ")+
+    "CUT_NAME=\""+RDEscapeString(cutname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   setCutQuantity(cutQuantity()-1);
@@ -1267,29 +1316,60 @@ bool RDCart::removeCutAudio(RDStation *station,RDUser *user,
 }
 
 
-bool RDCart::create(const QString &groupname,RDCart::Type type)
-{
-  QString sql=QString().sprintf("insert into CART set NUMBER=%d,TYPE=%d,\
-                                 GROUP_NAME=\"%s\",TITLE=\"%s\"",
-				cart_number,type,
-				(const char *)RDEscapeString(groupname),
-				(const char *)
-				RDEscapeString(RDCart::uniqueCartTitle(cart_number)));
-  RDSqlQuery *q=new RDSqlQuery(sql);
-  bool ret=q->isActive();
-  delete q;
-  metadata_changed=true;
-
-  return ret;
-}
-
-
 bool RDCart::remove(RDStation *station,RDUser *user,RDConfig *config) const
 {
   return RDCart::removeCart(cart_number,station,user,config);
 }
 
 
+unsigned RDCart::create(const QString &groupname,RDCart::Type type,
+			QString *err_msg,unsigned cartnum)
+{
+  bool ok=false;
+
+  RDGroup *group=new RDGroup(groupname);
+  if(!group->exists()) {
+    *err_msg=QObject::tr("No such group");
+    delete group;
+    return 0;
+  }
+
+  if(cartnum==0) {
+    while(!ok) {
+      if((cartnum=group->nextFreeCart())==0) {
+	*err_msg=QObject::tr("No free cart available in group");
+	delete group;
+	return 0;
+      }
+      QString sql=QString("insert into CART set ")+
+	QString().sprintf("NUMBER=%d,",cartnum)+
+	QString().sprintf("TYPE=%d,",type)+
+	"GROUP_NAME=\""+RDEscapeString(groupname)+"\","+
+	"TITLE=\""+RDEscapeString(RDCart::uniqueCartTitle(cartnum))+"\"";
+      RDSqlQuery *q=new RDSqlQuery(sql);
+      ok=q->isActive();
+      delete q;
+    }
+    return cartnum;
+  }
+  else {
+    QString sql=QString("insert into CART set ")+
+      QString().sprintf("NUMBER=%d,",cartnum)+
+      QString().sprintf("TYPE=%d,",type)+
+      "GROUP_NAME=\""+RDEscapeString(groupname)+"\","+
+      "TITLE=\""+RDEscapeString(RDCart::uniqueCartTitle(cartnum))+"\"";
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    ok=q->isActive();
+    delete q;
+  }
+  delete group;
+  if(!ok) {
+    return 0;
+  }
+  return cartnum;
+}
+
+
 QString RDCart::xmlSql(bool include_cuts)
 {
   QString sql=QString("select ")+
@@ -1312,59 +1392,63 @@ QString RDCart::xmlSql(bool include_cuts)
     "CART.LENGTH_DEVIATION,"+      // 16
     "CART.AVERAGE_SEGUE_LENGTH,"+  // 17
     "CART.AVERAGE_HOOK_LENGTH,"+   // 18
-    "CART.CUT_QUANTITY,"+          // 19
-    "CART.LAST_CUT_PLAYED,"+       // 20
-    "CART.VALIDITY,"+              // 21
-    "CART.ENFORCE_LENGTH,"+        // 22
-    "CART.ASYNCRONOUS,"+           // 23
-    "CART.OWNER,"+                 // 24
-    "CART.METADATA_DATETIME,"+     // 25
-    "CART.CONDUCTOR,"+             // 26
-    "CART.MACROS,"+                // 27
-    "CART.SONG_ID ";               // 28
+    "CART.MINIMUM_TALK_LENGTH,"+   // 19
+    "CART.MAXIMUM_TALK_LENGTH,"+   // 20
+    "CART.CUT_QUANTITY,"+          // 21
+    "CART.LAST_CUT_PLAYED,"+       // 22
+    "CART.VALIDITY,"+              // 23
+    "CART.ENFORCE_LENGTH,"+        // 24
+    "CART.ASYNCRONOUS,"+           // 25
+    "CART.OWNER,"+                 // 26
+    "CART.METADATA_DATETIME,"+     // 27
+    "CART.CONDUCTOR,"+             // 28
+    "CART.MACROS,"+                // 29
+    "CART.SONG_ID ";               // 30
   if(include_cuts) {
     sql+=QString(",")+
-      "CUTS.CUT_NAME,"+            // 29
-      "CUTS.EVERGREEN,"+           // 30
-      "CUTS.DESCRIPTION,"+         // 31
-      "CUTS.OUTCUE,"+              // 32
-      "CUTS.ISRC,"+                // 33
-      "CUTS.ISCI,"+                // 34
-      "CUTS.LENGTH,"+              // 35
-      "CUTS.ORIGIN_DATETIME,"+     // 36
-      "CUTS.START_DATETIME,"+      // 37
-      "CUTS.END_DATETIME,"+        // 38
-      "CUTS.SUN,"+                 // 39
-      "CUTS.MON,"+                 // 40
-      "CUTS.TUE,"+                 // 41
-      "CUTS.WED,"+                 // 42
-      "CUTS.THU,"+                 // 43
-      "CUTS.FRI,"+                 // 44
-      "CUTS.SAT,"+                 // 45
-      "CUTS.START_DAYPART,"+       // 46
-      "CUTS.END_DAYPART,"+         // 47
-      "CUTS.ORIGIN_NAME,"+         // 48
-      "CUTS.WEIGHT,"+              // 49
-      "CUTS.LAST_PLAY_DATETIME,"+  // 50
-      "CUTS.PLAY_COUNTER,"+        // 51
-      "CUTS.LOCAL_COUNTER,"+       // 52
-      "CUTS.VALIDITY,"+            // 53
-      "CUTS.CODING_FORMAT,"+       // 54
-      "CUTS.SAMPLE_RATE,"+         // 55
-      "CUTS.BIT_RATE,"+            // 56
-      "CUTS.CHANNELS,"+            // 57
-      "CUTS.PLAY_GAIN,"+           // 58
-      "CUTS.START_POINT,"+         // 59
-      "CUTS.END_POINT,"+           // 60
-      "CUTS.FADEUP_POINT,"+        // 61
-      "CUTS.FADEDOWN_POINT,"+      // 62
-      "CUTS.SEGUE_START_POINT,"+   // 63
-      "CUTS.SEGUE_END_POINT,"+     // 64
-      "CUTS.SEGUE_GAIN,"+          // 65
-      "CUTS.HOOK_START_POINT,"+    // 66
-      "CUTS.HOOK_END_POINT,"+      // 67
-      "CUTS.TALK_START_POINT,"+    // 68
-      "CUTS.TALK_END_POINT "+      // 69
+      "CUTS.CUT_NAME,"+            // 31
+      "CUTS.EVERGREEN,"+           // 32
+      "CUTS.DESCRIPTION,"+         // 33
+      "CUTS.OUTCUE,"+              // 34
+      "CUTS.ISRC,"+                // 35
+      "CUTS.ISCI,"+                // 36
+      "CUTS.LENGTH,"+              // 37
+      "CUTS.ORIGIN_DATETIME,"+     // 38
+      "CUTS.START_DATETIME,"+      // 39
+      "CUTS.END_DATETIME,"+        // 40
+      "CUTS.SUN,"+                 // 41
+      "CUTS.MON,"+                 // 42
+      "CUTS.TUE,"+                 // 43
+      "CUTS.WED,"+                 // 44
+      "CUTS.THU,"+                 // 45
+      "CUTS.FRI,"+                 // 46
+      "CUTS.SAT,"+                 // 47
+      "CUTS.START_DAYPART,"+       // 48
+      "CUTS.END_DAYPART,"+         // 49
+      "CUTS.ORIGIN_NAME,"+         // 50
+      "CUTS.ORIGIN_LOGIN_NAME,"+   // 51
+      "CUTS.SOURCE_HOSTNAME,"+     // 52
+      "CUTS.WEIGHT,"+              // 53
+      "CUTS.LAST_PLAY_DATETIME,"+  // 54
+      "CUTS.PLAY_COUNTER,"+        // 55
+      "CUTS.LOCAL_COUNTER,"+       // 56
+      "CUTS.VALIDITY,"+            // 57
+      "CUTS.CODING_FORMAT,"+       // 58
+      "CUTS.SAMPLE_RATE,"+         // 59
+      "CUTS.BIT_RATE,"+            // 60
+      "CUTS.CHANNELS,"+            // 61
+      "CUTS.PLAY_GAIN,"+           // 62
+      "CUTS.START_POINT,"+         // 63
+      "CUTS.END_POINT,"+           // 64
+      "CUTS.FADEUP_POINT,"+        // 65
+      "CUTS.FADEDOWN_POINT,"+      // 66
+      "CUTS.SEGUE_START_POINT,"+   // 67
+      "CUTS.SEGUE_END_POINT,"+     // 68
+      "CUTS.SEGUE_GAIN,"+          // 69
+      "CUTS.HOOK_START_POINT,"+    // 70
+      "CUTS.HOOK_END_POINT,"+      // 71
+      "CUTS.TALK_START_POINT,"+    // 72
+      "CUTS.TALK_END_POINT "+      // 73
       "from CART left join CUTS "+
       "on CART.NUMBER=CUTS.CART_NUMBER ";
   }
@@ -1420,18 +1504,22 @@ QString RDCart::xml(RDSqlQuery *q,bool include_cuts,
 			 "0"+RDGetTimeLength(q->value(17).toUInt(),true));
     xml+="  "+RDXmlField("averageHookLength",
 			 "0"+RDGetTimeLength(q->value(18).toUInt(),true));
-    xml+="  "+RDXmlField("cutQuantity",q->value(19).toUInt());
-    xml+="  "+RDXmlField("lastCutPlayed",q->value(20).toUInt());
-    xml+="  "+RDXmlField("enforceLength",RDBool(q->value(22).toString()));
-    xml+="  "+RDXmlField("asyncronous",RDBool(q->value(23).toString()));
-    xml+="  "+RDXmlField("owner",q->value(24).toString());
-    xml+="  "+RDXmlField("metadataDatetime",q->value(25).toDateTime());
-    xml+="  "+RDXmlField("songId",q->value(28).toString());
+    xml+="  "+RDXmlField("minimumTalkLength",
+			 "0"+RDGetTimeLength(q->value(19).toUInt(),true));
+    xml+="  "+RDXmlField("maximumTalkLength",
+			 "0"+RDGetTimeLength(q->value(20).toUInt(),true));
+    xml+="  "+RDXmlField("cutQuantity",q->value(21).toUInt());
+    xml+="  "+RDXmlField("lastCutPlayed",q->value(22).toUInt());
+    xml+="  "+RDXmlField("enforceLength",RDBool(q->value(24).toString()));
+    xml+="  "+RDXmlField("asyncronous",RDBool(q->value(25).toString()));
+    xml+="  "+RDXmlField("owner",q->value(26).toString());
+    xml+="  "+RDXmlField("metadataDatetime",q->value(27).toDateTime());
+    xml+="  "+RDXmlField("songId",q->value(30).toString());
     switch((RDCart::Type)q->value(1).toInt()) {
     case RDCart::Audio:
       if(include_cuts) {
 	cartnum=q->value(0).toUInt();
-	if(q->value(29).toString().isEmpty()) {
+	if(q->value(31).toString().isEmpty()) {
 	  xml+="  <cutList/>\n";
 	}
 	else {
@@ -1452,13 +1540,13 @@ QString RDCart::xml(RDSqlQuery *q,bool include_cuts,
       break;
 
     case RDCart::Macro:
-      mlist=mlist.split("!",q->value(27).toString());
+      mlist=q->value(29).toString().split("!");
       if(mlist.size()==0) {
 	xml+="  <macroList/>\n";
       }
       else {
 	xml+="  <macroList>\n";
-	for(unsigned i=0;i<mlist.size();i++) {
+	for(int i=0;i<mlist.size();i++) {
 	  xml+="    "+RDXmlField(QString().sprintf("macro%d",i),mlist[i]+"!");
 	}
 	xml+="  </macroList>\n";
@@ -1586,6 +1674,9 @@ bool RDCart::removeCart(unsigned cart_num,RDStation *station,RDUser *user,
   sql=QString().sprintf("delete from CUTS where CART_NUMBER=%u",cart_num);
   q=new RDSqlQuery(sql);
   delete q;
+  sql=QString().sprintf("delete from CART_SCHED_CODES where CART_NUMBER=%u",cart_num);
+  q=new RDSqlQuery(sql);
+  delete q;
   sql=QString().sprintf("delete from REPL_CART_STATE where CART_NUMBER=%u",
 			cart_num);
   q=new RDSqlQuery(sql);
@@ -1602,9 +1693,10 @@ bool RDCart::removeCutAudio(RDStation *station,RDUser *user,unsigned cart_num,
 			    const QString &cutname,RDConfig *config)
 {
   bool ret=true;
-#ifndef WIN32
   CURL *curl=NULL;
   long response_code=0;
+  struct curl_httppost *first=NULL;
+  struct curl_httppost *last=NULL;
   char url[1024];
   QString xml="";
   QString sql;
@@ -1622,14 +1714,25 @@ bool RDCart::removeCutAudio(RDStation *station,RDUser *user,unsigned cart_num,
     //
     // Generate POST Data
     //
-    QString post=QString().
-      sprintf("COMMAND=%d&LOGIN_NAME=%s&PASSWORD=%s&CART_NUMBER=%u&CUT_NUMBER=%u",
-	      RDXPORT_COMMAND_DELETEAUDIO,
-	      (const char *)RDFormPost::urlEncode(user->name()),
-	      (const char *)RDFormPost::urlEncode(user->password()),
-	      cart_num,
-	      cutname.right(3).toUInt());
+    curl_formadd(&first,&last,CURLFORM_PTRNAME,"COMMAND",
+		 CURLFORM_COPYCONTENTS,
+		 (const char *)QString().sprintf("%u",RDXPORT_COMMAND_DELETEAUDIO),
+	       CURLFORM_END);
+    curl_formadd(&first,&last,CURLFORM_PTRNAME,"LOGIN_NAME",
+		 CURLFORM_COPYCONTENTS,(const char *)user->name().utf8(),CURLFORM_END);
+    curl_formadd(&first,&last,CURLFORM_PTRNAME,"PASSWORD",
+		 CURLFORM_COPYCONTENTS,(const char *)user->password().utf8(),
+		 CURLFORM_END);
+    curl_formadd(&first,&last,CURLFORM_PTRNAME,"CART_NUMBER",
+		 CURLFORM_COPYCONTENTS,
+		 (const char *)QString().sprintf("%u",cart_num),
+		 CURLFORM_END);
+    curl_formadd(&first,&last,CURLFORM_PTRNAME,"CUT_NUMBER",
+		 CURLFORM_COPYCONTENTS,
+		 (const char *)QString().sprintf("%u",RDCut::cutNumber(cutname)),
+		 CURLFORM_END);
     if((curl=curl_easy_init())==NULL) {
+      curl_formfree(first);
       return false;
     }
     //
@@ -1639,8 +1742,9 @@ bool RDCart::removeCutAudio(RDStation *station,RDUser *user,unsigned cart_num,
     //
     strncpy(url,station->webServiceUrl(config),1024);
     curl_easy_setopt(curl,CURLOPT_URL,url);
-    curl_easy_setopt(curl,CURLOPT_POST,1);
-    curl_easy_setopt(curl,CURLOPT_POSTFIELDS,(const char *)post);
+    curl_easy_setopt(curl,CURLOPT_HTTPPOST,first);
+    curl_easy_setopt(curl,CURLOPT_USERAGENT,
+		     (const char *)rda->config()->userAgent());
     curl_easy_setopt(curl,CURLOPT_TIMEOUT,RD_CURL_TIMEOUT);
     curl_easy_setopt(curl,CURLOPT_WRITEFUNCTION,CartWriteCallback);
     curl_easy_setopt(curl,CURLOPT_WRITEDATA,&xml);
@@ -1648,15 +1752,14 @@ bool RDCart::removeCutAudio(RDStation *station,RDUser *user,unsigned cart_num,
     curl_easy_getinfo(curl,CURLINFO_RESPONSE_CODE,&response_code);
     ret&=response_code==200;
     curl_easy_cleanup(curl);
+    curl_formfree(first);
   }
-#endif  // WIN32
   return ret;
 }
 
 
 void RDCart::removePending(RDStation *station,RDUser *user,RDConfig *config)
 {
-#ifndef WIN32
   QString sql;
   RDSqlQuery *q;
 
@@ -1668,7 +1771,6 @@ void RDCart::removePending(RDStation *station,RDUser *user,RDConfig *config)
     
   }
   delete q;
-#endif  // WIN32
 }
 
 
@@ -1686,13 +1788,13 @@ unsigned RDCart::readXml(std::vector<RDWaveData> *data,const QString &xml)
   int istate=0;
   RDWaveData cartdata;
   RDSettings *settings=NULL;
-  QStringList f0=f0.split("\n",xml);
+  QStringList f0=xml.split("\n");
 
-  for(unsigned i=0;i<f0.size();i++) {
-    f0[i]=f0[i].stripWhiteSpace();
+  for(int i=0;i<f0.size();i++) {
+    f0[i]=f0[i].trimmed();
   }
 
-  for(unsigned i=0;i<f0.size();i++) {
+  for(int i=0;i<f0.size();i++) {
     switch(istate) {
     case 0:
       if(f0[i]=="<cart>") {
@@ -1786,6 +1888,18 @@ unsigned RDCart::readXml(std::vector<RDWaveData> *data,const QString &xml)
 					   toString()));
 	cartdata.setMetadataFound(true);
       }
+      if(f0[i].contains("<minimumTalkLength>")) {
+	cartdata.
+	  setMinimumTalkLength(RDSetTimeLength(GetXmlValue("minimumTalkLength",f0[i]).
+					   toString()));
+	cartdata.setMetadataFound(true);
+      }
+      if(f0[i].contains("<maximumTalkLength>")) {
+	cartdata.
+	  setMaximumTalkLength(RDSetTimeLength(GetXmlValue("maximumTalkLength",f0[i]).
+					   toString()));
+	cartdata.setMetadataFound(true);
+      }
       if(f0[i].contains("<cutQuantity>")) {
 	cartdata.setCutQuantity(GetXmlValue("cutQuantity",f0[i]).toInt());
 	cartdata.setMetadataFound(true);
@@ -1946,12 +2060,12 @@ unsigned RDCart::readXml(std::vector<RDWaveData> *data,const QString &xml)
 	cartdata.setMetadataFound(true);
       }
       if(f0[i].contains("<talkStartPoint>")) {
-	data->back().setIntroStartPos(GetXmlValue("talkStartPoint",f0[i]).
+	data->back().setTalkStartPos(GetXmlValue("talkStartPoint",f0[i]).
 				      toInt());
 	cartdata.setMetadataFound(true);
       }
       if(f0[i].contains("<talkEndPoint>")) {
-	data->back().setIntroEndPos(GetXmlValue("talkEndPoint",f0[i]).toInt());
+	data->back().setTalkEndPos(GetXmlValue("talkEndPoint",f0[i]).toInt());
 	cartdata.setMetadataFound(true);
       }
       if(f0[i].contains("<hookStartPoint>")) {
@@ -2011,6 +2125,21 @@ QString RDCart::uniqueCartTitle(unsigned cartnum)
 }
 
 
+bool RDCart::titleIsUnique(unsigned except_cartnum,const QString &str)
+{
+  bool ret=false;
+
+  QString sql=QString("select NUMBER from CART where ")+
+    "(TITLE=\""+RDEscapeString(str)+"\")&&"+
+    QString().sprintf("NUMBER!=%u",except_cartnum);
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  ret=!q->first();
+  delete q;
+
+  return ret;
+}
+
+
 QVariant RDCart::GetXmlValue(const QString &tag,const QString &line)
 {
   bool ok=false;
@@ -2178,9 +2307,9 @@ QString RDCart::VerifyTitle(const QString &title) const
   if(!system->allowDuplicateCartTitles()) {
     int n=1;
     while(1==1) {
-      sql=QString().sprintf("select NUMBER from CART \
-                             where (TITLE=\"%s\")&&(NUMBER!=%u)",
-			    (const char *)RDEscapeString(ret),cart_number);
+      sql=QString("select NUMBER from CART where ")+
+	"(TITLE=\""+RDEscapeString(ret)+"\")&&"+
+	QString().sprintf("(NUMBER!=%u)",cart_number);
       q=new RDSqlQuery(sql);
       if(!q->first()) {
 	delete q;
@@ -2200,10 +2329,9 @@ void RDCart::SetRow(const QString &param,const QString &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE CART SET %s=\"%s\" WHERE NUMBER=%u",
-			(const char *)param,
-			(const char *)RDEscapeString(value.utf8()),
-			cart_number);
+  sql=QString("update CART set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    QString().sprintf("NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -2214,10 +2342,8 @@ void RDCart::SetRow(const QString &param,unsigned value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE CART SET %s=%d WHERE NUMBER=%u",
-			(const char *)param,
-			value,
-			cart_number);
+  sql=QString("update CART set ")+
+    param+QString().sprintf("=%d where NUMBER=%u",value,cart_number);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -2228,10 +2354,9 @@ void RDCart::SetRow(const QString &param,const QDateTime &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE CART SET %s=%s WHERE NUMBER=%u",
-			(const char *)param,
-			(const char *)RDCheckDateTime(value,"yyyy-MM-dd hh:mm:ss"),
-			cart_number);
+  sql=QString("update CART set ")+
+    param+"="+RDCheckDateTime(value,"yyyy-MM-dd hh:mm:ss")+" where "+
+    QString().sprintf("NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -2242,10 +2367,9 @@ void RDCart::SetRow(const QString &param,const QDate &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE CART SET %s=%s WHERE NUMBER=%u",
-			(const char *)param,
-			(const char *)RDCheckDateTime(value,"yyyy-MM-dd"),
-			cart_number);
+  sql=QString("update CART set ")+
+    param+"="+RDCheckDateTime(value,"yyyy-MM-dd")+" where "+
+    QString().sprintf("NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -2256,9 +2380,9 @@ void RDCart::SetRow(const QString &param) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE CART SET %s=NULL WHERE NUMBER=%u",
-			(const char *)param,
-			cart_number);
+  sql=QString("update CART set ")+
+    param+"=NULL where "+
+    QString().sprintf("NUMBER=%u",cart_number);
   q=new RDSqlQuery(sql);
   delete q;
 }
