@@ -99,6 +99,10 @@ class RDCart
   unsigned calculateAverageLength(unsigned *max_dev=0) const;
   unsigned averageLength() const;
   void setAverageLength(unsigned length) const;
+  unsigned minimumTalkLength() const;
+  void setMinimumTalkLength(unsigned length) const;
+  unsigned maximumTalkLength() const;
+  void setMaximumTalkLength(unsigned length) const;
   unsigned averageSegueLength() const;
   void setAverageSegueLength(unsigned length) const;
   unsigned averageHookLength() const;
@@ -149,8 +153,9 @@ class RDCart
 		 RDConfig *config);
   bool removeCutAudio(RDStation *station,RDUser *user,
 		      const QString &cutname,RDConfig *config);
-  bool create(const QString &groupname,RDCart::Type type);
   bool remove(RDStation *station,RDUser *user,RDConfig *config) const;
+  static unsigned create(const QString &groupname,RDCart::Type type,
+			 QString *err_msg,unsigned cartnum=0);
   static QString xmlSql(bool include_cuts);
   static QString xml(RDSqlQuery *q,bool include_cuts,bool absolute,
 		     RDSettings *settings=NULL,int cutnum=-1);
