@@ -2,9 +2,7 @@
 //
 // A widget to select a Rivendell Cart.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcart_dialog.cpp,v 1.48.4.8 2014/02/11 23:46:25 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,27 +21,23 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qsqlquery.h>
-#include <qdatetime.h>
+#include <q3filedialog.h>
+
 #include <qapplication.h>
-#include <qeventloop.h>
-#include <qfiledialog.h>
 #include <qmessagebox.h>
 
-#include <rdconf.h>
-#include <rdcart_dialog.h>
-#include <rdcart_search_text.h>
-#include <rdtextvalidator.h>
-#include <rdprofile.h>
-#include <rddb.h>
-#include <rdgroup.h>
-#ifndef WIN32
-#include <rdaudioimport.h>
-#endif  // WIN32
-#include <rdsettings.h>
-#include <rdwavefile.h>
+#include "rdapplication.h"
+#include "rdaudioimport.h"
+#include "rdcart_dialog.h"
+#include "rdcart_search_text.h"
+#include "rdconf.h"
+#include "rddb.h"
+#include "rdescape_string.h"
+#include "rdgroup.h"
+#include "rdprofile.h"
+#include "rdsettings.h"
+#include "rdtextvalidator.h"
+#include "rdwavefile.h"
 
 //
 // Icons
@@ -52,9 +46,8 @@
 #include "../icons/rml5.xpm"
 
 RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
-			   RDCae *cae,RDRipc *ripc,RDStation *station,
-			   RDSystem *system,RDConfig *config,QWidget *parent)
-  : QDialog(parent,"",true)
+			   QWidget *parent)
+  : RDDialog(parent)
 {
   //
   // Fix the Window Size
@@ -62,19 +55,15 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   setMinimumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
 
-  cart_station=station;
-  cart_system=system;
-  cart_config=config;
   cart_cartnum=NULL;
   cart_type=RDCart::All;
   cart_group=group;
   cart_schedcode=schedcode;
+  if(cart_schedcode->isNull()) {
+    *cart_schedcode=tr("ALL");
+  }
   cart_temp_allowed=NULL;
-#ifdef WIN32
-  cart_filter_mode=RDStation::FilterSynchronous;
-#else
-  cart_filter_mode=station->filterMode();
-#endif  // WIN32
+  cart_filter_mode=rda->station()->filterMode();
 
   if(filter==NULL) {
     cart_filter=new QString();
@@ -87,15 +76,7 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   cart_import_path=RDGetHomeDir();
   cart_import_file_filter=RD_AUDIO_FILE_FILTER;
 
-  setCaption(tr("Select Cart"));
-
-  // 
-  // Create Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont progress_font=QFont("Helvetica",16,QFont::Bold);
-  progress_font.setPixelSize(16);
+  setWindowTitle(tr("Select Cart"));
 
   //
   // Create Icons
@@ -112,13 +93,13 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   // Progress Dialog
   //
   cart_progress_dialog=
-    new QProgressDialog(tr("Please Wait..."),"Cancel",10,this,
+    new Q3ProgressDialog(tr("Please Wait..."),"Cancel",10,this,
 			"cart_progress_dialog",false,
 			Qt::WStyle_Customize|Qt::WStyle_NormalBorder);
   cart_progress_dialog->setCaption(" ");
   QLabel *label=new QLabel(tr("Please Wait..."),cart_progress_dialog);
-  label->setAlignment(AlignCenter);
-  label->setFont(progress_font);
+  label->setAlignment(Qt::AlignCenter);
+  label->setFont(progressFont());
   cart_progress_dialog->setLabel(label);
   cart_progress_dialog->setCancelButton(NULL);
   cart_progress_dialog->setMinimumDuration(2000);
@@ -130,10 +111,9 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   //
   cart_filter_edit=new QLineEdit(this);
   cart_filter_edit->setValidator(validator);
-  cart_filter_label=new QLabel(cart_filter_edit,tr("Cart Filter:"),
-		   this,"cart_filter_label");
-  cart_filter_label->setAlignment(AlignRight|AlignVCenter);
-  cart_filter_label->setFont(button_font);
+  cart_filter_label=new QLabel(cart_filter_edit,tr("Cart Filter:"),this);
+  cart_filter_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+  cart_filter_label->setFont(labelFont());
   connect(cart_filter_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(filterChangedData(const QString &)));
 
@@ -142,7 +122,7 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   //
   cart_search_button=new QPushButton(this);
   cart_search_button->setText(tr("&Search"));
-  cart_search_button->setFont(button_font);
+  cart_search_button->setFont(buttonFont());
   connect(cart_search_button,SIGNAL(clicked()),this,SLOT(filterSearchedData()));
 
   //
@@ -150,7 +130,7 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   //
   cart_clear_button=new QPushButton(this);
   cart_clear_button->setText(tr("C&lear"));
-  cart_clear_button->setFont(button_font);
+  cart_clear_button->setFont(buttonFont());
   connect(cart_clear_button,SIGNAL(clicked()),this,SLOT(filterClearedData()));
 
   //
@@ -158,8 +138,8 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   //
   cart_group_box=new RDComboBox(this);
   cart_group_label=new QLabel(cart_group_box,tr("Group:"),this);
-  cart_group_label->setAlignment(AlignRight|AlignVCenter);
-  cart_group_label->setFont(button_font);
+  cart_group_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+  cart_group_label->setFont(labelFont());
   connect(cart_group_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(groupActivatedData(const QString &)));
 
@@ -169,8 +149,8 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   cart_schedcode_box=new RDComboBox(this);
   cart_schedcode_label=
     new QLabel(cart_schedcode_box,tr("Scheduler Code:"),this);
-  cart_schedcode_label->setAlignment(AlignRight|AlignVCenter);
-  cart_schedcode_label->setFont(button_font);
+  cart_schedcode_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+  cart_schedcode_label->setFont(labelFont());
   connect(cart_schedcode_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(schedcodeActivatedData(const QString &)));
 
@@ -183,8 +163,8 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
     new QLabel(cart_limit_box,tr("Show Only First")+
 	       QString().sprintf(" %d ",
 		      RD_LIMITED_CART_SEARCH_QUANTITY)+tr("Matches"),this);
-  cart_limit_label->setAlignment(AlignLeft|AlignVCenter);
-  cart_limit_label->setFont(button_font);
+  cart_limit_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
+  cart_limit_label->setFont(labelFont());
   connect(cart_limit_box,SIGNAL(stateChanged(int)),
 	  this,SLOT(limitChangedData(int)));
 
@@ -192,82 +172,80 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   // Cart List
   //
   cart_cart_list=new RDListView(this);
-  cart_cart_list->setSelectionMode(QListView::Single);
+  cart_cart_list->setSelectionMode(Q3ListView::Single);
   cart_cart_list->setAllColumnsShowFocus(true);
   cart_cart_list->setItemMargin(5);
-  connect(cart_cart_list,SIGNAL(clicked(QListViewItem *)),
-	  this,SLOT(clickedData(QListViewItem *)));
+  connect(cart_cart_list,SIGNAL(clicked(Q3ListViewItem *)),
+	  this,SLOT(clickedData(Q3ListViewItem *)));
   connect(cart_cart_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
   cart_cart_label=new QLabel(cart_cart_list,"Carts",this);
-  cart_cart_label->setFont(button_font);
+  cart_cart_label->setFont(labelFont());
   cart_cart_list->addColumn("");
   cart_cart_list->setColumnAlignment(0,Qt::AlignHCenter);
 
-  cart_cart_list->addColumn(tr("NUMBER"));
+  cart_cart_list->addColumn(tr("Number"));
   cart_cart_list->setColumnAlignment(1,Qt::AlignHCenter);
 
-  cart_cart_list->addColumn(tr("LENGTH"));
+  cart_cart_list->addColumn(tr("Length"));
   cart_cart_list->setColumnAlignment(2,Qt::AlignRight);
   cart_cart_list->setColumnSortType(2,RDListView::TimeSort);
 
-  cart_cart_list->addColumn(tr("TITLE"),200);
+  cart_cart_list->addColumn(tr("Title"),200);
   cart_cart_list->setColumnAlignment(3,Qt::AlignLeft);
-  cart_cart_list->setColumnWidthMode(3,QListView::Manual);
+  cart_cart_list->setColumnWidthMode(3,Q3ListView::Manual);
 
-  cart_cart_list->addColumn(tr("ARTIST"));
+  cart_cart_list->addColumn(tr("Artist"));
   cart_cart_list->setColumnAlignment(4,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("GROUP"));
+  cart_cart_list->addColumn(tr("Group"));
   cart_cart_list->setColumnAlignment(5,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("COMPOSER"));
+  cart_cart_list->addColumn(tr("Composer"));
   cart_cart_list->setColumnAlignment(6,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("CONDUCTOR"));
+  cart_cart_list->addColumn(tr("Conductor"));
   cart_cart_list->setColumnAlignment(7,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("CLIENT"));
+  cart_cart_list->addColumn(tr("Client"));
   cart_cart_list->setColumnAlignment(8,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("AGENCY"));
+  cart_cart_list->addColumn(tr("Agency"));
   cart_cart_list->setColumnAlignment(9,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("USER DEF"));
+  cart_cart_list->addColumn(tr("User Def"));
   cart_cart_list->setColumnAlignment(10,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("START"));
+  cart_cart_list->addColumn(tr("Start"));
   cart_cart_list->setColumnAlignment(11,Qt::AlignLeft);
 
-  cart_cart_list->addColumn(tr("END"));
+  cart_cart_list->addColumn(tr("End"));
   cart_cart_list->setColumnAlignment(12,Qt::AlignLeft);
 
   //
   // Audition Player
   //
-#ifndef WIN32
-  if((cae==NULL)||(station->cueCard()<0)||(station->cuePort()<0)) {
+  if((rda->station()->cueCard()<0)||(rda->station()->cuePort()<0)) {
     cart_player=NULL;
   }
   else {
     cart_player=
-      new RDSimplePlayer(cae,ripc,station->cueCard(),station->cuePort(),
-			 station->cueStartCart(),station->cueStopCart(),this);
+      new RDSimplePlayer(rda->cae(),rda->ripc(),rda->station()->cueCard(),rda->station()->cuePort(),
+			 rda->station()->cueStartCart(),rda->station()->cueStopCart(),this);
     cart_player->playButton()->setDisabled(true);
     cart_player->stopButton()->setDisabled(true);
-    cart_player->stopButton()->setOnColor(red);
+    cart_player->stopButton()->setOnColor(Qt::red);
   }
-#endif  // WIN32
 
   //
   // Send to Editor Button
   //
   cart_editor_button=new QPushButton(tr("Send to\n&Editor"),this);
-  cart_editor_button->setFont(button_font);
+  cart_editor_button->setFont(buttonFont());
   connect(cart_editor_button,SIGNAL(clicked()),this,SLOT(editorData()));
-  if(station->editorPath().isEmpty()) {
+  if(rda->station()->editorPath().isEmpty()) {
     cart_editor_button->hide();
   }
 
@@ -275,27 +253,24 @@ RDCartDialog::RDCartDialog(QString *filter,QString *group,QString *schedcode,
   // Load From File Button
   //
   cart_file_button=new QPushButton(tr("Load From\n&File"),this);
-  cart_file_button->setFont(button_font);
+  cart_file_button->setFont(buttonFont());
   connect(cart_file_button,SIGNAL(clicked()),this,SLOT(loadFileData()));
-  if(station->editorPath().isEmpty()) {
+  if(rda->station()->editorPath().isEmpty()) {
     cart_file_button->hide();
   }
-#ifdef WIN32
-  cart_file_button->hide();
-#endif  // WIN32
 
   //
   // OK Button
   //
   cart_ok_button=new QPushButton(tr("&OK"),this);
-  cart_ok_button->setFont(button_font);
+  cart_ok_button->setFont(buttonFont());
   connect(cart_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   // Cancel Button
   //
   cart_cancel_button=new QPushButton(tr("&Cancel"),this);
-  cart_cancel_button->setFont(button_font);
+  cart_cancel_button->setFont(buttonFont());
   connect(cart_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 }
 
@@ -305,11 +280,9 @@ RDCartDialog::~RDCartDialog()
   if(local_filter) {
     delete cart_filter;
   }
-#ifndef WIN32
   if(cart_player!=NULL) {
     delete cart_player;
   }
-#endif  // WIN32
   delete cart_playout_map;
   delete cart_macro_map;
 }
@@ -335,7 +308,7 @@ int RDCartDialog::exec(int *cartnum,RDCart::Type type,QString *svcname,
   switch(cart_type) {
     case RDCart::All:
     case RDCart::Audio:
-      if(cart_station->editorPath().isEmpty()) {
+      if(rda->station()->editorPath().isEmpty()) {
 	cart_editor_button->hide();
       }
       else {
@@ -347,22 +320,18 @@ int RDCartDialog::exec(int *cartnum,RDCart::Type type,QString *svcname,
       else {
 	cart_file_button->show();
       }
-#ifndef WIN32
       if(cart_player!=NULL) {
 	cart_player->playButton()->show();
 	cart_player->stopButton()->show();
       }
-#endif  // WIN32
       break;
 
     case RDCart::Macro:
       cart_editor_button->hide();
-#ifndef WIN32
       if(cart_player!=NULL) {
 	cart_player->playButton()->hide();
 	cart_player->stopButton()->hide();
       }
-#endif  // WIN32
       break;
   }
   if(*cart_cartnum==0) {
@@ -390,6 +359,7 @@ int RDCartDialog::exec(int *cartnum,RDCart::Type type,QString *svcname,
     }
     item=(RDListViewItem *)item->nextSibling();
   }
+  cart_filter_edit->setFocus();
   return QDialog::exec();
 }
 
@@ -439,9 +409,6 @@ void RDCartDialog::groupActivatedData(const QString &group)
   if(cart_group!=NULL) {
     *cart_group=group;
   }
-  if(cart_group!=NULL) {
-    *cart_group=group;
-  }
 }
 
 
@@ -463,7 +430,7 @@ void RDCartDialog::limitChangedData(int state)
 }
 
 
-void RDCartDialog::clickedData(QListViewItem *item)
+void RDCartDialog::clickedData(Q3ListViewItem *item)
 {
   RDListViewItem *i=(RDListViewItem *)item;
   if (i==NULL) {
@@ -471,18 +438,16 @@ void RDCartDialog::clickedData(QListViewItem *item)
   }
   cart_ok_button->setEnabled(true);
   bool audio=((RDCart::Type)i->id())==RDCart::Audio;
-#ifndef WIN32
   if(cart_player!=NULL) {
     cart_player->playButton()->setEnabled(audio);
     cart_player->stopButton()->setEnabled(audio);
     cart_player->setCart(i->text(1).toUInt());
   }
-#endif  // WIN32
   cart_editor_button->setEnabled(audio);
 }
 
 
-void RDCartDialog::doubleClickedData(QListViewItem *,const QPoint &,int)
+void RDCartDialog::doubleClickedData(Q3ListViewItem *,const QPoint &,int)
 {
   okData();
 }
@@ -490,7 +455,6 @@ void RDCartDialog::doubleClickedData(QListViewItem *,const QPoint &,int)
 
 void RDCartDialog::editorData()
 {
-#ifndef WIN32
   RDListViewItem *item=(RDListViewItem *)cart_cart_list->currentItem();
   if(item==NULL) {
     return;
@@ -512,7 +476,7 @@ void RDCartDialog::editorData()
     delete q;
     return;
   }
-  QString cmd=cart_station->editorPath();
+  QString cmd=rda->station()->editorPath();
   cmd.replace("%f",RDCut::pathName(q->value(0).toString()));
   cmd.replace("%n",QString().sprintf("%06u",item->text(1).toUInt()));
   cmd.replace("%h",QString().sprintf("%d",q->value(1).toInt()));
@@ -533,15 +497,12 @@ void RDCartDialog::editorData()
     system(cmd+" &");
     exit(0);
   }
-#endif
 }
 
 
 void RDCartDialog::loadFileData()
 {
-#ifndef WIN32
   QString filename;
-  RDGroup *group=NULL;
   RDCart *cart=NULL;
   RDCut *cut=NULL;
   RDAudioImport *conv;
@@ -552,42 +513,33 @@ void RDCartDialog::loadFileData()
   QString file_title="";
   RDWaveFile *wavefile=NULL;
   RDWaveData wavedata;
+  QString err_msg;
 
-  filename=QFileDialog::getOpenFileName(cart_import_path,
+  filename=Q3FileDialog::getOpenFileName(cart_import_path,
 					cart_import_file_filter,this);
   if(!filename.isEmpty()) {
-
-    //
-    // Get Cart Number
-    //
     cart_import_path=RDGetPathPart(filename);
-    group=new RDGroup(cart_system->tempCartGroup());
-    if((!group->exists())||((cartnum=group->nextFreeCart())==0)) {
-      delete group;
-      QMessageBox::warning(this,tr("Cart Error"),
-		       tr("Unable to get temporary cart number for import!"));
-      return;
-    }
-    delete group;
 
     //
     // Create Cart
     //
-    cart=new RDCart(cartnum);
-    if(!cart->create(cart_system->tempCartGroup(),RDCart::Audio)) {
+    if((cartnum=RDCart::create(rda->system()->tempCartGroup(),RDCart::Audio,
+			       &err_msg))==0) {
       delete cart;
       QMessageBox::warning(this,tr("Cart Error"),
-			   tr("Unable to create temporary cart for import!"));
+			   tr("Unable to create temporary cart for import!")+
+			   "["+err_msg+"]");
       return;
     }
-    cart->setOwner(cart_station->name());
+    cart=new RDCart(cartnum);
+    cart->setOwner(rda->station()->name());
     cut=new RDCut(cartnum,1,true);
 
     //
     // Import Audio
     //
     cart_busy_dialog->show(tr("Importing"),tr("Importing..."));
-    conv=new RDAudioImport(cart_station,cart_config,this);
+    conv=new RDAudioImport(this);
     conv->setCartNumber(cartnum);
     conv->setCutNumber(1);
     conv->setSourceFile(filename);
@@ -627,7 +579,6 @@ void RDCartDialog::loadFileData()
     delete cut;
     done(0);
   }
-#endif  // WIN32
 }
 
 
@@ -638,12 +589,10 @@ void RDCartDialog::okData()
     return;
   }
 
-#ifndef WIN32
   SaveState();
   if(cart_player!=NULL) {
     cart_player->stop();
   }
-#endif  // WIN32
   if(!local_filter) {
     *cart_filter=cart_filter_edit->text();
   }
@@ -657,12 +606,10 @@ void RDCartDialog::okData()
 
 void RDCartDialog::cancelData()
 {
-#ifndef WIN32
   SaveState();
   if(cart_player!=NULL) {
     cart_player->stop();
   }
-#endif  // WIN32
   done(-1);
 }
 
@@ -694,22 +641,18 @@ void RDCartDialog::resizeEvent(QResizeEvent *e)
       cart_filter_edit->setGeometry(100,10,size().width()-200,20);
       break;
   }
-#ifndef WIN32
   if(cart_player!=NULL) {
     cart_player->playButton()->setGeometry(10,size().height()-60,80,50);
     cart_player->stopButton()->setGeometry(100,size().height()-60,80,50);
   }
-#endif  // WIN32
 }
 
 
 void RDCartDialog::closeEvent(QCloseEvent *e)
 {
-#ifndef WIN32
   if(cart_player!=NULL) {
     cart_player->stop();
   }
-#endif  // WIN32
   cancelData();
 }
 
@@ -719,7 +662,6 @@ void RDCartDialog::RefreshCarts()
   QString sql;
   RDSqlQuery *q;
   RDListViewItem *l;
-  RDListViewItem *active_item=NULL;
 
   cart_cart_list->clear();
   QString group=cart_group_box->currentText();
@@ -727,32 +669,49 @@ void RDCartDialog::RefreshCarts()
     group="";
   }
   QString schedcode=cart_schedcode_box->currentText();
-  if(group==QString(tr("ALL"))) {
+  if(schedcode==QString(tr("ALL"))) {
     schedcode="";
   }
   if(cart_type==RDCart::All) {
-    sql=QString().sprintf("select CART.NUMBER,CART.TITLE,CART.ARTIST,\
-                           CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
-                           CART.COMPOSER,CART.CONDUCTOR,\
-                           CART.START_DATETIME,CART.END_DATETIME,CART.TYPE,\
-                           CART.FORCED_LENGTH,CART.GROUP_NAME,GROUPS.COLOR \
-                           from CART left join GROUPS \
-                           on CART.GROUP_NAME=GROUPS.NAME where %s",
-		 (const char *)GetSearchFilter(cart_filter_edit->text(),
-					       group,schedcode));
+    sql=QString("select ")+
+      "CART.NUMBER,"+          // 00
+      "CART.TITLE,"+           // 01
+      "CART.ARTIST,"+          // 02
+      "CART.CLIENT,"+          // 03
+      "CART.AGENCY,"+          // 04
+      "CART.USER_DEFINED,"+    // 05
+      "CART.COMPOSER,"+        // 06
+      "CART.CONDUCTOR,"+       // 07
+      "CART.START_DATETIME,"+  // 08
+      "CART.END_DATETIME,"+    // 09
+      "CART.TYPE,"+            // 10
+      "CART.FORCED_LENGTH,"+   // 11
+      "CART.GROUP_NAME,"+      // 12
+      "GROUPS.COLOR "+         // 13
+      "from CART left join GROUPS "+
+      "on CART.GROUP_NAME=GROUPS.NAME "+
+      GetSearchFilter(cart_filter_edit->text(),group,schedcode);
   }
   else {
-    sql=QString().sprintf("select CART.NUMBER,CART.TITLE,CART.ARTIST,\
-                           CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
-                           CART.COMPOSER,CART.CONDUCTOR,\
-                           CART.START_DATETIME,CART.END_DATETIME,CART.TYPE,\
-                           CART.FORCED_LENGTH,CART.GROUP_NAME,GROUPS.COLOR \
-                           from CART left join GROUPS \
-                           on CART.GROUP_NAME=GROUPS.NAME \
-                           where (%s)&&(TYPE=%d)",
-			(const char *)GetSearchFilter(cart_filter_edit->text(),
-						      group,schedcode),
-			  cart_type);
+    sql=QString("select ")+
+      "CART.NUMBER,"+          // 00
+      "CART.TITLE,"+           // 01
+      "CART.ARTIST,"+          // 02
+      "CART.CLIENT,"+          // 03
+      "CART.AGENCY,"+          // 04
+      "CART.USER_DEFINED,"+    // 05
+      "CART.COMPOSER,"+        // 06
+      "CART.CONDUCTOR,"+       // 07
+      "CART.START_DATETIME,"+  // 08
+      "CART.END_DATETIME,"+    // 09
+      "CART.TYPE,"+            // 10
+      "CART.FORCED_LENGTH,"+   // 11
+      "CART.GROUP_NAME,"+      // 12
+      "GROUPS.COLOR "+         // 13
+      "from CART left join GROUPS "+
+      "on CART.GROUP_NAME=GROUPS.NAME "+
+      GetSearchFilter(cart_filter_edit->text(),group,schedcode)+"&&"+
+      QString().sprintf("(TYPE=%d)",cart_type);
   }
   if(cart_limit_box->isChecked()) {
     sql+=QString().sprintf(" limit %d",RD_LIMITED_CART_SEARCH_QUANTITY);
@@ -797,13 +756,10 @@ void RDCartDialog::RefreshCarts()
     else {
       l->setText(12,"TFN");
     }
-    if(*cart_cartnum==q->value(0).toInt()) {
-      active_item=l;
-    }
     if(count++>RDCART_DIALOG_STEP_SIZE) {
       cart_progress_dialog->setProgress(++step);
       count=0;
-      qApp->eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+      QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
     }
   }
   cart_progress_dialog->reset();
@@ -827,8 +783,8 @@ void RDCartDialog::BuildGroupList()
     sql+=" where ";
     for(int i=0;i<cart_service_quan;i++) {
       if(!cart_service[i].isEmpty()) {
-	sql+=QString().sprintf("(SERVICE_NAME=\"%s\")||",
-			       (const char *)cart_service[i]);
+	sql+=QString("(SERVICE_NAME=\"")+
+	  RDEscapeString(cart_service[i])+"\")||";
       }
     }
     sql=sql.left(sql.length()-2);
@@ -847,7 +803,7 @@ void RDCartDialog::BuildGroupList()
     for(int i=0;i<cart_group_box->count();i++) {
       if(*cart_group==cart_group_box->text(i)) {
 	cart_group_box->setCurrentItem(i);
-	return;
+	break;
       }
     }
   }
@@ -871,7 +827,7 @@ void RDCartDialog::BuildGroupList()
     for(int i=0;i<cart_schedcode_box->count();i++) {
       if(*cart_schedcode==cart_schedcode_box->text(i)) {
 	cart_schedcode_box->setCurrentItem(i);
-	return;
+	break;
       }
     }
   }
@@ -889,34 +845,49 @@ QString RDCartDialog::GetSearchFilter(const QString &filter,
   if(schedcode!=tr("ALL")) {
     sched=schedcode;
   }
-  QString search=RDCartSearchText(filter,group,sched,false).utf8();
+  QString search=RDCartSearchText(filter,group,sched,false);
 
   //
   // Excluded Groups
   //
   sql=QString().sprintf("select NAME from GROUPS where ");
   for(int i=1;i<cart_group_box->count();i++) {
-    sql+=QString().sprintf("(NAME!=\"%s\")&&",
-			   (const char *)cart_group_box->text(i));
+    sql+=QString("(NAME!=\"")+RDEscapeString(cart_group_box->text(i))+"\")&&";
   }
   sql=sql.left(sql.length()-2);
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    search+=QString().sprintf("&&(GROUP_NAME!=\"%s\")",
-			      (const char *)q->value(0).toString());
+    search+=QString("&&(GROUP_NAME!=\"")+
+      RDEscapeString(q->value(0).toString())+"\")";
   }
   delete q;
   return search;
 }
 
+QString RDCartDialog::StateFile() {
+  bool home_found = false;
+  QString home = RDGetHomeDir(&home_found);
+  if (home_found) {
+    return home+"/.rdcartdialog";
+  } 
+  else {
+    return NULL;
+  }
+}
 
 void RDCartDialog::LoadState()
 {
-  if(getenv("HOME")==NULL) {
+  QString state_file=StateFile();
+  if (state_file.isEmpty()) {
     return;
   }
+
   RDProfile *p=new RDProfile();
-  p->setSource(QString().sprintf("%s/.rdcartdialog",getenv("HOME")));
+  p->setSource(state_file);
+
+  bool value_read = false;
+  cart_limit_box->setChecked(p->boolValue("RDCartDialog", "LimitSearch", true, &value_read));
+
   delete p;
 }
 
@@ -925,11 +896,12 @@ void RDCartDialog::SaveState()
 {
   FILE *f=NULL;
 
-  if(getenv("HOME")==NULL) {
+  QString state_file=StateFile();
+  if (state_file.isEmpty()) {
     return;
   }
-  if((f=fopen(QString().sprintf("%s/.rdcartdialog",getenv("HOME")),"w"))==
-    NULL) {
+
+  if((f=fopen(state_file,"w"))==NULL) {
     return;
   }
   fprintf(f,"[RDCartDialog]\n");
