@@ -2,7 +2,7 @@
 //
 // A widget to select a Rivendell Cart.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,35 +21,27 @@
 #ifndef RDCART_DIALOG_H
 #define RDCART_DIALOG_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include <qprogressdialog.h>
+#include <q3progressdialog.h>
 #include <qcheckbox.h>
 
-#include <rdcae.h>
-#include <rdconfig.h>
-#include <rdripc.h>
-#include <rdsystem.h>
-#include <rdsimpleplayer.h>
-#include <rdlistviewitem.h>
-#include <rdcart.h>
-#include <rdstation.h>
-#include <rdcombobox.h>
-#include <rduser.h>
 #include <rdbusydialog.h>
+#include <rdcart.h>
+#include <rdcombobox.h>
+#include <rddialog.h>
+#include <rdlistviewitem.h>
+#include <rdsimpleplayer.h>
 
 #define RDCART_DIALOG_STEP_SIZE 1000
 
-class RDCartDialog : public QDialog
+class RDCartDialog : public RDDialog
 {
  Q_OBJECT
  public:
   RDCartDialog(QString *filter,QString *group,QString *schedcode,
-	       RDCae *cae,RDRipc *ripc,RDStation *station,RDSystem *system,
-	       RDConfig *config,QWidget *parent=0);
-
+	       QWidget *parent=0);
   ~RDCartDialog();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -66,8 +58,8 @@ class RDCartDialog : public QDialog
   void groupActivatedData(const QString &group);
   void schedcodeActivatedData(const QString &schedcode);
   void limitChangedData(int state);
-  void clickedData(QListViewItem *item);
-  void doubleClickedData(QListViewItem *,const QPoint &,int);
+  void clickedData(Q3ListViewItem *item);
+  void doubleClickedData(Q3ListViewItem *,const QPoint &,int);
   void editorData();
   void loadFileData();
   void okData();
@@ -112,19 +104,14 @@ class RDCartDialog : public QDialog
   QString *cart_service;
   int cart_service_quan;
   RDStation::FilterMode cart_filter_mode;
-  QProgressDialog *cart_progress_dialog;
+  Q3ProgressDialog *cart_progress_dialog;
   QString cart_import_path;
   QString cart_import_file_filter;
   bool *cart_temp_allowed;
-  RDStation *cart_station;
-  RDSystem *cart_system;
-  RDConfig *cart_config;
   QString cart_user_name;
   QString cart_user_password;
   RDBusyDialog *cart_busy_dialog;
-#ifndef WIN32
   RDSimplePlayer *cart_player;
-#endif  // WIN32
 };
 
 
