@@ -2,7 +2,7 @@
 //
 // Stored value drag object for Rivendell carts.
 //
-//   (C) Copyright 2013,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2013-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,16 +22,18 @@
 #define RDCARTDRAG_H
 
 #include <qcolor.h>
-#include <qdragobject.h>
 #include <qpixmap.h>
 
+#include <q3dragobject.h>
+
 #include <rdcart.h>
 #include <rdlog_line.h>
 
-class RDCartDrag : public QStoredDrag
+class RDCartDrag : public Q3StoredDrag
 {
  public:
-  RDCartDrag(unsigned cartnum,const QPixmap *icon,QWidget *src=0);
+  RDCartDrag(unsigned cartnum,const QPixmap *icon,const QColor &color,
+	     QWidget *src=0);
   RDCartDrag(unsigned cartnum,const QString &title,const QColor &color,
 	     QWidget *src=0);
   static bool canDecode(QMimeSource *e);
