@@ -2,7 +2,7 @@
 //
 // Process Rivendell Command-Line Switches
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,64 +18,47 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef WIN32
+#include <stdio.h>
 #include <syslog.h>
-#endif  // WIN32
-
 #include <stdlib.h>
-#include <rdcmd_switch.h>
+
 #include <qmessagebox.h>
 
+#include <rdcmd_switch.h>
+
 RDCmdSwitch::RDCmdSwitch(int argc,char *argv[],const char *modname,
 			 const char *usage)
 {
-  unsigned l=0;
-  bool handled=false;
-  bool debug=false;
+  switch_debug=false;
 
   for(int i=1;i<argc;i++) {
-#ifndef WIN32
-    if(!strcmp(argv[i],"--version")) {
+    QString value=QString::fromUtf8(argv[i]);
+    if(value=="--version") {
       printf("Rivendell v%s [%s]\n",VERSION,modname);
       exit(0);
     }
-#endif  // WIN32
-    if(!strcmp(argv[i],"--help")) {
+    if(value=="--help") {
       printf("\n%s %s\n",modname,usage);
       exit(0);
     }
-    if(!strcmp(argv[i],"-d")) {
-      debug=true;
+    if(value=="-d") {
+      switch_debug=true;
     }
-    l=strlen(argv[i]);
-    handled=false;
-    for(unsigned j=0;j<l;j++) {
-      if(argv[i][j]=='=') {
-	switch_keys.push_back(QString(argv[i]).left(j));
-	switch_values.push_back(QString(argv[i]).right(l-(j+1)));
-	switch_processed.push_back(false);
-	j=l;
-	handled=true;
+    QStringList f0=value.split("=");
+    if(f0.size()>=2) {
+      switch_keys.push_back(f0[0]);
+      for(int i=2;i<f0.size();i++) {
+	f0[1]+="="+f0[i];
       }
+      switch_values.push_back(f0[1]);
+      switch_processed.push_back(false);
     }
-    if(!handled) {
-      switch_keys.push_back(QString(argv[i]));
-      switch_values.push_back(QString(""));
+    else {
+      switch_keys.push_back(value);
+      switch_values.push_back("");
       switch_processed.push_back(false);
     }
   }
-
-  //
-  // Initialize Logging
-  //
-#ifndef WIN32
-  if(debug) {
-    openlog(modname,LOG_PERROR,LOG_USER);
-  }
-  else {
-    openlog(modname,0,LOG_USER);
-  }
-#endif  // WIN32
 }
 
 
@@ -118,3 +101,9 @@ bool RDCmdSwitch::allProcessed() const
   }
   return true;
 }
+
+
+bool RDCmdSwitch::debugActive() const
+{
+  return switch_debug;
+}
