@@ -2,9 +2,7 @@
 //
 // Cueing Editor for RDLogLine-based Events
 //
-//   (C) Copyright 2013 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcueedit.cpp,v 1.1.2.3.2.1 2014/05/20 01:45:16 cvs Exp $
+//   (C) Copyright 2013-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,12 +21,13 @@
 #include <qpainter.h>
 #include <qmessagebox.h>
 
-#include <rdconf.h>
-#include <rdcueedit.h>
+#include <q3frame.h>
 
-RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,
-		     QWidget *parent,const char *name)
-  : QWidget(parent,name)
+#include "rdconf.h"
+#include "rdcueedit.h"
+
+RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,QWidget *parent)
+  : RDWidget(parent)
 {
   edit_cae=cae;
   edit_play_card=card;
@@ -41,18 +40,6 @@ RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,
   edit_start_rml="";
   edit_stop_rml="";
 
-  //
-  // Create Fonts
-  //
-  QFont radio_font=QFont("Helvetica",10,QFont::Normal);
-  radio_font.setPixelSize(10);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont counter_font=QFont("Helvetica",20,QFont::Bold);
-  counter_font.setPixelSize(20);
-
   //
   // Create Palettes
   //
@@ -61,32 +48,32 @@ RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,
   edit_start_color=palette();
   edit_start_color.setColor(QColorGroup::Foreground,RD_CUEEDITOR_START_MARKER);
 
-  edit_position_label=new QLabel(this,"edit_position_label");
+  edit_position_label=new QLabel(this);
   edit_position_label->setGeometry(0,0,sizeHint().width()-30,30);
-  edit_position_label->setBackgroundColor(QColor(white));
+  edit_position_label->setBackgroundColor(QColor(Qt::white));
   edit_position_label->setLineWidth(1);
   edit_position_label->setMidLineWidth(0);
-  edit_position_label->setFrameStyle(QFrame::Box|QFrame::Plain);
+  edit_position_label->setFrameStyle(Q3Frame::Box|Q3Frame::Plain);
 
-  edit_position_bar=new RDMarkerBar(this,"edit_position_bar");
+  edit_position_bar=new RDMarkerBar(this);
   edit_position_bar->setGeometry(85,8,sizeHint().width()-200,14);
 
-  edit_up_label=new QLabel("00:00:00",this,"edit_up_label");
+  edit_up_label=new QLabel("00:00:00",this);
   edit_up_label->setGeometry(5,8,70,14);
-  edit_up_label->setBackgroundColor(white);
-  edit_up_label->setFont(label_font);
-  edit_up_label->setAlignment(AlignRight|AlignVCenter);
+  edit_up_label->setBackgroundColor(Qt::white);
+  edit_up_label->setFont(labelFont());
+  edit_up_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
-  edit_down_label=new QLabel("00:00:00",this,"edit_down_label");
+  edit_down_label=new QLabel("00:00:00",this);
   edit_down_label->setGeometry(sizeHint().width()-110,8,70,14);
-  edit_down_label->setBackgroundColor(white);
-  edit_down_label->setFont(label_font);
-  edit_down_label->setAlignment(AlignRight|AlignVCenter);
+  edit_down_label->setBackgroundColor(Qt::white);
+  edit_down_label->setFont(labelFont());
+  edit_down_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Position Slider
   //
-  edit_slider=new RDSlider(RDSlider::Right,this,"edit_slider");
+  edit_slider=new RDSlider(RDSlider::Right,this);
   edit_slider->setGeometry(60,30,sizeHint().width()-150,50);
   edit_slider->setKnobSize(50,50);
   edit_slider->setKnobColor(QColor(RD_CUEEDITOR_KNOB_COLOR));
@@ -99,62 +86,60 @@ RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,
   //
   // Button Area
   //
-  QLabel *label=new QLabel(this,"button_area");
+  QLabel *label=new QLabel(this);
   label->setGeometry(0,85,sizeHint().width()-30,60);
-  label->setBackgroundColor(QColor(gray));
+  label->setBackgroundColor(QColor(Qt::gray));
   label->setLineWidth(1);
   label->setMidLineWidth(0);
-  label->setFrameStyle(QFrame::Box|QFrame::Plain);
+  label->setFrameStyle(Q3Frame::Box|Q3Frame::Plain);
 
   //
   //  Audition Button
   //
-  edit_audition_button=new RDTransportButton(RDTransportButton::PlayBetween,
-					    this,"edit_audition_button");
+  edit_audition_button=
+    new RDTransportButton(RDTransportButton::PlayBetween,this);
   edit_audition_button->setGeometry(sizeHint().width()/2-130,90,80,50);
   edit_audition_button->
-    setPalette(QPalette(backgroundColor(),QColor(gray)));
-  edit_audition_button->setFont(button_font);
-  edit_audition_button->setText(tr("&Audition"));
+    setPalette(QPalette(backgroundColor(),QColor(Qt::gray)));
+  edit_audition_button->setFont(buttonFont());
+  //  edit_audition_button->setText(tr("&Audition"));
   connect(edit_audition_button,SIGNAL(clicked()),
 	  this,SLOT(auditionButtonData()));
 
   //
   //  Pause Button
   //
-  edit_pause_button=new RDTransportButton(RDTransportButton::Pause,
-					 this,"edit_pause_button");
+  edit_pause_button=new RDTransportButton(RDTransportButton::Pause,this);
   edit_pause_button->setGeometry(sizeHint().width()/2-40,90,80,50);
   edit_pause_button->
-    setPalette(QPalette(backgroundColor(),QColor(gray)));
-  edit_pause_button->setFont(button_font);
-  edit_pause_button->setText(tr("&Pause"));
+    setPalette(QPalette(backgroundColor(),QColor(Qt::gray)));
+  edit_pause_button->setFont(buttonFont());
+  //  edit_pause_button->setText(tr("&Pause"));
   connect(edit_pause_button,SIGNAL(clicked()),this,SLOT(pauseButtonData()));
 
   //
   //  Stop Button
   //
-  edit_stop_button=new RDTransportButton(RDTransportButton::Stop,
-					this,"edit_stop_button");
+  edit_stop_button=new RDTransportButton(RDTransportButton::Stop,this);
   edit_stop_button->setGeometry(sizeHint().width()/2+50,90,80,50);
-  edit_stop_button->setOnColor(QColor(red));
+  edit_stop_button->setOnColor(QColor(Qt::red));
   edit_stop_button->
-    setPalette(QPalette(backgroundColor(),QColor(gray)));
-  edit_stop_button->setFont(button_font);
-  edit_stop_button->setText(tr("&Stop"));
+    setPalette(QPalette(backgroundColor(),QColor(Qt::gray)));
+  edit_stop_button->setFont(buttonFont());
+  //  edit_stop_button->setText(tr("&Stop"));
   connect(edit_stop_button,SIGNAL(clicked()),this,SLOT(stopButtonData()));
 
   //
   // Start Marker Control
   //
-  edit_start_button=new RDPushButton(this,"button");
+  edit_start_button=new RDPushButton(this);
   edit_start_button->setToggleButton(true);
   edit_start_button->setGeometry(0,155,66,45);
   edit_start_button->setFlashColor(backgroundColor());
   edit_start_button->setFlashPeriod(RD_CUEEDITOR_BUTTON_FLASH_PERIOD);
   edit_start_button->setPalette(QPalette(QColor(RD_CUEEDITOR_START_MARKER),
 					   backgroundColor()));
-  edit_start_button->setFont(button_font);
+  edit_start_button->setFont(buttonFont());
   edit_start_button->setText(tr("Start"));
   connect(edit_start_button,SIGNAL(clicked()),this,SLOT(startClickedData()));
 
@@ -168,7 +153,7 @@ RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,
   edit_end_button->setFlashPeriod(RD_CUEEDITOR_BUTTON_FLASH_PERIOD);
   edit_end_button->setPalette(QPalette(QColor(RD_CUEEDITOR_START_MARKER),
 				       backgroundColor()));
-  edit_end_button->setFont(button_font);
+  edit_end_button->setFont(buttonFont());
   edit_end_button->setText(tr("End"));
   connect(edit_end_button,SIGNAL(clicked()),this,SLOT(endClickedData()));
 
@@ -182,21 +167,20 @@ RDCueEdit::RDCueEdit(RDCae *cae,int card,int port,
   edit_recue_button->setFlashPeriod(RD_CUEEDITOR_BUTTON_FLASH_PERIOD);
   edit_recue_button->setPalette(QPalette(QColor(RD_CUEEDITOR_START_MARKER),
 				       backgroundColor()));
-  edit_recue_button->setFont(button_font);
+  edit_recue_button->setFont(buttonFont());
   edit_recue_button->setText(tr("&Recue"));
   connect(edit_recue_button,SIGNAL(clicked()),this,SLOT(recue()));
 
   //
   // Audition Stop Timer
   //
-  edit_audition_timer=new QTimer(this,"edit_audition_timer");
+  edit_audition_timer=new QTimer(this);
   connect(edit_audition_timer,SIGNAL(timeout()),this,SLOT(auditionTimerData()));
 
   //
   // Play Deck
   //
-  edit_play_deck=new RDPlayDeck(edit_cae,RDPLAYDECK_AUDITION_ID,
-				this,"edit_play_deck");
+  edit_play_deck=new RDPlayDeck(edit_cae,RDPLAYDECK_AUDITION_ID,this);
   connect(edit_play_deck,SIGNAL(stateChanged(int,RDPlayDeck::State)),this,
 	  SLOT(stateChangedData(int,RDPlayDeck::State)));
   connect(edit_play_deck,SIGNAL(position(int,int)),
@@ -667,7 +651,7 @@ void RDCueEdit::wheelEvent(QWheelEvent *e)
 void RDCueEdit::mousePressEvent(QMouseEvent *e)
 {
   switch(e->button()) {
-      case QMouseEvent::RightButton:
+      case Qt::RightButton:
         if(edit_audition_button->isShown()) {
           if(edit_right_click_stop) {
             stopButtonData();
@@ -678,7 +662,7 @@ void RDCueEdit::mousePressEvent(QMouseEvent *e)
           }
         break;
 
-      case QMouseEvent::MidButton:
+      case Qt::MidButton:
         if(edit_audition_button->isShown()) {
           if(edit_logline->forcedLength()>10000) {
             if(edit_play_deck->state()==RDPlayDeck::Playing) {
