@@ -2,7 +2,7 @@
 //
 // A widget to select a Rivendell Cut.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,28 +21,24 @@
 #ifndef RDCUT_DIALOG_H
 #define RDCUT_DIALOG_H
 
-#include <qdialog.h>
-#include <qlistview.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
+#include <q3listview.h>
+#include <q3progressdialog.h>
+
 #include <qcombobox.h>
-#include <qprogressdialog.h>
 #include <qcheckbox.h>
 
+#include <rddialog.h>
 #include <rdlistviewitem.h>
-#include <rdstation.h>
-#include <rdsystem.h>
 
 #define RDCUT_DIALOG_STEP_SIZE 1000
 
-class RDCutDialog : public QDialog
+class RDCutDialog : public RDDialog
 {
  Q_OBJECT
  public:
-  RDCutDialog(QString *cutname,RDStation *station,RDSystem *system,
-	      QString *filter=0,QString *group=0,QString *schedcode=NULL,
-	      QString username="",bool show_clear=false,bool allow_add=false,
-	      bool exclude_tracks=false,QWidget *parent=0);
+ RDCutDialog(QString *cutname,const QString &caption,QString *filter=0,
+	     QString *group=0,QString *schedcode=NULL,bool show_clear=false,
+	     bool allow_add=false,bool exclude_tracks=false,QWidget *parent=0);
   ~RDCutDialog();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -55,7 +51,7 @@ class RDCutDialog : public QDialog
   void clearData();
   void groupActivatedData(const QString &);
   void limitChangedData(int state);
-  void cartClickedData(QListViewItem *);
+  void cartClickedData(Q3ListViewItem *);
   void selectionChangedData();
   void searchButtonData();
   void clearButtonData();
@@ -75,7 +71,7 @@ class RDCutDialog : public QDialog
   void LoadState();
   void SaveState();
   RDListView *cut_cart_list;
-  QListView *cut_cut_list;
+  Q3ListView *cut_cut_list;
   QLineEdit *cut_filter_edit;
   QCheckBox *cart_limit_box;
   QPushButton *cut_search_button;
@@ -92,12 +88,10 @@ class RDCutDialog : public QDialog
   bool local_filter;
   QPixmap *cut_playout_map;
   QPixmap *cut_macro_map;
-  QString cut_username;
   bool cut_allow_clear;
   bool cut_exclude_tracks;
-  RDStation::FilterMode cut_filter_mode;
-  RDSystem *cut_system;
-  QProgressDialog *cut_progress_dialog;
+  Q3ProgressDialog *cut_progress_dialog;
+  QString cut_caption;
 };
 
 
