@@ -29,6 +29,7 @@ class RDDropbox
  public:
   RDDropbox(int id,const QString &stationname="");
   int id() const;
+  int duplicate() const;
   QString stationName() const;
   void setStationName(const QString &name) const;
   QString groupName() const;
@@ -63,6 +64,8 @@ class RDDropbox
   void setEnddateOffset(int offset) const;
   bool fixBrokenFormats() const;
   void setFixBrokenFormats(bool state) const;
+  bool logToSyslog() const;
+  void setLogToSyslog(bool state) const;
   QString logPath() const;
   void setLogPath(const QString &path) const;
   bool createDates() const;
@@ -71,6 +74,10 @@ class RDDropbox
   void setCreateStartdateOffset(int offset) const;
   int createEnddateOffset() const;
   void setCreateEnddateOffset(int offset) const;
+  int segueLevel() const;
+  void setSegueLevel(int level) const;
+  int segueLength() const;
+  void setSegueLength(int length) const;
 
  private:
   void SetRow(const QString &param,int value) const;
