@@ -1,10 +1,8 @@
 // rdedit_audio.h
 //
-// Edit Rivendell Audio
+// Rivendell Audio Marker Editor
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdedit_audio.h,v 1.9.6.2 2013/11/13 23:36:33 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,33 +21,31 @@
 #ifndef RDEDIT_AUDIO_H
 #define RDEDIT_AUDIO_H
 
-#include <qdialog.h>
+#include <q3pointarray.h>
+#include <q3popupmenu.h>
+#include <q3rangecontrol.h>
+
 #include <qscrollbar.h>
 #include <qpixmap.h>
 #include <qimage.h>
 #include <qlineedit.h>
-#include <qpointarray.h>
 #include <qcursor.h>
-#include <qpopupmenu.h>
 #include <qlabel.h>
 #include <qspinbox.h>
 #include <qtimer.h>
 #include <qnamespace.h>
 #include <qcheckbox.h>
 
-#include <rdconfig.h>
-#include <rdmarker_edit.h>
-#include <rdtransportbutton.h>
-#include <rdstereometer.h>
-#include <rdwavefile.h>
-#include <rdpushbutton.h>
-#include <rdmarker_button.h>
 #include <rdcart.h>
 #include <rdcut.h>
-#include <rdcae.h>
-#include <rduser.h>
-#include <rdstation.h>
+#include <rddialog.h>
+#include <rdmarker_button.h>
+#include <rdmarker_edit.h>
 #include <rdpeaksexport.h>
+#include <rdpushbutton.h>
+#include <rdstereometer.h>
+#include <rdtransportbutton.h>
+#include <rdwavefile.h>
 
 //
 // Widget Settings
@@ -67,19 +63,17 @@
 //
 // Widget Colors
 //
-#define EDITAUDIO_PLAY_COLOR white
-#define EDITAUDIO_REMOVE_FLASH_COLOR blue
-#define EDITAUDIO_WAVEFORM_COLOR black
+#define EDITAUDIO_PLAY_COLOR Qt::white
+#define EDITAUDIO_REMOVE_FLASH_COLOR Qt::blue
+#define EDITAUDIO_WAVEFORM_COLOR Qt::black
 #define EDITAUDIO_HIGHLIGHT_COLOR colorGroup().mid()
 
-class RDEditAudio : public QDialog
+class RDEditAudio : public RDDialog
 {
   Q_OBJECT
  public:
-  RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
-	      RDStation *station,RDConfig *config,int card,int port,
-	      int preroll,int trim_level,
-	      QWidget *parent=0,const char *name=0);
+  RDEditAudio(RDCart *cart,QString cut_name,int card,int port,
+	      int preroll,int trim_level,QWidget *parent=0);
   ~RDEditAudio();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -149,9 +143,13 @@ class RDEditAudio : public QDialog
   void DrawMaps();
   void UpdateCursors();
   void DrawCursors(int xpos,int ypos,int xsize,int ysize,int chan);
+  //  int DrawCursor(int xpos,int ypos,int xsize,int ysize,int chan,
+  //		 int samp,int prev,QColor color,Arrow arrow,int apos,
+  //		 RDEditAudio::CuePoints pt,Qt::RasterOp op=Qt::CopyROP);
   int DrawCursor(int xpos,int ypos,int xsize,int ysize,int chan,
 		 int samp,int prev,QColor color,Arrow arrow,int apos,
-		 RDEditAudio::CuePoints pt,Qt::RasterOp op=Qt::CopyROP);
+		 RDEditAudio::CuePoints pt,
+		 QPainter::CompositionMode op=QPainter::CompositionMode_SourceOver);
   void EraseCursor(int xpos,int ypos,int xsize,int ysize,int chan,
 		   int samp,int prev,QColor color,Arrow arrow,int apos);
   void DrawWave(int xsize,int ysize,int chan,QString label,QPixmap *pix);
@@ -163,7 +161,7 @@ class RDEditAudio : public QDialog
   unsigned edit_sample_rate;
   unsigned edit_sample_length;
   unsigned edit_channels;
-  QPopupMenu *edit_menu;
+  Q3PopupMenu *edit_menu;
   QScrollBar *edit_hscroll;
   QImage edit_left_ref_image;
   QImage edit_right_ref_image;
@@ -176,7 +174,7 @@ class RDEditAudio : public QDialog
   RDMarkerEdit *edit_cursor_edit[RDEditAudio::LastMarker];
   QCursor *edit_arrow_cursor;
   QCursor *edit_cross_cursor;
-  QPointArray *edit_wave_array;
+  Q3PointArray *edit_wave_array;
   QSpinBox *edit_trim_box;
   RDMarkerButton *edit_cue_button[RDEditAudio::LastMarker];
   QString edit_cue_string;
@@ -188,7 +186,7 @@ class RDEditAudio : public QDialog
   RDTransportButton *edit_pause_button;
   RDTransportButton *edit_stop_button;
   RDStereoMeter *edit_meter;
-  QRangeControl *edit_gain_control;
+  Q3RangeControl *edit_gain_control;
   RDMarkerEdit *edit_gain_edit;
   QTimer *edit_gain_timer;
   QTimer *edit_meter_timer;
@@ -221,10 +219,7 @@ class RDEditAudio : public QDialog
   int edit_stream;
   int edit_port;
   int edit_preroll;
-  RDCae *edit_cae;
-  RDStation *edit_station;
-  RDUser *edit_user;
-  RDConfig *edit_config;
+  int edit_prev_x[2][LastMarker];
 };
 
 
