@@ -33,14 +33,15 @@ RDEvent::RDEvent(const QString &name,bool create)
   event_name=name;
 
   if(create) {
-    sql=QString().sprintf("select NAME from EVENTS where \
-(NAME=\"%s\")",(const char *)event_name);
+    sql=QString("select NAME from EVENTS where ")+
+      "(NAME=\""+RDEscapeString(event_name)+"\")";
     q=new RDSqlQuery(sql);
     if(q->size()!=1) {
       delete q;
-      sql=QString().
-        sprintf("INSERT INTO EVENTS SET NAME=\"%s\",TITLE_SEP=100",
-		(const char *)event_name);
+      sql=QString("insert into EVENTS set ")+
+	"NAME=\""+RDEscapeString(event_name)+"\","+
+	"ARTIST_SEP=15,"+
+	"TITLE_SEP=100";
       q=new RDSqlQuery(sql);
       delete q;
     }
@@ -285,31 +286,14 @@ void RDEvent::setRemarks(const QString &str) const
 }
 
 
-QString RDEvent::preimportTableName(const QString event_name)
-{
-  QString ret=event_name;
-  ret.replace(" ","_");
-  return ret+"_PRE";
-}
-
-
-QString RDEvent::postimportTableName(const QString event_name)
-{
-  QString ret=event_name;
-  ret.replace(" ","_");
-  return ret+"_POST";
-}
-
-
 int RDEvent::GetIntValue(const QString &field) const
 {
   QString sql;
   RDSqlQuery *q;
   int accum;
   
-  sql=QString().sprintf("select %s from EVENTS where NAME=\"%s\"",
-			(const char *)field,
-			(const char *)event_name);
+  sql=QString("select ")+field+" from EVENTS where "+
+    "NAME=\""+RDEscapeString(event_name)+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     accum=q->value(0).toInt();
@@ -327,9 +311,8 @@ QString RDEvent::GetStringValue(const QString &field,bool *ok) const
   RDSqlQuery *q;
   QString accum;
   
-  sql=QString().sprintf("select %s from EVENTS where NAME=\"%s\"",
-			(const char *)field,
-			(const char *)event_name);
+  sql=QString("select ")+field+" from EVENTS where "+
+    "NAME=\""+RDEscapeString(event_name)+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     if(q->value(0).isNull()) {
@@ -352,10 +335,9 @@ void RDEvent::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE EVENTS SET %s=%d WHERE NAME=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)event_name);
+  sql=QString("update EVENTS set ")+
+    param+QString().sprintf("=%d where ",value)+
+    "NAME=\""+RDEscapeString(event_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -367,22 +349,21 @@ void RDEvent::SetRow(const QString &param,const QString &value,bool ok) const
   QString sql;
 
   if(ok) {
-    sql=QString().sprintf("UPDATE EVENTS SET %s=\"%s\" WHERE NAME=\"%s\"",
-			  (const char *)param,
-			  (const char *)RDEscapeString(value),
-			  (const char *)event_name);
+    sql=QString("update EVENTS set ")+
+      param+"=\""+RDEscapeString(value)+"\" where "+
+      "NAME=\""+RDEscapeString(event_name)+"\"";
   }
   else {
-    sql=QString().sprintf("UPDATE EVENTS SET %s=NULL WHERE NAME=\"%s\"",
-			  (const char *)param,
-			  (const char *)event_name);
+    sql=QString("update EVENTS set ")+
+      param+"=NULL where "+
+      "NAME=\""+RDEscapeString(event_name)+"\"";
   }
   q=new RDSqlQuery(sql);
   delete q;
 }
 
 
-QString RDEvent::SchedGroup()
+QString RDEvent::schedGroup()
 {
   bool ok;
   return GetStringValue("SCHED_GROUP",&ok);
@@ -418,13 +399,26 @@ void RDEvent::setHaveCode2(QString str)
   SetRow("HAVE_CODE2",str,true);
 }
 
-unsigned RDEvent::titleSep()
+
+int RDEvent::artistSep()
+{
+  return GetIntValue("ARTIST_SEP");
+}
+
+
+void RDEvent::setArtistSep(int artistsep)
+{
+  SetRow("ARTIST_SEP",artistsep);
+}
+
+
+int RDEvent::titleSep()
 {
   return GetIntValue("TITLE_SEP");
 }
 
 
-void RDEvent::setTitleSep(unsigned titlesep)
+void RDEvent::setTitleSep(int titlesep)
 {
   SetRow("TITLE_SEP",titlesep);
 }
