@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Log Manager Event
 //
-//   (C) Copyright 2002-2006,2016-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,20 +18,22 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qtextstream.h>
+#include <q3textstream.h>
 
-#include <rdconf.h>
-#include <rdcart.h>
-#include <rdevent.h>
-#include <rdevent_line.h>
-#include <schedcartlist.h>
-#include <rddb.h>
-#include <rdescape_string.h>
+#include "rdconf.h"
+#include "rdcart.h"
+#include "rddb.h"
+#include "rdescape_string.h"
+#include "rdevent.h"
+#include "rdevent_line.h"
+#include "rdeventimportlist.h"
+#include "rdschedcartlist.h"
 
-RDEventLine::RDEventLine()
+RDEventLine::RDEventLine(RDStation *station)
 {
-  event_preimport_log=new RDLogEvent();
-  event_postimport_log=new RDLogEvent();
+  event_station=station;
+  event_preimport_list=new RDEventImportList();
+  event_postimport_list=new RDEventImportList();
   clear();
 }
 
@@ -45,8 +47,10 @@ QString RDEventLine::name() const
 void RDEventLine::setName(const QString &name)
 {
   event_name=name;
-  event_preimport_log->setLogName(RDEvent::preimportTableName(event_name));
-  event_postimport_log->setLogName(RDEvent::postimportTableName(event_name));
+  event_preimport_list->setEventName(event_name);
+  event_preimport_list->setType(RDEventImportList::PreImport);
+  event_postimport_list->setEventName(event_name);
+  event_postimport_list->setType(RDEventImportList::PostImport);
 }
 
 
@@ -218,7 +222,7 @@ void RDEventLine::setColor(const QColor &color)
 }
 
 
-QString RDEventLine::SchedGroup() const
+QString RDEventLine::schedGroup() const
 {
   return event_sched_group;
 }
@@ -264,19 +268,6 @@ void RDEventLine::setTitleSep(unsigned titlesep)
 }
 
 
-
-RDLogEvent *RDEventLine::preimportCarts()
-{
-  return event_preimport_log;
-}
-
-
-RDLogEvent *RDEventLine::postimportCarts()
-{
-  return event_postimport_log;
-}
-
-
 QTime RDEventLine::startTime() const
 {
   return event_start_time;
@@ -317,14 +308,15 @@ void RDEventLine::clear()
    event_first_transtype=RDLogLine::Segue;
    event_default_transtype=RDLogLine::Segue;
    event_color=QColor();
-   event_preimport_log->clear();
-   event_postimport_log->clear();
-   event_start_time=QTime();
+   event_preimport_list->clear();
+   event_postimport_list->clear();
+   event_start_time=QTime(0,0,0,0);
    event_length=0;
    event_autofill_slop=-1;
    event_sched_group="";
    event_have_code="";
    event_have_code2="";
+   event_artist_sep=15;
    event_title_sep=100;
    event_nested_event="";
 }
@@ -349,9 +341,10 @@ bool RDEventLine::load()
     "AUTOFILL_SLOP,"+       // 13
     "NESTED_EVENT,"+        // 14
     "SCHED_GROUP,"+         // 15
-    "TITLE_SEP,"+           // 16
-    "HAVE_CODE,"+           // 17
-    "HAVE_CODE2	"+          // 18
+    "ARTIST_SEP,"+          // 16
+    "TITLE_SEP,"+           // 17
+    "HAVE_CODE,"+           // 18
+    "HAVE_CODE2	"+          // 19
     "from EVENTS where "+
     "NAME=\""+RDEscapeString(event_name)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
@@ -382,21 +375,22 @@ bool RDEventLine::load()
   event_autofill_slop=q->value(13).toInt();
   event_nested_event=q->value(14).toString();
   event_sched_group=q->value(15).toString();
-  event_title_sep=q->value(16).toUInt();
-  event_have_code=q->value(17).toString();
-  event_have_code2=q->value(18).toString();
+  event_artist_sep=q->value(16).toInt();
+  event_title_sep=q->value(17).toInt();
+  event_have_code=q->value(18).toString();
+  event_have_code2=q->value(19).toString();
 
   delete q;
-  event_preimport_log->load();
-  event_postimport_log->load();
+  event_preimport_list->load();
+  event_postimport_list->load();
   return true;
 }
 
 
 bool RDEventLine::save(RDConfig *config)
 {
-  QString sql=QString().sprintf("select NAME from EVENTS where NAME=\"%s\"",
-				(const char *)event_name);
+  QString sql=QString("select NAME from EVENTS where ")+
+    "NAME=\""+RDEscapeString(event_name)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     sql=QString("update EVENTS set ")+
@@ -416,6 +410,7 @@ bool RDEventLine::save(RDConfig *config)
       QString().sprintf("AUTOFILL_SLOP=%d,",event_autofill_slop)+
       "NESTED_EVENT=\""+RDEscapeString(event_nested_event)+"\","+
       "SCHED_GROUP=\""+RDEscapeString(event_sched_group)+"\","+
+      QString().sprintf("ARTIST_SEP=%d,",event_artist_sep)+
       QString().sprintf("TITLE_SEP=%d,",event_title_sep)+
       "HAVE_CODE=\""+RDEscapeString(event_have_code)+"\","+
       "HAVE_CODE2=\""+RDEscapeString(event_have_code2)+"\" "+
@@ -448,15 +443,14 @@ bool RDEventLine::save(RDConfig *config)
     return false;
   }
   delete q;
-  event_preimport_log->save(config);
-  event_postimport_log->save(config);
+  event_preimport_list->save();
+  event_postimport_list->save();
   return true;
 }
 
 
 bool RDEventLine::generateLog(QString logname,const QString &svcname,
-			      QString *errors, unsigned artistsep,
-			      QString clockname)
+			      QString *report, QString clockname)
 {
   QString sql;
   RDSqlQuery *q;
@@ -464,8 +458,6 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   QTime time=event_start_time;
   QTime fill_start_time;
   int count=0;
-  logname.replace(" ","_");
-  RDLogLine *logline;
   QString import_table;
   int postimport_length=0;
   RDLogLine::TransType trans_type=event_first_transtype;
@@ -478,17 +470,19 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   //
   // Get Current Count and Link ID
   //
-  sql=QString().sprintf("select COUNT from `%s_LOG` order by COUNT desc",
-			(const char *)logname);
+  sql=QString("select COUNT from LOG_LINES where ")+
+    "LOG_NAME=\""+RDEscapeString(logname)+"\" "+
+    "order by COUNT desc";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     count=q->value(0).toInt()+1;
   }
   delete q;
 
-  sql=QString().sprintf("select LINK_ID from `%s_LOG` where LINK_ID>=0 \
-                         order by LINK_ID desc",
-			(const char *)logname);
+  sql=QString("select LINK_ID from LOG_LINES where ")+
+    "LOG_NAME=\""+RDEscapeString(logname)+"\" && "+
+    "LINK_ID>=0 "+
+    "order by LINK_ID desc";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     link_id=q->value(0).toInt()+1;
@@ -512,38 +506,31 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   //
   // Pre-Import Carts
   //
-  for(int i=0;i<event_preimport_log->size();i++) {
-    if((logline=event_preimport_log->logLine(i))!=NULL) {
-      sql=QString("insert into `")+logname+"_LOG` set "+
-	QString().sprintf("ID=%d,",count)+
-	QString().sprintf("COUNT=%d,",count)+
-	QString().sprintf("TYPE=%d,",logline->type())+
-	QString().sprintf("SOURCE=%d,",RDLogLine::Template)+
-	QString().sprintf("START_TIME=%d,",QTime().msecsTo(time))+
-	QString().sprintf("GRACE_TIME=%d,",grace_time)+
-	QString().sprintf("CART_NUMBER=%u,",logline->cartNumber())+
-	QString().sprintf("TIME_TYPE=%d,",time_type)+
-	"POST_POINT=\""+RDYesNo(post_point)+"\","+
-	QString().sprintf("TRANS_TYPE=%d,",logline->transType())+
-	"COMMENT=\""+RDEscapeString(logline->markerComment())+"\","+
-	QString().sprintf("EVENT_LENGTH=%d",event_length);
-      q=new RDSqlQuery(sql);
-      delete q;
-      count++;
-      time=time.addMSecs(GetLength(logline->cartNumber()));
-      trans_type=event_default_transtype;
-      time_type=RDLogLine::Relative;
-      post_point=false;
-      grace_time=-1;
-    }
-  }
+  postimport_length=0;
+  for(int i=0;i<event_preimport_list->size()-1;i++) {
+    RDEventImportItem *i_item=event_preimport_list->item(i);
+    sql=QString("insert into LOG_LINES set ")+
+      "LOG_NAME=\""+RDEscapeString(logname)+"\","+
+      QString().sprintf("LINE_ID=%d,",count)+
+      QString().sprintf("COUNT=%d,",count)+
+      QString().sprintf("TYPE=%d,",i_item->eventType())+
+      QString().sprintf("SOURCE=%d,",RDLogLine::Template)+
+      QString().sprintf("START_TIME=%d,",QTime().msecsTo(time))+
+      QString().sprintf("GRACE_TIME=%d,",grace_time)+
+      QString().sprintf("CART_NUMBER=%u,",i_item->cartNumber())+
+      QString().sprintf("TIME_TYPE=%d,",time_type)+
+      "POST_POINT=\""+RDYesNo(post_point)+"\","+
+      QString().sprintf("TRANS_TYPE=%d,",i_item->transType())+
+      "COMMENT=\""+RDEscapeString(i_item->markerComment())+"\","+
+      QString().sprintf("EVENT_LENGTH=%d",event_length);
+    RDSqlQuery::apply(sql);
+    count++;
+    trans_type=event_default_transtype;
+    time_type=RDLogLine::Relative;
+    post_point=false;
+    grace_time=-1;
 
-  //
-  // Calculate Post Import Length
-  //
-  for(int i=0;i<event_postimport_log->size();i++) {
-    postimport_length+=
-      GetLength(event_postimport_log->logLine(i)->cartNumber());
+    postimport_length+=GetLength(i_item->cartNumber());
   }
 
   //
@@ -551,21 +538,22 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
   //
   if(event_import_source==RDEventLine::Traffic || event_import_source==RDEventLine::Music) {
     switch(event_import_source) {
-	case RDEventLine::Traffic:
-	  link_type=RDLogLine::TrafficLink;
-	  break;
+    case RDEventLine::Traffic:
+      link_type=RDLogLine::TrafficLink;
+      break;
 	  
-	case RDEventLine::Music:
-	  link_type=RDLogLine::MusicLink;
-	  break;
+    case RDEventLine::Music:
+      link_type=RDLogLine::MusicLink;
+      break;
 	  
-	default:
-	  break;
+    default:
+      break;
     }
     QTime end_start_time=event_start_time.addMSecs(event_length);
 
-    sql=QString("insert into `")+logname+"_LOG` set "+
-      QString().sprintf("ID=%d,",count)+
+    sql=QString("insert into LOG_LINES set ")+
+      "LOG_NAME=\""+RDEscapeString(logname)+"\","+
+      QString().sprintf("LINE_ID=%d,",count)+
       QString().sprintf("COUNT=%d,",count)+
       QString().sprintf("TYPE=%d,",link_type)+
       QString().sprintf("SOURCE=%d,",RDLogLine::Template)+
@@ -593,9 +581,10 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
     grace_time=-1;
   }
 
-// Scheduler 
+  // Scheduler 
 
-  if(event_import_source == RDEventLine::Scheduler ) {
+  if(event_import_source == RDEventLine::Scheduler) {
+    int artistsep;
     int titlesep;
     int stackid;
     int counter;   		
@@ -605,122 +594,156 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
     svcname_rp.replace(" ","_");
     
     time.addMSecs(postimport_length);
-    
+
+    if(event_artist_sep>=-1 && event_artist_sep<=50000) {
+      artistsep = event_artist_sep;
+    }
+    else {
+      artistsep = 15;
+    }
+
+    if(event_title_sep>=-1 && event_title_sep<=50000) {
+      titlesep = event_title_sep;
+    }
+    else {
+      titlesep = 100;
+    }
+
+    //
+    // Get next stack id from the stack
+    //
     sql=QString("select ")+
-      "NUMBER,"+
-      "ARTIST,"+
-      "SCHED_CODES "+
-      "from CART where "+
-      "GROUP_NAME=\""+RDEscapeString(SchedGroup())+"\"";
+      "MAX(SCHED_STACK_ID) "+
+      "from STACK_LINES where "+
+      "SERVICE_NAME=\""+RDEscapeString(svcname)+"\"";
     q=new RDSqlQuery(sql);
-    if(q->size()>0)
-    {
-      if(event_title_sep>=0 && event_title_sep<=50000)
-      {
-	titlesep = (int)event_title_sep;
-      }
-      else
-      {
-	titlesep = 100;
+    if (q->next()) { 
+      stackid=q->value(0).toUInt();
+    }
+    else { 
+      stackid=0;
+    }
+    stackid++;    
+    delete q;
+      
+    //
+    // Load all carts in requested group into schedCL
+    //
+    sql=QString("select NUMBER,ARTIST,")+
+      "CONCAT(GROUP_CONCAT(RPAD(SC.SCHED_CODE,11,' ') separator ''),'.') as SCHED_CODES"+
+      " from CART LEFT JOIN CART_SCHED_CODES AS SC on (NUMBER=SC.CART_NUMBER)"+
+      " where GROUP_NAME='"+RDEscapeString(schedGroup())+"'"+
+      " group by NUMBER";
+    RDSchedCartList *schedCL=new RDSchedCartList();
+    q=new RDSqlQuery(sql);
+    while(q->next()) {
+      QStringList codes=q->value(2).toString().split(" ",QString::SkipEmptyParts);
+      if((codes.size()>0)&&(codes.last()==".")) {
+	codes.removeLast();
       }
+      schedCL->
+	insertItem(q->value(0).toUInt(),0,0,q->value(1).toString(),codes);
+    }
+    delete q;
       
-      int querysize=(int)q->size();
-      SchedCartList *schedCL;
-      schedCL=new SchedCartList(querysize);
-      
-      for(counter=0;counter<querysize;counter++)
-      {
-	q->seek(counter);
-	schedCL->insertItem(q->value(0).toUInt(),0,0,q->value(1).toString(),q->value(2).toString());
-      }
-      delete q;
-      
-      sql=QString("select SCHED_STACK_ID from `")+svcname_rp+"_STACK` "+
-	"order by SCHED_STACK_ID";
-      q=new RDSqlQuery(sql);
-      if (q->last())
-      { 
-	stackid=q->value(0).toUInt();
-      }
-      else
-      { 
-	stackid=0;
-      }
-      stackid++;    
-      delete q;
-      
-      
-      // Add deconflicting rules here		  
-      // Title separation 
-      schedCL->save();		  
-      sql=QString("select CART from `")+svcname_rp+"_STACK` where "+
-	QString().sprintf("SCHED_STACK_ID >= %d",stackid-titlesep);
-      q=new RDSqlQuery(sql);
-      
-      while (q->next())	{
-	for(counter=0;counter<schedCL->getNumberOfItems();counter++) { 
-	  if(q->value(0).toUInt()==schedCL->getItemCartnumber(counter)) {
-	    schedCL->removeItem(counter);
-	    counter--;
-	  }
-	}
-      }
-      delete q;
-      if(schedCL->getNumberOfItems()==0)
-	*errors+=QString().sprintf("%s Rule broken: Title Separation\n",(const char *)time.toString("hh:mm:ss"));
-      schedCL->restore();
-      
-      // Artist separation
-      schedCL->save();		  
-      sql=QString("select ARTIST from `")+svcname_rp+"_STACK` where "+
-	QString().sprintf("SCHED_STACK_ID >= %d",stackid-artistsep);
-      q=new RDSqlQuery(sql);
-      while (q->next()) {
-	for(counter=0;counter<schedCL->getNumberOfItems();counter++) { 
-	  if(q->value(0).toString()==schedCL->getItemArtist(counter)) {
-	    schedCL->removeItem(counter);
-	    counter--;
-	  }
-	}
-      }          
-      delete q;
-      if(schedCL->getNumberOfItems()==0) {
-	*errors+=QString().sprintf("%s Rule broken: Artist Separation\n",(const char *)time.toString("hh:mm:ss"));
-      }
-      schedCL->restore();
-      
-      // Must have scheduler code
+    //////////////////////////////////
+    //                              //
+    // Add deconflicting rules here //
+    //                              //
+    //////////////////////////////////
+
+    // Reduce schedCL to match requested scheduler code
+    if(event_have_code!=""||event_have_code2!="") {
+      QStringList codes;
       if(event_have_code!="") {
-	schedCL->save();		  
-	for(counter=0;counter<schedCL->getNumberOfItems();counter++) { 
-	  if(!schedCL->itemHasCode(counter,event_have_code)) {
-	    schedCL->removeItem(counter);
-	    counter--;
-	  }
-	}
-	if(schedCL->getNumberOfItems()==0) {
-	  *errors+=QString().sprintf("%s Rule broken: Must have code %s\n",(const char *)time.toString("hh:mm:ss"),(const char*)event_have_code);
-	}
-	schedCL->restore();
+        codes << event_have_code;
       }
-
-      // Must have second scheduler code
       if(event_have_code2!="") {
-	schedCL->save();
-	for(counter=0;counter<schedCL->getNumberOfItems();counter++) {
-	  if(!schedCL->itemHasCode(counter,event_have_code2)) {
-	    schedCL->removeItem(counter);
-	    counter--;
-	  }
-	}
-	if(schedCL->getNumberOfItems()==0) {
-	  *errors+=QString().sprintf("%s Rule broken: Must have second code %s\n",(const char *)time.toString("hh:mm:ss"),(const char*)event_have_code2);
-	}
-	schedCL->restore();
+        codes << event_have_code2;
       }
+      for(counter=0;counter<schedCL->getNumberOfItems();counter++) { 
+        if(!schedCL->itemHasCodes(counter,codes)) {
+          schedCL->removeItem(counter);
+          counter--;
+        }
+      }
+    }
 
-      // Scheduler Codes
-      sql=QString().sprintf("select CODE,MAX_ROW,MIN_WAIT,NOT_AFTER, OR_AFTER,OR_AFTER_II from %s_RULES",(const char *)clockname);
+    if(schedCL->getNumberOfItems()) {
+      //
+      // Title separation
+      //
+      // Iterate through schedCL and remove carts from schedCL that
+      // match cart number on the stack essentially removing matched titles.
+      //
+      if(titlesep>=0) {
+        schedCL->save();		  
+        sql=QString("select CART from STACK_LINES where ")+
+          "SERVICE_NAME=\""+RDEscapeString(svcname)+"\" && "+
+          QString().sprintf("SCHED_STACK_ID >= %d",stackid-titlesep);
+        q=new RDSqlQuery(sql);
+        while (q->next()) {
+          for(counter=0;counter<schedCL->getNumberOfItems();counter++) { 
+            if(q->value(0).toUInt()==schedCL->getItemCartNumber(counter)) {
+              schedCL->removeItem(counter);
+              counter--;
+            }
+          }
+        }
+        delete q;
+        if(schedCL->getNumberOfItems()==0) {
+          *report+=time.toString("hh:mm:ss")+" "+
+            QObject::tr("Rule broken: Title separation");
+          if(!HaveCode().isEmpty()) {
+            *report+=QObject::tr(" with sched code(s): ")+HaveCode()+" "+HaveCode2();
+          }
+          *report+="\n";
+          schedCL->restore();
+        }
+      }
+      
+      //
+      // Artist separation
+      //
+      // Iterate through schedCL and remove carts from schedCL that
+      // match artist on the stack.
+      //
+      if(artistsep>=0) {
+        schedCL->save();		  
+        sql=QString("select ARTIST from STACK_LINES where ")+
+          "SERVICE_NAME=\""+RDEscapeString(svcname)+"\" && "+
+          QString().sprintf("SCHED_STACK_ID >= %d",stackid-artistsep);
+        q=new RDSqlQuery(sql);
+        while (q->next()) {
+          for(counter=0;counter<schedCL->getNumberOfItems();counter++) { 
+            if(q->value(0).toString()==schedCL->getItemArtist(counter)) {
+              schedCL->removeItem(counter);
+              counter--;
+            }
+          }
+        }          
+        delete q;
+        if(schedCL->getNumberOfItems()==0) {
+          *report+=time.toString("hh:mm:ss")+" "+
+            QObject::tr("Rule broken: Artist separation");
+          if(!HaveCode().isEmpty()) {
+            *report+=QObject::tr(" with sched code(s): ")+HaveCode()+" "+HaveCode2();
+          }
+          *report+="\n";
+          schedCL->restore();
+        }
+      }
+      
+      // Clock Scheduler Rules
+      sql=QString("select ")+
+	"CODE,"+         // 00
+	"MAX_ROW,"+      // 01
+	"MIN_WAIT,"+     // 02
+	"NOT_AFTER,"+    // 03
+	"OR_AFTER,"+     // 04
+	"OR_AFTER_II "+  // 05
+	"from RULE_LINES where "+
+	"CLOCK_NAME=\""+RDEscapeString(clockname)+"\"";
       q=new RDSqlQuery(sql);
       while (q->next()) {
 	// max in a row, min wait
@@ -730,9 +753,13 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	QString wstr=q->value(0).toString();
 	wstr+="          ";
 	wstr=wstr.left(11);
-	sql=QString("select CART from `")+svcname_rp+"_STACK` where "+
-	  QString().sprintf("SCHED_STACK_ID > %d and ",stackid-range)+
-	  "SCHED_CODES like \"%%"+RDEscapeString(wstr)+"%%\"";
+	sql=QString("select STACK_LINES.CART ")+
+	  "from STACK_LINES left join STACK_SCHED_CODES "+
+	  "on STACK_LINES.ID=STACK_SCHED_CODES.STACK_LINES_ID where "+
+	  "STACK_LINES.SERVICE_NAME=\""+RDEscapeString(svcname)+"\" && "+
+	  QString().sprintf("STACK_LINES.SCHED_STACK_ID > %d && ",
+			    stackid-range)+
+	  "STACK_SCHED_CODES.SCHED_CODE=\""+RDEscapeString(wstr)+"\"";
 	q1=new RDSqlQuery(sql);
 	if(q1->size()>=allowed || allowed==0) {
 	  for(counter=0;counter<schedCL->getNumberOfItems();counter++) {
@@ -743,17 +770,24 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	}
 	delete q1;
 	if(schedCL->getNumberOfItems()==0) {
-	  *errors+=QString().sprintf("%s Rule broken: Max. in a Row/Min. Wait for %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString());
+	  *report+=time.toString("hh:mm:ss")+" "+
+	    QObject::tr("Rule broken: Max. in a Row/Min. Wait for ")+
+	    q->value(0).toString()+"\n";
+	  schedCL->restore();
 	}
-	schedCL->restore();
+
 	// do not play after
-	if(q->value(3).toString()!="") { 
+	if(q->value(3).toString()!="") {
 	  schedCL->save();	
 	  QString wstr=q->value(3).toString();
 	  wstr+="          ";
 	  wstr=wstr.left(11);
-	  sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
+	  sql=QString("select STACK_LINES.CART ")+
+	    "from STACK_LINES left join STACK_SCHED_CODES "+
+	    "on STACK_LINES.ID=STACK_SCHED_CODES.STACK_LINES_ID where "+
+	    "STACK_LINES.SERVICE_NAME=\""+RDEscapeString(svcname)+"\" && "+
+	    QString().sprintf("STACK_LINES.SCHED_STACK_ID=%d && ",stackid-1)+
+	    "STACK_SCHED_CODES.SCHED_CODE=\""+RDEscapeString(wstr)+"\"";
 	  q1=new RDSqlQuery(sql);
 	  if(q1->size()>0) {
 	    for(counter=0;counter<schedCL->getNumberOfItems();counter++) {
@@ -764,9 +798,12 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	  }
 	  delete q1;
 	  if(schedCL->getNumberOfItems()==0) {
-	    *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(3).toString());
+	    *report+=time.toString("hh:mm:ss")+" "+
+	      QObject::tr("Rule broken: Do not schedule ")+
+	      q->value(0).toString()+" "+QObject::tr("after")+" "+
+	      q->value(3).toString()+"\n";
+	    schedCL->restore();
 	  }
-	  schedCL->restore();
 	}
 	// or after
 	if (q->value(4).toString()!="") {
@@ -774,8 +811,11 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	  QString wstr=q->value(4).toString();
 	  wstr+="          ";
 	  wstr=wstr.left(11);
-	  sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
+	  sql=QString("select STACK_LINES.CART ")+
+	    "from STACK_LINES left join STACK_SCHED_CODES "+
+	    "on STACK_LINES.ID=STACK_SCHED_CODES.STACK_LINES_ID where "+
+	    QString().sprintf("STACK_LINES.SCHED_STACK_ID=%d && ",stackid-1)+
+	    "STACK_SCHED_CODES.SCHED_CODE=\""+RDEscapeString(wstr)+"\"";
 	  q1=new RDSqlQuery(sql);
 	  if(q1->size()>0) {	
 	    for(counter=0;counter<schedCL->getNumberOfItems();counter++) {
@@ -786,9 +826,12 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	  }
 	  delete q1;
 	  if(schedCL->getNumberOfItems()==0) {
-	    *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(4).toString());
+	    *report+=time.toString("hh:mm:ss")+" "+
+	      QObject::tr("Rule broken: Do not schedule")+" "+
+	      q->value(0).toString()+" "+QObject::tr("after")+" "+
+	      q->value(4).toString()+"\n";
+	    schedCL->restore();
 	  }
-	  schedCL->restore();
 	}
 	// or after II
 	if (q->value(5).toString()!="") {
@@ -796,8 +839,11 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	  QString wstr=q->value(5).toString();
 	  wstr+="          ";
 	  wstr=wstr.left(11);
-	  sql=QString().sprintf("select CART from %s_STACK \
-			  where SCHED_STACK_ID = %d and SCHED_CODES like \"%%%s%%\"",(const char*)svcname_rp,(stackid-1),(const char *)wstr);
+	  sql=QString("select STACK_LINES.CART ")+
+	    "from STACK_LINES left join STACK_SCHED_CODES "+
+	    "on STACK_LINES.ID=STACK_SCHED_CODES.STACK_LINES_ID where "+
+	    QString().sprintf("STACK_LINES.SCHED_STACK_ID=%d && ",stackid-1)+
+	    "STACK_SCHED_CODES.SCHED_CODE=\""+RDEscapeString(wstr)+"\"";
 	  q1=new RDSqlQuery(sql);
 	  if(q1->size()>0) {
 	    for(counter=0;counter<schedCL->getNumberOfItems();counter++) {
@@ -808,25 +854,35 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 	  }
 	  delete q1;
 	  if(schedCL->getNumberOfItems()==0) {
-	    *errors+=QString().sprintf("%s Rule broken: Do not schedule %s after %s\n",(const char *)time.toString("hh:mm:ss"),(const char *)q->value(0).toString(),(const char *)q->value(5).toString());
+	    *report+=time.toString("hh:mm:ss")+" "+
+	      QObject::tr("Rule broken: Do not schedule")+" "+
+	      q->value(0).toString()+" "+QObject::tr("after")+" "+
+	      q->value(5).toString()+"\n";
+	    schedCL->restore();
 	  }
-	  schedCL->restore();
 	}
       }
       delete q;
+
+      ////////////////////////////////
+      //                            //
+      // End of deconflicting rules //
+      //                            //
+      ////////////////////////////////
       
-      
-// end of deconflicting rules
-      
+      //
+      // Pick a random cart from those that are remaining.
+      //
       int schedpos=rand()%schedCL->getNumberOfItems();
-      sql=QString("insert into `")+logname+"_LOG` set "+
-	QString().sprintf("ID=%d,",count)+
+      sql=QString("insert into LOG_LINES set ")+
+	"LOG_NAME=\""+RDEscapeString(logname)+"\","+
+	QString().sprintf("LINE_ID=%d,",count)+
 	QString().sprintf("COUNT=%d,",count)+
 	QString().sprintf("TYPE=%d,",RDLogLine::Cart)+
 	QString().sprintf("SOURCE=%d,",source)+
 	QString().sprintf("START_TIME=%d,",QTime().msecsTo(time))+
 	QString().sprintf("GRACE_TIME=%d,",grace_time)+
-	QString().sprintf("CART_NUMBER=%u,",schedCL->getItemCartnumber(schedpos))+
+	QString().sprintf("CART_NUMBER=%u,",schedCL->getItemCartNumber(schedpos))+
 	QString().sprintf("TIME_TYPE=%d,",time_type)+
 	"POST_POINT=\""+RDYesNo(post_point)+"\","+
 	QString().sprintf("TRANS_TYPE=%d,",trans_type)+
@@ -837,59 +893,71 @@ bool RDEventLine::generateLog(QString logname,const QString &svcname,
 
       count++;
 
-      sql=QString("insert into `")+svcname_rp+"_STACK` set "+
+      sql=QString("insert into STACK_LINES set ")+
+	"SERVICE_NAME=\""+RDEscapeString(svcname)+"\","+
+	"SCHEDULED_AT=now(),"+
 	QString().sprintf("SCHED_STACK_ID=%u,",stackid)+
-	QString().sprintf("CART=%u,",schedCL->getItemCartnumber(schedpos))+
-	"ARTIST=\""+RDEscapeString(schedCL->getItemArtist(schedpos))+"\","+
-	"SCHED_CODES=\""+RDEscapeString(schedCL->getItemSchedCodes(schedpos))+
-	"\"";
-      q=new RDSqlQuery(sql);
-      delete q;
+	QString().sprintf("CART=%u,",schedCL->getItemCartNumber(schedpos))+
+	"ARTIST=\""+RDEscapeString(schedCL->getItemArtist(schedpos))+"\"";
+      unsigned line_id=RDSqlQuery::run(sql).toUInt();
+      QStringList codes=schedCL->getItemSchedCodes(schedpos);
+      for(int i=0;i<codes.size();i++) {
+	sql=QString("insert into STACK_SCHED_CODES set ")+
+	  QString().sprintf("STACK_LINES_ID=%u,",line_id)+
+	  "SCHED_CODE=\""+RDEscapeString(codes.at(i))+"\"";
+	RDSqlQuery::apply(sql);
+      }
       delete schedCL;
     }
-    else
-    {
-      delete q;
+    else {
+      // We don't have any carts to work with
+      *report+=time.toString("hh:mm:ss")+
+        " "+QObject::tr("No carts found in group")+" "+schedGroup();
+      if(!HaveCode().isEmpty()) {
+        *report+=QObject::tr(" with sched code(s): ")+HaveCode()+" "+HaveCode2();
+      }
+      *report+="\n";
+
+      delete schedCL;
     }
   }
 
   //
   // Post-Import Carts
   //
-  for(int i=0;i<event_postimport_log->size();i++) {
-    if((logline=event_postimport_log->logLine(i))!=NULL) {
-      sql=QString("insert into `")+logname+"_LOG` set "+
-	QString().sprintf("ID=%d,",count)+
-	QString().sprintf("COUNT=%d,",count)+
-	QString().sprintf("TYPE=%d,",logline->type())+
-	QString().sprintf("SOURCE=%d,",RDLogLine::Template)+
-	QString().sprintf("START_TIME=%d,",QTime().msecsTo(time))+
-	QString().sprintf("GRACE_TIME=%d,",grace_time)+
-	QString().sprintf("CART_NUMBER=%u,",logline->cartNumber())+
-	QString().sprintf("TIME_TYPE=%d,",time_type)+
-	"POST_POINT=\""+RDYesNo(post_point)+"\","+
-	QString().sprintf("TRANS_TYPE=%d,",logline->transType())+
-	"COMMENT=\""+RDEscapeString(logline->markerComment())+"\","+
-	QString().sprintf("EVENT_LENGTH=%d",event_length);
-      q=new RDSqlQuery(sql);
-      delete q;
-      count++;
-      time=time.addMSecs(GetLength(logline->cartNumber()));
-      time_type=RDLogLine::Relative;
-      trans_type=event_default_transtype;
-      post_point=false;
-      grace_time=-1;
-    }
+  for(int i=0;i<event_postimport_list->size()-1;i++) {
+    RDEventImportItem *i_item=event_postimport_list->item(i);
+    sql=QString("insert into LOG_LINES set ")+
+      "LOG_NAME=\""+RDEscapeString(logname)+"\","+
+      QString().sprintf("LINE_ID=%d,",count)+
+      QString().sprintf("COUNT=%d,",count)+
+      QString().sprintf("TYPE=%d,",i_item->eventType())+
+      QString().sprintf("SOURCE=%d,",RDLogLine::Template)+
+      QString().sprintf("START_TIME=%d,",QTime().msecsTo(time))+
+      QString().sprintf("GRACE_TIME=%d,",grace_time)+
+      QString().sprintf("CART_NUMBER=%u,",i_item->cartNumber())+
+      QString().sprintf("TIME_TYPE=%d,",time_type)+
+      "POST_POINT=\""+RDYesNo(post_point)+"\","+
+      QString().sprintf("TRANS_TYPE=%d,",i_item->transType())+
+      "COMMENT=\""+RDEscapeString(i_item->markerComment())+"\","+
+      QString().sprintf("EVENT_LENGTH=%d",event_length);
+    RDSqlQuery::apply(sql);
+    count++;
+    time=time.addMSecs(GetLength(i_item->cartNumber()));
+    time_type=RDLogLine::Relative;
+    trans_type=event_default_transtype;
+    post_point=false;
+    grace_time=-1;
   }
 
   return true;
 }
 
 
-bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
+bool RDEventLine::linkLog(RDLogEvent *e,RDLog *log,const QString &svcname,
 			  RDLogLine *link_logline,const QString &track_str,
 			  const QString &label_cart,const QString &track_cart,
-			  const QString &import_table,QString *errors)
+			  QString *errors)
 {
   QString sql;
   RDSqlQuery *q;
@@ -920,13 +988,15 @@ bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
   //
   // Insert Parent Link
   //
-  e->insert(e->size(),1);
-  logline=new RDLogLine();
-  *logline=*link_logline;
-  logline->setId(e->nextId());
-  *(e->logLine(e->size()-1))=*logline;
-  delete logline;
-  logline=NULL;
+  if(log->includeImportMarkers()) {
+    e->insert(e->size(),1);
+    logline=new RDLogLine();
+    *logline=*link_logline;
+    logline->setId(e->nextId());
+    *(e->logLine(e->size()-1))=*logline;
+    delete logline;
+    logline=NULL;
+  }
 
   //
   // Clear Leading Event Values
@@ -974,11 +1044,13 @@ bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
     "TRACK_STRING,"+    // 11
     "LINK_START_TIME,"+ // 12
     "LINK_LENGTH "+     // 13
-    "from `"+import_table+"` where "+
+    "from IMPORTER_LINES where "+
+    "STATION_NAME=\""+RDEscapeString(event_station->name())+"\" && "+
+    QString().sprintf("PROCESS_ID=%u && ",getpid())+
     QString().sprintf("(START_HOUR=%d)&&",start_start_hour)+
     QString().sprintf("(START_SECS>=%d)&&",start_start_secs/1000)+
     QString().sprintf("(START_SECS<=%d)&&",end_start_secs/1000)+
-    "(EVENT_USED=\"N\") order by ID";
+    "(EVENT_USED=\"N\") order by LINE_ID";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     int length=GetLength(q->value(0).toUInt(),q->value(2).toInt());
@@ -1073,11 +1145,16 @@ bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
       }
     }
 
+    //
+    // Insert imported event
+    //
     e->insert(e->size(),1);
     logline=e->logLine(e->size()-1);
     logline->setId(e->nextId());
     logline->setSource(event_src);
-    logline->setStartTime(RDLogLine::Logged,time);
+    logline->
+      setStartTime(RDLogLine::Logged,
+		   QTime(start_start_hour,0,0).addSecs(q->value(1).toInt()));
     logline->setGraceTime(grace_time);
     logline->setTimeType(time_type);
     logline->setTransType(trans_type);
@@ -1112,25 +1189,17 @@ bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
 	logline->setCartNumber(q->value(0).toUInt());
       }
     }
-    /*
-    //
-    // Clear Leading Event Values
-    //
-    time_type=RDLogLine::Relative;
-    trans_type=event_default_transtype;
-    */
     time=time.addMSecs(length);
-    /*
-    grace_time=-1;
-    */
   }
   delete q;
 
   //
   // Mark Events as Used
   //
-  sql=QString("update `")+import_table+"` set "+
+  sql=QString("update IMPORTER_LINES set ")+
     "EVENT_USED=\"Y\" where "+
+    "STATION_NAME=\""+RDEscapeString(event_station->name())+"\" && "+
+    QString().sprintf("PROCESS_ID=%u && ",getpid())+
     QString().sprintf("(START_HOUR=%d)&&",start_start_hour)+
     QString().sprintf("(START_SECS>=%d)&&",start_start_secs/1000)+
     QString().sprintf("(START_SECS<=%d)&&",end_start_secs/1000)+
@@ -1145,8 +1214,11 @@ bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
     addMSecs(link_logline->linkLength());
   if(event_use_autofill&&(event_start_time<=time)) {
     QTime fill_start_time=time;
-    sql=QString("select AUTOFILLS.CART_NUMBER,CART.FORCED_LENGTH from ")+
-      "AUTOFILLS left join CART on AUTOFILLS.CART_NUMBER=CART.NUMBER where "+
+    sql=QString("select ")+
+      "AUTOFILLS.CART_NUMBER,"+  // 00
+      "CART.FORCED_LENGTH "+     // 01
+      "from AUTOFILLS left join CART "+
+      "on AUTOFILLS.CART_NUMBER=CART.NUMBER where "+
       "(AUTOFILLS.SERVICE=\""+RDEscapeString(svcname)+"\")&&"+
       QString().sprintf("(CART.FORCED_LENGTH<=%d)&&",time.msecsTo(end_time))+
       "(CART.FORCED_LENGTH>0) "+
@@ -1195,20 +1267,14 @@ bool RDEventLine::linkLog(RDLogEvent *e,const QString &svcname,
     int slop=QTime().msecsTo(end_time)-QTime().msecsTo(time);
     if(abs(slop)>=event_autofill_slop) {
       if(slop>0) {
-	*errors+=QString().
-	  sprintf("  %s -- \"%s\" is underscheduled by %s.\n",
-		  (const char *)time.toString("hh:mm:ss"),
-		  (const char *)event_name,
-		  (const char *)QTime().addMSecs(slop).
-		  toString("hh:mm:ss"));
+	*errors+=QString("  ")+time.toString("hh:mm:ss")+
+	  " -- \""+event_name+"\" "+QObject::tr("is underscheduled by")+" "+
+	  QTime().addMSecs(slop).toString("hh:mm:ss")+".\n";
       }
       else {
-	*errors+=QString().
-	  sprintf("  %s -- \"%s\" is overscheduled by %s.\n",
-		  (const char *)time.toString("hh:mm:ss"),
-		  (const char *)event_name,
-		  (const char *)QTime().addMSecs(-slop).
-		  toString("hh:mm:ss"));
+	*errors+=QString("  ")+time.toString("hh:mm:ss")+
+	  " -- \""+event_name+"\" "+QObject::tr("is overscheduled by")+" "+
+	  QTime().addMSecs(-slop).toString("hh:mm:ss")+".\n";
       }
     }
   }
