@@ -2,9 +2,7 @@
 //
 // A container class for Rivendell Groups
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdgroup_list.h,v 1.4 2007/02/14 21:48:41 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,7 +30,6 @@ class RDGroupList
 {
  public:
   RDGroupList();
-  void loadStation(QString stationname);
   void loadSvc(QString svcname);
   void clear();
   int size() const;
@@ -44,4 +41,4 @@ class RDGroupList
 };
 
 
-#endif 
+#endif  // RDGROUP_LIST_H
