@@ -2,7 +2,7 @@
 //
 // Audio File Importation Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,30 +27,29 @@
 #include <math.h>
 
 #include <qpushbutton.h>
-#include <qfiledialog.h>
+#include <q3filedialog.h>
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qpainter.h>
+//Added by qt3to4:
+#include <QCloseEvent>
+#include <QPaintEvent>
+#include <QLabel>
 
-#include <rd.h>
-#include <rdconf.h>
-#include <rdwavefile.h>
-#include <rdcart.h>
-#include <rdcut.h>
-#include <rdescape_string.h>
-#include <rdstation.h>
-#include <rdimport_audio.h>
-#include <rdlibrary_conf.h>
+#include "rd.h"
+#include "rdapplication.h"
+#include "rdcart.h"
+#include "rdconf.h"
+#include "rdcut.h"
+#include "rdescape_string.h"
+#include "rdimport_audio.h"
 
 RDImportAudio::RDImportAudio(QString cutname,QString *path,
 			     RDSettings *settings,bool *import_metadata,
 			     RDWaveData *wavedata,RDCut *clipboard,
-			     RDStation *station,RDUser *user,
-			     bool *running,RDConfig *config,
-			     QWidget *parent) 
-  : QDialog(parent)
+			     bool *running,QWidget *parent) 
+  : RDDialog(parent)
 {
-  import_config=config;
   import_default_settings=settings;
   import_path=path;
   import_settings=settings;
@@ -59,36 +58,22 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_wavedata=wavedata;
   import_clipboard=clipboard;
   import_running=running;
-  import_station=station;
-  import_user=user;
   import_file_filter=RD_AUDIO_FILE_FILTER;
   import_import_conv=NULL;
   import_export_conv=NULL;
 
-  setCaption(tr("Import/Export Audio File"));
+  setWindowTitle(tr("Import/Export Audio File"));
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont mode_font=QFont("Helvetica",14,QFont::Bold);
-  mode_font.setPixelSize(14);
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Mode Group
   //
-  import_mode_group=new QButtonGroup(this);
+  import_mode_group=new Q3ButtonGroup(this);
   import_mode_group->hide();
   connect(import_mode_group,SIGNAL(clicked(int)),
 	  this,SLOT(modeClickedData(int)));
@@ -99,7 +84,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_importmode_button=new QRadioButton(tr("Import File"), this);
   import_mode_group->insert(import_importmode_button);
   import_importmode_button->setGeometry(10,10,sizeHint().width()-40,15);
-  import_importmode_button->setFont(mode_font);
+  import_importmode_button->setFont(sectionLabelFont());
   import_importmode_button->setChecked(true);
 
   //
@@ -112,8 +97,8 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_in_filename_label=
     new QLabel(import_in_filename_edit,tr("Filename:"),this);
   import_in_filename_label->setGeometry(10,30,70,20);
-  import_in_filename_label->setFont(label_font);
-  import_in_filename_label->setAlignment(AlignVCenter|AlignRight);
+  import_in_filename_label->setFont(labelFont());
+  import_in_filename_label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Input File Selector Button
@@ -129,7 +114,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_in_metadata_box=new QCheckBox(tr("Import file metadata"),this);
   import_in_metadata_box->setGeometry(95,56,160,15);
   import_in_metadata_box->setChecked(*import_import_metadata);
-  import_in_metadata_box->setFont(label_font);
+  import_in_metadata_box->setFont(labelFont());
 
   //
   // Input Channels
@@ -139,8 +124,8 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_channels_label=
     new QLabel(import_channels_box,tr("Channels:"),this);
   import_channels_label->setGeometry(230,54,75,20);
-  import_channels_label->setFont(label_font);
-  import_channels_label->setAlignment(AlignRight|AlignVCenter);
+  import_channels_label->setFont(labelFont());
+  import_channels_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Autotrim Check Box
@@ -148,7 +133,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_autotrim_box=new QCheckBox(tr("Autotrim"),this);
   import_autotrim_box->setGeometry(95,82,80,15);
   import_autotrim_box->setChecked(true);
-  import_autotrim_box->setFont(label_font);
+  import_autotrim_box->setFont(labelFont());
   connect(import_autotrim_box,SIGNAL(toggled(bool)),
 	  this,SLOT(autotrimCheckData(bool)));
 
@@ -160,12 +145,12 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_autotrim_spin->setRange(-99,0);
   import_autotrim_label=new QLabel(import_autotrim_spin,tr("Level:"),this);
   import_autotrim_label->setGeometry(185,80,45,20);
-  import_autotrim_label->setFont(label_font);
-  import_autotrim_label->setAlignment(AlignRight|AlignVCenter);
+  import_autotrim_label->setFont(labelFont());
+  import_autotrim_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   import_autotrim_unit=new QLabel(tr("dBFS"),this);
   import_autotrim_unit->setGeometry(280,80,40,20);
-  import_autotrim_unit->setFont(label_font);
-  import_autotrim_unit->setAlignment(AlignLeft|AlignVCenter);
+  import_autotrim_unit->setFont(labelFont());
+  import_autotrim_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Output Mode Button
@@ -173,7 +158,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_exportmode_button=new QRadioButton(tr("Export File"),this);
   import_mode_group->insert(import_exportmode_button);
   import_exportmode_button->setGeometry(10,120,sizeHint().width()-40,15);
-  import_exportmode_button->setFont(mode_font);
+  import_exportmode_button->setFont(sectionLabelFont());
 
   //
   // Output Filename
@@ -186,8 +171,8 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_out_filename_label=
     new QLabel(import_out_filename_edit,tr("Filename:"),this);
   import_out_filename_label->setGeometry(10,140,70,20);
-  import_out_filename_label->setFont(label_font);
-  import_out_filename_label->setAlignment(AlignVCenter|AlignRight);
+  import_out_filename_label->setFont(labelFont());
+  import_out_filename_label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Output File Selector Button
@@ -203,7 +188,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_out_metadata_box=new QCheckBox(tr("Export file metadata"),this);
   import_out_metadata_box->setGeometry(95,161,sizeHint().width()-210,15);
   import_out_metadata_box->setChecked(*import_import_metadata);
-  import_out_metadata_box->setFont(label_font);
+  import_out_metadata_box->setFont(labelFont());
 
   //
   // Output Format
@@ -214,8 +199,8 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_format_edit->setText(import_settings->description());
   import_format_label=new QLabel(import_out_filename_edit,tr("Format:"),this);
   import_format_label->setGeometry(10,181,70,20);
-  import_format_label->setFont(label_font);
-  import_format_label->setAlignment(AlignVCenter|AlignRight);
+  import_format_label->setFont(labelFont());
+  import_format_label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Output Format Selector Button
@@ -237,7 +222,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_normalize_box=new QCheckBox(tr("Normalize"),this);
   import_normalize_box->setGeometry(10,262,113,15);
   import_normalize_box->setChecked(true);
-  import_normalize_box->setFont(label_font);
+  import_normalize_box->setFont(labelFont());
   connect(import_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
@@ -249,12 +234,12 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_normalize_spin->setRange(-30,0);
   import_normalize_label=new QLabel(import_normalize_spin,tr("Level:"),this);
   import_normalize_label->setGeometry(110,260,45,20);
-  import_normalize_label->setFont(label_font);
-  import_normalize_label->setAlignment(AlignRight|AlignVCenter);
+  import_normalize_label->setFont(labelFont());
+  import_normalize_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   import_normalize_unit=new QLabel(tr("dBFS"),this);
   import_normalize_unit->setGeometry(205,260,40,20);
-  import_normalize_unit->setFont(label_font);
-  import_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
+  import_normalize_unit->setFont(labelFont());
+  import_normalize_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Import Button
@@ -262,7 +247,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_import_button=new QPushButton(tr("&Import"),this);
   import_import_button->
     setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
-  import_import_button->setFont(button_font);
+  import_import_button->setFont(buttonFont());
   connect(import_import_button,SIGNAL(clicked()),this,SLOT(importData()));
 
   //
@@ -271,7 +256,7 @@ RDImportAudio::RDImportAudio(QString cutname,QString *path,
   import_cancel_button=new QPushButton(tr("&Cancel"),this);
   import_cancel_button->
     setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  import_cancel_button->setFont(button_font);
+  import_cancel_button->setFont(buttonFont());
   import_cancel_button->setDefault(true);
   connect(import_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -421,12 +406,12 @@ void RDImportAudio::selectInputFileData()
 
   if(import_in_filename_edit->text().isEmpty()) {
     filename=
-      QFileDialog::getOpenFileName(*import_path,
+      Q3FileDialog::getOpenFileName(*import_path,
 				   import_file_filter,this);
   }
   else {
     filename=
-      QFileDialog::getOpenFileName(import_in_filename_edit->text(),
+      Q3FileDialog::getOpenFileName(import_in_filename_edit->text(),
 				   import_file_filter,this);
   }
   if(!filename.isEmpty()) {
@@ -440,20 +425,20 @@ void RDImportAudio::selectOutputFileData()
 {
   QString filename;
   QString filter=import_settings->formatName()+" (*."+
-    RDSettings::defaultExtension(import_station->name(),
+    RDSettings::defaultExtension(rda->station()->name(),
 				 import_settings->format())+")";
 
   if(import_out_filename_edit->text().isEmpty()) {
     filename=
-      QFileDialog::getSaveFileName(*import_path,filter,this);
+      Q3FileDialog::getSaveFileName(*import_path,filter,this);
   }
   else {
-    filename=QFileDialog::getSaveFileName(import_out_filename_edit->text(),
+    filename=Q3FileDialog::getSaveFileName(import_out_filename_edit->text(),
 					  filter,this);
   }
   if(!filename.isEmpty()) {
     import_out_filename_edit->
-      setText(RDSettings::pathName(import_station->name(),filename,
+      setText(RDSettings::pathName(rda->station()->name(),filename,
 				   import_settings->format()));
     *import_path=RDGetPathPart(import_out_filename_edit->text());
   }
@@ -463,12 +448,12 @@ void RDImportAudio::selectOutputFileData()
 void RDImportAudio::selectOutputFormatData()
 {
   RDExportSettingsDialog *dialog=
-    new RDExportSettingsDialog(import_settings,import_station,this);
+    new RDExportSettingsDialog(import_settings,this);
   dialog->exec();
   delete dialog;
   import_format_edit->setText(import_settings->description());
   import_out_filename_edit->
-    setText(RDSettings::pathName(import_station->name(),
+    setText(RDSettings::pathName(rda->station()->name(),
 				 import_out_filename_edit->text(),
 				 import_settings->format()));
 }
@@ -502,13 +487,10 @@ void RDImportAudio::cancelData()
 void RDImportAudio::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
-  p->moveTo(10,110);
-  p->lineTo(sizeHint().width()-10,110);
-  p->moveTo(0,215);
-  p->lineTo(sizeHint().width(),215);
-  p->moveTo(0,216);
-  p->lineTo(sizeHint().width(),216);  
+  p->setPen(QColor(Qt::black));
+  p->drawLine(10,110,sizeHint().width()-10,110);
+  p->drawLine(0,215,sizeHint().width(),215);
+  p->drawLine(0,216,sizeHint().width(),216);  
   p->end();
   delete p;
 }
@@ -544,7 +526,7 @@ void RDImportAudio::Import()
   //
   StartBar();
   RDCut *cut=new RDCut(import_cutname);
-  import_import_conv=new RDAudioImport(import_station,import_config,this);
+  import_import_conv=new RDAudioImport(this);
   import_import_conv->setCartNumber(cut->cartNumber());
   import_import_conv->setCutNumber(cut->cutNumber());
   import_import_conv->setSourceFile(import_in_filename_edit->text());
@@ -559,7 +541,7 @@ void RDImportAudio::Import()
   import_import_conv->setUseMetadata(import_in_metadata_box->isChecked());
   *import_running=true;
   import_import_aborted=false;
-  conv_err=import_import_conv->runImport(import_user->name(),import_user->password(),&audio_conv_err);
+  conv_err=import_import_conv->runImport(rda->user()->name(),rda->user()->password(),&audio_conv_err);
   *import_running=false;
   StopBar();
   switch(conv_err) {
@@ -570,7 +552,7 @@ void RDImportAudio::Import()
       wave->closeWave();
       delete wave;
     }
-    cut->setOriginName(import_station->name());
+    cut->setOriginName(rda->station()->name());
     cut->
       setOriginDatetime(QDateTime(QDate::currentDate(),QTime::currentTime()));
     QMessageBox::information(this,tr("Import Complete"),
@@ -618,7 +600,7 @@ void RDImportAudio::Export()
   StartBar();
   RDCut *cut=new RDCut(import_cutname);
   import_settings->setNormalizationLevel(import_normalize_spin->value());
-  import_export_conv=new RDAudioExport(import_station,import_config,this);
+  import_export_conv=new RDAudioExport(this);
   import_export_conv->setCartNumber(cut->cartNumber());
   import_export_conv->setCutNumber(cut->cutNumber());
   import_export_conv->setDestinationFile(import_dest_filename);
@@ -627,8 +609,8 @@ void RDImportAudio::Export()
   import_export_conv->setEnableMetadata(import_out_metadata_box->isChecked());
   *import_running=true;
   import_import_aborted=false;
-  conv_err=import_export_conv->runExport(import_user->name(),
-					 import_user->password(),
+  conv_err=import_export_conv->runExport(rda->user()->name(),
+					 rda->user()->password(),
 					 &audio_conv_err);
   *import_running=false;
   StopBar();
