@@ -2,9 +2,7 @@
 //
 //   Multiline button labelling that is smart about spaces and the like 
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdlabel.cpp,v 1.4 2010/07/29 19:32:33 cvs Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -35,15 +33,15 @@
 #include <rdlabel.h>
 
 
-RDLabel::RDLabel(QWidget *parent,const char *name,WFlags f)
-  : QLabel(parent,name,f)
+RDLabel::RDLabel(QWidget *parent,Qt::WFlags f)
+  : QLabel(parent,"",f)
 {
   label_wrap=false;
 }
 
 
-RDLabel::RDLabel(const QString &text,QWidget *parent=0,const char *name=0,
-	       WFlags f)  : QLabel(text,parent,name,f)
+RDLabel::RDLabel(const QString &text,QWidget *parent=0,Qt::WFlags f)
+  : QLabel(text,parent,"",f)
 {
   label_wrap=false;
   label_text=text;
@@ -51,8 +49,8 @@ RDLabel::RDLabel(const QString &text,QWidget *parent=0,const char *name=0,
 }
 
 
-RDLabel::RDLabel(QWidget *buddy,const QString &text,QWidget *parent,
-	       const char *name,WFlags f): QLabel(buddy,text,parent,name,f)
+RDLabel::RDLabel(QWidget *buddy,const QString &text,QWidget *parent,Qt::WFlags f)
+  : QLabel(buddy,text,parent,"",f)
 {
   label_wrap=false;
   label_text=text;
