@@ -2,9 +2,7 @@
 //
 //   A color-selectable QListViewItem class for Rivendell
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdlistviewitem.cpp,v 1.20.6.1 2013/02/21 02:46:23 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,7 +17,6 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #include <qpainter.h>
 #include <qstringlist.h>
@@ -27,9 +24,8 @@
 #include <rdconf.h>
 #include <rdlistviewitem.h>
 
-
-RDListViewItem::RDListViewItem(QListView *parent) 
-  : QListViewItem(parent)
+RDListViewItem::RDListViewItem(Q3ListView *parent) 
+  : Q3ListViewItem(parent)
 {
   item_line=-1;
   item_id=-1;
@@ -43,6 +39,20 @@ RDListViewItem::RDListViewItem(QListView *parent)
   }
 }
 
+RDListViewItem::RDListViewItem(RDListViewItem *parent)
+  : Q3ListViewItem((Q3ListViewItem *)parent)
+{
+  item_line=-1;
+  item_id=-1;
+  list_parent=(RDListView *)listView();
+  item_background_color=
+    list_parent->palette().color(QPalette::Active,QColorGroup::Base);
+  for(int i=0;i<list_parent->columns();i++) {
+    item_text_color.
+      push_back(list_parent->palette().color(QPalette::Active,QColorGroup::Text));
+    item_text_weight.push_back(list_parent->font().weight());
+  }
+}
 
 int RDListViewItem::line() const
 {
@@ -134,10 +144,10 @@ void RDListViewItem::paintCell(QPainter *p,const QColorGroup &cg,int column,
       }
     }
     x=listView()->itemMargin();
-    if(((align&AlignHCenter)!=0)||((align&AlignCenter)!=0)) {
+    if(((align&Qt::AlignHCenter)!=0)||((align&Qt::AlignCenter)!=0)) {
       x=(width-p->fontMetrics().width(text(column)))/2;
     }
-    if((align&AlignRight)!=0) {
+    if((align&Qt::AlignRight)!=0) {
       x=width-p->fontMetrics().width(text(column))-listView()->itemMargin();
     }
     p->setPen(text_color);
@@ -146,10 +156,10 @@ void RDListViewItem::paintCell(QPainter *p,const QColorGroup &cg,int column,
   else {
     x=listView()->itemMargin();
     y=(height()-pixmap(column)->height())/2;
-    if((align&AlignRight)!=0) {
+    if((align&Qt::AlignRight)!=0) {
       x=width-pixmap(column)->width()-listView()->itemMargin();
     }
-    if(((align&AlignHCenter)!=0)||((align&AlignCenter)!=0)) {
+    if(((align&Qt::AlignHCenter)!=0)||((align&Qt::AlignCenter)!=0)) {
       x=(width-pixmap(column)->width())/2;
     }
     p->drawPixmap(x,y,*pixmap(column));
@@ -157,7 +167,7 @@ void RDListViewItem::paintCell(QPainter *p,const QColorGroup &cg,int column,
 }
 
 
-int RDListViewItem::compare(QListViewItem *i,int col,bool ascending) const
+int RDListViewItem::compare(Q3ListViewItem *i,int col,bool ascending) const
 {
   int hard_column;
   int prev_length;
@@ -167,39 +177,39 @@ int RDListViewItem::compare(QListViewItem *i,int col,bool ascending) const
 
   if((hard_column=list_parent->hardSortColumn())<0) {
     switch(list_parent->columnSortType(col)) {
-	case RDListView::TimeSort:
-	  prev_length=RDSetTimeLength(i->text(col));
-	  length=RDSetTimeLength(text(col));
-	  if(length<prev_length) {
-	    return -1;
-	  }
-	  if(length>prev_length) {
-	    return 1;
-	  }
-	  return 0;
+    case RDListView::TimeSort:
+      prev_length=RDSetTimeLength(i->text(col));
+      length=RDSetTimeLength(text(col));
+      if(length<prev_length) {
+	return -1;
+      }
+      if(length>prev_length) {
+	return 1;
+      }
+      return 0;
 
-	case RDListView::LineSort:
-	  if(line()<((RDListViewItem *)i)->line()) {
-	    return -1;
-	  }
-	  if(line()>((RDListViewItem *)i)->line()) {
-	    return 1;
-	  }
-	  return 0;
+    case RDListView::LineSort:
+      if(line()<((RDListViewItem *)i)->line()) {
+	return -1;
+      }
+      if(line()>((RDListViewItem *)i)->line()) {
+	return 1;
+      }
+      return 0;
 
-	case RDListView::GpioSort:
-	  fields=fields.split("-",text(col));
-	  prev_fields=fields.split("-",i->text(col));
-	  if(fields[0].toInt()>prev_fields[0].toInt()) {
-	    return 1;
-	  }
-	  if(fields[0].toInt()<prev_fields[0].toInt()) {
-	    return -1;
-	  }
-	  return 0;
-
-	case RDListView::NormalSort:
-	  return QListViewItem::compare(i,col,ascending);
+    case RDListView::GpioSort:
+      fields=text(col).split("-");
+      prev_fields=i->text(col).split("-");
+      if(fields[0].toInt()>prev_fields[0].toInt()) {
+	return 1;
+      }
+      if(fields[0].toInt()<prev_fields[0].toInt()) {
+	return -1;
+      }
+      return 0;
+      
+    case RDListView::NormalSort:
+      return Q3ListViewItem::compare(i,col,ascending);
     }
   }
   if(ascending) {
