@@ -2,7 +2,7 @@
 //
 // Abstract Rivendell Log Events.
 //
-//   (C) Copyright 2002-2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2014,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,14 +19,16 @@
 //
 
 #include <map>
-#include <rddb.h>
-#include <rdconf.h>
-#include <rdlog.h>
-#include <rdlog_event.h>
-#include <rdcreate_log.h>
-#include <rddebug.h>
-#include <rd.h>
-#include <rdescape_string.h>
+
+#include "rd.h"
+#include "rdapplication.h"
+#include "rdconf.h"
+#include "rddb.h"
+#include "rddebug.h"
+#include "rdescape_string.h"
+#include "rdlog.h"
+#include "rdlog_event.h"
+#include "rdreport.h"
 
 //
 // Global Classes
@@ -48,20 +50,7 @@ RDLogEvent::~RDLogEvent()
 
 bool RDLogEvent::exists()
 {
-  if(log_name.isEmpty()) {
-    return false;
-  }
-  QString sql="show tables";
-  RDSqlQuery *q=new RDSqlQuery(sql);
-  while(q->next()) {
-    if(q->value(0).toString()==log_name) {
-      delete q;
-      return true;
-    }
-  }
-  delete q;
-
-  return false;
+  return RDLog::exists(log_name);
 }
 
 
@@ -95,7 +84,9 @@ QString RDLogEvent::logName() const
 
 void RDLogEvent::setLogName(QString logname)
 {
-  log_name=logname;
+  RDLog *log=new RDLog(logname);
+  log_name=log->name();  // So we normalize the case
+  delete log;
 }
 
 
@@ -114,33 +105,33 @@ int RDLogEvent::load(bool track_ptrs)
   //
   // Get the service name
   //
-  sql=QString().sprintf("select SERVICE from LOGS where NAME=\"%s\"",
-	     (const char *)RDEscapeString(log_name.left(log_name.length()-4)));
+  sql=QString("select SERVICE from LOGS where ")+
+    "NAME=\""+RDEscapeString(log_name)+"\"";
   q=new RDSqlQuery(sql);
   if(q->next()) {
     log_service_name=q->value(0).toString();
   }
   delete q;
 
-  RDLog *log=new RDLog(log_name.left(log_name.length()-4));
+  RDLog *log=new RDLog(log_name);
   log_max_id=log->nextId();
   delete log;
 
-  LoadLines(log_name,0,track_ptrs);
+  LoadLines(0,track_ptrs);
 
   return log_line.size();
 }
 
-void RDLogEvent::saveModified(bool update_tracks)
+void RDLogEvent::saveModified(RDConfig *config,bool update_tracks)
 {
   for(unsigned i=0;i<log_line.size();i++) {
     if(log_line[i]->hasBeenModified()) {
-      save(update_tracks, i);
+      save(config,update_tracks, i);
     }
   }
 }
 
-void RDLogEvent::save(bool update_tracks,int line)
+void RDLogEvent::save(RDConfig *config,bool update_tracks,int line)
 {
   QString sql;
   RDSqlQuery *q;
@@ -150,11 +141,10 @@ void RDLogEvent::save(bool update_tracks,int line)
   }
   if(line<0) {
     if(exists()) {
-      sql=QString().sprintf("drop table `%s`",(const char *)log_name);
-      q=new RDSqlQuery(sql);
-      delete q;
+      sql=QString("delete from LOG_LINES where ")+
+	"LOG_NAME=\""+RDEscapeString(log_name)+"\"";
+      RDSqlQuery::apply(sql);
     }
-    RDCreateLogTable(log_name);
     if (log_line.size() > 0) {
        QString values = "";
        for(unsigned i=0;i<log_line.size();i++) {
@@ -167,15 +157,16 @@ void RDLogEvent::save(bool update_tracks,int line)
     }
   }
   else {
-    sql=QString().sprintf("delete from `%s` where COUNT=%d",
-			  (const char *)log_name,line);
+    sql=QString("delete from LOG_LINES where ")+
+      "LOG_NAME=\""+RDEscapeString(log_name)+"\" && "+
+      QString().sprintf("COUNT=%d",line);
     q=new RDSqlQuery(sql);
     delete q;
     SaveLine(line);
     // BPM - Clear the modified flag
     log_line[line]->clearModified();
   }
-  RDLog *log=new RDLog(log_name.left(log_name.length()-4));
+  RDLog *log=new RDLog(log_name);
   if(log->nextId()<nextId()) {
     log->setNextId(nextId());
   }
@@ -188,7 +179,7 @@ void RDLogEvent::save(bool update_tracks,int line)
 
 int RDLogEvent::append(const QString &logname,bool track_ptrs)
 {
-  return LoadLines(RDLog::tableName(logname),log_max_id,track_ptrs);
+  return LoadLines(log_max_id,track_ptrs);
 }
 
 
@@ -211,15 +202,11 @@ int RDLogEvent::validate(QString *report,const QDate &date)
   // Report Header
   //
   *report="Rivendell Log Exception Report\n";
-  *report+=
-    QString().
-    sprintf("Generated at: %s - %s\n",
-	    (const char *)QDate::currentDate().toString("MM/dd/yyyy"),
-	    (const char *)QTime::currentTime().toString("hh:mm:ss"));
-  *report+=QString().sprintf("Log: %s\n",
-			     (const char *)log_name.left(log_name.length()-4));
-  *report+=QString().sprintf("Effective Airdate: %s\n",
-			     (const char *)date.toString("MM/dd/yyyy"));
+  *report+=QString("Generated at: ")+
+    QDate::currentDate().toString("MM/dd/yyyy")+" - "+
+    QTime::currentTime().toString("hh:mm:ss")+"\n";
+  *report+=QString("Log: ")+log_name+"\n";
+  *report+=QString("Effective Airdate: ")+date.toString("MM/dd/yyyy")+"\n";
   *report+="\n";
 
   //
@@ -227,15 +214,17 @@ int RDLogEvent::validate(QString *report,const QDate &date)
   //
   for(int i=0;i<size();i++) {
     if(logLine(i)->cartNumber()>0) {
-      sql=QString().sprintf("select TYPE,TITLE from CART where NUMBER=%d",
-			    logLine(i)->cartNumber());
+      sql=QString("select ")+
+	"TYPE,"+   // 00
+	"TITLE "+  // 01
+	"from CART where "+
+	QString().sprintf("NUMBER=%d",logLine(i)->cartNumber());
       q=new RDSqlQuery(sql);
       if(!q->first()) {
-	*report+=QString().
-	  sprintf(" %s - missing cart %06d\n",
-		  (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		  toString("hh:mm:ss"),
-		  logLine(i)->cartNumber());
+	*report+=QString(" ")+
+	  logLine(i)->startTime(RDLogLine::Logged).toString("hh:mm:ss")+
+	  QString().sprintf(" - missing cart %06d",logLine(i)->cartNumber())+
+	  "\n";
 	errs++;
       }
       else {
@@ -245,49 +234,41 @@ int RDLogEvent::validate(QString *report,const QDate &date)
 	    // Handle events with no logged start time (e.g. manual inserts)
 	    //
 		//TODO do we need to verify date here?
-	    sql=QString().
-	      sprintf("select CUT_NAME from CUTS where \
-                      (CART_NUMBER=%u)&&			\
-                      ((START_DATETIME is null)||		\
-                         (START_DATETIME<=\"%s 23:59:59\"))&&	\
-                      ((END_DATETIME is null)||			\
-                         (END_DATETIME>=\"%s 00:00:00\"))&&	\
-                      (%s=\"Y\")&&(LENGTH>0)",
-		      logLine(i)->cartNumber(),
-		      (const char *)date.toString("yyyy-MM-dd"),
-		      (const char *)date.toString("yyyy-MM-dd"),
-		      (const char *)RDDowCode(date.dayOfWeek()));
+	    sql=QString("select CUT_NAME from CUTS where ")+
+	      QString().sprintf("(CART_NUMBER=%u)&&",logLine(i)->cartNumber())+
+	      "((START_DATETIME is null)||"+
+	      "(START_DATETIME<=\""+date.toString("yyyy-MM-dd")+" 23:59:59\"))&&"+
+	      "((END_DATETIME is null)||"+
+	      "(END_DATETIME>=\""+date.toString("yyyy-MM-dd")+" 00:00:00\"))&&"+
+	      "("+RDDowCode(date.dayOfWeek())+"=\"Y\")&&(LENGTH>0)";
 	  }
 	  else {
 		//TODO Do we need to verify date and logLine(i)->startTime?
-	    sql=QString().
-	      sprintf("select CUT_NAME from CUTS where \
-                     (CART_NUMBER=%u)&&					\
-                     ((START_DATETIME is null)||(START_DATETIME<=\"%s %s\"))&& \
-                     ((END_DATETIME is null)||(END_DATETIME>=\"%s %s\"))&& \
-                     ((START_DAYPART is null)||(START_DAYPART<=\"%s\"))&& \
-                     ((END_DAYPART is null)||(END_DAYPART>=\"%s\"))&&	\
-                     (%s=\"Y\")&&(LENGTH>0)",
-		      logLine(i)->cartNumber(),
-		      (const char *)date.toString("yyyy-MM-dd"),
-		      (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		      toString("hh:mm:ss"),
-		      (const char *)date.toString("yyyy-MM-dd"),
-		      (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		      toString("hh:mm:ss"),
-		      (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		      toString("hh:mm:ss"),
-		      (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		      toString("hh:mm:ss"),
-		      (const char *)RDDowCode(date.dayOfWeek()));
+	    sql=QString("select CUT_NAME from CUTS where ")+
+	      QString().sprintf("(CART_NUMBER=%u)&&",logLine(i)->cartNumber())+
+	      "((START_DATETIME is null)||"+
+	      "(START_DATETIME<=\""+date.toString("yyyy-MM-dd")+" "+
+	      logLine(i)->startTime(RDLogLine::Logged).toString("hh:mm:ss")+
+	      "\"))&&"+
+	      "((END_DATETIME is null)||"+
+	      "(END_DATETIME>=\""+date.toString("yyyy-MM-dd")+" "+
+	      logLine(i)->startTime(RDLogLine::Logged).toString("hh:mm:ss")+
+	      "\"))&&"+
+	      "((START_DAYPART is null)||"+
+	      "(START_DAYPART<=\""+
+	      logLine(i)->startTime(RDLogLine::Logged).
+	      toString("hh:mm:ss")+"\"))&&"+
+	      "((END_DAYPART is null)||"+
+	      "(END_DAYPART>=\""+logLine(i)->startTime(RDLogLine::Logged).
+	      toString("hh:mm:ss")+"\"))&&"+
+	      "("+RDDowCode(date.dayOfWeek())+"=\"Y\")&&(LENGTH>0)";
 	  }
 	  q1=new RDSqlQuery(sql);
 	  if(!q1->first()) {
-	    *report+=QString().
-	      sprintf(" %s - cart %06d [%s] is not playable\n",
-		      (const char *)logLine(i)->startTime(RDLogLine::Logged).
-		      toString("hh:mm:ss"),logLine(i)->cartNumber(),
-		      (const char *)q->value(1).toString());
+	    *report+=QString(" ")+
+	      logLine(i)->startTime(RDLogLine::Logged).toString("hh:mm:ss")+
+	      QString().sprintf(" - cart %06d [",logLine(i)->cartNumber())+
+	      q->value(1).toString()+"] "+QObject::tr("is not playable")+"\n";
 	    errs++;
 	  }
 	  delete q1;
@@ -298,10 +279,10 @@ int RDLogEvent::validate(QString *report,const QDate &date)
   }
   *report+="\n";
   if(errs==1) {
-    *report+=QString().sprintf("%d exception found.\n\n",errs);
+    *report+=QString().sprintf("%d validation exception found.\n\n",errs);
   }
   else {
-    *report+=QString().sprintf("%d exceptions found.\n\n",errs);
+    *report+=QString().sprintf("%d validation exceptions found.\n\n",errs);
   }
   return errs;
 }
@@ -312,32 +293,46 @@ void RDLogEvent::refresh(int line)
   if(log_name.isEmpty()||log_line[line]->cartNumber()==0) {
     return;
   }
-  QString sql=QString().sprintf("select CART.TYPE,CART.GROUP_NAME,CART.TITLE,\
-                                 CART.ARTIST,CART.ALBUM,CART.YEAR,CART.LABEL,\
-                                 CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
-                                 CART.FORCED_LENGTH,CART.CUT_QUANTITY,\
-                                 CART.LAST_CUT_PLAYED,CART.PLAY_ORDER,\
-                                 CART.ENFORCE_LENGTH,CART.PRESERVE_PITCH,\
-                                 CART.PUBLISHER,CART.COMPOSER,CART.USAGE_CODE,\
-                                 CART.AVERAGE_SEGUE_LENGTH,CART.VALIDITY,\
-                                 CART.NOTES,GROUPS.COLOR from CART \
-                                 left join GROUPS \
-                                 on CART.GROUP_NAME=GROUPS.NAME \
-                                 where CART.NUMBER=%u",
-				log_line[line]->cartNumber());
+  QString sql=QString("select ")+
+    "CART.TYPE,"+                  // 00
+    "CART.GROUP_NAME,"+            // 01
+    "CART.TITLE,"+                 // 02
+    "CART.ARTIST,"+                // 03
+    "CART.ALBUM,"+                 // 04
+    "CART.YEAR,"+                  // 05
+    "CART.LABEL,"+                 // 06
+    "CART.CLIENT,"+                // 07
+    "CART.AGENCY,"+                // 08
+    "CART.USER_DEFINED,"+          // 09
+    "CART.FORCED_LENGTH,"+         // 10
+    "CART.CUT_QUANTITY,"+          // 11
+    "CART.LAST_CUT_PLAYED,"+       // 12
+    "CART.PLAY_ORDER,"+            // 13
+    "CART.ENFORCE_LENGTH,"+        // 14
+    "CART.PRESERVE_PITCH,"+        // 15
+    "CART.PUBLISHER,"+             // 16
+    "CART.COMPOSER,"+              // 17
+    "CART.USAGE_CODE,"+            // 18
+    "CART.AVERAGE_SEGUE_LENGTH,"+  // 19
+    "CART.VALIDITY,"+              // 20
+    "CART.NOTES,"+                 // 21
+    "GROUPS.COLOR "+               // 22
+    "from CART left join GROUPS "+
+    "on CART.GROUP_NAME=GROUPS.NAME where "+
+    QString().sprintf("CART.NUMBER=%u",log_line[line]->cartNumber());
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     switch((RDCart::Type)q->value(0).toInt()) {
-	case RDCart::Audio:
-	  log_line[line]->setType(RDLogLine::Cart);
-	  break;
+    case RDCart::Audio:
+      log_line[line]->setType(RDLogLine::Cart);
+      break;
 	  
-	case RDCart::Macro:
-	  log_line[line]->setType(RDLogLine::Macro);
-	  break;
+    case RDCart::Macro:
+      log_line[line]->setType(RDLogLine::Macro);
+      break;
 	  
-	default:
-	  break;
+    default:
+      break;
     }	
     log_line[line]->
       setCartType((RDCart::Type)q->value(0).toInt());        // Cart Type
@@ -383,7 +378,7 @@ int RDLogEvent::size() const
 void RDLogEvent::insert(int line,int num_lines,bool preserve_trans)
 {
   if(!preserve_trans) {
-    if(line>0) {
+    if((line>0)&&(log_line[line-1]!=NULL)) {
       log_line[line-1]->setEndPoint(-1,RDLogLine::LogPointer);
       log_line[line-1]->setSegueStartPoint(-1,RDLogLine::LogPointer);
       log_line[line-1]->setSegueEndPoint(-1,RDLogLine::LogPointer);
@@ -615,10 +610,22 @@ QTime RDLogEvent::blockStartTime(int line)
   //
   for(int i=start_line;i<line;i++) {
     if((i<(size()+1))&&((logLine(i+1)->transType()==RDLogLine::Segue))) {
-      actual_length+=logLine(i)->averageSegueLength();
+      if(logLine(i)->segueStartPoint(RDLogLine::LogPointer)<0) {
+	actual_length+=100*(logLine(i)->averageSegueLength()/100);
+      }
+      else {
+	if(logLine(i)->startPoint(RDLogLine::LogPointer)<0) {
+	  actual_length+=(logLine(i)->segueStartPoint(RDLogLine::LogPointer)-
+			  logLine(i)->startPoint(RDLogLine::CartPointer));
+	}
+	else {
+	  actual_length+=(logLine(i)->segueStartPoint(RDLogLine::LogPointer)-
+			  logLine(i)->startPoint(RDLogLine::LogPointer));
+	}
+      }
     }
     else {
-      actual_length+=logLine(i)->forcedLength();
+      actual_length+=100*(logLine(i)->forcedLength()/100);
     }
   }
   return_time=start_time.addMSecs(actual_length);
@@ -787,8 +794,7 @@ QString RDLogEvent::xml() const
 }
 
 
-int RDLogEvent::LoadLines(const QString &log_table,int id_offset,
-			  bool track_ptrs)
+int RDLogEvent::LoadLines(int id_offset,bool track_ptrs)
 {
   RDLogLine line;
   RDSqlQuery *q1;
@@ -810,101 +816,79 @@ int RDLogEvent::LoadLines(const QString &log_table,int id_offset,
   delete q;
 
   //
-  // Field Offsets:
-  //  0 - LOG.ID                    1 - LOG.CART_NUMBER
-  //  2 - LOG.START_TIME            3 - LOG.TIME_TYPE
-  //  4 - LOG.TRANS_TYPE            5 - LOG.START_POINT
-  //  6 - LOG.END_POINT             7 - LOG.SEGUE_START_POINT
-  //  8 - LOG.SEGUE_END_POINT       9 - CART.TYPE
-  // 10 - CART.GROUP_NAME          11 - CART.TITLE
-  // 12 - CART.ARTIST              13 - CART.ALBUM
-  // 14 - CART.YEAR
-  // 15 - CART.LABEL               16 - CART.CLIENT
-  // 17 - CART.AGENCY              18 - CART.USER_DEFINED
-  // 19 - CART.CONDUCTOR           20 - CART.SONG_ID
-  // 21 - CART.FORCED_LENGTH       22 - CART.CUT_QUANTITY
-  // 23 - CART.LAST_CUT_PLAYED     24 - CART.PLAY_ORDER
-  // 25 - CART.ENFORCE_LENGTH      26 - CART.PRESERVE_PITCH
-  // 27 - LOG.TYPE                 28 - LOG.COMMENT
-  // 29 - LOG.LABEL                30 - LOG.GRACE_TIME
-  // 31 - LOG.POST_POINT           32 - LOG.SOURCE
-  // 33 - LOG.EXT_START_TIME       34 - LOG.EXT_LENGTH           
-  // 35 - LOG.EXT_DATA             36 - LOG.EXT_EVENT_ID
-  // 37 - LOG.EXT_ANNC_TYPE        38 - LOG.EXT_CART_NAME
-  // 39 - CART.ASYNCRONOUS         40 - LOG.FADEUP_POINT
-  // 41 - LOG.FADEUP_GAIN          42 - LOG.FADEDOWN_POINT
-  // 43 - LOG.FADEDOWN_GAIN        44 - LOG.SEGUE_GAIN
-  // 45 - CART.PUBLISHER           46 - CART.COMPOSER
-  // 47 - CART.USAGE_CODE          48 - CART.AVERAGE_SEGUE_LENGTH
-  // 49 - LOG.LINK_EVENT_NAME      50 - LOG.LINK_START_TIME
-  // 51 - LOG.LINK_LENGTH          52 - LOG.LINK_ID
-  // 53 - LOG.LINK_EMBEDDED        54 - LOG.ORIGIN_USER
-  // 55 - LOG.ORIGIN_DATETIME      56 - CART.VALIDITY
-  // 57 - LOG.LINK_START_SLOP      58 - LOG.LINK_END_SLOP
-  // 59 - LOG.DUCK_UP_GAIN         60 - LOG.DUCK_DOWN_GAIN
-  // 61 - CART.START_DATETIME      62 - CART.END_DATETIME
-  // 63 - LOG.EVENT_LENGTH         64 - CART.USE_EVENT_LENGTH
-  // 65 - CART.NOTES
+  // Load log lines
   //
-  sql=QString().sprintf("select `%s`.ID,`%s`.CART_NUMBER,\
-`%s`.START_TIME,`%s`.TIME_TYPE,`%s`.TRANS_TYPE,`%s`.START_POINT,\
-`%s`.END_POINT,`%s`.SEGUE_START_POINT,`%s`.SEGUE_END_POINT,\
-CART.TYPE,CART.GROUP_NAME,CART.TITLE,CART.ARTIST,CART.ALBUM,CART.YEAR,\
-CART.LABEL,CART.CLIENT,CART.AGENCY,CART.USER_DEFINED,\
-CART.CONDUCTOR,CART.SONG_ID,\
-CART.FORCED_LENGTH,CART.CUT_QUANTITY,CART.LAST_CUT_PLAYED,CART.PLAY_ORDER,\
-CART.ENFORCE_LENGTH,CART.PRESERVE_PITCH ,`%s`.TYPE,`%s`.COMMENT,\
-`%s`.LABEL,`%s`.GRACE_TIME,`%s`.POST_POINT,`%s`.SOURCE,\
-`%s`.EXT_START_TIME,`%s`.EXT_LENGTH,`%s`.EXT_DATA,`%s`.EXT_EVENT_ID,\
-`%s`.EXT_ANNC_TYPE,`%s`.EXT_CART_NAME,CART.ASYNCRONOUS,`%s`.FADEUP_POINT,\
-`%s`.FADEUP_GAIN,`%s`.FADEDOWN_POINT,`%s`.FADEDOWN_GAIN,`%s`.SEGUE_GAIN,\
-CART.PUBLISHER,CART.COMPOSER,CART.USAGE_CODE,CART.AVERAGE_SEGUE_LENGTH,\
-`%s`.LINK_EVENT_NAME,`%s`.LINK_START_TIME,`%s`.LINK_LENGTH,`%s`.LINK_ID, \
-`%s`.LINK_EMBEDDED,`%s`.ORIGIN_USER,`%s`.ORIGIN_DATETIME,CART.VALIDITY, \
-`%s`.LINK_START_SLOP,`%s`.LINK_END_SLOP, \
-`%s`.DUCK_UP_GAIN,`%s`.DUCK_DOWN_GAIN,CART.START_DATETIME,CART.END_DATETIME,\
-`%s`.EVENT_LENGTH,CART.USE_EVENT_LENGTH,CART.NOTES \
-from `%s` left join CART on `%s`.CART_NUMBER=CART.NUMBER order by COUNT",
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table,
-				(const char *)log_table);
+  sql=QString("select ")+
+    "LOG_LINES.LINE_ID,"+            // 00
+    "LOG_LINES.CART_NUMBER,"+        // 01
+    "LOG_LINES.START_TIME,"+         // 02
+    "LOG_LINES.TIME_TYPE,"+          // 03
+    "LOG_LINES.TRANS_TYPE,"+         // 04
+    "LOG_LINES.START_POINT,"+        // 05
+    "LOG_LINES.END_POINT,"+          // 06
+    "LOG_LINES.SEGUE_START_POINT,"+  // 07
+    "LOG_LINES.SEGUE_END_POINT,"+    // 08
+    "CART.TYPE,"+                    // 09
+    "CART.GROUP_NAME,"+              // 10
+    "CART.TITLE,"+                   // 11
+    "CART.ARTIST,"+                  // 12
+    "CART.ALBUM,"+                   // 13
+    "CART.YEAR,"+                    // 14
+    "CART.LABEL,"+                   // 15
+    "CART.CLIENT,"+                  // 16
+    "CART.AGENCY,"+                  // 17
+    "CART.USER_DEFINED,"+            // 18
+    "CART.CONDUCTOR,"+               // 19
+    "CART.SONG_ID,"+                 // 20
+    "CART.FORCED_LENGTH,"+           // 21
+    "CART.CUT_QUANTITY,"+            // 22
+    "CART.LAST_CUT_PLAYED,"+         // 23
+    "CART.PLAY_ORDER,"+              // 24
+    "CART.ENFORCE_LENGTH,"+          // 25
+    "CART.PRESERVE_PITCH ,"+         // 26
+    "LOG_LINES.TYPE,"+               // 27
+    "LOG_LINES.COMMENT,"+            // 28
+    "LOG_LINES.LABEL,"+              // 29
+    "LOG_LINES.GRACE_TIME,"+         // 30
+    "LOG_LINES.POST_POINT,"+         // 31
+    "LOG_LINES.SOURCE,"+             // 32
+    "LOG_LINES.EXT_START_TIME,"+     // 33
+    "LOG_LINES.EXT_LENGTH,"+         // 34
+    "LOG_LINES.EXT_DATA,"+           // 35
+    "LOG_LINES.EXT_EVENT_ID,"+       // 36
+    "LOG_LINES.EXT_ANNC_TYPE,"+      // 37
+    "LOG_LINES.EXT_CART_NAME,"+      // 38
+    "CART.ASYNCRONOUS,"+             // 39
+    "LOG_LINES.FADEUP_POINT,"+       // 40
+    "LOG_LINES.FADEUP_GAIN,"+        // 41
+    "LOG_LINES.FADEDOWN_POINT,"+     // 42
+    "LOG_LINES.FADEDOWN_GAIN,"+      // 43
+    "LOG_LINES.SEGUE_GAIN,"+         // 44
+    "CART.PUBLISHER,"+               // 45
+    "CART.COMPOSER,"+                // 46
+    "CART.USAGE_CODE,"+              // 47
+    "CART.AVERAGE_SEGUE_LENGTH,"+    // 48
+    "LOG_LINES.LINK_EVENT_NAME,"+    // 49
+    "LOG_LINES.LINK_START_TIME,"+    // 50
+    "LOG_LINES.LINK_LENGTH,"+        // 51
+    "LOG_LINES.LINK_ID,"+            // 52
+    "LOG_LINES.LINK_EMBEDDED,"+      // 53
+    "LOG_LINES.ORIGIN_USER,"+        // 54
+    "LOG_LINES.ORIGIN_DATETIME,"+    // 55
+    "CART.VALIDITY,"+                // 56
+    "LOG_LINES.LINK_START_SLOP,"+    // 57
+    "LOG_LINES.LINK_END_SLOP,"+      // 58
+    "LOG_LINES.DUCK_UP_GAIN,"+       // 59
+    "LOG_LINES.DUCK_DOWN_GAIN,"+     // 60
+    "CART.START_DATETIME,"+          // 61
+    "CART.END_DATETIME,"+            // 62
+    "LOG_LINES.EVENT_LENGTH,"+       // 63
+    "CART.USE_EVENT_LENGTH,"+        // 64
+    "CART.NOTES	"+                   // 65
+    "from LOG_LINES left join CART "+
+    "on LOG_LINES.CART_NUMBER=CART.NUMBER where "+
+    "LOG_LINES.LOG_NAME=\""+RDEscapeString(log_name)+"\" "+
+    "order by COUNT";
    q=new RDSqlQuery(sql);
   if(q->size()<=0) {
     delete q;
@@ -970,7 +954,7 @@ from `%s` left join CART on `%s`.CART_NUMBER=CART.NUMBER order by COUNT",
       line.setSongId(q->value(20).toString());          // Song ID
       line.setUsageCode((RDCart::UsageCode)q->value(47).toInt());
       line.setForcedLength(q->value(21).toUInt());      // Forced Length
-      if((q->value(7).toInt()<0)||(q->value(8).toInt()<0)) {
+      if(q->value(7).toInt()<0) {
 	line.setAverageSegueLength(q->value(48).toInt());
       }
       else {
@@ -1081,9 +1065,8 @@ from `%s` left join CART on `%s`.CART_NUMBER=CART.NUMBER order by COUNT",
       break;
 
     case RDLogLine::Chain:
-      sql=
-	QString().sprintf("select DESCRIPTION from LOGS where NAME=\"%s\"",
-			  (const char *)line.markerLabel());
+      sql=QString("select DESCRIPTION from LOGS where ")+
+	"NAME=\""+RDEscapeString(line.markerLabel())+"\"";
       q1=new RDSqlQuery(sql);
       if(q1->first()) {
 	line.setMarkerComment(q1->value(0).toString());
@@ -1104,16 +1087,15 @@ from `%s` left join CART on `%s`.CART_NUMBER=CART.NUMBER order by COUNT",
     else {
       prev_custom=false;
     }
-/*    
-    printf("LINE: %u  START: %d  END: %d  S_START: %d  S_END: %d  FD_UP: %d  FD_DN: %d\n",
-	   log_line.size(),
-	   q->value(5).toInt(),
-	   q->value(6).toInt(),
-	   q->value(7).toInt(),
-	   q->value(8).toInt(),
-	   q->value(38).toInt(),
-	   q->value(40).toInt());
-*/
+
+//    printf("LINE: %u  START: %d  END: %d  S_START: %d  S_END: %d  FD_UP: %d  FD_DN: %d\n",
+//	   log_line.size(),
+//	   q->value(5).toInt(),
+//	   q->value(6).toInt(),
+//	   q->value(7).toInt(),
+//	   q->value(8).toInt(),
+//	   q->value(38).toInt(),
+//	   q->value(40).toInt());
 
     line.clearModified();
     log_line.push_back(new RDLogLine(line));
@@ -1163,21 +1145,51 @@ from `%s` left join CART on `%s`.CART_NUMBER=CART.NUMBER order by COUNT",
 }
 
 
-
 void RDLogEvent::InsertLines(QString values) {
   QString sql;
   RDSqlQuery *q;
 
-  sql = QString().sprintf("insert into `%s` (ID,COUNT,CART_NUMBER,START_TIME,TIME_TYPE,\
-  TRANS_TYPE,START_POINT,END_POINT,SEGUE_START_POINT,SEGUE_END_POINT,TYPE, \
-  COMMENT,LABEL,GRACE_TIME,SOURCE,EXT_START_TIME,                       \
-  EXT_LENGTH,EXT_DATA,EXT_EVENT_ID,EXT_ANNC_TYPE,EXT_CART_NAME,         \
-  FADEUP_POINT,FADEUP_GAIN,FADEDOWN_POINT,FADEDOWN_GAIN,SEGUE_GAIN,     \
-  LINK_EVENT_NAME,LINK_START_TIME,LINK_LENGTH,LINK_ID,LINK_EMBEDDED,    \
-  ORIGIN_USER,ORIGIN_DATETIME,LINK_START_SLOP,LINK_END_SLOP,            \
-  DUCK_UP_GAIN,DUCK_DOWN_GAIN,EVENT_LENGTH) values %s",
-                          (const char *)log_name,
-                          (const char *)values);
+  sql = QString("insert into LOG_LINES (")+
+    "LOG_NAME,"+           // 00
+    "LINE_ID,"+            // 01
+    "COUNT,"+              // 02
+    "CART_NUMBER,"+        // 03
+    "START_TIME,"+         // 04
+    "TIME_TYPE,"+          // 05
+    "TRANS_TYPE,"+         // 06
+    "START_POINT,"+        // 07
+    "END_POINT,"+          // 08
+    "SEGUE_START_POINT,"+  // 09
+    "SEGUE_END_POINT,"+    // 10
+    "TYPE,"+               // 11
+    "COMMENT,"+            // 12
+    "LABEL,"+              // 13
+    "GRACE_TIME,"+         // 14
+    "SOURCE,"+             // 15
+    "EXT_START_TIME,"+     // 16
+    "EXT_LENGTH,"+         // 17
+    "EXT_DATA,"+           // 18
+    "EXT_EVENT_ID,"+       // 19
+    "EXT_ANNC_TYPE,"+      // 20
+    "EXT_CART_NAME,"+      // 21
+    "FADEUP_POINT,"+       // 22
+    "FADEUP_GAIN,"+        // 23
+    "FADEDOWN_POINT,"+     // 24
+    "FADEDOWN_GAIN,"+      // 25
+    "SEGUE_GAIN,"+         // 26
+    "LINK_EVENT_NAME,"+    // 27
+    "LINK_START_TIME,"+    // 28
+    "LINK_LENGTH,"+        // 29
+    "LINK_ID,"+            // 30
+    "LINK_EMBEDDED,"+      // 31
+    "ORIGIN_USER,"+        // 32
+    "ORIGIN_DATETIME,"+    // 33
+    "LINK_START_SLOP,"+    // 34
+    "LINK_END_SLOP,"+      // 35
+    "DUCK_UP_GAIN,"+       // 36
+    "DUCK_DOWN_GAIN,"+     // 37
+    "EVENT_LENGTH) "+      // 38
+    "values "+values;
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -1186,55 +1198,47 @@ void RDLogEvent::InsertLines(QString values) {
 void RDLogEvent::InsertLineValues(QString *query, int line)
 {
   // one line to save query space
-  QString sql=QString().sprintf("(%d,%d,%u,%d,%d,%d,%d,%d,%d,%d,%d,\"%s\",\"%s\",%d,%d,%s,%d,\"%s\",\"%s\",\"%s\",\"%s\",%d,%d,%d,%d,%d,\"%s\",%d,%d,%d,\"%s\",\"%s\",%s,%d,%d,%d,%d,%d)",
-                        log_line[line]->id(),
-                        line,
-                        log_line[line]->cartNumber(),
-                        QTime().msecsTo(log_line[line]->
-                                        startTime(RDLogLine::Logged)),
-                        (int)log_line[line]->timeType(),
-                        (int)log_line[line]->transType(),
-                        log_line[line]->startPoint(RDLogLine::LogPointer),
-                        log_line[line]->endPoint(RDLogLine::LogPointer),
-                        log_line[line]->segueStartPoint(RDLogLine::LogPointer),
-                        log_line[line]->segueEndPoint(RDLogLine::LogPointer),
-                        log_line[line]->type(),
-                        (const char *)
-                        RDEscapeString(log_line[line]->markerComment()),
-                        (const char *)
-                        RDEscapeString(log_line[line]->markerLabel()),
-                        log_line[line]->graceTime(),
-                        log_line[line]->source(),
-                        (const char *)RDCheckDateTime(
-                        		log_line[line]->extStartTime(),"hh:mm:ss"),
-                        log_line[line]->extLength(),
-                        (const char *)RDEscapeString(log_line[line]->extData()),
-                        (const char *)
-                        RDEscapeString(log_line[line]->extEventId()),
-                        (const char *)
-                        RDEscapeString(log_line[line]->extAnncType()),
-                        (const char *)
-                        RDEscapeString(log_line[line]->extCartName()),
-                        log_line[line]->fadeupPoint(RDLogLine::LogPointer),
-                        log_line[line]->fadeupGain(),
-                        log_line[line]->fadedownPoint(RDLogLine::LogPointer),
-                        log_line[line]->fadedownGain(),
-                        log_line[line]->segueGain(),
-                        (const char *)
-                        RDEscapeString(log_line[line]->linkEventName()),
-                        QTime().msecsTo(log_line[line]->linkStartTime()),
-                        log_line[line]->linkLength(),
-                        log_line[line]->linkId(),
-                        (const char *)RDYesNo(log_line[line]->linkEmbedded()),
-                        (const char *)
-                        RDEscapeString(log_line[line]->originUser()),
-                        (const char *)RDCheckDateTime(
-                        log_line[line]->originDateTime(),"yyyy-MM-dd hh:mm:ss"),
-                        log_line[line]->linkStartSlop(),
-                        log_line[line]->linkEndSlop(),
-                        log_line[line]->duckUpGain(),
-                        log_line[line]->duckDownGain(),
-                        log_line[line]->eventLength());
+  RDLogLine *ll=log_line[line];
+  QString sql=QString("(")+
+    "\""+RDEscapeString(log_name)+"\","+
+    QString().sprintf("%d,",ll->id())+
+    QString().sprintf("%d,",line)+
+    QString().sprintf("%u,",ll->cartNumber())+
+    QString().sprintf("%d,",QTime().msecsTo(ll->startTime(RDLogLine::Logged)))+
+    QString().sprintf("%d,",ll->timeType())+
+    QString().sprintf("%d,",ll->transType())+
+    QString().sprintf("%d,",ll->startPoint(RDLogLine::LogPointer))+
+    QString().sprintf("%d,",ll->endPoint(RDLogLine::LogPointer))+
+    QString().sprintf("%d,",ll->segueStartPoint(RDLogLine::LogPointer))+
+    QString().sprintf("%d,",ll->segueEndPoint(RDLogLine::LogPointer))+
+    QString().sprintf("%d,",ll->type())+
+    "\""+RDEscapeString(ll->markerComment())+"\","+
+    "\""+RDEscapeString(ll->markerLabel())+"\","+
+    QString().sprintf("%d,",ll->graceTime())+
+    QString().sprintf("%d,",ll->source())+
+    RDCheckDateTime(ll->extStartTime(),"hh:mm:ss")+","+
+    QString().sprintf("%d,",ll->extLength())+
+    "\""+RDEscapeString(ll->extData())+"\","+
+    "\""+RDEscapeString(ll->extEventId())+"\","+
+    "\""+RDEscapeString(ll->extAnncType())+"\","+
+    "\""+RDEscapeString(ll->extCartName())+"\","+
+    QString().sprintf("%d,",ll->fadeupPoint(RDLogLine::LogPointer))+
+    QString().sprintf("%d,",ll->fadeupGain())+
+    QString().sprintf("%d,",ll->fadedownPoint(RDLogLine::LogPointer))+
+    QString().sprintf("%d,",ll->fadedownGain())+
+    QString().sprintf("%d,",ll->segueGain())+
+    "\""+RDEscapeString(ll->linkEventName())+"\","+
+    QString().sprintf("%d,",QTime().msecsTo(ll->linkStartTime()))+
+    QString().sprintf("%d,",ll->linkLength())+
+    QString().sprintf("%d,",ll->linkId())+
+    "\""+RDYesNo(ll->linkEmbedded())+"\","+
+    "\""+RDEscapeString(ll->originUser())+"\","+
+    RDCheckDateTime(ll->originDateTime(),"yyyy-MM-dd hh:mm:ss")+","+
+    QString().sprintf("%d,",ll->linkStartSlop())+
+    QString().sprintf("%d,",ll->linkEndSlop())+
+    QString().sprintf("%d,",ll->duckUpGain())+
+    QString().sprintf("%d,",ll->duckDownGain())+
+    QString().sprintf("%d)",ll->eventLength());
   *query += sql;
 }
 
