@@ -2,9 +2,7 @@
 //
 // Abstract an RDLogedit Configuration.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdlogedit_conf.cpp,v 1.12.8.1 2014/01/08 18:14:34 cvs Exp $
+//   (C) Copyright 2002-2005,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,13 +32,13 @@ RDLogeditConf::RDLogeditConf(const QString &station)
   
   lib_station=station;
 
-  sql=QString().sprintf("select ID from RDLOGEDIT where STATION=\"%s\"",
-			(const char *)RDEscapeString(lib_station));
+  sql=QString("select ID from RDLOGEDIT where ")+
+    "STATION=\""+RDEscapeString(lib_station)+"\"";
   q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
-    sql=QString().sprintf("insert into RDLOGEDIT set STATION=\"%s\"",
-			  (const char *)RDEscapeString(lib_station));
+    sql=QString("insert into RDLOGEDIT set ")+
+      "STATION=\""+RDEscapeString(lib_station)+"\"";
     q=new RDSqlQuery(sql);
   }
   delete q;
@@ -187,6 +185,19 @@ void RDLogeditConf::setTailPreroll(unsigned length) const
 }
 
 
+QString RDLogeditConf::waveformCaption() const
+{
+  return RDGetSqlValue("RDLOGEDIT","STATION",lib_station,"WAVEFORM_CAPTION").
+    toString();
+}
+
+
+void RDLogeditConf::setWaveformCaption(const QString &str)
+{
+  SetRow("WAVEFORM_CAPTION",str);
+}
+
+
 unsigned RDLogeditConf::startCart() const
 {
   return RDGetSqlValue("RDLOGEDIT","STATION",lib_station,"START_CART").toUInt();
@@ -276,23 +287,24 @@ void RDLogeditConf::setDefaultTransType(RDLogLine::TransType type)
 }
 
 
-#ifndef WIN32
 void RDLogeditConf::getSettings(RDSettings *s) const
 {
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("select DEFAULT_CHANNELS,SAMPRATE,\
-                         FORMAT,BITRATE,RIPPER_LEVEL,\
-                         TRIM_THRESHOLD from RDLOGEDIT \
-                         where STATION=\"%s\"",
-			(const char *)RDEscapeString(lib_station));
+  sql=QString("select ")+
+    "DEFAULT_CHANNELS,"+  // 00
+    "FORMAT,"+            // 02
+    "BITRATE,"+           // 03
+    "RIPPER_LEVEL,"+      // 04
+    "TRIM_THRESHOLD "+    // 05
+    "from RDLOGEDIT where "+
+    "STATION=\""+RDEscapeString(lib_station)+"\"";
   q=new RDSqlQuery(sql);
   s->clear();
   if(q->first()) {
     s->setChannels(q->value(0).toUInt());
-    s->setSampleRate(q->value(1).toUInt());
-    switch(q->value(2).toInt()) {
+    switch(q->value(1).toInt()) {
 	case 0:
 	  s->setFormat(RDSettings::Pcm16);
 	  break;
@@ -301,13 +313,18 @@ void RDLogeditConf::getSettings(RDSettings *s) const
 	  s->setFormat(RDSettings::MpegL2);
 	  break;
     }
-    s->setBitRate(q->value(3).toUInt());
-    s->setNormalizationLevel(q->value(4).toUInt());
-    s->setAutotrimLevel(q->value(5).toUInt());
+    s->setBitRate(q->value(2).toUInt());
+    s->setNormalizationLevel(q->value(3).toUInt());
+    s->setAutotrimLevel(q->value(4).toUInt());
+  }
+  delete q;
+  sql=QString("select SAMPLE_RATE from SYSTEM");
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    s->setSampleRate(q->value(0).toUInt());
   }
   delete q;
 }
-#endif  // WIN32
 
 
 void RDLogeditConf::SetRow(const QString &param,int value) const
@@ -315,10 +332,9 @@ void RDLogeditConf::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE RDLOGEDIT SET %s=%d WHERE STATION=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)RDEscapeString(lib_station));
+  sql=QString().sprintf("update RDLOGEDIT set ")+
+    param+QString().sprintf("=%d where ",value)+
+    "STATION=\""+RDEscapeString(lib_station)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -329,10 +345,22 @@ void RDLogeditConf::SetRow(const QString &param,unsigned value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE RDLOGEDIT SET %s=%d WHERE STATION=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)RDEscapeString(lib_station));
+  sql=QString("update RDLOGEDIT set ")+
+    param+QString().sprintf("=%d where ",value)+
+    "STATION=\""+RDEscapeString(lib_station)+"\"",
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
+void RDLogeditConf::SetRow(const QString &param,const QString &value) const
+{
+  RDSqlQuery *q;
+  QString sql;
+
+  sql=QString("update RDLOGEDIT set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    "STATION=\""+RDEscapeString(lib_station)+"\"",
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -343,10 +371,9 @@ void RDLogeditConf::SetRow(const QString &param,bool value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("update RDLOGEDIT set %s=\"%s\" where STATION=\"%s\"",
-			(const char *)param,
-			(const char *)RDYesNo(value),
-			(const char *)RDEscapeString(lib_station));
+  sql=QString("update RDLOGEDIT set ")+
+    param+"=\""+RDYesNo(value)+"\" where "+
+    "STATION=\""+RDEscapeString(lib_station)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
