@@ -1,10 +1,8 @@
 // rdnownext.h
 //
-// Rivendell Now & Next Implementation
+// Rivendell Metadata Wildcards Implementation
 //
-//   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdnownext.h,v 1.3.8.1 2013/10/16 21:14:36 cvs Exp $
+//   (C) Copyright 2008-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,9 +22,8 @@
 #define RDNOWNEXT_H
 
 #include <rdlog_line.h>
-#include "../rlm/rlm.h"
 
-void RDResolveNowNext(QString *str,RDLogLine **loglines,int encoding);
+QString RDResolveNowNext(const QString &pattern,RDLogLine *ll,int line);
 
 
 #endif  // RDNOWNEXT_H
