@@ -2,7 +2,7 @@
 //
 // Abstract a Rivendell Report Descriptor
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2004,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,14 +23,12 @@
 #include <qfile.h>
 #include <qobject.h>
 
-#include <rdconf.h>
-#include <rdreport.h>
-#include <rdcreate_log.h>
-#include <rdlog_line.h>
-#include <rdescape_string.h>
-#include <rddb.h>
-#include <rdescape_string.h>
-#include <rddatedecode.h>
+#include "rdapplication.h"
+#include "rdconf.h"
+#include "rddatedecode.h"
+#include "rdescape_string.h"
+#include "rdlog_line.h"
+#include "rdreport.h"
 
 RDReport::RDReport(const QString &rptname,RDStation *station,RDConfig *config,
 		   QObject *parent)
@@ -50,10 +48,9 @@ QString RDReport::name() const
 
 bool RDReport::exists() const
 {
-  RDSqlQuery *q=new RDSqlQuery(QString().sprintf("select NAME from REPORTS\
-                                                where NAME=\"%s\"",
-						 (const char *)
-						 RDEscapeString(report_name)));
+  QString sql=QString("select NAME from REPORTS where ")+
+    "NAME=\""+RDEscapeString(report_name)+"\"";
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     return false;
@@ -313,13 +310,8 @@ RDReport::ErrorCode RDReport::errorCode() const
 bool RDReport::outputExists(const QDate &startdate)
 {
   QString out_path;
-#ifdef WIN32
-  out_path=RDDateDecode(exportPath(RDReport::Windows),startdate,report_station,
-			report_config,serviceName());
-#else
   out_path=RDDateDecode(exportPath(RDReport::Linux),startdate,report_station,
 			report_config,serviceName());
-#endif
   return QFile::exists(out_path);
 }
 
@@ -332,7 +324,7 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   RDSqlQuery *q1;
   RDSqlQuery *q2;
   RDSvc *svc;
-  QString rec_name;
+  //  QString rec_name;
   QString daypart_sql;
   QString station_sql;
   QString group_sql;
@@ -376,13 +368,13 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   //
   // Generate the Station List
   //
-  sql=QString().sprintf("select STATION_NAME from REPORT_STATIONS \
-                         where REPORT_NAME=\"%s\"",
-			(const char *)name());
+  sql=QString("select STATION_NAME from REPORT_STATIONS where ")+
+    "REPORT_NAME=\""+RDEscapeString(name())+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    station_sql+=QString().sprintf("(STATION_NAME=\"%s\")||",
-				   (const char *)q->value(0).toString());
+    station_sql+=
+      QString("(STATION_NAME=\"")+
+      RDEscapeString(q->value(0).toString())+"\")||";
   }
   delete q;
   station_sql=station_sql.left(station_sql.length()-2);
@@ -405,25 +397,23 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
     }
   }
   if(filterGroups()) {
-    QString sql2=QString().sprintf("select GROUP_NAME from REPORT_GROUPS \
-                                    where REPORT_NAME=\"%s\"",
-				   (const char *)RDEscapeString(name()));
+    QString sql2=QString("select GROUP_NAME from REPORT_GROUPS where ")+
+      "REPORT_NAME=\""+RDEscapeString(name())+"\"";
     q=new RDSqlQuery(sql2);
     while(q->next()) {
       if(!where) {
 	sql+="where ";
 	where=true;
       }
-      sql+=QString().sprintf("(NAME=\"%s\")||",
-		     (const char *)RDEscapeString(q->value(0).toString()));
+      sql+=QString("(NAME=\"")+RDEscapeString(q->value(0).toString())+"\")||";
     }
     delete q;
   }
   sql=sql.left(sql.length()-2);
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    group_sql+=QString().sprintf("(CART.GROUP_NAME=\"%s\")||",
-				 (const char *)q->value(0).toString());
+    group_sql+=QString("(CART.GROUP_NAME=\"")+
+      RDEscapeString(q->value(0).toString())+"\")||";
   }
   delete q;
   group_sql=group_sql.left(group_sql.length()-2);
@@ -432,32 +422,19 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   }
   
   //
-  // Generate Mixdown Table
+  // Generate Mixdown ID
   //
-  // Create Table
-  //
-  QString mixname="MIXDOWN"+station->name();
-  sql=QString("drop table `")+mixname+"_SRT`";
-  QSqlQuery *p;
-  p=new QSqlQuery(sql);
-  delete p;
-  sql=RDCreateReconciliationTableSql(mixname+"_SRT",report_config);
-  q=new RDSqlQuery(sql);
-  delete q;
+  QString mixname=QString().sprintf("MIX-%d",getpid());
 
   //
   // Iterate Selected Services
   //
-  sql=QString().sprintf("select SERVICE_NAME from REPORT_SERVICES \
-                         where REPORT_NAME=\"%s\"",
-			(const char *)name());
+  sql=QString("select SERVICE_NAME from REPORT_SERVICES where ")+
+    "REPORT_NAME=\""+RDEscapeString(name())+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     svc=new RDSvc(q->value(0).toString(),report_station,report_config);
     if(svc->exists()) {
-      rec_name=q->value(0).toString();
-      rec_name.replace(" ","_");
-
       //
       // Generate Type Filters
       //
@@ -465,14 +442,12 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       if(!exportTypeEnabled(RDReport::Generic)) {
 	if(exportTypeForced(RDReport::Traffic)||
 	   exportTypeEnabled(RDReport::Traffic)) {
-	  force_sql+=QString().sprintf("(`%s_SRT`.EVENT_SOURCE=%d)||",
-				       (const char *)rec_name,
+	  force_sql+=QString().sprintf("(ELR_LINES.EVENT_SOURCE=%d)||",
 				       RDLogLine::Traffic);
 	}
 	if(exportTypeForced(RDReport::Music)||
 	   exportTypeEnabled(RDReport::Music)) {
-	  force_sql+=QString().sprintf("(`%s_SRT`.EVENT_SOURCE=%d)||",
-				       (const char *)rec_name,
+	  force_sql+=QString().sprintf("(ELR_LINES.EVENT_SOURCE=%d)||",
 				       RDLogLine::Music);
 	}
 	force_sql=force_sql.left(force_sql.length()-2);
@@ -495,28 +470,29 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 	"EXT_ANNC_TYPE,"+                    // 10
 	"PLAY_SOURCE,"+                      // 11
 	"CUT_NUMBER,"+                       // 12
-	"EVENT_SOURCE,"+                     // 13
-	"EXT_CART_NAME,"+                    // 14
-	"LOG_NAME,"+                         // 15
-	"`"+rec_name+"_SRT`.TITLE,"+         // 16
-	"`"+rec_name+"_SRT`.ARTIST,"+        // 17
-	"SCHEDULED_TIME,"+                   // 18
-	"START_SOURCE,"+                     // 19
-	"`"+rec_name+"_SRT`.PUBLISHER,"+     // 20
-	"`"+rec_name+"_SRT`.COMPOSER,"+      // 21
-	"`"+rec_name+"_SRT`.ALBUM,"+         // 22
-	"`"+rec_name+"_SRT`.LABEL,"+         // 23
-	"`"+rec_name+"_SRT`.ISRC,"+          // 24
-	"`"+rec_name+"_SRT`.USAGE_CODE,"+    // 25
-	"`"+rec_name+"_SRT`.ONAIR_FLAG,"+    // 26
-	"`"+rec_name+"_SRT`.ISCI,"+          // 27
-	"`"+rec_name+"_SRT`.CONDUCTOR,"+     // 28
-	"`"+rec_name+"_SRT`.USER_DEFINED,"+  // 29
-	"`"+rec_name+"_SRT`.SONG_ID,"+       // 30
-	"`"+rec_name+"_SRT`.DESCRIPTION,"+   // 31
-	"`"+rec_name+"_SRT`.OUTCUE "+        // 32
-	"from `"+rec_name+"_SRT` left join CART "+
-	"on `"+rec_name+"_SRT`.CART_NUMBER=CART.NUMBER where ";
+	"EVENT_SOURCE,"+            // 13
+	"EXT_CART_NAME,"+           // 14
+	"LOG_NAME,"+                // 15
+	"ELR_LINES.TITLE,"+         // 16
+	"ELR_LINES.ARTIST,"+        // 17
+	"SCHEDULED_TIME,"+          // 18
+	"START_SOURCE,"+            // 19
+	"ELR_LINES.PUBLISHER,"+     // 20
+	"ELR_LINES.COMPOSER,"+      // 21
+	"ELR_LINES.ALBUM,"+         // 22
+	"ELR_LINES.LABEL,"+         // 23
+	"ELR_LINES.ISRC,"+          // 24
+	"ELR_LINES.USAGE_CODE,"+    // 25
+	"ELR_LINES.ONAIR_FLAG,"+    // 26
+	"ELR_LINES.ISCI,"+          // 27
+	"ELR_LINES.CONDUCTOR,"+     // 28
+	"ELR_LINES.USER_DEFINED,"+  // 29
+	"ELR_LINES.SONG_ID,"+       // 30
+	"ELR_LINES.DESCRIPTION,"+   // 31
+	"ELR_LINES.OUTCUE "+        // 32
+	"from ELR_LINES left join CART "+
+	"on ELR_LINES.CART_NUMBER=CART.NUMBER where "+
+	"SERVICE_NAME=\""+RDEscapeString(q->value(0).toString())+"\" && ";
 
       //
       // OnAir Flag Filter
@@ -556,11 +532,12 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       sql+=")";
       q1=new RDSqlQuery(sql);
       while(q1->next()) {
-	sql=QString("insert into `")+mixname+"_SRT` "+
-	  "set "+QString().sprintf("LENGTH=%d,LOG_ID=%u,CART_NUMBER=%u,",
-				   q1->value(0).toInt(),
-				   q1->value(1).toUInt(),
-				   q1->value(2).toInt())+
+	sql=QString("insert into ELR_LINES set ")+
+	  "SERVICE_NAME=\""+RDEscapeString(mixname)+"\","+
+	  QString().sprintf("LENGTH=%d,LOG_ID=%u,CART_NUMBER=%u,",
+			    q1->value(0).toInt(),
+			    q1->value(1).toUInt(),
+			    q1->value(2).toInt())+
 	  "STATION_NAME=\""+RDEscapeString(q1->value(3).toString())+"\","+
 	  "EVENT_DATETIME="+RDCheckDateTime(q1->value(4).toDateTime(),
 				     "yyyy-MM-dd hh:mm:ss")+","+
@@ -604,14 +581,8 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   delete q;
 
   bool ret=false;
-#ifdef WIN32
-  QString filename=RDDateDecode(exportPath(RDReport::Windows),startdate,
-				report_station,report_config,serviceName());
-#else
   QString filename=RDDateDecode(exportPath(RDReport::Linux),startdate,
 				report_station,report_config,serviceName());
-#endif
-
   switch(filter()) {
   case RDReport::CbsiDeltaFlex:
     ret=ExportDeltaflex(filename,startdate,enddate,mixname);
@@ -683,22 +654,14 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
     return false;
     break;
   }
-#ifdef WIN32
-  *out_path=RDDateDecode(exportPath(RDReport::Windows),startdate,report_station,
-			 report_config,serviceName());
-  QString post_cmd=RDDateDecode(postExportCommand(RDReport::Windows),startdate,
-				report_station,report_config,serviceName());
-#else
   *out_path=RDDateDecode(exportPath(RDReport::Linux),startdate,report_station,
 			 report_config,serviceName());
   QString post_cmd=RDDateDecode(postExportCommand(RDReport::Linux),startdate,
 				report_station,report_config,serviceName());
-#endif
   system(post_cmd);
-  //  printf("MIXDOWN TABLE: %s_SRT\n",(const char *)mixname);
-  sql=QString().sprintf("drop table `%s_SRT`",(const char *)mixname);
-  q=new RDSqlQuery(sql);
-  delete q;
+  sql=QString("delete from ELR_LINES where ")+
+    "SERVICE_NAME=\""+RDEscapeString(mixname)+"\"";
+  RDSqlQuery::apply(sql);
 
   return ret;
 }
@@ -867,27 +830,50 @@ QString RDReport::errorText(RDReport::ErrorCode code)
 }
 
 
-QString RDReport::StringField(const QString &str,const QString &null_text) const
+QString RDReport::leftJustify(const QString &str,int width)
 {
-  QString ret=null_text;
+  QString ret=str.left(width);
 
-  if(!str.isEmpty()) {
-    ret=str;
+  while(ret.length()<width) {
+    ret+=" ";
   }
 
   return ret;
 }
 
 
+QString RDReport::rightJustify(const QString &str,int width)
+{
+  QString ret=str.left(width);
+
+  while(ret.length()<width) {
+    ret=" "+ret;
+  }
+
+  return ret;
+}
+
+
+QString RDReport::center(const QString &str,int width)
+{
+  QString ret=str.left(width);
+
+  int margin=(width-ret.length())/2;
+  for(int i=0;i<margin;i++) {
+    ret=" "+ret;
+  }
+  return ret;
+}
+
+
 void RDReport::SetRow(const QString &param,const QString &value) const
 {
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE REPORTS SET %s=\"%s\" WHERE NAME=\"%s\"",
-			(const char *)param,
-			(const char *)RDEscapeString(value),
-			(const char *)report_name);
+  sql=QString("update REPORTS set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    "NAME=\""+RDEscapeString(report_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -898,10 +884,9 @@ void RDReport::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE REPORTS SET %s=%d WHERE NAME=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)report_name);
+  sql=QString("update REPORTS set ")+
+    param+QString().sprintf("=%d where ",value)+
+    "NAME=\""+RDEscapeString(report_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -912,10 +897,9 @@ void RDReport::SetRow(const QString &param,unsigned value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE REPORTS SET %s=%u WHERE NAME=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)report_name);
+  sql=QString("update REPORTS set ")+
+    param+QString().sprintf("=%u where ",value)+
+    "NAME=\""+RDEscapeString(report_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -926,10 +910,9 @@ void RDReport::SetRow(const QString &param,bool value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE REPORTS SET %s=\"%s\" WHERE NAME=\"%s\"",
-			(const char *)param,
-			(const char *)RDYesNo(value),
-			(const char *)report_name);
+  sql=QString("update REPORTS set ")+
+    param+"=\""+RDYesNo(value)+"\" where "+
+    "NAME=\""+RDEscapeString(report_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -940,10 +923,9 @@ void RDReport::SetRow(const QString &param,const QTime &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE REPORTS SET %s=%s WHERE NAME=\"%s\"",
-			(const char *)param,
-			(const char *)RDCheckDateTime(value, "hh:mm:ss"),
-			(const char *)report_name);
+  sql=QString("update REPORTS set ")+
+    param+"="+RDCheckDateTime(value, "hh:mm:ss")+" where "+
+    "NAME=\""+RDEscapeString(report_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
