@@ -93,6 +93,9 @@ class RDReport
   static bool multipleDaysAllowed(RDReport::ExportFilter filter);
   static bool multipleMonthsAllowed(RDReport::ExportFilter filter);
   static QString errorText(RDReport::ErrorCode code);
+  static QString leftJustify(const QString &str,int width);
+  static QString rightJustify(const QString &str,int width);
+  static QString center(const QString &str,int width);
 
  private:
   bool ExportDeltaflex(const QString &filename,const QDate &startdate,
@@ -120,7 +123,6 @@ class RDReport
 		       const QDate &enddate,const QString &mixtable);
   bool ExportCutLog(const QString &filename,const QDate &startdate,
 		    const QDate &enddate,const QString &mixtable);
-  QString StringField(const QString &str,const QString &null_text="") const;
   void SetRow(const QString &param,const QString &value) const;
   void SetRow(const QString &param,int value) const;
   void SetRow(const QString &param,unsigned value) const;
