@@ -56,10 +56,6 @@ class RDStation
   QString webServiceUrl(RDConfig *config) const;
   int timeOffset();
   void setTimeOffset(int msecs);
-  QString backupPath() const;
-  void setBackupPath(QString path) const;
-  int backupLife() const;
-  void setBackupLife(int days) const;
   unsigned heartbeatCart() const;
   void setHeartbeatCart(unsigned cartnum) const;
   unsigned heartbeatInterval() const;
@@ -68,6 +64,8 @@ class RDStation
   void setStartupCart(unsigned cartnum) const;
   QString editorPath() const;
   void setEditorPath(const QString &cmd);
+  QString reportEditorPath() const;
+  void setReportEditorPath(const QString &cmd);
   RDStation::FilterMode filterMode() const;
   void setFilterMode(RDStation::FilterMode mode) const;
   bool startJack() const;
@@ -76,6 +74,8 @@ class RDStation
   void setJackServerName(const QString &str) const;
   QString jackCommandLine() const;
   void setJackCommandLine(const QString &str) const;
+  int jackPorts() const;
+  void setJackPorts(int ports) const;
   int cueCard() const;
   void setCueCard(int card);
   int cuePort() const;
