@@ -35,12 +35,24 @@ RDUser::RDUser(const QString &name)
 }
 
 
+RDUser::RDUser()
+{
+  user_name="";
+}
+
+
 QString RDUser::name() const
 {
   return user_name;
 }
 
 
+void RDUser::setName(const QString &name)
+{
+  user_name=name;
+}
+
+
 bool RDUser::exists() const
 {
   return RDDoesRowExist("USERS","LOGIN_NAME",user_name);
@@ -53,11 +65,12 @@ bool RDUser::authenticated(bool webuser) const
   QString sql;
 
   if(localAuthentication()) {
-    sql=QString().sprintf("select LOGIN_NAME,ENABLE_WEB from USERS \
-                         where LOGIN_NAME=\"%s\"		   \
-                         && PASSWORD=\"%s\"",
-			  (const char *)RDEscapeString(user_name),
-			  (const char *)RDEscapeString(user_password));
+    sql=QString("select ")+
+      "LOGIN_NAME,"+
+      "ENABLE_WEB "+
+      "from USERS where "+
+      "LOGIN_NAME=\""+RDEscapeString(user_name)+"\" && "+
+      "PASSWORD=\""+RDEscapeString(user_password)+"\"";
     q=new RDSqlQuery(sql);
     if(q->first()) {
       bool ret=RDBool(q->value(1).toString())||
@@ -67,7 +80,6 @@ bool RDUser::authenticated(bool webuser) const
     }
     delete q;
   }
-#ifndef WIN32
   else {
     bool ret=false;
     RDPam *pam=new RDPam(pamService());
@@ -75,7 +87,7 @@ bool RDUser::authenticated(bool webuser) const
     delete pam;
     return ret;
   }
-#endif  // WIN32
+
   return false;
 }
 
@@ -253,6 +265,19 @@ void RDUser::setEditAudio(bool priv) const
 }
 
 
+bool RDUser::webgetLogin() const
+{
+  return RDBool(RDGetSqlValue("USERS","LOGIN_NAME",user_name,
+			    "WEBGET_LOGIN_PRIV").toString());
+}
+
+
+void RDUser::setWebgetLogin(bool priv) const
+{
+  SetRow("WEBGET_LOGIN_PRIV",priv);
+}
+
+
 bool RDUser::createLog() const
 {
   return RDBool(RDGetSqlValue("USERS","LOGIN_NAME",user_name,
@@ -475,12 +500,11 @@ bool RDUser::cartAuthorized(unsigned cartnum) const
   RDSqlQuery *q;
   bool ret=false;
 
-  sql=QString().
-      sprintf("select CART.NUMBER from CART \
-               left join USER_PERMS \
-               on CART.GROUP_NAME=USER_PERMS.GROUP_NAME \
-               where (USER_PERMS.USER_NAME=\"%s\")&&(CART.NUMBER=%u)",
-	      (const char *)RDEscapeString(user_name),cartnum);
+  sql=QString("select CART.NUMBER from CART ")+
+    "left join USER_PERMS "+
+    "on CART.GROUP_NAME=USER_PERMS.GROUP_NAME where "+
+    "(USER_PERMS.USER_NAME=\""+RDEscapeString(user_name)+"\")&&"+
+    QString().sprintf("(CART.NUMBER=%u)",cartnum);
   q=new RDSqlQuery(sql);
   ret=q->first();
   delete q;
@@ -518,11 +542,11 @@ QStringList RDUser::services() const
     sql=QString().sprintf("SELECT NAME FROM SERVICES" );
   } 
   else {
-    sql=QString().sprintf("select distinct AUDIO_PERMS.SERVICE_NAME \
-                           from USER_PERMS left join AUDIO_PERMS \
-                           on USER_PERMS.GROUP_NAME=AUDIO_PERMS.GROUP_NAME \
-                           where USER_PERMS.USER_NAME=\"%s\"",
-			  (const char *)RDEscapeString(user_name));
+    sql=QString("select distinct ")+
+      "AUDIO_PERMS.SERVICE_NAME "+
+      "from USER_PERMS left join AUDIO_PERMS "+
+      "on USER_PERMS.GROUP_NAME=AUDIO_PERMS.GROUP_NAME where "+
+      "USER_PERMS.USER_NAME=\""+RDEscapeString(user_name)+"\"";
   }
   
   q=new RDSqlQuery(sql);
@@ -540,10 +564,9 @@ void RDUser::SetRow(const QString &param,const QString &value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE USERS SET %s=\"%s\" WHERE LOGIN_NAME=\"%s\"",
-			(const char *)param,
-			(const char *)RDEscapeString(value),
-			(const char *)user_name);
+  sql=QString("update USERS set ")+
+    param+"=\""+RDEscapeString(value)+"\" where "+
+    "LOGIN_NAME=\""+RDEscapeString(user_name)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -554,10 +577,9 @@ void RDUser::SetRow(const QString &param,int value) const
   RDSqlQuery *q;
   QString sql;
 
-  sql=QString().sprintf("UPDATE USERS SET %s=%d WHERE LOGIN_NAME=\"%s\"",
-			(const char *)param,
-			value,
-			(const char *)user_name);
+  sql=QString("update USERS set ")+
+    param+QString().sprintf("=%d where ",value)+
+    "LOGIN_NAME=\""+user_name+"\"";
   q=new RDSqlQuery(sql);
   delete q;
 }
