@@ -2,7 +2,7 @@
 //
 //   A Container Class for Audio Meta Data.
 //
-//   (C) Copyright 2002-2006,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -25,13 +25,26 @@
 #include <qstringlist.h>
 #include <qdatetime.h>
 
+#include <rdsettings.h>
+
 class RDWaveData
 {
  public:
   enum EndType {UnknownEnd='N',ColdEnd='C',FadeEnd='F'};
+  enum CartType {AudioType=0,MacroType=1};
+  enum UsageCode {UsageFeature=0,UsageOpen=1,UsageClose=2,UsageTheme=3,
+		  UsageBackground=4,UsagePromo=5,UsageLast=6};
   RDWaveData();
   bool metadataFound() const;
   void setMetadataFound(bool state);
+  unsigned cartNumber() const;
+  void setCartNumber(unsigned cartnum);
+  int cutNumber() const;
+  void setCutNumber(int cutnum);
+  QString cutName() const;
+  void setCutName(const QString &str);
+  CartType cartType() const;
+  void setCartType(CartType type);
   QString title() const;
   void setTitle(const QString &str);
   QString artist() const;
@@ -52,8 +65,10 @@ class RDWaveData
   void setComposer(const QString &str);
   QString publisher() const;
   void setPublisher(const QString &str);
-  int usageCode() const;
-  void setUsageCode(int code);
+  QString songId() const;
+  void setSongId(const QString &str);
+  UsageCode usageCode() const;
+  void setUsageCode(UsageCode code);
   QStringList schedCodes() const;
   void setSchedCodes(const QStringList &codes);
   QString licensingOrganization() const;
@@ -90,14 +105,52 @@ class RDWaveData
   void setOutCue(const QString &str);
   RDWaveData::EndType endType() const;
   void setEndType(RDWaveData::EndType type);
-  int introStartPos() const;
-  void setIntroStartPos(int msec);
-  int introEndPos() const;
-  void setIntroEndPos(int msec);
+  int forcedLength() const;
+  void setForcedLength(int msecs);
+  int averageLength() const;
+  void setAverageLength(int msecs);
+  int lengthDeviation() const;
+  void setLengthDeviation(int msecs);
+  int minimumTalkLength() const;
+  void setMinimumTalkLength(int msecs);
+  int maximumTalkLength() const;
+  void setMaximumTalkLength(int msecs);
+  int averageSegueLength() const;
+  void setAverageSegueLength(int msecs);
+  int averageHookLength() const;
+  void setAverageHookLength(int msecs);
+  int cutQuantity() const;
+  void setCutQuantity(int n);
+  int lastCutPlayed() const;
+  void setLastCutPlayed(int cutnum);
+  QDateTime lastPlayDatetime() const;
+  void setLastPlayDatetime(const QDateTime &dt);
+  int length() const;
+  void setLength(int msecs);
+  bool enforceLength() const;
+  void setEnforceLength(bool state);
+  bool asyncronous() const;
+  void setAsyncronous(bool state);
+  QString owner() const;
+  void setOwner(const QString &str);
+  QDateTime metadataDatetime() const;
+  void setMetadataDatetime(const QDateTime &dt);
+  bool dayOfWeek(int dow) const;
+  void setDayOfWeek(int dow,bool state);
+  int weight() const;
+  void setWeight(int weight);
+  bool evergreen() const;
+  void setEvergreen(bool state);
+  int talkStartPos() const;
+  void setTalkStartPos(int msec);
+  int talkEndPos() const;
+  void setTalkEndPos(int msec);
   int segueStartPos() const;
   void setSegueStartPos(int msec);
   int segueEndPos() const;
   void setSegueEndPos(int msec);
+  int segueGain() const;
+  void setSegueGain(int lvl);
   int startPos() const;
   void setStartPos(int msec);
   int endPos() const;
@@ -122,29 +175,49 @@ class RDWaveData
   void setStartDate(const QDate &date);
   QTime startTime() const;
   void setStartTime(const QTime &time);
+  QDateTime startDateTime() const;
   QDate endDate() const;
   void setEndDate(const QDate &date);
   QTime endTime() const;
   void setEndTime(const QTime &time);
+  QDateTime endDateTime() const;
   QTime daypartStartTime() const;
   void setDaypartStartTime(const QTime &time);
   QTime daypartEndTime() const;
   void setDaypartEndTime(const QTime &time);
+  unsigned playCounter() const;
+  void setPlayCounter(unsigned count);
+  RDSettings audioSettings() const;
+  void setAudioSettings(const RDSettings &settings);
+  int playGain() const;
+  void setPlayGain(int lvl);
+  bool validateMarkers(int msec=-1);
+  bool validateDateTimes();
+  QString dump() const;
   void clear();
+  static QString endTypeText(EndType type);
+  static QString cartTypeText(CartType type);
+  static QString usageText(UsageCode code);
 
  private:
   bool data_metadata_found;
+  bool data_datetime_set;
+  unsigned data_cart_number;
+  CartType data_cart_type;
+  int data_cut_number;
+  QString data_cutname;
   QString data_title;
   QString data_artist;
   QString data_album;
   QString data_conductor;
+  QString data_song_id;
   QString data_label;
   int data_release_year;
   QString data_client;
   QString data_agency;
   QString data_composer;
   QString data_publisher;
-  int data_usage_code;
+  UsageCode data_usage_code;
   QStringList data_sched_codes;
   QString data_licensing_organization;
   QString data_copyright_notice;
@@ -162,22 +235,38 @@ class RDWaveData
   QString data_isci;
   QString data_mcn;
   QString data_out_cue;
-  RDWaveData::EndType data_end_type;
-  int data_intro_start_pos;
-  int data_intro_end_pos;
+  EndType data_end_type;
+
+  int data_length;
+  int data_forced_length;
+  int data_average_length;
+  int data_length_deviation;
+  int data_minimum_talk_length;
+  int data_maximum_talk_length;
+  int data_average_segue_length;
+  int data_average_hook_length;
+  int data_cut_quantity;
+  int data_last_cut_played;
+  QDateTime data_last_play_datetime;
+  bool data_enforce_length;
+  bool data_asyncronous;
+  QString data_owner;
+  QDateTime data_metadata_datetime;
+
+  bool data_evergreen;
+  bool data_day_of_week[7];
+  int data_weight;
+  int data_talk_start_pos;
+  int data_talk_end_pos;
   int data_segue_start_pos;
   int data_segue_end_pos;
+  int data_segue_gain;
   int data_start_pos;
   int data_end_pos;
   int data_hook_start_pos;
   int data_hook_end_pos;
   int data_fade_up_pos;
   int data_fade_down_pos;
-/*
-  int data_intro_length;
-  int data_segue_length;
-  int data_full_length;
-*/
   int data_beats_per_minute;
   QString data_tmci_song_id;
   QDate data_origination_date;
@@ -188,6 +277,9 @@ class RDWaveData
   QTime data_end_time;
   QTime data_daypart_start_time;
   QTime data_daypart_end_time;
+  unsigned data_play_counter;
+  RDSettings data_settings;
+  int data_play_gain;
 };
 
 
