@@ -1,7 +1,8 @@
+// add_matrix.cpp
 //
 // Add a Rivendell Matrix
 //
-//   (C) Copyright 2002-2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -17,8 +18,6 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qcombobox.h>
 #include <qspinbox.h>
 #include <qmessagebox.h>
@@ -33,8 +32,10 @@
 #include "rdpasswd.h"
 
 AddMatrix::AddMatrix(QString station,QWidget *parent)
-  : QDialog(parent,"")
+  : RDDialog(parent)
 {
+  setModal(true);
+
   add_station=station;
 
   //
@@ -45,13 +46,7 @@ AddMatrix::AddMatrix(QString station,QWidget *parent)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  setCaption(tr("RDAdmin - Add Switcher"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
+  setWindowTitle("RDAdmin - "+tr("Add Switcher"));
 
   //
   // Matrix Number
@@ -61,7 +56,7 @@ AddMatrix::AddMatrix(QString station,QWidget *parent)
   add_matrix_box->setRange(0,MAX_MATRICES-1);
   QLabel *label=new QLabel(add_matrix_box,tr("&New Matrix Number:"),this);
   label->setGeometry(10,11,150,19);
-  label->setFont(font);
+  label->setFont(labelFont());
   label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -74,7 +69,7 @@ AddMatrix::AddMatrix(QString station,QWidget *parent)
   }
   label=new QLabel(add_type_box,tr("&Switcher Type:"),this);
   label->setGeometry(10,36,150,19);
-  label->setFont(font);
+  label->setFont(labelFont());
   label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -83,7 +78,7 @@ AddMatrix::AddMatrix(QString station,QWidget *parent)
   QPushButton *ok_button=new QPushButton(this);
   ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   ok_button->setDefault(true);
-  ok_button->setFont(font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("&OK"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -93,7 +88,7 @@ AddMatrix::AddMatrix(QString station,QWidget *parent)
   QPushButton *cancel_button=new QPushButton(this);
   cancel_button->
     setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  cancel_button->setFont(font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
