@@ -2,9 +2,7 @@
 //
 // Edit Rivendell RSS Feed Permissions
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: edit_feed_perms.h,v 1.3 2010/07/29 19:32:34 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,18 +21,16 @@
 #ifndef EDIT_FEED_PERMS_H
 #define EDIT_FEED_PERMS_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
+#include <rddialog.h>
 #include <rdlistselector.h>
 
 #include <rduser.h>
 
-
-class EditFeedPerms : public QDialog
+class EditFeedPerms : public RDDialog
 {
   Q_OBJECT
  public:
-  EditFeedPerms(RDUser *user,QWidget *parent=0,const char *name=0);
+  EditFeedPerms(RDUser *user,QWidget *parent=0);
   ~EditFeedPerms();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
