@@ -2,7 +2,7 @@
 //
 // Edit an RDPanel Configuration
 //
-//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,56 +18,35 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
+#include <q3filedialog.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qpainter.h>
-#include <qfiledialog.h>
+#include <qpushbutton.h>
 
-#include <rddb.h>
 #include <rd.h>
-#include <rdtextvalidator.h>
+#include <rddb.h>
+#include <rdescape_string.h>
 #include <rdlist_logs.h>
+#include <rdtextvalidator.h>
 
-#include <edit_rdpanel.h>
-#include <edit_now_next.h>
-
+#include "edit_rdpanel.h"
 
 EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
 			 QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   QString sql;
   RDSqlQuery *q;
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   air_conf=new RDAirPlayConf(station->name(),"RDPANEL");
 
-  //
-  // Create Fonts
-  //
-  QFont unit_font=QFont("Helvetica",12,QFont::Normal);
-  unit_font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",12,QFont::Bold);
-  small_font.setPixelSize(12);
-  QFont big_font=QFont("Helvetica",14,QFont::Bold);
-  big_font.setPixelSize(14);
-
   //
   // Text Validator
   //
@@ -76,21 +55,20 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   //
   // Dialog Name
   //
-  setCaption(tr("Configure RDPanel"));
+  setWindowTitle("RDAdmin - "+tr("Configure RDPanel"));
 
   //
   // Channel Assignments Section
   //
   QLabel *label=new QLabel(tr("Channel Assignments"),this);
-  label->setFont(big_font);
+  label->setFont(sectionLabelFont());
   label->setGeometry(10,10,200,16);
 
   //
   // Sound Panel First Play Output
   //
   label=new QLabel(tr("SoundPanel First Play Output"),this);
-  label->setFont(small_font);
-//  label->setGeometry(395,32,300,16);
+  label->setFont(labelFont());
   label->setGeometry(20,32,300,16);
   air_card_sel[0]=new RDCardSelector(this);
   air_card_sel[0]->setGeometry(15,50,120,117);
@@ -98,20 +76,22 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_start_rml_edit[0]->setGeometry(205,50,160,19);
   air_start_rml_edit[0]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[0],tr("Start RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,50,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   air_stop_rml_edit[0]=new QLineEdit(this);
   air_stop_rml_edit[0]->setGeometry(205,71,160,19);
   air_stop_rml_edit[0]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[0],tr("Stop RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,71,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Sound Panel Second Play Output
   //
   label=new QLabel(tr("SoundPanel Second Play Output"),this);
-  label->setFont(small_font);
+  label->setFont(labelFont());
   label->setGeometry(20,100,300,16);
   air_card_sel[1]=new RDCardSelector(this);
   air_card_sel[1]->setGeometry(15,118,120,117);
@@ -119,20 +99,22 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_start_rml_edit[1]->setGeometry(205,118,160,19);
   air_start_rml_edit[1]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[1],tr("Start RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,118,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   air_stop_rml_edit[1]=new QLineEdit(this);
   air_stop_rml_edit[1]->setGeometry(205,139,160,19);
   air_stop_rml_edit[1]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[1],tr("Stop RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,139,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Sound Panel Third Play Output
   //
   label=new QLabel(tr("SoundPanel Third Play Output"),this);
-  label->setFont(small_font);
+  label->setFont(labelFont());
   label->setGeometry(20,168,300,16);
   air_card_sel[2]=new RDCardSelector(this);
   air_card_sel[2]->setGeometry(15,186,120,117);
@@ -140,20 +122,22 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_start_rml_edit[2]->setGeometry(205,186,160,19);
   air_start_rml_edit[2]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[2],tr("Start RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,186,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   air_stop_rml_edit[2]=new QLineEdit(this);
   air_stop_rml_edit[2]->setGeometry(205,207,160,19);
   air_stop_rml_edit[2]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[2],tr("Stop RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,207,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Sound Panel Fourth Play Output
   //
   label=new QLabel(tr("SoundPanel Fourth Play Output"),this);
-  label->setFont(small_font);
+  label->setFont(labelFont());
   label->setGeometry(20,236,300,16);
   air_card_sel[3]=new RDCardSelector(this);
   air_card_sel[3]->setGeometry(15,254,120,117);
@@ -161,20 +145,22 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_start_rml_edit[3]->setGeometry(205,254,160,19);
   air_start_rml_edit[3]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[3],tr("Start RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,254,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   air_stop_rml_edit[3]=new QLineEdit(this);
   air_stop_rml_edit[3]->setGeometry(205,275,160,19);
   air_stop_rml_edit[3]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[3],tr("Stop RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,275,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Sound Panel Fifth Play Output
   //
   label=new QLabel(tr("SoundPanel Fifth and Later Play Output"),this);
-  label->setFont(small_font);
+  label->setFont(labelFont());
   label->setGeometry(20,304,300,16);
   air_card_sel[4]=new RDCardSelector(this);
   air_card_sel[4]->setGeometry(15,322,120,117);
@@ -182,20 +168,22 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_start_rml_edit[4]->setGeometry(205,322,160,19);
   air_start_rml_edit[4]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[4],tr("Start RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,322,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   air_stop_rml_edit[4]=new QLineEdit(this);
   air_stop_rml_edit[4]->setGeometry(205,343,160,19);
   air_stop_rml_edit[4]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[4],tr("Stop RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,343,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Sound Panel Cue Play Output
   //
   label=new QLabel(tr("SoundPanel Cue Output"),this);
-  label->setFont(small_font);
+  label->setFont(labelFont());
   label->setGeometry(20,372,300,16);
   air_card_sel[5]=new RDCardSelector(this);
   air_card_sel[5]->setGeometry(15,390,120,117);
@@ -203,21 +191,23 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_start_rml_edit[5]->setGeometry(205,390,160,19);
   air_start_rml_edit[5]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[5],tr("Start RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,390,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   air_stop_rml_edit[5]=new QLineEdit(this);
   air_stop_rml_edit[5]->setGeometry(205,411,160,19);
   air_stop_rml_edit[5]->setValidator(validator);
   label=new QLabel(air_start_rml_edit[5],tr("Stop RML:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(135,411,65,19);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
 
   //
   // Display Settings Section
   //
   label=new QLabel(tr("Display Settings"),this);
-  label->setFont(big_font);
-  label->setGeometry(20,438,200,16);
+  label->setFont(sectionLabelFont());
+  label->setGeometry(20,440,200,16);
 
   //
   // Skin Path
@@ -225,8 +215,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_skin_edit=new QLineEdit(this);
   air_skin_edit->setGeometry(135,460,180,20);
   label=new QLabel(air_skin_edit,tr("Background Image:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(10,460,115,20);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   QPushButton *button=new QPushButton(tr("Select"),this);
   button->setGeometry(320,458,50,25);
   connect(button,SIGNAL(clicked()),this,SLOT(selectSkinData()));
@@ -235,8 +226,7 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   // Sound Panel Section
   //
   label=new QLabel(tr("Sound Panel Settings"),this);
-  label->setFont(big_font);
-//  label->setGeometry(430,179,200,16);
+  label->setFont(sectionLabelFont());
   label->setGeometry(430,10,200,16);
 
   //
@@ -247,8 +237,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_station_box->setRange(0,MAX_PANELS);
   air_station_box->setSpecialValueText(tr("None"));
   air_station_label=new QLabel(air_station_box,tr("Host Panels:"),this);
+  air_station_label->setFont(subLabelFont());
   air_station_label->setGeometry(405,35,100,20);
-  air_station_label->setAlignment(AlignRight|AlignVCenter);
+  air_station_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // # of User Panels
@@ -258,8 +249,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_user_box->setRange(0,MAX_PANELS);
   air_user_box->setSpecialValueText(tr("None"));
   air_user_label=new QLabel(air_user_box,tr("User Panels:"),this);
+  air_user_label->setFont(subLabelFont());
   air_user_label->setGeometry(405,57,100,20);
-  air_user_label->setAlignment(AlignRight|AlignVCenter);
+  air_user_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Flash Active Button
@@ -267,8 +259,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_flash_box=new QCheckBox(this);
   air_flash_box->setGeometry(435,85,15,15);
   label=new QLabel(air_flash_box,tr("Flash Active Buttons"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(455,85,150,15);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Pause Panel Button
@@ -276,8 +269,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_panel_pause_box=new QCheckBox(this);
   air_panel_pause_box->setGeometry(435,107,15,15);
   label=new QLabel(air_panel_pause_box,tr("Enable Button Pausing"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(455,107,150,15);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Clear Cart Filter
@@ -285,8 +279,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_clearfilter_box=new QCheckBox(this);
   air_clearfilter_box->setGeometry(435,129,15,15);
   label=new QLabel(air_clearfilter_box,tr("Clear Cart Search Filter"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(455,129,150,15);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Default Service
@@ -294,8 +289,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_defaultsvc_box=new QComboBox(this);
   air_defaultsvc_box->setGeometry(520,151,100,20);
   label=new QLabel(air_defaultsvc_box,tr("Default Service:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(385,151,130,20);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Label Template
@@ -303,8 +299,9 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   air_label_template_edit=new QLineEdit(this);
   air_label_template_edit->setGeometry(520,173,sizeHint().width()-530,20);
   label=new QLabel(air_label_template_edit,tr("Label Template:"),this);
+  label->setFont(subLabelFont());
   label->setGeometry(415,173,100,20);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   //  Ok Button
@@ -312,7 +309,7 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(small_font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -321,7 +318,7 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(small_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -338,7 +335,7 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
   }
   else {
     QMessageBox::information(this,tr("No Audio Configuration Data"),
-			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"/etc/init.d/rivendell start\")\nin order to populate the audio resources database."));
+			    tr("Channel assignments will not be available for this host, as audio resource data\nhas not yet been generated.  Please start the Rivendell daemons on this host\n(by executing, as user 'root',  the command \"systemctl start rivendell\")\nin order to populate the audio resources database."));
     for(int i=0;i<6;i++) {
       air_card_sel[i]->setDisabled(true);
     }
@@ -363,9 +360,8 @@ EditRDPanel::EditRDPanel(RDStation *station,RDStation *cae_station,
 
   air_defaultsvc_box->insertItem(tr("[none]"));
   QString defaultsvc=air_conf->defaultSvc();
-  sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
-                         where STATION_NAME=\"%s\"",
-			(const char *)air_conf->station());
+  sql=QString("select SERVICE_NAME from SERVICE_PERMS where ")+
+    "STATION_NAME=\""+RDEscapeString(air_conf->station())+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     air_defaultsvc_box->insertItem(q->value(0).toString());
@@ -431,7 +427,7 @@ QSizePolicy EditRDPanel::sizePolicy() const
 void EditRDPanel::selectSkinData()
 {
  QString filename=air_skin_edit->text();
-  filename=QFileDialog::getOpenFileName(filename,RD_IMAGE_FILE_FILTER,this,"",
+  filename=Q3FileDialog::getOpenFileName(filename,RD_IMAGE_FILE_FILTER,this,"",
 					tr("Select Image File"));
   if(!filename.isNull()) {
     air_skin_edit->setText(filename);
