@@ -2,7 +2,7 @@
 //
 // Edit Rivendell System-wide Settings.
 //
-//   (C) Copyright 2009,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2009-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,21 +21,21 @@
 #ifndef EDIT_SETTINGS_H
 #define EDIT_SETTINGS_H
 
-#include <map>
+#include <q3listview.h>
 
-#include <qdialog.h>
 #include <qcheckbox.h>
-#include <qlistview.h>
-#include <qspinbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
 #include <qcombobox.h>
+#include <qdialog.h>
+#include <qlabel.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
+#include <qspinbox.h>
 
-#include <rdlabel.h>
-#include <rdsystem.h>
 #include <rdaudiosettings.h>
+#include <rddialog.h>
+#include <rdsystem.h>
 
-class EditSettings : public QDialog
+class EditSettings : public RDDialog
 {
   Q_OBJECT
   public:
@@ -54,14 +54,15 @@ class EditSettings : public QDialog
  private:
    QComboBox *edit_sample_rate_box;
    QCheckBox *edit_duplicate_carts_box;
-   RDLabel *edit_duplicate_label;
+   QLabel *edit_duplicate_label;
    QCheckBox *edit_fix_duplicate_carts_box;
    QLabel *edit_fix_duplicate_carts_label;
    QSpinBox *edit_maxpost_spin;
    QLineEdit *edit_isci_path_edit;
    QComboBox *edit_temp_cart_group_box;
    QCheckBox *edit_show_user_list_box;
-   QListView *edit_duplicate_list;
+   Q3ListView *edit_duplicate_list;
+   QLineEdit *edit_notification_address_edit;
    QPushButton *edit_settings_button;
    QPushButton *edit_save_button;
    QPushButton *edit_ok_button;
