@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Workstation Configuration
 //
-//   (C) Copyright 2002-2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,70 +18,53 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qvalidator.h>
 
-#include <rddb.h>
-#include <rdconf.h>
+#include <rdapplication.h>
 #include <rdcatch_connect.h>
 #include <rdcart_dialog.h>
-#include <rdtextvalidator.h>
+#include <rdconf.h>
+#include <rddb.h>
 #include <rdescape_string.h>
+#include <rdtextvalidator.h>
 
-#include <edit_station.h>
-#include <edit_rdlibrary.h>
-#include <edit_rdairplay.h>
-#include <edit_rdpanel.h>
-#include <edit_rdlogedit.h>
-#include <edit_cartslots.h>
-#include <edit_decks.h>
-#include <edit_audios.h>
-#include <edit_ttys.h>
-#include <list_matrices.h>
-#include <list_hostvars.h>
-#include <edit_backup.h>
-#include <view_adapters.h>
-#include <list_dropboxes.h>
-#include <list_encoders.h>
-#include <edit_jack.h>
-#include <globals.h>
+#include "edit_audios.h"
+#include "edit_cartslots.h"
+#include "edit_decks.h"
+#include "edit_jack.h"
+#include "edit_rdairplay.h"
+#include "edit_rdlibrary.h"
+#include "edit_rdlogedit.h"
+#include "edit_rdpanel.h"
+#include "edit_station.h"
+#include "edit_ttys.h"
+#include "globals.h"
+#include "list_dropboxes.h"
+#include "list_hostvars.h"
+#include "list_matrices.h"
+#include "list_pypads.h"
+#include "view_adapters.h"
 
 EditStation::EditStation(QString sname,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   RDSqlQuery *q;
   QString sql;
   int item=0;
   char temp[256];
 
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
-
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
   setMaximumHeight(sizeHint().height());
 
   station_station=new RDStation(sname);
   station_cae_station=NULL;
 
-  setCaption(tr("Host: ")+sname);
+  setWindowTitle("RDAdmin - "+tr("Host: ")+sname);
 
   GetPrivateProfileString(RD_CONF_FILE,"Identity","Password",temp,"",255);
   station_catch_connect=new RDCatchConnect(0,this);
@@ -94,164 +77,145 @@ EditStation::EditStation(QString sname,QWidget *parent)
   RDTextValidator *validator=new RDTextValidator(this);
   QIntValidator *macro_validator=new QIntValidator(1,RD_MAX_CART_NUMBER,this);
 
-
   //
   // Station Name
   //
   station_name_edit=new QLineEdit(this);
-  station_name_edit->setGeometry(115,11,80,19);
   station_name_edit->setReadOnly(true);
-  QLabel *station_name_label=
-    new QLabel(station_name_edit,tr("Ho&st Name:"),this);
-  station_name_label->setGeometry(10,11,100,19);
-  station_name_label->setFont(font);
-  station_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_name_label=new QLabel(station_name_edit,tr("Ho&st Name:"),this);
+  station_name_label->setFont(labelFont());
+  station_name_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+
+  //
+  // Station Short Name
+  //
+  station_short_name_edit=new QLineEdit(this);
+  station_short_name_edit->setMaxLength(64);
+  station_short_name_label=
+    new QLabel(station_short_name_edit,tr("Short Name:"),this);
+  station_short_name_label->setFont(labelFont());
+  station_short_name_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Station Description
   //
   station_description_edit=new QLineEdit(this);
-  station_description_edit->setGeometry(115,32,sizeHint().width()-125,19);
   station_description_edit->setMaxLength(64);
   station_description_edit->setValidator(validator);
-  QLabel *station_description_label=new QLabel(station_description_edit,
-					       tr("&Description:"),this);
-  station_description_label->setGeometry(10,32,100,19);
-  station_description_label->setFont(font);
-  station_description_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_description_label=
+    new QLabel(station_description_edit,tr("&Description:"),this);
+  station_description_label->setFont(labelFont());
+  station_description_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Station Default Name
   //
   station_default_name_edit=new QComboBox(this);
-  station_default_name_edit->setGeometry(115,53,160,19);
   station_default_name_edit->setEditable(false);
-  QLabel *station_default_name_label=new QLabel(station_default_name_edit,
-						tr("Default &User:"),this);
-  station_default_name_label->setGeometry(10,53,100,19);
-  station_default_name_label->setFont(font);
-  station_default_name_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-
-  //
-  // Broadcast security model
-  //
-  station_broadcast_sec_edit=new QComboBox(this);
-  station_broadcast_sec_edit->setGeometry(115,74,140,19);
-  // Index values should match RDStation class enum and database schema.
-  station_broadcast_sec_edit->insertItem(tr("Host"),0);
-  station_broadcast_sec_edit->insertItem(tr("User"),1);
-  station_broadcast_sec_edit->setEditable(false);
-  QLabel *station_broadcast_sec_label=new QLabel(station_broadcast_sec_edit,
-						 tr("Security Model:"),this);
-  station_broadcast_sec_label->setGeometry(10,74,100,19);
-  station_broadcast_sec_label->setFont(font);
-  station_broadcast_sec_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_default_name_label=
+    new QLabel(station_default_name_edit,tr("Default &User:"),this);
+  station_default_name_label->setFont(labelFont());
+  station_default_name_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Station IP Address
   //
   station_address_edit=new QLineEdit(this);
-  station_address_edit->setGeometry(115,95,120,19);
   station_address_edit->setMaxLength(15);
   station_address_edit->setValidator(validator);
-  QLabel *station_address_label=new QLabel(station_address_edit,
-					   tr("&IP Address:"),this);
-  station_address_label->setGeometry(10,95,100,19);
-  station_address_label->setFont(font);
-  station_address_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_address_label=
+    new QLabel(station_address_edit,tr("&IP Address:"),this);
+  station_address_label->setFont(labelFont());
+  station_address_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
-  // Station Editor Command
+  // Audio Editor Command
   //
-  station_editor_cmd_edit=new QLineEdit(this);
-  station_editor_cmd_edit->setGeometry(115,116,sizeHint().width()-130,19);
-  station_editor_cmd_edit->setMaxLength(255);
-  QLabel *station_editor_cmd_label=new QLabel(station_editor_cmd_edit,
-					      tr("Editor &Command:"),this);
-  station_editor_cmd_label->setGeometry(10,116,100,19);
-  station_editor_cmd_label->setFont(font);
-  station_editor_cmd_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_audio_editor_edit=new QLineEdit(this);
+  station_audio_editor_edit->setMaxLength(191);
+  station_audio_editor_label=
+    new QLabel(station_audio_editor_edit,tr("Audio Editor")+":",this);
+  station_audio_editor_label->setFont(labelFont());
+  station_audio_editor_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
+
+  //
+  // Report Editor Command
+  //
+  station_report_editor_edit=new QLineEdit(this);
+  station_report_editor_edit->setMaxLength(191);
+  station_report_editor_label=
+    new QLabel(station_report_editor_edit,tr("Report Editor")+":",this);
+  station_report_editor_label->setFont(labelFont());
+  station_report_editor_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Station Time Offset
   //
   station_timeoffset_box=new QSpinBox(this);
-  station_timeoffset_box->setGeometry(115,137,80,19);
   station_timeoffset_box->setRange(-RD_MAX_TIME_OFFSET,RD_MAX_TIME_OFFSET);
   station_timeoffset_box->setSuffix(tr(" mS"));
-  QLabel *station_timeoffset_label=new QLabel(station_timeoffset_box,
-					      tr("&Time Offset:"),this);
-  station_timeoffset_label->setGeometry(10,137,100,19);
-  station_timeoffset_label->setFont(font);
-  station_timeoffset_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_timeoffset_label=
+    new QLabel(station_timeoffset_box,tr("&Time Offset:"),this);
+  station_timeoffset_label->setFont(labelFont());
+  station_timeoffset_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Startup Cart
   //
   station_startup_cart_edit=new QLineEdit(this);
-  station_startup_cart_edit->setGeometry(115,158,60,19);
   station_startup_cart_edit->setMaxLength(15);
   station_startup_cart_edit->setValidator(macro_validator);
-  QLabel *station_startup_cart_label=new QLabel(station_startup_cart_edit,
-						tr("&Startup Cart:"),this);
-  station_startup_cart_label->setGeometry(10,158,100,19);
-  station_startup_cart_label->setFont(font);
-  station_startup_cart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_startup_cart_label=
+    new QLabel(station_startup_cart_edit,tr("&Startup Cart:"),this);
+  station_startup_cart_label->setFont(labelFont());
+  station_startup_cart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
-  QPushButton *select_button=new QPushButton(tr("Select"),this);
-  select_button->setFont(small_font);
-  select_button->setGeometry(180,157,50,22);
-  connect(select_button,SIGNAL(clicked()),this,SLOT(selectClicked()));
+  station_startup_select_button=new QPushButton(tr("Select"),this);
+  station_startup_select_button->setFont(subButtonFont());
+  connect(station_startup_select_button,SIGNAL(clicked()),
+	  this,SLOT(selectClicked()));
 
   //
   // Cue Output
   //
   station_cue_sel=new RDCardSelector(this);
-  station_cue_sel->setGeometry(90,179,110,117);
-  QLabel *station_cue_sel_label=new QLabel(station_cue_sel,
-					   tr("Cue &Output:"),this);
-  station_cue_sel_label->setGeometry(10,179,100,19);
-  station_cue_sel_label->setFont(font);
-  station_cue_sel_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_cue_sel_label=
+    new QLabel(station_cue_sel,tr("Cue &Output:"),this);
+  station_cue_sel_label->setFont(labelFont());
+  station_cue_sel_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   station_start_cart_edit=new QLineEdit(this);
-  station_start_cart_edit->setGeometry(270,179,60,20);
   station_start_cart_edit->setValidator(macro_validator);
-  QLabel *station_start_cart_label=new QLabel(station_start_cart_edit,
-					      tr("Start Cart")+":",this);
-  station_start_cart_label->setGeometry(205,179,60,20);
+  station_start_cart_label=
+    new QLabel(station_start_cart_edit,tr("Start Cart")+":",this);
+  station_start_cart_label->setFont(subLabelFont());
   station_start_cart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   station_start_cart_button=new QPushButton(tr("Select"),this);
-  station_start_cart_button->setGeometry(335,178,50,22);
-  station_start_cart_button->setFont(small_font);
+  station_start_cart_button->setFont(subButtonFont());
   connect(station_start_cart_button,SIGNAL(clicked()),
 	  this,SLOT(startCartClickedData()));
 
   station_stop_cart_edit=new QLineEdit(this);
-  station_stop_cart_edit->setGeometry(270,201,60,20);
   station_stop_cart_edit->setValidator(macro_validator);
-  QLabel *station_stop_cart_label=new QLabel(station_stop_cart_edit,
-					      tr("Stop Cart")+":",this);
-  station_stop_cart_label->setGeometry(205,201,60,20);
+  station_stop_cart_label=
+    new QLabel(station_stop_cart_edit,tr("Stop Cart")+":",this);
+  station_stop_cart_label->setFont(subLabelFont());
   station_stop_cart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   station_stop_cart_button=new QPushButton(tr("Select"),this);
-  station_stop_cart_button->setGeometry(335,200,50,22);
-  station_stop_cart_button->setFont(small_font);
+  station_stop_cart_button->setFont(subButtonFont());
   connect(station_stop_cart_button,SIGNAL(clicked()),
 	  this,SLOT(stopCartClickedData()));
-  caeStationActivatedData(station_station->caeStation());
 
   //
   // Heartbeat Checkbox
   //
   station_heartbeat_box=new QCheckBox(this);
-  station_heartbeat_box->setGeometry(10,226,15,15);
-  QLabel *label=new QLabel(station_heartbeat_box,tr("Enable Heartbeat"),this);
-  label->setGeometry(30,224,150,20);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  station_heartbeat_label=
+    new QLabel(station_heartbeat_box,tr("Enable Heartbeat"),this);
+  station_heartbeat_label->setFont(labelFont());
+  station_heartbeat_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(station_heartbeat_box,SIGNAL(toggled(bool)),
 	  this,SLOT(heartbeatToggledData(bool)));
 
@@ -259,25 +223,21 @@ EditStation::EditStation(QString sname,QWidget *parent)
   // Filter Checkbox
   //
   station_filter_box=new QCheckBox(this);
-  station_filter_box->setGeometry(210,226,15,15);
-  label=new QLabel(station_filter_box,tr("Use Realtime Filtering"),this);
-  label->setGeometry(230,226,150,20);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  station_filter_label=
+    new QLabel(station_filter_box,tr("Use Realtime Filtering"),this);
+  station_filter_label->setFont(labelFont());
+  station_filter_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Heartbeat Cart
   //
   station_hbcart_edit=new QLineEdit(this);
-  station_hbcart_edit->setGeometry(65,248,60,19);
   station_hbcart_edit->setValidator(macro_validator);
   station_hbcart_label=new QLabel(station_hbcart_edit,tr("Cart:"),this);
-  station_hbcart_label->setGeometry(10,248,50,19);
-  station_hbcart_label->setFont(font);
-  station_hbcart_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_hbcart_label->setFont(labelFont());
+  station_hbcart_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   station_hbcart_button=new QPushButton(this);
-  station_hbcart_button->setGeometry(140,245,60,26);
-  station_hbcart_button->setFont(font);
+  station_hbcart_button->setFont(subButtonFont());
   station_hbcart_button->setText(tr("Select"));
   connect(station_hbcart_button,SIGNAL(clicked()),
 	  this,SLOT(heartbeatClickedData()));
@@ -286,50 +246,42 @@ EditStation::EditStation(QString sname,QWidget *parent)
   // Heartbeat Interval
   //
   station_hbinterval_spin=new QSpinBox(this);
-  station_hbinterval_spin->setGeometry(275,248,45,19);
   station_hbinterval_spin->setRange(1,300);
   station_hbinterval_label=
     new QLabel(station_hbinterval_spin,tr("Interval:"),this);
-  station_hbinterval_label->setGeometry(220,248,50,19);
-  station_hbinterval_label->setFont(font);
-  station_hbinterval_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_hbinterval_label->setFont(labelFont());
+  station_hbinterval_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   station_hbinterval_unit=new QLabel(tr("secs"),this);
-  station_hbinterval_unit->setGeometry(325,248,100,19);
-  station_hbinterval_unit->setFont(font);
-  station_hbinterval_unit->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  station_hbinterval_unit->setFont(labelFont());
+  station_hbinterval_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // System Maintenance Checkbox
   //
   station_maint_box=new QCheckBox(this);
-  station_maint_box->setGeometry(10,275,15,15);
-  label=
+  station_maint_label=
     new QLabel(station_maint_box,tr("Include in System Maintenance Pool"),this);
-  label->setGeometry(30,273,sizeHint().width()-40,20);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  station_maint_label->setFont(labelFont());
+  station_maint_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Enable Drag & Drop Checkbox
   //
   station_dragdrop_box=new QCheckBox(this);
-  station_dragdrop_box->setGeometry(10,296,15,15);
-  label=new QLabel(station_dragdrop_box,tr("Enable Drag && Drop"),this);
-  label->setGeometry(30,293,sizeHint().width()-40,20);
-  label->setFont(font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  station_dragdrop_label=
+    new QLabel(station_dragdrop_box,tr("Enable Drag && Drop"),this);
+  station_dragdrop_label->setFont(labelFont());
+  station_dragdrop_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Enforce Panel Setup Checkbox
   //
   station_panel_enforce_box=new QCheckBox(this);
-  station_panel_enforce_box->setGeometry(25,314,15,15);
   station_panel_enforce_label=
     new QLabel(station_panel_enforce_box,
 	       tr("Allow Drops on Panels not in Setup Mode"),this);
-  station_panel_enforce_label->setGeometry(45,312,sizeHint().width()-55,20);
-  station_panel_enforce_label->setFont(font);
-  station_panel_enforce_label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  station_panel_enforce_label->setFont(labelFont());
+  station_panel_enforce_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(station_dragdrop_box,SIGNAL(toggled(bool)),
 	  station_panel_enforce_label,SLOT(setEnabled(bool)));
   connect(station_dragdrop_box,SIGNAL(toggled(bool)),
@@ -338,190 +290,179 @@ EditStation::EditStation(QString sname,QWidget *parent)
   //
   // System Services Section
   //
-  label=new QLabel(tr("System Services"),this);
-  label->setGeometry(30,333,110,20);
-  label->setFont(font);
-  label->setAlignment(AlignCenter|ShowPrefix);
+  station_systemservices_groupbox=new QGroupBox(tr("System Services"),this);
+  station_systemservices_groupbox->setFont(labelFont());
 
   //
   // HTTP Service Host
   //
   station_http_station_box=new QComboBox(this);
-  station_http_station_box->setGeometry(145,354,200,19);
   station_http_station_box->setEditable(false);
-  QLabel *station_http_station_label=
+  station_http_station_label=
     new QLabel(station_http_station_box,tr("HTTP Xport:"),this);
-  station_http_station_label->setGeometry(11,354,130,19);
-  station_http_station_label->setFont(font);
-  station_http_station_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_http_station_label->setFont(labelFont());
+  station_http_station_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // CAE Service Host
   //
   station_cae_station_box=new QComboBox(this);
-  station_cae_station_box->setGeometry(145,375,200,19);
   station_cae_station_box->setEditable(false);
   connect(station_cae_station_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(caeStationActivatedData(const QString &)));
-  QLabel *station_cae_station_label=new QLabel(station_cae_station_box,
-					       tr("Core Audio Engine:"),this);
-  station_cae_station_label->setGeometry(11,375,130,19);
-  station_cae_station_label->setFont(font);
-  station_cae_station_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  station_cae_station_label=
+    new QLabel(station_cae_station_box,tr("Core Audio Engine:"),this);
+  station_cae_station_label->setFont(labelFont());
+  station_cae_station_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
-  //  RDLibrary Configuration Button
+  // RDLibrary Configuration Button
   //
-  QPushButton *button=new QPushButton(this);
-  button->setGeometry(20,413,80,50);
-  button->setFont(font);
-  button->setText(tr("RD&Library"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editLibraryData()));
+  station_rdlibrary_button=new QPushButton(this);
+  station_rdlibrary_button->setFont(buttonFont());
+  station_rdlibrary_button->setText(tr("RD&Library"));
+  connect(station_rdlibrary_button,SIGNAL(clicked()),this,SLOT(editLibraryData()));
 
   //
-  //  RDCatch Configuration Button
+  // RDCatch Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(110,413,80,50);
-  button->setFont(font);
-  button->setText(tr("RDCatch"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editDeckData()));
+  station_rdcatch_button=new QPushButton(this);
+  station_rdcatch_button->setFont(buttonFont());
+  station_rdcatch_button->setText(tr("RDCatch"));
+  connect(station_rdcatch_button,SIGNAL(clicked()),this,SLOT(editDeckData()));
 
   //
-  //  RDAirPlay Configuration Button
+  // RDAirPlay Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(200,413,80,50);
-  button->setFont(font);
-  button->setText(tr("RDAirPlay"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editAirPlayData()));
+  station_rdairplay_button=new QPushButton(this);
+  station_rdairplay_button->setFont(buttonFont());
+  station_rdairplay_button->setText(tr("RDAirPlay"));
+  connect(station_rdairplay_button,SIGNAL(clicked()),
+	  this,SLOT(editAirPlayData()));
 
   //
-  //  RDPanel Configuration Button
+  // RDPanel Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(290,413,80,50);
-  button->setFont(font);
-  button->setText(tr("RDPanel"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editPanelData()));
+  station_rdpanel_button=new QPushButton(this);
+  station_rdpanel_button->setFont(buttonFont());
+  station_rdpanel_button->setText(tr("RDPanel"));
+  connect(station_rdpanel_button,SIGNAL(clicked()),this,SLOT(editPanelData()));
 
   //
-  //  RDLogEdit Configuration Button
+  // RDLogEdit Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(20,473,80,50);
-  button->setFont(font);
-  button->setText(tr("RDLogEdit"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editLogEditData()));
+  station_rdlogedit_button=new QPushButton(this);
+  station_rdlogedit_button->setFont(buttonFont());
+  station_rdlogedit_button->setText(tr("RDLogEdit"));
+  connect(station_rdlogedit_button,SIGNAL(clicked()),
+	  this,SLOT(editLogEditData()));
 
   //
-  //  RDCartSlots Configuration Button
+  // RDCartSlots Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(110,473,80,50);
-  button->setFont(font);
-  button->setText(tr("RDCart\nSlots"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editCartSlotsData()));
+  station_rdcartslots_button=new QPushButton(this);
+  station_rdcartslots_button->setFont(buttonFont());
+  station_rdcartslots_button->setText(tr("RDCart\nSlots"));
+  connect(station_rdcartslots_button,SIGNAL(clicked()),
+	  this,SLOT(editCartSlotsData()));
 
   //
   // Dropboxes Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(200,473,80,50);
-  button->setFont(font);
-  button->setText(tr("Dropboxes"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editDropboxesData()));
+  station_dropboxes_button=new QPushButton(this);
+  station_dropboxes_button->setFont(buttonFont());
+  station_dropboxes_button->setText(tr("Dropboxes"));
+  connect(station_dropboxes_button,SIGNAL(clicked()),
+	  this,SLOT(editDropboxesData()));
 
   //
-  //  Switcher Configuration Button
+  // Switcher Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(290,473,80,50);
-  button->setFont(font);
-  button->setText(tr("Switchers\nGPIO"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editSwitcherData()));
+  station_switchers_button=new QPushButton(this);
+  station_switchers_button->setFont(buttonFont());
+  station_switchers_button->setText(tr("Switchers\nGPIO"));
+  connect(station_switchers_button,SIGNAL(clicked()),
+	  this,SLOT(editSwitcherData()));
 
   //
-  //  Host Variables Configuration Button
+  // Host Variables Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(20,533,80,50);
-  button->setFont(font);
-  button->setText(tr("Host\nVariables"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editHostvarsData()));
+  station_hostvars_button=new QPushButton(this);
+  station_hostvars_button->setFont(buttonFont());
+  station_hostvars_button->setText(tr("Host\nVariables"));
+  connect(station_hostvars_button,SIGNAL(clicked()),
+	  this,SLOT(editHostvarsData()));
 
   //
-  //  Audio Ports Configuration Button
+  // Audio Ports Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(110,533,80,50);
-  button->setFont(font);
-  button->setText(tr("Audio\nPorts"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editAudioData()));
+  station_audioports_button=new QPushButton(this);
+  station_audioports_button->setFont(buttonFont());
+  station_audioports_button->setText(tr("ASI Audio\nPorts"));
+  connect(station_audioports_button,SIGNAL(clicked()),
+	  this,SLOT(editAudioData()));
 
   //
-  //  TTY Configuration Button
+  // TTY Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(200,533,80,50);
-  button->setFont(font);
-  button->setText(tr("Serial\nPorts"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editTtyData()));
+  station_ttys_button=new QPushButton(this);
+  station_ttys_button->setFont(buttonFont());
+  station_ttys_button->setText(tr("Serial\nPorts"));
+  connect(station_ttys_button,SIGNAL(clicked()),this,SLOT(editTtyData()));
 
   //
-  //  View Adapters (Audio Resources) Configuration Button
+  // View Adapters (Audio Resources) Configuration Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(290,533,80,50);
-  button->setFont(font);
-  button->setText(tr("Audio\nResources"));
-  connect(button,SIGNAL(clicked()),this,SLOT(viewAdaptersData()));
+  station_adapters_button=new QPushButton(this);
+  station_adapters_button->setFont(buttonFont());
+  station_adapters_button->setText(tr("Audio\nResources"));
+  connect(station_adapters_button,SIGNAL(clicked()),
+	  this,SLOT(viewAdaptersData()));
 
   //
   // JACK Settings Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(110,593,80,50);
-  button->setFont(font);
-  button->setText(tr("JACK\nSettings"));
-  connect(button,SIGNAL(clicked()),this,SLOT(jackSettingsData()));
+  station_jack_button=new QPushButton(this);
+  station_jack_button->setFont(buttonFont());
+  station_jack_button->setText(tr("JACK\nSettings"));
+  connect(station_jack_button,SIGNAL(clicked()),this,SLOT(jackSettingsData()));
 
   //
-  // Backups Configuration Button
+  // PyPAD Instances Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(200,593,80,50);
-  button->setFont(font);
-  button->setText(tr("Backups"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editBackupsData()));
+  station_pypad_button=new QPushButton(this);
+  station_pypad_button->setFont(buttonFont());
+  station_pypad_button->setText(tr("PyPAD\nInstances"));
+  connect(station_pypad_button,SIGNAL(clicked()),
+	  this,SLOT(pypadInstancesData()));
 
   //
-  //  Ok Button
+  // Ok Button
   //
-  QPushButton *ok_button=new QPushButton(this);
-  ok_button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
-  ok_button->setDefault(true);
-  ok_button->setFont(font);
-  ok_button->setText(tr("&OK"));
-  connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
+  station_ok_button=new QPushButton(this);
+  station_ok_button->setDefault(true);
+  station_ok_button->setFont(buttonFont());
+  station_ok_button->setText(tr("&OK"));
+  connect(station_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
-  //  Cancel Button
+  // Cancel Button
   //
-  QPushButton *cancel_button=new QPushButton(this);
-  cancel_button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
-			     80,50);
-  cancel_button->setFont(font);
-  cancel_button->setText(tr("&Cancel"));
-  connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
+  station_cancel_button=new QPushButton(this);
+  station_cancel_button->setFont(buttonFont());
+  station_cancel_button->setText(tr("&Cancel"));
+  connect(station_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Populate Fields
   //
+  caeStationActivatedData(station_station->caeStation());
   station_name_edit->setText(station_station->name());
+  station_short_name_edit->setText(station_station->shortName());
   station_description_edit->setText(station_station->description());
   station_address_edit->setText(station_station->address().toString());
-  station_editor_cmd_edit->setText(station_station->editorPath());
+  station_audio_editor_edit->setText(station_station->editorPath());
+  station_report_editor_edit->setText(station_station->reportEditorPath());
   station_timeoffset_box->setValue(station_station->timeOffset());
   unsigned cartnum=station_station->startupCart();
   if(cartnum>0) {
@@ -568,9 +509,6 @@ EditStation::EditStation(QString sname,QWidget *parent)
     item++;
   }
   delete q;
-  station_broadcast_sec_edit->
-    setCurrentItem((RDStation::BroadcastSecurityMode)station_station->
-                     broadcastSecurity());
   if((cartnum=station_station->heartbeatCart())>0) {
     station_heartbeat_box->setChecked(true);
     station_hbcart_edit->setText(QString().sprintf("%u",cartnum));
@@ -600,12 +538,9 @@ EditStation::EditStation(QString sname,QWidget *parent)
   }
 
   station_http_station_box->insertItem("localhost");
-  //station_http_station_box->insertItem(RD_RDSELECT_LABEL);
   station_cae_station_box->insertItem("localhost");
-  //station_cae_station_box->insertItem(RD_RDSELECT_LABEL);
-  sql=QString().sprintf("select NAME from STATIONS \
-                         where NAME!=\"%s\" order by NAME",
-			(const char *)RDEscapeString(sname));
+  sql=QString("select NAME from STATIONS where ")+
+    "NAME!=\""+RDEscapeString(sname)+"\" order by NAME";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     station_http_station_box->insertItem(q->value(0).toString());
@@ -640,8 +575,8 @@ EditStation::~EditStation()
 
 QSize EditStation::sizeHint() const
 {
-  return QSize(395,723);
-  return QSize(375,723);
+  return QSize(415,744);
+  //  return QSize(395,744);
 } 
 
 
@@ -650,7 +585,7 @@ void EditStation::selectClicked()
   int cartnum=station_startup_cart_edit->text().toInt();
 
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     station_startup_cart_edit->setText(QString().sprintf("%06d",cartnum));
   }
 }
@@ -672,7 +607,7 @@ void EditStation::heartbeatClickedData()
   int cartnum=station_hbcart_edit->text().toInt();
 
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     station_hbcart_edit->setText(QString().sprintf("%06d",cartnum));
   }
 }
@@ -701,7 +636,6 @@ void EditStation::caeStationActivatedData(const QString &station_name)
     station_cue_sel->setDisabled(true);
     station_cue_sel->setDisabled(true);
   }
-
 }
 
 
@@ -711,25 +645,6 @@ QSizePolicy EditStation::sizePolicy() const
 }
 
 
-void EditStation::paintEvent(QPaintEvent *e)
-{
-  QPainter *p=new QPainter(this);
-  p->setPen(black);
-  p->setBrush(black);
-
-  //
-  // System Services
-  //
-  p->moveTo(10,343);
-  p->lineTo(sizeHint().width()-10,343);
-  p->lineTo(sizeHint().width()-10,401);
-  p->lineTo(10,401);
-  p->lineTo(10,343);
-
-  delete p;
-}
-
-
 void EditStation::okData()
 {
   QHostAddress addr;
@@ -739,9 +654,9 @@ void EditStation::okData()
   RDSqlQuery *q;
 
   if(!station_maint_box->isChecked()) {
-    sql=QString().sprintf("select NAME from STATIONS where \
-                         (NAME!=\"%s\")&&(SYSTEM_MAINT=\"Y\")",
-			(const char *)RDEscapeString(station_station->name()));
+    sql=QString("select NAME from STATIONS where ")+
+      "(NAME!=\""+RDEscapeString(station_station->name())+"\")&&"+
+      "(SYSTEM_MAINT=\"Y\")";
     q=new RDSqlQuery(sql);
     if(!q->first()) {
       QMessageBox::warning(this,tr("System Maintenance"),
@@ -771,18 +686,18 @@ void EditStation::okData()
     station_station->setHeartbeatCart(0);
     station_station->setHeartbeatInterval(0);
   }
+  station_station->setShortName(station_short_name_edit->text());
   station_station->setCueCard(station_cue_sel->card());
   station_station->setCuePort(station_cue_sel->port());
   station_station->setCueStartCart(station_start_cart_edit->text().toInt());
   station_station->setCueStopCart(station_stop_cart_edit->text().toInt());
   station_station->setDescription(station_description_edit->text());
   station_station->setDefaultName(station_default_name_edit->currentText());
-  station_station->
-    setBroadcastSecurity((RDStation::BroadcastSecurityMode)
-                           station_broadcast_sec_edit->currentItem());
   station_station->setAddress(addr);
   station_station->
-    setEditorPath(station_editor_cmd_edit->text());
+    setEditorPath(station_audio_editor_edit->text());
+  station_station->
+    setReportEditorPath(station_report_editor_edit->text());
   station_station->setTimeOffset(station_timeoffset_box->value());
   cartnum=station_startup_cart_edit->text().toUInt(&ok);
   if(ok&&(cartnum<=999999)) {
@@ -921,13 +836,6 @@ void EditStation::editHostvarsData()
   delete list_conf;
 }
 
-void EditStation::editBackupsData()
-{
-  EditBackup *edit_backup=new EditBackup(station_station,this);
-  edit_backup->exec();
-  delete edit_backup;
-}
-
 
 void EditStation::editDropboxesData()
 {
@@ -946,12 +854,20 @@ void EditStation::jackSettingsData()
 }
 
 
+void EditStation::pypadInstancesData()
+{
+  ListPypads *d=new ListPypads(station_station,this);
+  d->exec();
+  delete d;
+}
+
+
 void EditStation::startCartClickedData()
 {
   int cartnum=station_start_cart_edit->text().toUInt();
 
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     station_start_cart_edit->setText(QString().sprintf("%06d",cartnum));
   }
 }
@@ -962,15 +878,121 @@ void EditStation::stopCartClickedData()
   int cartnum=station_stop_cart_edit->text().toUInt();
 
   if(admin_cart_dialog->exec(&cartnum,RDCart::Macro,NULL,0,
-			     admin_user->name(),admin_user->password())==0) {
+			     rda->user()->name(),rda->user()->password())==0) {
     station_stop_cart_edit->setText(QString().sprintf("%06d",cartnum));
   }
 }
 
 
+void EditStation::resizeEvent(QResizeEvent *e)
+{
+  station_name_edit->setGeometry(115,11,size().width()-120,19);
+  station_name_label->setGeometry(10,11,100,19);
+
+  station_short_name_edit->setGeometry(115,32,size().width()-120,19);
+  station_short_name_label->setGeometry(10,32,100,19);
+
+  station_description_edit->setGeometry(115,53,size().width()-120,19);
+  station_description_label->setGeometry(10,53,100,19);
+
+  station_default_name_edit->setGeometry(115,74,160,19);
+  station_default_name_label->setGeometry(10,74,100,19);
+
+  station_address_edit->setGeometry(115,95,120,19);
+  station_address_label->setGeometry(10,95,100,19);
+
+  station_audio_editor_edit->setGeometry(115,116,size().width()-120,19);
+  station_audio_editor_label->setGeometry(10,116,100,19);
+
+  station_report_editor_edit->setGeometry(115,137,size().width()-120,19);
+  station_report_editor_label->setGeometry(10,137,100,19);
+
+  station_timeoffset_box->setGeometry(115,158,80,19);
+  station_timeoffset_label->setGeometry(10,158,100,19);
+
+  station_startup_cart_edit->setGeometry(115,179,60,19);
+  station_startup_cart_label->setGeometry(10,179,100,19);
+  station_startup_select_button->setGeometry(180,178,50,22);
+
+  station_cue_sel->setGeometry(90,200,110,117);
+  station_cue_sel_label->setGeometry(10,200,100,19);
+
+  station_start_cart_edit->setGeometry(290,200,60,20);
+  station_start_cart_label->setGeometry(205,200,80,20);
+  station_start_cart_button->setGeometry(355,199,50,22);
+
+  station_stop_cart_edit->setGeometry(290,222,60,20);
+  station_stop_cart_label->setGeometry(205,222,80,20);
+  station_stop_cart_button->setGeometry(355,221,50,22);
+
+  station_heartbeat_box->setGeometry(10,247,15,15);
+  station_heartbeat_label->setGeometry(30,245,150,20);
+
+  station_filter_box->setGeometry(210,247,15,15);
+  station_filter_label->setGeometry(230,245,150,20);
+
+  station_hbcart_edit->setGeometry(65,269,60,19);
+  station_hbcart_label->setGeometry(10,269,50,19);
+  station_hbcart_button->setGeometry(140,266,60,26);
+
+  station_hbinterval_spin->setGeometry(275,269,45,19);
+  station_hbinterval_label->setGeometry(220,269,50,19);
+  station_hbinterval_unit->setGeometry(325,269,100,19);
+
+  station_maint_box->setGeometry(10,296,15,15);
+  station_maint_label->setGeometry(30,294,size().width()-40,20);
+
+  station_dragdrop_box->setGeometry(10,317,15,15);
+  station_dragdrop_label->setGeometry(30,314,size().width()-40,20);
+
+  station_panel_enforce_box->setGeometry(25,335,15,15);
+  station_panel_enforce_label->setGeometry(45,333,size().width()-55,20);
+
+  station_systemservices_groupbox->setGeometry(10,360,size().width()-20,60);
+
+  station_http_station_box->setGeometry(145,375,size().width()-165,19);
+  station_http_station_label->setGeometry(11,375,130,19);
+
+  station_cae_station_box->setGeometry(145,396,size().width()-165,19);
+  station_cae_station_label->setGeometry(11,396,130,19);
+
+  station_rdlibrary_button->setGeometry(30,434,80,50);
+
+  station_rdcatch_button->setGeometry(120,434,80,50);
+
+  station_rdairplay_button->setGeometry(210,434,80,50);
+
+  station_rdpanel_button->setGeometry(300,434,80,50);
+
+  station_rdlogedit_button->setGeometry(30,494,80,50);
+
+  station_rdcartslots_button->setGeometry(120,494,80,50);
+
+  station_dropboxes_button->setGeometry(210,494,80,50);
+
+  station_switchers_button->setGeometry(300,494,80,50);
+
+  station_hostvars_button->setGeometry(30,554,80,50);
+
+  station_audioports_button->setGeometry(120,554,80,50);
+
+  station_ttys_button->setGeometry(210,554,80,50);
+
+  station_adapters_button->setGeometry(300,554,80,50);
+
+  station_jack_button->setGeometry(120,614,80,50);
+
+  station_pypad_button->setGeometry(210,614,80,50);
+
+  station_ok_button->setGeometry(size().width()-180,size().height()-60,80,50);
+  station_cancel_button->
+    setGeometry(size().width()-90,size().height()-60,80,50);
+}
+
+
 QString EditStation::DisplayPart(QString string)
 {
-  for(unsigned i=0;i<string.length();i++) {
+  for(int i=0;i<string.length();i++) {
     if(string.at(i)=='|') {
       return string.right(string.length()-i-1);
     }
@@ -981,7 +1003,7 @@ QString EditStation::DisplayPart(QString string)
 
 QString EditStation::HostPart(QString string)
 {
-  for(unsigned i=0;i<string.length();i++) {
+  for(int i=0;i<string.length();i++) {
     if(string.at(i)=='|') {
       return string.left(i);
     }
