@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Service
 //
-//   (C) Copyright 2002-2004,2008,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,23 +18,13 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
 
-#include <rddb.h>
 #include <rd.h>
-#include <rduser.h>
-#include <rdpasswd.h>
+#include <rdapplication.h>
+#include <rddb.h>
 #include <rdidvalidator.h>
+#include <rdpasswd.h>
 #include <rdtextvalidator.h>
 
 #include "autofill_carts.h"
@@ -44,8 +34,10 @@
 #include "test_import.h"
 
 EditSvc::EditSvc(QString svc,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   QString sql;
   RDSqlQuery *q;
   QString group;
@@ -59,17 +51,9 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   setMinimumHeight(sizeHint().height());
   setMaximumHeight(sizeHint().height());
 
-  svc_svc=new RDSvc(svc,admin_station,admin_config);
+  svc_svc=new RDSvc(svc,rda->station(),rda->config());
 
-  setCaption(tr("Edit Service"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont section_font=QFont("Helvetica",14,QFont::Bold);
-  section_font.setPixelSize(14);
+  setWindowTitle("RDAdmin - "+tr("Edit Service"));
 
   //
   // Text Validators
@@ -83,8 +67,8 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   //
   QLabel *label=new QLabel("General",this);
   label->setGeometry(10,10,120,24);
-  label->setFont(section_font);
-  label->setAlignment(AlignLeft);
+  label->setFont(sectionLabelFont());
+  label->setAlignment(Qt::AlignLeft);
 
   //
   // Service Name
@@ -95,7 +79,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_name_edit->setReadOnly(true);
   label=new QLabel(svc_name_edit,tr("&Service Name:"),this);
   label->setGeometry(10,33,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Service Description
@@ -106,7 +90,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_description_edit->setValidator(validator);
   label=new QLabel(svc_description_edit,tr("Service &Description:"),this);
   label->setGeometry(10,54,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Service Program Code
@@ -117,7 +101,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_program_code_edit->setValidator(validator);
   label=new QLabel(svc_program_code_edit,tr("&Program Code:"),this);
   label->setGeometry(10,73,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Log Name Template
@@ -128,7 +112,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_name_template_edit->setValidator(log_validator);
   label=new QLabel(svc_name_template_edit,tr("Log Name &Template:"),this);
   label->setGeometry(10,94,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Log Description Template
@@ -139,7 +123,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   label=new QLabel(svc_description_template_edit,
 		   tr("Log &Description Template:"),this);
   label->setGeometry(10,115,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Voicetracking Group
@@ -149,7 +133,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_voice_group_box->insertItem(tr("[none]"));
   label=new QLabel(svc_voice_group_box,tr("Voicetrack Group:"),this);
   label->setGeometry(10,136,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Autospot Group
@@ -159,7 +143,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_autospot_group_box->insertItem(tr("[none]"));
   label=new QLabel(svc_autospot_group_box,tr("AutoSpot Group:"),this);
   label->setGeometry(10,157,170,19);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setAlignment(Qt::AlignRight);
 
   //
   // Chain Log
@@ -168,7 +152,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_chain_box->setGeometry(30,180,15,15);
   label=new QLabel(svc_chain_box,tr("Insert CHAIN TO at log end"),this);
   label->setGeometry(50,180,170,19);
-  label->setAlignment(AlignLeft|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft);
 
   //
   // Default Auto Refresh
@@ -178,14 +162,14 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   label=
     new QLabel(svc_autorefresh_box,tr("Enable AutoRefresh By Default"),this);
   label->setGeometry(250,180,200,19);
-  label->setAlignment(AlignLeft|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft);
 
   //
   // Autofill Button
   //
   QPushButton *button=new QPushButton(this);
   button->setGeometry(455,31,150,50);
-  button->setFont(font);
+  button->setFont(buttonFont());
   button->setText(tr("Configure \n&Autofill Carts"));
   connect(button,SIGNAL(clicked()),this,SLOT(autofillData()));
 
@@ -196,7 +180,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_loglife_box->setGeometry(460,95,15,15);
   label=new QLabel(svc_loglife_box,tr("Set Logs to auto-delete"),this);
   label->setGeometry(480,95,240,19);
-  label->setAlignment(AlignLeft|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft);
   svc_loglife_spin=new QSpinBox(this);
   svc_loglife_spin->setGeometry(625,93,50,19);
   svc_loglife_spin->setRange(0,365);
@@ -204,7 +188,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
 	  svc_loglife_spin,SLOT(setEnabled(bool)));
   svc_loglifeorigin_label=new QLabel(svc_loglife_box,tr("days after"),this);
   svc_loglifeorigin_label->setGeometry(685,95,100,19);
-  svc_loglifeorigin_label->setAlignment(AlignLeft|ShowPrefix);
+  svc_loglifeorigin_label->setAlignment(Qt::AlignLeft);
   connect(svc_loglife_box,SIGNAL(toggled(bool)),
 	  svc_loglifeorigin_label,SLOT(setEnabled(bool)));
   svc_loglifeorigin_box=new QComboBox(this);
@@ -221,7 +205,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_shelflife_box->setGeometry(460,117,15,15);
   label=new QLabel(svc_shelflife_box,tr("Purge ELR Data"),this);
   label->setGeometry(480,117,170,19);
-  label->setAlignment(AlignLeft|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft);
   svc_shelflife_spin=new QSpinBox(this);
   svc_shelflife_spin->setGeometry(580,115,50,19);
   svc_shelflife_spin->setRange(0,365);
@@ -229,14 +213,25 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
 	  svc_shelflife_spin,SLOT(setEnabled(bool)));
   label=new QLabel(svc_shelflife_box,tr("days after airing"),this);
   label->setGeometry(640,117,200,19);
-  label->setAlignment(AlignLeft|ShowPrefix);
+  label->setAlignment(Qt::AlignLeft);
+
+  //
+  // Include Import Markers by Default
+  //
+  svc_import_markers_check=new QCheckBox(this);
+  svc_import_markers_check->setGeometry(460,140,15,15);
+  label=
+    new QLabel(svc_shelflife_box,tr("Include Import Markers in Finished Logs"),
+	       this);
+  label->setGeometry(480,140,sizeHint().width()-490,19);
+  label->setAlignment(Qt::AlignLeft);
 
   //
   // Enable Hosts Button
   //
   button=new QPushButton(this);
   button->setGeometry(625,31,150,50);
-  button->setFont(font);
+  button->setFont(buttonFont());
   button->setText(tr("Enable &Hosts"));
   connect(button,SIGNAL(clicked()),this,SLOT(enableHostsData()));
 
@@ -245,8 +240,8 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   //
   label=new QLabel(tr("Traffic Data Import"),this);
   label->setGeometry(10,213,160,24);
-  label->setFont(section_font);
-  label->setAlignment(AlignLeft);
+  label->setFont(sectionLabelFont());
+  label->setAlignment(Qt::AlignLeft);
 
   //
   // Linux Traffic Import Path
@@ -255,9 +250,9 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_tfc_path_edit->setGeometry(185,234,240,19);
   svc_tfc_path_edit->setMaxLength(255);
   svc_tfc_path_edit->setValidator(validator);
-  label=new QLabel(svc_tfc_path_edit,tr("Linux Import Path:"),this);
+  label=new QLabel(svc_tfc_path_edit,tr("Import Path:"),this);
   label->setGeometry(10,234,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_tfc_path_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -268,45 +263,21 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_tfc_preimport_cmd_edit->setGeometry(185,255,240,19);
   svc_tfc_preimport_cmd_edit->setValidator(validator);
   label=
-    new QLabel(svc_tfc_preimport_cmd_edit,tr("Linux Preimport Command:"),this);
+    new QLabel(svc_tfc_preimport_cmd_edit,tr("Preimport Command:"),this);
   label->setGeometry(10,255,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_tfc_preimport_cmd_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
-  //
-  // Windows Traffic Import Path
-  //
-  svc_tfc_win_path_edit=new QLineEdit(this);
-  svc_tfc_win_path_edit->setGeometry(185,276,240,19);
-  svc_tfc_win_path_edit->setMaxLength(255);
-  label=new QLabel(svc_tfc_win_path_edit,tr("Windows Import Path:"),this);
-  label->setGeometry(10,276,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  connect(svc_tfc_win_path_edit,SIGNAL(textChanged(const QString &)),
-	  this,SLOT(textChangedData(const QString &)));
-
-  //
-  // Linux Traffic Preimport Command
-  //
-  svc_tfc_win_preimport_cmd_edit=new QLineEdit(this);
-  svc_tfc_win_preimport_cmd_edit->setGeometry(185,297,240,19);
-  label=new QLabel(svc_tfc_win_preimport_cmd_edit,
-		   tr("Windows Preimport Command:"),this);
-  label->setGeometry(10,297,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  connect(svc_tfc_win_preimport_cmd_edit,SIGNAL(textChanged(const QString &)),
-	  this,SLOT(textChangedData(const QString &)));
-
   //
   // Note Cart
   //
   svc_tfc_label_cart_edit=new QLineEdit(this);
-  svc_tfc_label_cart_edit->setGeometry(185,318,240,19);
+  svc_tfc_label_cart_edit->setGeometry(185,276,240,19);
   svc_tfc_label_cart_edit->setMaxLength(32);
   label=new QLabel(svc_tfc_label_cart_edit,tr("Note Cart String:"),this);
-  label->setGeometry(10,318,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(10,276,170,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_tfc_label_cart_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -314,11 +285,11 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Track String
   //
   svc_tfc_track_edit=new QLineEdit(this);
-  svc_tfc_track_edit->setGeometry(185,339,240,19);
+  svc_tfc_track_edit->setGeometry(185,297,240,19);
   svc_tfc_track_edit->setMaxLength(32);
   label=new QLabel(svc_tfc_track_edit,tr("Insert Voice Track String:"),this);
-  label->setGeometry(10,339,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(10,297,170,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_tfc_track_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -326,10 +297,10 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Traffic Import Template
   //
   svc_tfc_import_template_box=new QComboBox(this);
-  svc_tfc_import_template_box->setGeometry(185,360,240,19);
+  svc_tfc_import_template_box->setGeometry(185,318,240,19);
   label=new QLabel(svc_tfc_import_template_box,tr("Import Template:"),this);
-  label->setGeometry(10,360,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(10,318,170,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_tfc_import_template_box,SIGNAL(activated(int)),
 	  this,SLOT(tfcTemplateActivatedData(int)));
 
@@ -337,15 +308,15 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Traffic Parser Settings
   //
   svc_tfc_fields=new ImportFields(this);
-  svc_tfc_fields->setGeometry(10,381,svc_tfc_fields->sizeHint().width(),
+  svc_tfc_fields->setGeometry(10,339,svc_tfc_fields->sizeHint().width(),
 			      svc_tfc_fields->sizeHint().height());
 
   //
   //  Traffic Test Button
   //
   button=new QPushButton(this);
-  button->setGeometry(360,381,60,40);
-  button->setFont(font);
+  button->setGeometry(360,339,60,40);
+  button->setFont(buttonFont());
   button->setText(tr("Test \n&Traffic"));
   connect(button,SIGNAL(clicked()),this,SLOT(trafficData()));
 
@@ -354,8 +325,8 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   //
   label=new QLabel(tr("Music Data Import"),this);
   label->setGeometry(445,213,160,24);
-  label->setFont(section_font);
-  label->setAlignment(AlignLeft);
+  label->setFont(sectionLabelFont());
+  label->setAlignment(Qt::AlignLeft);
 
   //
   // Linux Music Import Path
@@ -364,9 +335,9 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_mus_path_edit->setGeometry(620,234,240,19);
   svc_mus_path_edit->setMaxLength(255);
   svc_mus_path_edit->setValidator(validator);
-  label=new QLabel(svc_mus_path_edit,tr("Linux Import Path:"),this);
+  label=new QLabel(svc_mus_path_edit,tr("Import Path:"),this);
   label->setGeometry(450,234,165,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_mus_path_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -377,45 +348,21 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   svc_mus_preimport_cmd_edit->setGeometry(620,255,240,19);
   svc_mus_preimport_cmd_edit->setValidator(validator);
   label=
-    new QLabel(svc_mus_preimport_cmd_edit,tr("Linux Preimport Command:"),this);
-  label->setGeometry(450,255,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+    new QLabel(svc_mus_preimport_cmd_edit,tr("Preimport Command:"),this);
+  label->setGeometry(450,255,165,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_mus_preimport_cmd_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
-  //
-  // Windows Music Import Path
-  //
-  svc_mus_win_path_edit=new QLineEdit(this);
-  svc_mus_win_path_edit->setGeometry(620,276,240,19);
-  svc_mus_win_path_edit->setMaxLength(255);
-  label=new QLabel(svc_mus_win_path_edit,tr("Windows Import Path:"),this);
-  label->setGeometry(450,276,165,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  connect(svc_mus_win_path_edit,SIGNAL(textChanged(const QString &)),
-	  this,SLOT(textChangedData(const QString &)));
-
-  //
-  // Windows Music Preimport Command
-  //
-  svc_mus_win_preimport_cmd_edit=new QLineEdit(this);
-  svc_mus_win_preimport_cmd_edit->setGeometry(620,297,240,19);
-  label=new QLabel(svc_mus_win_preimport_cmd_edit,
-		   tr("Windows Preimport Command:"),this);
-  label->setGeometry(450,297,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
-  connect(svc_mus_win_preimport_cmd_edit,SIGNAL(textChanged(const QString &)),
-	  this,SLOT(textChangedData(const QString &)));
-
   //
   // Label Cart
   //
   svc_mus_label_cart_edit=new QLineEdit(this);
-  svc_mus_label_cart_edit->setGeometry(620,318,240,19);
+  svc_mus_label_cart_edit->setGeometry(620,276,240,19);
   svc_mus_label_cart_edit->setMaxLength(32);
   label=new QLabel(svc_mus_label_cart_edit,tr("Note Cart String:"),this);
-  label->setGeometry(450,318,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(450,276,165,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_mus_label_cart_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -423,11 +370,11 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Insert Voice Track String
   //
   svc_mus_track_edit=new QLineEdit(this);
-  svc_mus_track_edit->setGeometry(620,339,240,19);
+  svc_mus_track_edit->setGeometry(620,297,240,19);
   svc_mus_track_edit->setMaxLength(255);
   label=new QLabel(svc_mus_track_edit,tr("Insert Voice Track String:"),this);
-  label->setGeometry(450,339,165,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(450,297,165,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_mus_track_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -435,11 +382,11 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Insert Spot Break String
   //
   svc_mus_break_edit=new QLineEdit(this);
-  svc_mus_break_edit->setGeometry(620,360,240,19);
+  svc_mus_break_edit->setGeometry(620,318,240,19);
   svc_mus_break_edit->setMaxLength(255);
   label=new QLabel(svc_mus_break_edit,tr("Insert Traffic Break String:"),this);
-  label->setGeometry(450,360,165,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(450,318,165,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_mus_break_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(textChangedData(const QString &)));
 
@@ -447,10 +394,10 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Music Import Template
   //
   svc_mus_import_template_box=new QComboBox(this);
-  svc_mus_import_template_box->setGeometry(620,381,240,19);
+  svc_mus_import_template_box->setGeometry(620,339,240,19);
   label=new QLabel(svc_mus_import_template_box,tr("Import Template:"),this);
-  label->setGeometry(450,381,170,19);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setGeometry(450,339,165,19);
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(svc_mus_import_template_box,SIGNAL(activated(int)),
 	  this,SLOT(musTemplateActivatedData(int)));
 
@@ -458,15 +405,15 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   // Music Parser Settings
   //
   svc_mus_fields=new ImportFields(this);
-  svc_mus_fields->setGeometry(445,402,svc_mus_fields->sizeHint().width(),
+  svc_mus_fields->setGeometry(445,360,svc_mus_fields->sizeHint().width(),
 			      svc_mus_fields->sizeHint().height());
 
   //
   // Music Test Button
   //
   button=new QPushButton(this);
-  button->setGeometry(795,402,60,40);
-  button->setFont(font);
+  button->setGeometry(795,360,60,40);
+  button->setFont(buttonFont());
   button->setText(tr("Test \n&Music"));
   connect(button,SIGNAL(clicked()),this,SLOT(musicData()));
 
@@ -476,7 +423,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -486,7 +433,7 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,
 			     80,50);
-  button->setFont(font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -537,14 +484,10 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   else {
     svc_shelflife_spin->setDisabled(true);
   }
-  svc_tfc_path_edit->setText(svc_svc->importPath(RDSvc::Traffic,RDSvc::Linux));
+  svc_import_markers_check->setChecked(svc_svc->includeImportMarkers());
+  svc_tfc_path_edit->setText(svc_svc->importPath(RDSvc::Traffic));
   svc_tfc_preimport_cmd_edit->
-    setText(svc_svc->preimportCommand(RDSvc::Traffic,RDSvc::Linux));
-  svc_tfc_win_path_edit->
-    setText(svc_svc->importPath(RDSvc::Traffic,RDSvc::Windows));  
-  svc_tfc_win_preimport_cmd_edit->
-    setText(svc_svc->preimportCommand(RDSvc::Traffic,RDSvc::Windows));  
-
+    setText(svc_svc->preimportCommand(RDSvc::Traffic));
   svc_tfc_import_template_box->insertItem(tr("[custom]"));
   svc_mus_import_template_box->insertItem(tr("[custom]"));
   sql="select NAME from IMPORT_TEMPLATES order by NAME";
@@ -564,13 +507,9 @@ EditSvc::EditSvc(QString svc,QWidget *parent)
   delete q;
   svc_tfc_label_cart_edit->setText(svc_svc->labelCart(RDSvc::Traffic));
   svc_tfc_track_edit->setText(svc_svc->trackString(RDSvc::Traffic));
-  svc_mus_path_edit->setText(svc_svc->importPath(RDSvc::Music,RDSvc::Linux));
+  svc_mus_path_edit->setText(svc_svc->importPath(RDSvc::Music));
   svc_mus_preimport_cmd_edit->
-    setText(svc_svc->preimportCommand(RDSvc::Music,RDSvc::Linux));
-  svc_mus_win_path_edit->
-    setText(svc_svc->importPath(RDSvc::Music,RDSvc::Windows));  
-  svc_mus_win_preimport_cmd_edit->
-    setText(svc_svc->preimportCommand(RDSvc::Music,RDSvc::Windows));  
+    setText(svc_svc->preimportCommand(RDSvc::Music));
   svc_mus_label_cart_edit->setText(svc_svc->labelCart(RDSvc::Music));
   svc_mus_break_edit->
     setText(svc_svc->breakString());
@@ -593,7 +532,7 @@ EditSvc::~EditSvc()
 
 QSize EditSvc::sizeHint() const
 {
-  return QSize(870,712);
+  return QSize(870,670);
 } 
 
 
@@ -708,16 +647,10 @@ void EditSvc::Save()
   else {
     svc_svc->setElrShelflife(-1);
   }
+  svc_svc->setIncludeImportMarkers(svc_import_markers_check->isChecked());
+  svc_svc->setImportPath(RDSvc::Traffic,svc_tfc_path_edit->text());
   svc_svc->
-    setImportPath(RDSvc::Traffic,RDSvc::Linux,svc_tfc_path_edit->text());
-  svc_svc->
-    setPreimportCommand(RDSvc::Traffic,RDSvc::Linux,
-			svc_tfc_preimport_cmd_edit->text());
-  svc_svc->
-    setImportPath(RDSvc::Traffic,RDSvc::Windows,svc_tfc_win_path_edit->text());
-  svc_svc->
-    setPreimportCommand(RDSvc::Traffic,RDSvc::Windows,
-			svc_tfc_win_preimport_cmd_edit->text());
+    setPreimportCommand(RDSvc::Traffic,svc_tfc_preimport_cmd_edit->text());
   if(svc_tfc_import_template_box->currentItem()==0) {
     svc_svc->setImportTemplate(RDSvc::Traffic,"");
   }
@@ -728,14 +661,8 @@ void EditSvc::Save()
   svc_svc->setLabelCart(RDSvc::Traffic,svc_tfc_label_cart_edit->text());
   svc_svc->setTrackString(RDSvc::Traffic,svc_tfc_track_edit->text());
   svc_tfc_fields->readFields(svc_svc,RDSvc::Traffic);
-  svc_svc->setImportPath(RDSvc::Music,RDSvc::Linux,svc_mus_path_edit->text());
-  svc_svc->setPreimportCommand(RDSvc::Music,RDSvc::Linux,
-			       svc_mus_preimport_cmd_edit->text());
-  svc_svc->
-    setImportPath(RDSvc::Music,RDSvc::Windows,svc_mus_win_path_edit->text());
-  svc_svc->
-    setPreimportCommand(RDSvc::Music,RDSvc::Windows,
-			svc_mus_win_preimport_cmd_edit->text());
+  svc_svc->setImportPath(RDSvc::Music,svc_mus_path_edit->text());
+  svc_svc->setPreimportCommand(RDSvc::Music,svc_mus_preimport_cmd_edit->text());
   if(svc_mus_import_template_box->currentItem()==0) {
     svc_svc->setImportTemplate(RDSvc::Music,"");
   }
