@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Service
 //
-//   (C) Copyright 2002-2010,2016-2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,18 +21,18 @@
 #ifndef EDIT_SVC_H
 #define EDIT_SVC_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
+#include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
 
+#include <rddialog.h>
 #include <rdsvc.h>
-#include <importfields.h>
 
-class EditSvc : public QDialog
+#include "importfields.h"
+
+class EditSvc : public RDDialog
 {
  Q_OBJECT
  public:
@@ -65,8 +65,6 @@ class EditSvc : public QDialog
   QComboBox *svc_autospot_group_box;
   QLineEdit *svc_tfc_path_edit;
   QLineEdit *svc_tfc_preimport_cmd_edit;
-  QLineEdit *svc_tfc_win_path_edit;
-  QLineEdit *svc_tfc_win_preimport_cmd_edit;
   QComboBox *svc_tfc_import_template_box;
   QLineEdit *svc_tfc_label_cart_edit;
   QLineEdit *svc_tfc_track_edit;
@@ -74,8 +72,6 @@ class EditSvc : public QDialog
   ImportFields *svc_mus_fields;
   QLineEdit *svc_mus_path_edit;
   QLineEdit *svc_mus_preimport_cmd_edit;
-  QLineEdit *svc_mus_win_path_edit;
-  QLineEdit *svc_mus_win_preimport_cmd_edit;
   QComboBox *svc_mus_import_template_box;
   QLineEdit *svc_mus_label_cart_edit;
   QLineEdit *svc_mus_break_edit;
@@ -88,6 +84,7 @@ class EditSvc : public QDialog
   QComboBox *svc_loglifeorigin_box;
   QCheckBox *svc_shelflife_box;
   QSpinBox *svc_shelflife_spin;
+  QCheckBox *svc_import_markers_check;
   bool import_changed;
 };
 
