@@ -2,7 +2,7 @@
 //
 // Display System Information for Rivendell
 //
-//   (C) Copyright 2002-2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,47 +18,35 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qstring.h>
 #include <qpushbutton.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qsqldatabase.h>
-#include <qimage.h>
 
 #include <rdlabel.h>
-#include <rdlicense.h>
-#include <rdstation.h>
 #include <rd.h>
 #include <dbversion.h>
 
-#include <info_dialog.h>
+#include "info_dialog.h"
+#include "license.h"
 
 //
 // This is a kludge, but apparently needed to get the bitmap data
 // for the info banners, as Automake refuses to process the cwrap
 // dependency correctly.
 //
-#include <xpm_info_banner1.cpp>
-#include <xpm_info_banner2.cpp>
+#include "xpm_info_banner1.cpp"
+#include "xpm_info_banner2.cpp"
 
 InfoDialog::InfoDialog(QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
-  QString str;
+  setModal(true);
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
-  setCaption(tr("System Information"));
+  setWindowTitle("RDAdmin - "+tr("System Information"));
 
   //
   // Create Fonts
@@ -67,12 +55,6 @@ InfoDialog::InfoDialog(QWidget *parent)
   title_font.setPixelSize(22);
   QFont slogan_font=QFont("Helvetica",14,QFont::Normal);
   slogan_font.setPixelSize(14);
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont bold_font=QFont("Helvetica",10,QFont::Bold);
-  bold_font.setPixelSize(10);
-  QFont font=QFont("Helvetica",10,QFont::Normal);
-  font.setPixelSize(10);
 
   //
   // Banners
@@ -105,47 +87,54 @@ InfoDialog::InfoDialog(QWidget *parent)
   //
   label=new QLabel(tr("A Radio Automation System"),this);
   label->setGeometry(130,52,200,18);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   label->setFont(slogan_font);
 
   //
   // Version
   //
-  str=QString(tr("Version"));
-  label=new QLabel(QString().sprintf("%s %s",(const char *)str,VERSION),this);
+  label=new QLabel(tr("Version")+" "+VERSION,this);
   label->setGeometry(10,73,200,14);
-  label->setFont(font);
+  label->setFont(subLabelFont());
 
-  str=QString(tr("Database Schema"));
-  label=new QLabel(QString().sprintf("%s %d",(const char *)str,
-				     RD_VERSION_DATABASE),this);
-  label->setGeometry(210,73,120,14);
-  label->setAlignment(AlignVCenter|AlignRight);
-  label->setFont(font);
+  label=new QLabel(tr("Database Schema")+
+		   QString().sprintf(" %d",RD_VERSION_DATABASE),this);
+  label->setGeometry(210,73,sizeHint().width()-220,14);
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
+  label->setFont(subLabelFont());
 
   //
   // Signature
   //
-  str=QString(tr("Copyright 2002-2018"));
-  label=new QLabel(QString().sprintf("%s %s",(const char *)str,
-				     PACKAGE_BUGREPORT),this);
+  label=new QLabel(QString::fromUtf8(RD_COPYRIGHT_NOTICE),this);
   label->setGeometry(10,87,sizeHint().width()-20,14);
-  label->setFont(font);
+  label->setFont(subLabelFont());
 
   //
   // Disclaimer
   //
   label=new RDLabel(this);
   label->setGeometry(10,104,sizeHint().width()-20,60);
-  label->setFont(font);
-  label->setText(tr("This program is free software, and comes with ABSOLUTELY NO WARRANTY,\nnot even the implied warranties of MERCHANTIBILITY or FITNESS FOR A\nPARTICULAR PURPOSE.  Touch the \"View License\" button for details."));
+  label->setFont(subLabelFont());
+  label->setWordWrap(true);
+  label->setText(tr("This program is free software, and comes with ABSOLUTELY NO WARRANTY, not even the implied warranties of MERCHANTIBILITY or FITNESS FOR A PARTICULAR PURPOSE. Touch the \"View License\" button for details."));
+  //  label->setText(tr("This program is free software, and comes with ABSOLUTELY NO WARRANTY,\nnot even the implied warranties of MERCHANTIBILITY or FITNESS FOR A\nPARTICULAR PURPOSE.  Touch the \"View License\" button for details."));
+
+  //
+  // Credits Button
+  //
+  QPushButton *button=new QPushButton(this);
+  button->setGeometry(sizeHint().width()/2-145,174,80,50);
+  button->setFont(buttonFont());
+  button->setText(tr("View\n&Credits"));
+  connect(button,SIGNAL(clicked()),this,SLOT(viewCreditsData()));
 
   //
   // License Button
   //
-  QPushButton *button=new QPushButton(this);
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()/2-45,174,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("View\n&License"));
   connect(button,SIGNAL(clicked()),this,SLOT(viewLicenseData()));
 
@@ -153,9 +142,8 @@ InfoDialog::InfoDialog(QWidget *parent)
   //  Close Button
   //
   button=new QPushButton(this);
-  button->setGeometry(sizeHint().width()-90,sizeHint().height()-90,
-			    80,50);
-  button->setFont(button_font);
+  button->setGeometry(sizeHint().width()-90,sizeHint().height()-90,80,50);
+  button->setFont(buttonFont());
   button->setText(tr("&Close"));
   button->setDefault(true);
   connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
@@ -174,10 +162,18 @@ QSizePolicy InfoDialog::sizePolicy() const
 }
 
 
+void InfoDialog::viewCreditsData()
+{
+  License *lic=new License(this);
+  lic->exec(License::Credits);
+  delete lic;
+}
+
+
 void InfoDialog::viewLicenseData()
 {
-  RDLicense *lic=new RDLicense(this);
-  lic->exec(RDLicense::GplV2);
+  License *lic=new License(this);
+  lic->exec(License::GplV2);
   delete lic;
 }
 
