@@ -2,7 +2,7 @@
 //
 // List Rivendell Feeds
 //
-//   (C) Copyright 2002-2007,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,56 +22,40 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
 #include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qbuttongroup.h>
-#include <qprogressdialog.h>
 #include <qapplication.h>
 
+#include <rdapplication.h>
 #include <rddb.h>
-#include <rdcart.h>
-#include <rdtextfile.h>
-#include <rdpodcast.h>
+#include <rdescape_string.h>
 #include <rdfeedlog.h>
+#include <rdpodcast.h>
+#include <rdtextfile.h>
 
-#include <list_feeds.h>
-#include <edit_feed.h>
-#include <add_feed.h>
-#include <globals.h>
+#include "add_feed.h"
+#include "edit_feed.h"
+#include "globals.h"
+#include "list_feeds.h"
 
 ListFeeds::ListFeeds(QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
   setMinimumWidth(sizeHint().width());
   setMinimumHeight(sizeHint().height());
 
-  setCaption(tr("Rivendell Feed List"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont list_font=QFont("Helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
+  setWindowTitle("RDAdmin - "+tr("Rivendell Feed List"));
 
   //
   //  Add Button
   //
   list_add_button=new QPushButton(this);
-  list_add_button->setFont(font);
+  list_add_button->setFont(buttonFont());
   list_add_button->setText(tr("&Add"));
   connect(list_add_button,SIGNAL(clicked()),this,SLOT(addData()));
 
@@ -79,7 +63,7 @@ ListFeeds::ListFeeds(QWidget *parent)
   //  Edit Button
   //
   list_edit_button=new QPushButton(this);
-  list_edit_button->setFont(font);
+  list_edit_button->setFont(buttonFont());
   list_edit_button->setText(tr("&Edit"));
   connect(list_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
 
@@ -87,7 +71,7 @@ ListFeeds::ListFeeds(QWidget *parent)
   //  Delete Button
   //
   list_delete_button=new QPushButton(this);
-  list_delete_button->setFont(font);
+  list_delete_button->setFont(buttonFont());
   list_delete_button->setText(tr("&Delete"));
   connect(list_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
@@ -96,7 +80,7 @@ ListFeeds::ListFeeds(QWidget *parent)
   //
   list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -104,25 +88,24 @@ ListFeeds::ListFeeds(QWidget *parent)
   // Group List
   //
   list_feeds_view=new RDListView(this);
-  list_feeds_view->setFont(list_font);
   list_feeds_view->setAllColumnsShowFocus(true);
   list_feeds_view->addColumn(tr("Key"));
-  list_feeds_view->setColumnAlignment(0,AlignCenter);
+  list_feeds_view->setColumnAlignment(0,Qt::AlignCenter);
   list_feeds_view->addColumn(tr("Title"));
-  list_feeds_view->setColumnAlignment(1,AlignVCenter|AlignLeft);
+  list_feeds_view->setColumnAlignment(1,Qt::AlignLeft);
   list_feeds_view->addColumn(tr("AutoPost"));
-  list_feeds_view->setColumnAlignment(2,AlignVCenter|AlignLeft);
+  list_feeds_view->setColumnAlignment(2,Qt::AlignCenter);
   list_feeds_view->addColumn(tr("Keep Metadata"));
-  list_feeds_view->setColumnAlignment(3,AlignVCenter|AlignLeft);
+  list_feeds_view->setColumnAlignment(3,Qt::AlignCenter);
   list_feeds_view->addColumn(tr("Creation Date"));
-  list_feeds_view->setColumnAlignment(4,AlignCenter);
+  list_feeds_view->setColumnAlignment(4,Qt::AlignCenter);
   QLabel *list_box_label=new QLabel(list_feeds_view,tr("&Feeds:"),this);
-  list_box_label->setFont(font);
+  list_box_label->setFont(labelFont());
   list_box_label->setGeometry(14,11,85,19);
   connect(list_feeds_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   RefreshList();
 }
@@ -162,19 +145,15 @@ void ListFeeds::addData()
 
   EditFeed *edit_feed=new EditFeed(feed,this);
   if(edit_feed->exec()<0) {
-    sql=QString().sprintf("delete from FEED_PERMS where KEY_NAME=\"%s\"",
-			  (const char *)feed);
+    sql=QString("delete from FEED_PERMS where ")+
+      "KEY_NAME=\""+RDEscapeString(feed)+"\"";
     q=new RDSqlQuery(sql);
     delete q;
-    sql=QString().sprintf("delete from FEEDS where KEY_NAME=\"%s\"",
-			  (const char *)feed);
+    sql=QString("delete from FEEDS where ")+
+      "KEY_NAME=\""+RDEscapeString(feed)+"\"";
     q=new RDSqlQuery(sql);
     delete q;
     RDDeleteFeedLog(feed);
-    feed.replace(" ","_");
-    sql=QString().sprintf("drop table %s_FIELDS",(const char *)feed);
-    q=new RDSqlQuery(sql);
-    delete q;
     delete edit_feed;
     return;
   }
@@ -220,9 +199,7 @@ void ListFeeds::deleteData()
   if(feedname.isEmpty()) {
     return;
   }
-  str=QString(tr("Are you sure you want to delete feed"));
-  warning+=QString().sprintf("%s %s?",(const char *)str,
-			     (const char *)feedname);
+  warning+=tr("Are you sure you want to delete feed")+" \""+feedname+"\"?";
   switch(QMessageBox::warning(this,tr("Delete Feed"),warning,
 			      QMessageBox::Yes,QMessageBox::No)) {
       case QMessageBox::No:
@@ -232,7 +209,7 @@ void ListFeeds::deleteData()
       default:
 	break;
   }
-  feed=new RDFeed(feedname);
+  feed=new RDFeed(feedname,rda->config());
 
   //
   // Delete Casts
@@ -242,8 +219,9 @@ void ListFeeds::deleteData()
   RDPodcast *cast;
   sql=QString().sprintf("select ID from PODCASTS where FEED_ID=%d",item->id());
   q=new RDSqlQuery(sql);
-  QProgressDialog *pd=new QProgressDialog(tr("Deleting Audio..."),tr("Cancel"),
-					  q->size()+1,this);
+  Q3ProgressDialog *pd=
+    new Q3ProgressDialog(tr("Deleting Audio..."),tr("Cancel"),q->size()+1,this,
+			 NULL);
   pd->setCaption(tr("Deleting"));
   pd->setProgress(0);
   qApp->processEvents();
@@ -251,8 +229,8 @@ void ListFeeds::deleteData()
   while(q->next()) {
     pd->setProgress(pd->progress()+1);
     qApp->processEvents();
-    cast=new RDPodcast(q->value(0).toUInt());
-    cast->removeAudio(feed,&errs,admin_config->logXloadDebugData());
+    cast=new RDPodcast(rda->config(),q->value(0).toUInt());
+    cast->removeAudio(feed,&errs,rda->config()->logXloadDebugData());
     delete cast;
   }
   delete q;
@@ -267,19 +245,15 @@ void ListFeeds::deleteData()
   //
   // Delete Feed
   //
-  sql=QString().sprintf("delete from FEED_PERMS where KEY_NAME=\"%s\"",
-			(const char *)feedname);
+  sql=QString("delete from FEED_PERMS where ")+
+    "KEY_NAME=\""+RDEscapeString(feedname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
-  sql=QString().sprintf("delete from FEEDS where KEY_NAME=\"%s\"",
-			(const char *)feedname);
+  sql=QString("delete from FEEDS where ")+
+    "KEY_NAME=\""+RDEscapeString(feedname)+"\"";
   q=new RDSqlQuery(sql);
   delete q;
   RDDeleteFeedLog(feedname);
-  feedname.replace(" ","_");
-  sql=QString().sprintf("drop table %s_FIELDS",(const char *)feedname);
-  q=new RDSqlQuery(sql);
-  delete q;
   item->setSelected(false);
 
   pd->reset();
@@ -290,7 +264,7 @@ void ListFeeds::deleteData()
 }
 
 
-void ListFeeds::doubleClickedData(QListViewItem *item,const QPoint &pt,
+void ListFeeds::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
   editData();
