@@ -2,9 +2,7 @@
 //
 // Rename a Rivendell Group
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rename_group.h,v 1.4 2007/09/14 14:06:27 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,22 +21,16 @@
 #ifndef RENAME_GROUP_H
 #define RENAME_GROUP_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpixmap.h>
-#include <qspinbox.h>
-#include <qsqldatabase.h>
 #include <qlineedit.h>
 
+#include <rddialog.h>
 #include <rdgroup.h>
 
-
-class RenameGroup : public QDialog
+class RenameGroup : public RDDialog
 {
   Q_OBJECT
   public:
-   RenameGroup(QString group,QWidget *parent=0,const char *name=0);
+   RenameGroup(QString group,QWidget *parent=0);
    ~RenameGroup();
    QSize sizeHint() const;
    QSizePolicy sizePolicy() const;
