@@ -2,7 +2,7 @@
 //
 // The full log list widget for RDAirPlay.
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,29 +21,20 @@
 #ifndef LIST_LOG_H
 #define LIST_LOG_H
 
-#include <qwidget.h>
-#include <qdatetime.h>
-#include <qlabel.h>
-#include <qpixmap.h>
-#include <qpushbutton.h>
+#include <rdwidget.h>
 
-#include <rdlistview.h>
-#include <rdlistviewitem.h>
-#include <rdairplay_conf.h>
-
-#include <lib_listview.h>
-#include <list_logs.h>
-#include <log_play.h>
-#include <edit_event.h>
-#include <hourselector.h>
+#include "edit_event.h"
+#include "hourselector.h"
+#include "lib_listview.h"
+#include "list_logs.h"
 
 #define END_MARKER_ID -2
 
-class ListLog : public QWidget
+class ListLog : public RDWidget
 {
  Q_OBJECT
  public:
-  ListLog(LogPlay *log,RDCae *cae,int id,bool allow_pause=false,
+  ListLog(RDLogPlay *log,RDCae *cae,int id,bool allow_pause=false,
 	  QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -71,7 +62,7 @@ class ListLog : public QWidget
   void takeButtonData();
   void playButtonData();
   void modifyButtonData();
-  void doubleclickedData(QListViewItem *,const QPoint &,int);
+  void doubleclickedData(Q3ListViewItem *,const QPoint &,int);
   void scrollButtonData();
   void refreshButtonData();
   void nextButtonData();
@@ -88,9 +79,6 @@ class ListLog : public QWidget
   void refreshabilityChangedData(bool state);
   void cartDroppedData(int line,RDLogLine *ll);
 
- protected:
-  void paintEvent(QPaintEvent *e);
-
  private:
   enum PlayButtonMode {ButtonDisabled=0,ButtonPlay=1,ButtonStop=2};
   void RefreshList();
@@ -111,7 +99,7 @@ class ListLog : public QWidget
   int PredictedStartHour(RDListViewItem *item);
   HourSelector *list_hour_selector;
   LibListView *list_log_list;
-  LogPlay *list_log;
+  RDLogPlay *list_log;
   ListLogs *list_logs_dialog;
   RDAirPlayConf::ActionMode list_action_mode;
   ListLog::PlayButtonMode list_playbutton_mode;
