@@ -2,9 +2,7 @@
 //
 // On Air Playout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: loglinebox.cpp,v 1.89.6.8 2014/02/06 20:43:50 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,13 +21,11 @@
 #include <qpainter.h>
 
 #include <rdconf.h>
-#include <rdplay_deck.h>
-#include <rdairplay_conf.h>
 #include <rdnownext.h>
 
-#include <loglinebox.h>
-#include <colors.h>
-#include <globals.h>
+#include "colors.h"
+#include "globals.h"
+#include "loglinebox.h"
 
 #include "../icons/play.xpm"
 #include "../icons/rml5.xpm"
@@ -40,9 +36,8 @@
 #include "../icons/traffic.xpm"
 #include "../icons/music.xpm"
 
-
-LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
-  : QWidget(parent,name)
+LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent)
+  : RDWidget(parent)
 {
   line_status=RDLogLine::Scheduled;
   line_type=RDLogLine::UnknownType;
@@ -63,16 +58,12 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   line_description_template=conf->descriptionTemplate();
 
   //
-  // Create Font
+  // Assign Fonts
   //
-  line_bold_font=QFont("Helvetica",12,QFont::Bold);
-  line_bold_font.setPixelSize(12);
-  line_font=QFont("Helvetica",12,QFont::Normal);
-  line_font.setPixelSize(12);
-  talk_font=QFont("Helvetica",12,QFont::Bold);
-  talk_font.setPixelSize(12);
-  QFont outcue_font=QFont("Helvetica",12,QFont::Normal);
-  outcue_font.setPixelSize(12);
+  line_bold_font=labelFont();
+  line_font=font();
+  talk_font=labelFont();
+  QFont outcue_font=font();
   outcue_font.setItalic(true);
 
   //
@@ -133,23 +124,23 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
 
   line_text_palette=palette();
   line_text_palette.setColor(QPalette::Active,QColorGroup::Foreground,
-				  QColor(black));
+				  QColor(Qt::black));
   line_text_palette.setColor(QPalette::Inactive,QColorGroup::Foreground,
-				  QColor(black));
+				  QColor(Qt::black));
 
   //
   // Count Up
   //
   line_up_label=new QLabel(this);
   line_up_label->setGeometry(5,65,65,16);
-  line_up_label->setAlignment(AlignLeft|AlignVCenter);
+  line_up_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   line_up_label->setFont(line_font);
   line_up_label->hide();
 
   //
   // Position Slider
   //
-  line_position_bar=new QProgressBar(this);
+  line_position_bar=new Q3ProgressBar(this);
   line_position_bar->setGeometry(75,66,sizeHint().width()-150,13);
   line_position_bar->setPercentageVisible(false);
   line_position_bar->hide();
@@ -159,7 +150,7 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   //
   line_down_label=new QLabel(this);
   line_down_label->setGeometry(sizeHint().width()-72,65,65,16);
-  line_down_label->setAlignment(AlignLeft|AlignVCenter);
+  line_down_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   line_down_label->setFont(line_font);
   line_down_label->hide();
 
@@ -199,7 +190,7 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   line_comment_label=new RDLabel(this);
   line_comment_label->setGeometry(5,18,sizeHint().width()-10,62);
   line_comment_label->setFont(line_font);
-  line_comment_label->setAlignment(AlignTop|AlignLeft);
+  line_comment_label->setAlignment(Qt::AlignTop|Qt::AlignLeft);
   line_comment_label->setWordWrapEnabled(true);
   line_comment_label->hide();
 
@@ -236,7 +227,7 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   line_time_label=new QLabel(this);
   line_time_label->setGeometry(185,3,70,16);
   line_time_label->setFont(line_font);
-  line_time_label->setAlignment(AlignRight);
+  line_time_label->setAlignment(Qt::AlignRight);
   line_time_label->setPalette(line_time_palette);
 
   //
@@ -245,7 +236,7 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   line_talktime_label=new QLabel(this);
   line_talktime_label->setGeometry(257,3,36,16);
   line_talktime_label->setFont(talk_font);
-  line_talktime_label->setAlignment(AlignRight);
+  line_talktime_label->setAlignment(Qt::AlignRight);
 
   //
   // Length
@@ -253,17 +244,17 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   line_length_label=new QLabel(this);
   line_length_label->setGeometry(297,3,40,16);
   line_length_label->setFont(line_font);
-  line_length_label->setAlignment(AlignRight);
+  line_length_label->setAlignment(Qt::AlignRight);
 
   //
   // Transition Type
   //
   line_trans_label=new QLabel(this);
   line_trans_label->setGeometry(sizeHint().width()-53,3,48,16);
-  line_trans_label->setAlignment(AlignRight);
+  line_trans_label->setAlignment(Qt::AlignRight);
   line_trans_label->setFont(line_bold_font);
 
-  SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
+  setBackgroundColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
 
   //
   // Countdown Timer
@@ -278,13 +269,13 @@ LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
 QSize LogLineBox::sizeHint() const
 {
   switch(line_mode) {
-      case LogLineBox::Full:
-	return QSize(393,LOGLINEBOX_FULL_HEIGHT);
-	break;
+  case LogLineBox::Full:
+    return QSize(393,LOGLINEBOX_FULL_HEIGHT);
+    break;
 
-      case LogLineBox::Half:
-	return QSize(393,LOGLINEBOX_HALF_HEIGHT);
-	break;
+  case LogLineBox::Half:
+    return QSize(393,LOGLINEBOX_HALF_HEIGHT);
+    break;
   }
   return QSize(0,0);
 }
@@ -329,46 +320,46 @@ RDLogLine *LogLineBox::logLine()
 void LogLineBox::setMode(LogLineBox::Mode mode)
 {
   switch(mode) {
-      case LogLineBox::Full:
-	switch(line_type) {
-	    case RDLogLine::Cart:
-	      if(log_id!=-1) {
-		line_up_label->show();
-		line_down_label->show();
-		line_position_bar->show();
-                line_description_label->show();
-	      }
-	      else {
-		line_up_label->hide();
-		line_down_label->hide();
-		line_position_bar->hide();
-                line_description_label->hide();
-	      }
-	      break;
-
-	    case RDLogLine::Marker:
-	    case RDLogLine::Track:
-	    case RDLogLine::Macro:
-	    case RDLogLine::Chain:
-	      line_up_label->hide();
-	      line_down_label->hide();
-	      line_position_bar->hide();
-              line_description_label->hide();
-	      break;
-
-	    default:
-	      break;
-	}
-	line_comment_label->setGeometry(5,18,sizeHint().width()-10,62);
-	break;
-
-      case LogLineBox::Half:
+  case LogLineBox::Full:
+    switch(line_type) {
+    case RDLogLine::Cart:
+      if(log_id!=-1) {
+	line_up_label->show();
+	line_down_label->show();
+	line_position_bar->show();
+	line_description_label->show();
+      }
+      else {
 	line_up_label->hide();
 	line_down_label->hide();
 	line_position_bar->hide();
-        line_description_label->hide();
-	line_comment_label->setGeometry(5,18,sizeHint().width()-10,31);
-	break;
+	line_description_label->hide();
+      }
+      break;
+
+    case RDLogLine::Marker:
+    case RDLogLine::Track:
+    case RDLogLine::Macro:
+    case RDLogLine::Chain:
+      line_up_label->hide();
+      line_down_label->hide();
+      line_position_bar->hide();
+      line_description_label->hide();
+      break;
+
+    default:
+      break;
+    }
+    line_comment_label->setGeometry(5,18,sizeHint().width()-10,62);
+    break;
+
+  case LogLineBox::Half:
+    line_up_label->hide();
+    line_down_label->hide();
+    line_position_bar->hide();
+    line_description_label->hide();
+    line_comment_label->setGeometry(5,18,sizeHint().width()-10,31);
+    break;
   }
   line_mode=mode;
   update();
@@ -378,13 +369,13 @@ void LogLineBox::setMode(LogLineBox::Mode mode)
 void LogLineBox::setStatus(RDLogLine::Status status)
 {
   switch(status) {
-      case RDLogLine::Scheduled:
-	line_outcue_label->hide();
-	break;
+  case RDLogLine::Scheduled:
+    line_outcue_label->hide();
+    break;
 
-      default:
-	line_outcue_label->show();
-	break;
+  default:
+    line_outcue_label->show();
+    break;
   }
   line_status=status;
 }
@@ -406,34 +397,39 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
   log_line=line;
   line_type=logline->type();
   switch(line_logline->transType()) {
-      case RDLogLine::Stop:
-	line_trans_label->setText(tr("STOP"));
-	line_trans_label->setPalette(palette());
-	break;
+  case RDLogLine::Stop:
+    line_trans_label->setText(tr("STOP"));
+    line_trans_label->setPalette(palette());
+    break;
 	
-      case RDLogLine::Play:
-	line_trans_label->setText(tr("PLAY"));
-	line_trans_label->setPalette(palette());
-	break;
+  case RDLogLine::Play:
+    line_trans_label->setText(tr("PLAY"));
+    line_trans_label->setPalette(palette());
+    break;
 	
-      case RDLogLine::Segue:
-	line_trans_label->setText(tr("SEGUE"));
-	if(logline->hasCustomTransition()) {
-	  line_trans_label->setPalette(line_transition_palette);
-	}
-	else {
-	  line_trans_label->setPalette(palette());
-	}
-	break;
+  case RDLogLine::Segue:
+    line_trans_label->setText(tr("SEGUE"));
+    if(logline->hasCustomTransition()) {
+      line_trans_label->setPalette(line_transition_palette);
+    }
+    else {
+      line_trans_label->setPalette(palette());
+    }
+    break;
 
-      default:
-	break;
+  default:
+    break;
   }
   switch(line_type) {
   case RDLogLine::Cart:
     line_comment_label->hide();
     cart=new RDCart(logline->cartNumber());
-    cut=new RDCut(logline->cartNumber(),logline->cutNumber());
+    if(logline->cutNumber()>0) {
+      cut=new RDCut(logline->cartNumber(),logline->cutNumber());
+    }
+    else {
+      cut=NULL;
+    }
     if(!cart->exists()) {
       line_cart_label->
 	setText(QString().sprintf("%06u",logline->cartNumber()));
@@ -455,16 +451,16 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_icon_label->setPixmap(*line_playout_map);
 	break;
       }
-      SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
-      delete cart;
-      delete cut;
+      setBackgroundColor(QColor(LOGLINEBOX_MISSING_COLOR));
     }
     else {
       if(((cart->forcedLength()==0)&&(cart->type()==RDCart::Audio))||
 	 (line_logline->state()==RDLogLine::NoCut)) {
 	line_cart_label->
 	  setText(QString().sprintf("%06u",logline->cartNumber()));
-	line_description_label->setText(cut->description());
+	if(cut!=NULL) {
+	  line_description_label->setText(cut->description());
+	}
 	line_artist_label->setText(tr("[NO AUDIO AVAILABLE]"));
 	line_cut_label->clear();
 	line_group_label->clear();
@@ -476,18 +472,16 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	line_comment_label->clear();
 	line_icon_label->setPixmap(*line_playout_map);
 	line_title_label->setText(logline->title());
-	SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
-	delete cart;
-	delete cut;
+	setBackgroundColor(QColor(LOGLINEBOX_MISSING_COLOR));
       }
       else {
 	line_cart_label->
 	  setText(QString().sprintf("%06u",logline->cartNumber()));
 	if(line_logline->evergreen()) {
-	  SetColor(QColor(LOGLINEBOX_EVERGREEN_COLOR));
+	  setBackgroundColor(QColor(LOGLINEBOX_EVERGREEN_COLOR));
 	}
 	else {
-	  SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
+	  setBackgroundColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
 	}
 	if(line_logline->source()==RDLogLine::Tracker) {
 	  line_icon_label->setPixmap(*line_track_cart_map);
@@ -529,20 +523,19 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	   line_logline->originUser().isEmpty()||
 	   (!line_logline->originDateTime().isValid())) {
 	  line_title_label->
-	    setText(RDResolveNowNext(line_title_template,line_logline));
+	    setText(RDResolveNowNext(line_title_template,line_logline,line));
 	}
 	else {
-	  line_title_label->setText(QString().
-				    sprintf("%s -- %s %s",
-					    (const char *)line_logline->title(),
-					    (const char *)line_logline->originUser(),
-					    (const char *)line_logline->originDateTime().
-					    toString("M/d hh:mm")));
+	  line_title_label->setText(line_logline->title()+" -- "+
+				    line_logline->originUser()+" "+
+				    line_logline->originDateTime().
+				    toString("M/d hh:mm"));
 	}
 	line_description_label->
-	  setText(RDResolveNowNext(line_description_template,line_logline));
+	  setText(RDResolveNowNext(line_description_template,line_logline,
+				   line));
 	line_artist_label->
-	  setText(RDResolveNowNext(line_artist_template,line_logline));
+	  setText(RDResolveNowNext(line_artist_template,line_logline,line));
 	line_up_label->
 	  setText(RDGetTimeLength(line_logline->playPosition(),true,true));
 	line_down_label->
@@ -554,25 +547,27 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	  line_cut_label->
 	    setText(QString().sprintf("%03u",logline->cutNumber()));
 	  line_outcue_label->
-	    setText(RDResolveNowNext(line_outcue_template,line_logline));
+	    setText(RDResolveNowNext(line_outcue_template,line_logline,line));
 	}
 	else {
-	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+	  setBackgroundColor(QColor(LOGLINEBOX_MISSING_COLOR));
 	  line_cut_label->clear();
 	  line_outcue_label->setText(tr("[NO VALID CUT AVAILABLE]"));
 	}
-	delete cart;
-	delete cut;
 	setMode(line_mode);
 	line_title_label->show();
 	line_artist_label->show();
       }
     }
+    delete cart;
+    if(cut!=NULL) {
+      delete cut;
+    }
     break;
     
   case RDLogLine::Marker:
     line_icon_label->setPixmap(*line_notemarker_map);
-    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    setBackgroundColor(QColor(LOGLINEBOX_MARKER_COLOR));
     line_title_label->hide();
     line_description_label->hide();
     line_artist_label->hide();
@@ -587,7 +582,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
     
   case RDLogLine::Track:
     line_icon_label->setPixmap(*line_mic16_map);
-    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    setBackgroundColor(QColor(LOGLINEBOX_MARKER_COLOR));
     line_title_label->hide();
     line_description_label->hide();
     line_artist_label->hide();
@@ -602,7 +597,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
     
   case RDLogLine::MusicLink:
     line_icon_label->setPixmap(*line_music_map);
-    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    setBackgroundColor(QColor(LOGLINEBOX_MARKER_COLOR));
     line_title_label->hide();
     line_description_label->hide();
     line_artist_label->hide();
@@ -617,7 +612,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
     
   case RDLogLine::TrafficLink:
     line_icon_label->setPixmap(*line_traffic_map);
-    SetColor(QColor(LOGLINEBOX_MARKER_COLOR));
+    setBackgroundColor(QColor(LOGLINEBOX_MARKER_COLOR));
     line_title_label->hide();
     line_description_label->hide();
     line_artist_label->hide();
@@ -632,7 +627,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 
   case RDLogLine::Chain:
     line_icon_label->setPixmap(*line_chain_map);
-    SetColor(QColor(LOGLINEBOX_CHAIN_COLOR));
+    setBackgroundColor(QColor(LOGLINEBOX_CHAIN_COLOR));
     line_title_label->setText(logline->markerLabel());
     line_description_label->setText("");
     line_artist_label->setText(logline->markerComment());
@@ -653,10 +648,10 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
     cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
 				    logline->cutNumber()));
     if(!cart->exists()) {
-      SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
+      setBackgroundColor(QColor(LOGLINEBOX_MISSING_COLOR));
     }
     else {
-      SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
+      setBackgroundColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
     }
     line_cart_label->setText(QString().sprintf("%06u",cart->number()));
     line_cut_label->setText("");
@@ -669,13 +664,13 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 			      false,false));
 
     line_title_label->
-      setText(RDResolveNowNext(line_title_template,line_logline));
+      setText(RDResolveNowNext(line_title_template,line_logline,line));
     line_description_label->
-      setText(RDResolveNowNext(line_description_template,line_logline));
+      setText(RDResolveNowNext(line_description_template,line_logline,line));
     line_artist_label->
-      setText(RDResolveNowNext(line_artist_template,line_logline));
+      setText(RDResolveNowNext(line_artist_template,line_logline,line));
     line_outcue_label->
-      setText(RDResolveNowNext(line_outcue_template,line_logline));
+      setText(RDResolveNowNext(line_outcue_template,line_logline,line));
     delete cart;
     delete cut;
     setMode(line_mode);
@@ -701,7 +696,7 @@ void LogLineBox::setTimer(int msecs)
 
 void LogLineBox::clear()
 {
-  SetColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
+  setBackgroundColor(QColor(LOGLINEBOX_BACKGROUND_COLOR));
   line_cart_label->setText("");
   line_cut_label->setText("");
   line_group_label->setText("");
@@ -737,33 +732,33 @@ void LogLineBox::clear()
 void LogLineBox::setBarMode(LogLineBox::BarMode mode)
 {
   switch(mode) {
-      case LogLineBox::Transitioning:
-	if(line_logline!=NULL) {
-	  if(line_logline->playPositionChanged()) {
-	    line_position_bar->setPalette(line_changed_play_palette);
-	  }
-	  else {
-	    line_position_bar->setPalette(line_unchanged_play_palette);
-	  }
-	}
-	else {
-	  line_position_bar->setPalette(line_unchanged_play_palette);
-	}
-	break;
+  case LogLineBox::Transitioning:
+    if(line_logline!=NULL) {
+      if(line_logline->playPositionChanged()) {
+	line_position_bar->setPalette(line_changed_play_palette);
+      }
+      else {
+	line_position_bar->setPalette(line_unchanged_play_palette);
+      }
+    }
+    else {
+      line_position_bar->setPalette(line_unchanged_play_palette);
+    }
+    break;
 
-      case LogLineBox::Stopping:
-	if(line_logline!=NULL) {
-	  if(line_logline->playPositionChanged()) {
-	    line_position_bar->setPalette(line_changed_stop_palette);
-	  }
-	  else {
-	    line_position_bar->setPalette(line_unchanged_stop_palette);
-	  }
-	}
-	else {
-	  line_position_bar->setPalette(line_unchanged_stop_palette);
-	}
-	break;
+  case LogLineBox::Stopping:
+    if(line_logline!=NULL) {
+      if(line_logline->playPositionChanged()) {
+	line_position_bar->setPalette(line_changed_stop_palette);
+      }
+      else {
+	line_position_bar->setPalette(line_unchanged_stop_palette);
+      }
+    }
+    else {
+      line_position_bar->setPalette(line_unchanged_stop_palette);
+    }
+    break;
   }
 }
 
@@ -788,19 +783,25 @@ void LogLineBox::mousePressEvent(QMouseEvent *e)
 {
   QWidget::mousePressEvent(e);
   line_move_count=3;
+  line_drag_start_pos=e->pos();
 }
 
 
 void LogLineBox::mouseMoveEvent(QMouseEvent *e)
 {
   QWidget::mouseMoveEvent(e);
-  line_move_count--;
-  if(line_move_count==0) {
-    if(line_allow_drags&&(line_logline!=NULL)) {
-      RDCartDrag *d=
-	new RDCartDrag(line_logline->cartNumber(),line_icon_label->pixmap(),
-		       this);
-      d->dragCopy();
+  
+  if((e->pos()-line_drag_start_pos).manhattanLength()>
+     LOGLINEBOX_DRAG_THRESHOLD) {
+    line_move_count--;
+    if(line_move_count==0) {
+      if(line_allow_drags&&(line_logline!=NULL)) {
+	RDCartDrag *d=
+	  new RDCartDrag(line_logline->cartNumber(),line_icon_label->pixmap(),
+			 line_group_label->palette().
+			 color(QColorGroup::Foreground),this);
+	d->dragCopy();
+      }
     }
   }
 }
@@ -809,6 +810,7 @@ void LogLineBox::mouseMoveEvent(QMouseEvent *e)
 void LogLineBox::mouseReleaseEvent(QMouseEvent *e)
 {
   line_move_count=-1;
+  line_drag_start_pos=QPoint();
 }
 
 
@@ -825,7 +827,9 @@ void LogLineBox::mouseDoubleClickEvent(QMouseEvent *e)
 void LogLineBox::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
-  p->drawRect(0,0,sizeHint().width(),sizeHint().height());
+  p->fillRect(0,0,sizeHint().width()-2,sizeHint().height()-2,
+	      backgroundColor());
+  p->drawRect(0,0,sizeHint().width()-2,sizeHint().height()-2);
   p->end();
   delete p;
 }
@@ -847,45 +851,9 @@ void LogLineBox::dropEvent(QDropEvent *e)
 }
 
 
-void LogLineBox::SetColor(QColor color)
-{
-  setBackgroundColor(color);
-  //  color=Qt::red;
-  line_cart_label->setBackgroundColor(color);
-  line_cart_label->setPalette(line_text_palette);
-  line_cut_label->setBackgroundColor(color);
-  line_cut_label->setPalette(line_text_palette);
-  line_group_label->setBackgroundColor(color);
-  line_trans_label->setBackgroundColor(color);
-  line_trans_label->setPalette(line_text_palette);
-  line_title_label->setBackgroundColor(color);
-  line_title_label->setPalette(line_text_palette);
-  line_description_label->setBackgroundColor(color);
-  line_description_label->setPalette(line_text_palette);
-  line_artist_label->setBackgroundColor(color);
-  line_artist_label->setPalette(line_text_palette);
-  line_outcue_label->setBackgroundColor(color);
-  line_outcue_label->setPalette(line_text_palette);
-  line_time_label->setBackgroundColor(color);
-  line_time_label->setPalette(line_text_palette);
-  line_length_label->setBackgroundColor(color);
-  line_length_label->setPalette(line_text_palette);
-  line_talktime_label->setBackgroundColor(color);
-  line_talktime_label->setPalette(line_text_palette);
-  line_up_label->setBackgroundColor(color);
-  line_up_label->setPalette(line_text_palette);
-  line_position_bar->setBackgroundColor(QColor(lightGray));
-  line_down_label->setBackgroundColor(color);
-  line_down_label->setPalette(line_text_palette);
-  line_comment_label->setBackgroundColor(color);
-  line_comment_label->setPalette(line_text_palette);
-  line_icon_label->setBackgroundColor(color);
-}
-
-
 void LogLineBox::UpdateCountdown()
 {
-  QTime current=QTime::currentTime().addMSecs(rdstation_conf->timeOffset());
+  QTime current=QTime::currentTime().addMSecs(rda->station()->timeOffset());
 
   if(current<line_end_time) {
     line_length_label->setText(RDGetTimeLength(current.msecsTo(line_end_time),
@@ -899,28 +867,22 @@ void LogLineBox::UpdateCountdown()
 
 void LogLineBox::PrintTime()
 {
-  QString str;
-  
   if(line_logline==NULL) {
     return;
   }
   switch(line_logline->timeType()) {
       case RDLogLine::Hard:
 	line_time_label->setFont(line_bold_font);
-	str=QString(tr("T"));
-	line_time_label->setText(QString().sprintf("%s%s",(const char *)str,
-		     (const char *)TimeString(line_logline->
-					      startTime(RDLogLine::Logged))));
+	line_time_label->setText("T"+TimeString(line_logline->
+						startTime(RDLogLine::Logged)));
 	line_time_label->setPalette(line_hard_palette);
 	break;
 
       default:
 	line_time_label->setFont(line_font);
 	if(!line_logline->startTime(RDLogLine::Logged).isNull()) {
-	  line_time_label->
-	    setText(QString().sprintf("%s",
-				      (const char *)TimeString(line_logline->
-					   startTime(RDLogLine::Logged))));
+	  line_time_label->setText(TimeString(line_logline->
+					      startTime(RDLogLine::Logged)));
 	}
 	else {
 	  line_time_label->setText("");
