@@ -2,9 +2,7 @@
 //
 // On Air Playout Utility for Rivendell.
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: loglinebox.h,v 1.47.8.6 2014/02/06 20:43:51 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,43 +18,34 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef LOGLINEBOX_H
 #define LOGLINEBOX_H
 
-#include <qwidget.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qtimer.h>
-#include <qdatetime.h>
-#include <qpushbutton.h>
-#include <qprogressbar.h>
-#include <qpalette.h>
+#include <q3progressbar.h>
+
 #include <qpixmap.h>
 
+#include <rdairplay_conf.h>
+#include <rdcartdrag.h>
 #include <rdlabel.h>
 #include <rdlog_line.h>
 #include <rdlog_event.h>
-#include <rdplay_deck.h>
-#include <rdairplay_conf.h>
-#include <rdcartdrag.h>
-
-#include <mode_display.h>
-#include <colors.h>
+#include <rdwidget.h>
 
 //
 // Widget Settings
 //
 #define LOGLINEBOX_FULL_HEIGHT 85
 #define LOGLINEBOX_HALF_HEIGHT 50
+#define LOGLINEBOX_DRAG_THRESHOLD 20
 
-class LogLineBox : public QWidget
+class LogLineBox : public RDWidget
 {
   Q_OBJECT
  public:
   enum Mode {Full=0,Half=1};
   enum BarMode {Transitioning=0,Stopping=1};
-  LogLineBox(RDAirPlayConf *conf,QWidget *parent=0,const char *name=0);
+  LogLineBox(RDAirPlayConf *conf,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   LogLineBox::Mode mode() const;
@@ -89,7 +78,6 @@ class LogLineBox : public QWidget
   void dropEvent(QDropEvent *e);
 
  private:
-  void SetColor(QColor);
   void UpdateCountdown();
   void PrintTime();
   QString TimeString(const QTime &time);
@@ -109,7 +97,7 @@ class LogLineBox : public QWidget
   QLabel *line_up_label;
   QLabel *line_down_label;
   RDLabel *line_comment_label;
-  QProgressBar *line_position_bar;
+  Q3ProgressBar *line_position_bar;
   QTimer *line_countdown_timer;
   QTime line_end_time;
   int log_id;
@@ -127,6 +115,7 @@ class LogLineBox : public QWidget
   QPalette line_hard_palette;
   QPalette line_timescale_palette;
   QPalette line_transition_palette;
+  QPalette line_text_palette;
   RDLogLine::TransType line_next_type;
   RDAirPlayConf::TimeMode line_time_mode;
   RDLogLine::Type line_type;
@@ -139,6 +128,7 @@ class LogLineBox : public QWidget
   QPixmap *line_traffic_map;
   QPixmap *line_music_map;
   int line_move_count;
+  QPoint line_drag_start_pos;
   RDLogLine::Status line_status;
   QString line_title_template;
   QString line_artist_template;
@@ -148,4 +138,4 @@ class LogLineBox : public QWidget
 };
 
 
-#endif 
+#endif  // LOGLINEBOX_H
