@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>EditEvent</name>
     <message>
@@ -205,59 +207,59 @@
     <name>ListLog</name>
     <message>
         <source>EST TIME</source>
-        <translation>ODH. ČAS</translation>
+        <translation type="obsolete">ODH. ČAS</translation>
     </message>
     <message>
         <source>LEN</source>
-        <translation>DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>PŘECHOD</translation>
+        <translation type="obsolete">PŘECHOD</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>VOZÍK</translation>
+        <translation type="obsolete">VOZÍK</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>UMĚLEC</translation>
+        <translation type="obsolete">UMĚLEC</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation>ČAS</translation>
+        <translation type="obsolete">ČAS</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>ZÁKAZNÍK</translation>
+        <translation type="obsolete">ZÁKAZNÍK</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTURA</translation>
+        <translation type="obsolete">AGENTURA</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>ŠTÍTEK</translation>
+        <translation type="obsolete">ŠTÍTEK</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>ID ŘÁDKU</translation>
+        <translation type="obsolete">ID ŘÁDKU</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>POČÍTADLO</translation>
+        <translation type="obsolete">POČÍTADLO</translation>
     </message>
     <message>
         <source>STATUS</source>
-        <translation>STAV</translation>
+        <translation type="obsolete">STAV</translation>
     </message>
     <message>
         <source>Select</source>
@@ -291,11 +293,11 @@ zápis</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Zápis existuje</translation>
+        <translation type="obsolete">Zápis existuje</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Zápis již existuje!</translation>
+        <translation type="obsolete">Zápis již existuje!</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
@@ -394,7 +396,71 @@ Tail</source>
 poslechu</translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -402,19 +468,19 @@ poslechu</translation>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Vybrat zápis</translation>
+        <translation type="obsolete">Vybrat zápis</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>POPIS</translation>
+        <translation type="obsolete">POPIS</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SLUŽBA</translation>
+        <translation type="obsolete">SLUŽBA</translation>
     </message>
     <message>
         <source>Load</source>
@@ -430,7 +496,7 @@ poslechu</translation>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>Uložit &amp;jako</translation>
+        <translation type="obsolete">Uložit &amp;jako</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -440,6 +506,46 @@ poslechu</translation>
         <source>Rename Log</source>
         <translation>Přejmenovat zápis</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must refresh the log before it can be saved.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -493,7 +599,7 @@ poslechu</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="obsolete">T</translation>
     </message>
 </context>
 <context>
@@ -512,7 +618,7 @@ poslechu</translation>
     </message>
     <message>
         <source>Database Error</source>
-        <translation>Chyba databáze</translation>
+        <translation type="obsolete">Chyba databáze</translation>
     </message>
     <message>
         <source>ADD</source>
@@ -604,6 +710,22 @@ OBNOVEN</translation>
         <source>Unable to lock all memory</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log channel assignments are invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
@@ -624,11 +746,11 @@ OBNOVEN</translation>
         <translation>Ruční</translation>
     </message>
     <message>
-        <source>Aux1</source>
+        <source>A1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Aux2</source>
+        <source>A2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
