@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>EditEvent</name>
     <message>
@@ -205,59 +207,59 @@
     <name>ListLog</name>
     <message>
         <source>EST TIME</source>
-        <translation>CA. ZEIT</translation>
+        <translation type="obsolete">CA. ZEIT</translation>
     </message>
     <message>
         <source>LEN</source>
-        <translation>LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>ÜBERG</translation>
+        <translation type="obsolete">ÜBERG</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CART</translation>
+        <translation type="obsolete">CART</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>KÜNSTLER</translation>
+        <translation type="obsolete">KÜNSTLER</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation>ZEIT</translation>
+        <translation type="obsolete">ZEIT</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KUNDE</translation>
+        <translation type="obsolete">KUNDE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTUR</translation>
+        <translation type="obsolete">AGENTUR</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>LABEL</translation>
+        <translation type="obsolete">LABEL</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>LINE ID</translation>
+        <translation type="obsolete">LINE ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>ZÄHLER</translation>
+        <translation type="obsolete">ZÄHLER</translation>
     </message>
     <message>
         <source>STATUS</source>
-        <translation>STATUS</translation>
+        <translation type="obsolete">STATUS</translation>
     </message>
     <message>
         <source>Select</source>
@@ -291,11 +293,11 @@ auswählen</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Log existiert</translation>
+        <translation type="obsolete">Log existiert</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Log existiert bereits!</translation>
+        <translation type="obsolete">Log existiert bereits!</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
@@ -351,7 +353,7 @@ auswählen</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="unfinished">T</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -394,7 +396,71 @@ Tail</source>
 vorhören</translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -402,19 +468,19 @@ vorhören</translation>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Log auswählen</translation>
+        <translation type="obsolete">Log auswählen</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAME</translation>
+        <translation type="obsolete">NAME</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>BESCHREIBUNG</translation>
+        <translation type="obsolete">BESCHREIBUNG</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICE</translation>
+        <translation type="obsolete">SERVICE</translation>
     </message>
     <message>
         <source>Load</source>
@@ -430,7 +496,7 @@ vorhören</translation>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>Speichern &amp;Als</translation>
+        <translation type="obsolete">Speichern &amp;Als</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -440,6 +506,46 @@ vorhören</translation>
         <source>Rename Log</source>
         <translation>Log umbenennen</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must refresh the log before it can be saved.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -493,7 +599,7 @@ vorhören</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="obsolete">T</translation>
     </message>
 </context>
 <context>
@@ -512,7 +618,7 @@ vorhören</translation>
     </message>
     <message>
         <source>Database Error</source>
-        <translation>Datenbankfehler</translation>
+        <translation type="obsolete">Datenbankfehler</translation>
     </message>
     <message>
         <source>ADD</source>
@@ -596,6 +702,30 @@ AKTUALISIERT</translation>
         <source>Host:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Memory Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to lock all memory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log channel assignments are invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
@@ -616,11 +746,11 @@ AKTUALISIERT</translation>
         <translation>Manuell</translation>
     </message>
     <message>
-        <source>Aux1</source>
+        <source>A1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Aux2</source>
+        <source>A2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
