@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>EditEvent</name>
     <message>
@@ -63,7 +65,7 @@
     </message>
     <message>
         <source>Edit Marker</source>
-        <translation type="unfinished">Editar marcador</translation>
+        <translation>Editar marcador</translation>
     </message>
     <message>
         <source>Transition If Previous Cart Ends Before</source>
@@ -71,11 +73,11 @@
     </message>
     <message>
         <source>Edit Track</source>
-        <translation type="unfinished">Editar pista</translation>
+        <translation>Editar pista</translation>
     </message>
     <message>
         <source>Edit Log Track</source>
-        <translation type="unfinished">Editar Pista del Log</translation>
+        <translation>Editar Pista del Log</translation>
     </message>
     <message>
         <source>Start Transition Type:</source>
@@ -97,151 +99,155 @@
         <source>An event is already scheduled with this start time!</source>
         <translation>Un evento ha sido programado con esa misma hora de inicio!</translation>
     </message>
+    <message>
+        <source>Cart Notes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HourSelector</name>
     <message>
         <source>12a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>1a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>2a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>3a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>4a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>5a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>6a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>7a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>8a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>9a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>10a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>11a</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>12p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>1p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>2p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>3p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>4p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>5p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>6p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>7p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>8p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>9p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>10p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>11p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>ListLog</name>
     <message>
         <source>TIME</source>
-        <translation>HORA</translation>
+        <translation type="obsolete">HORA</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>TRANS</translation>
+        <translation type="obsolete">TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTUCHO</translation>
+        <translation type="obsolete">CARTUCHO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENTE</translation>
+        <translation type="obsolete">CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENCIA</translation>
+        <translation type="obsolete">AGENCIA</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>ETIQUETA</translation>
+        <translation type="obsolete">ETIQUETA</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>ID DE LÍNEA</translation>
+        <translation type="obsolete">ID DE LÍNEA</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>CUENTA</translation>
+        <translation type="obsolete">CUENTA</translation>
     </message>
     <message>
         <source>STATUS</source>
-        <translation>ESTADO</translation>
+        <translation type="obsolete">ESTADO</translation>
     </message>
     <message>
         <source>Select</source>
@@ -277,11 +283,11 @@ Lista</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>La lista ya existe</translation>
+        <translation type="obsolete">La lista ya existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>¡La lista de reproducción ya existe!</translation>
+        <translation type="obsolete">¡La lista de reproducción ya existe!</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
@@ -317,7 +323,7 @@ Lista</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="unfinished">T</translation>
     </message>
     <message>
         <source>[NO AUDIO AVAILABLE]</source>
@@ -329,7 +335,7 @@ Lista</translation>
     </message>
     <message>
         <source>LEN</source>
-        <translation>LONG</translation>
+        <translation type="obsolete">LONG</translation>
     </message>
     <message>
         <source>LINK</source>
@@ -345,11 +351,11 @@ Lista</translation>
     </message>
     <message>
         <source>EST TIME</source>
-        <translation>TIEMPO EST</translation>
+        <translation type="obsolete">TIEMPO EST</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>Refresh
@@ -389,24 +395,92 @@ Tail</source>
         <translation>Escuchar
 Final</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Seleccione una lista</translation>
+        <translation type="obsolete">Seleccione una lista</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOMBRE</translation>
+        <translation type="obsolete">NOMBRE</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIPCIÓN</translation>
+        <translation type="obsolete">DESCRIPCIÓN</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICIO</translation>
+        <translation type="obsolete">SERVICIO</translation>
     </message>
     <message>
         <source>Load</source>
@@ -422,7 +496,7 @@ Final</translation>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>Gu&amp;ard. como</translation>
+        <translation type="obsolete">Gu&amp;ard. como</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -432,6 +506,46 @@ Final</translation>
         <source>Rename Log</source>
         <translation>Cambiar nombre de la lista</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log already being edited by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Log Locked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must refresh the log before it can be saved.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -465,7 +579,7 @@ Final</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="obsolete">T</translation>
     </message>
     <message>
         <source>TRACK</source>
@@ -512,7 +626,7 @@ Final</translation>
     </message>
     <message>
         <source>Database Error</source>
-        <translation>Error en la base de datos</translation>
+        <translation type="obsolete">Error en la base de datos</translation>
     </message>
     <message>
         <source>ADD</source>
@@ -582,10 +696,34 @@ LISTA</translation>
     </message>
     <message>
         <source>Host</source>
-        <translation type="unfinished"></translation>
+        <translation>Equipo</translation>
     </message>
     <message>
         <source>Host:</source>
+        <translation>Equipo:</translation>
+    </message>
+    <message>
+        <source>Memory Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to lock all memory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log channel assignments are invalid!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -593,7 +731,7 @@ LISTA</translation>
     <name>ModeDisplay</name>
     <message>
         <source>Operating Mode</source>
-        <translation>Modo de operación</translation>
+        <translation type="unfinished">Modo de operación</translation>
     </message>
     <message>
         <source>LiveAssist</source>
@@ -607,6 +745,14 @@ LISTA</translation>
         <source>Manual</source>
         <translation>Manual</translation>
     </message>
+    <message>
+        <source>A1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PostCounter</name>
