@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>EditEvent</name>
     <message>
@@ -205,59 +207,59 @@
     <name>ListLog</name>
     <message>
         <source>EST TIME</source>
-        <translation>HORAIRE EST</translation>
+        <translation type="obsolete">HORAIRE EST</translation>
     </message>
     <message>
         <source>LEN</source>
-        <translation>DUREE</translation>
+        <translation type="obsolete">DUREE</translation>
     </message>
     <message>
         <source>TRANS</source>
-        <translation>TRANS</translation>
+        <translation type="obsolete">TRANS</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CART</translation>
+        <translation type="obsolete">CART</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITRE</translation>
+        <translation type="obsolete">TITRE</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTE</translation>
+        <translation type="obsolete">ARTISTE</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GROUPE</translation>
+        <translation type="obsolete">GROUPE</translation>
     </message>
     <message>
         <source>TIME</source>
-        <translation>HORAIRE</translation>
+        <translation type="obsolete">HORAIRE</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENT</translation>
+        <translation type="obsolete">CLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENCE</translation>
+        <translation type="obsolete">AGENCE</translation>
     </message>
     <message>
         <source>LABEL</source>
-        <translation>LABEL</translation>
+        <translation type="obsolete">LABEL</translation>
     </message>
     <message>
         <source>LINE ID</source>
-        <translation>LIGNE ID</translation>
+        <translation type="obsolete">LIGNE ID</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>NUMERO</translation>
+        <translation type="obsolete">NUMERO</translation>
     </message>
     <message>
         <source>STATUS</source>
-        <translation>STATUT</translation>
+        <translation type="obsolete">STATUT</translation>
     </message>
     <message>
         <source>Select</source>
@@ -395,12 +397,76 @@ la Fin</translation>
     </message>
     <message>
         <source>ALBUM</source>
-        <translation>ALBUM</translation>
+        <translation type="obsolete">ALBUM</translation>
     </message>
     <message>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Len</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Marker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Line ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Est. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sch. Time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
@@ -410,15 +476,15 @@ la Fin</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOM</translation>
+        <translation type="obsolete">NOM</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIPTION</translation>
+        <translation type="obsolete">DESCRIPTION</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICE</translation>
+        <translation type="obsolete">SERVICE</translation>
     </message>
     <message>
         <source>Load</source>
@@ -472,6 +538,18 @@ la Fin</translation>
         <source>You must refresh the log before it can be saved.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -525,7 +603,7 @@ la Fin</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="obsolete">T</translation>
     </message>
 </context>
 <context>
@@ -544,7 +622,7 @@ la Fin</translation>
     </message>
     <message>
         <source>Database Error</source>
-        <translation>Erreur de base de données</translation>
+        <translation type="obsolete">Erreur de base de données</translation>
     </message>
     <message>
         <source>ADD</source>
@@ -636,6 +714,22 @@ DU LOG</translation>
         <source>Unable to lock all memory</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log channel assignments are invalid!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
@@ -657,11 +751,19 @@ DU LOG</translation>
     </message>
     <message>
         <source>Aux1</source>
-        <translation>Aux1</translation>
+        <translation type="obsolete">Aux1</translation>
     </message>
     <message>
         <source>Aux2</source>
-        <translation>Aux2</translation>
+        <translation type="obsolete">Aux2</translation>
+    </message>
+    <message>
+        <source>A1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A2</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
