@@ -2,9 +2,7 @@
 //
 // The wall clock widget for Rivendell
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: wall_clock.h,v 1.9 2007/09/14 14:06:48 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,19 +21,14 @@
 #ifndef WALL_CLOCK_H
 #define WALL_CLOCK_H
 
-#include <qdatetime.h>
-#include <qtimer.h>
-#include <qevent.h>
-
-#include <rdpushbutton.h>
-
 #include <rdairplay_conf.h>
+#include <rdpushbutton.h>
 
 class WallClock : public RDPushButton
 {
   Q_OBJECT
  public:
-  WallClock(QWidget *parent=0,const char *name=0);
+  WallClock(QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   void setDateDisplay(bool state);
@@ -52,11 +45,13 @@ class WallClock : public RDPushButton
   void timeModeChanged(RDAirPlayConf::TimeMode);
 
  protected:
+  void flashButton(bool state);
   void keyPressEvent(QKeyEvent *e);
 
  private:
   QTime previous_time,current_time;
   QDate previous_date,current_date;
+  QString time_string;
   RDAirPlayConf::TimeMode time_mode;
   RDAirPlayConf::TimeMode previous_time_mode;
   bool show_date;
@@ -64,6 +59,8 @@ class WallClock : public RDPushButton
   QFont label_font;
   QFontMetrics *label_metrics;
   bool check_sync;
+  int time_offset;
+  bool flash_state;
 };
 
-#endif
+#endif  // WALL_CLOCK_H
