@@ -2,7 +2,7 @@
 //
 // A Dedicated Cart Slot Utility for Rivendell.
 //
-//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,60 +18,42 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <math.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <signal.h>
-
-#include <qmessagebox.h>
 #include <qapplication.h>
-#include <qwindowsstyle.h>
+#include <qmessagebox.h>
 #include <qtranslator.h>
-#include <qtextcodec.h>
-#include <qpainter.h>
-#include <qpixmap.h>
 
-#include <rdcartslots.h>
-#include <rd.h>
-#include <rdcheck_daemons.h>
-#include <rddbheartbeat.h>
-#include <rdcmd_switch.h>
-#include <dbversion.h>
+#include <rdescape_string.h>
+
+#include "rdcartslots.h"
 
 //
 // Icons
 //
 #include "../icons/rdcartslots-22x22.xpm"
 
-MainWidget::MainWidget(QWidget *parent)
-  :QWidget(parent)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
-  bool skip_db_check=false;
-  unsigned schema=0;
+  QString err_msg;
 
   //
-  // Force a reasonable default font.
+  // Open the Database
   //
-  QFont mfont("helvetica",12,QFont::Normal);
-  mfont.setPixelSize(12);
-  qApp->setFont(mfont);
+  rda=new RDApplication("RDCartSlots","rdcartslots",RDCARTSLOTS_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    QMessageBox::critical(this,"RDCartSlots - "+tr("Error"),err_msg);
+    exit(1);
+  }
 
   //
-  // Load Local Configs
+  // Read Command Options
   //
-  panel_config=new RDConfig(RD_CONF_FILE);
-  panel_config->load();
-  panel_config->setModuleName("RDCartSlots");
-
-  //
-  // Load the command-line arguments
-  //
-  RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdcartslots",
-				   RDCARTSLOTS_USAGE);
-  for(unsigned i=0;i<cmd->keys();i++) {
-    if(cmd->key(i)=="--skip-db-check") {
-      skip_db_check=true;
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      QMessageBox::critical(this,"RDCartSlots - "+tr("Error"),
+			    tr("Unknown command option")+": "+
+			    rda->cmdSwitch()->key(i));
+      exit(2);
     }
   }
 
@@ -79,60 +61,22 @@ MainWidget::MainWidget(QWidget *parent)
   // Create Icons
   //
   lib_rivendell_map=new QPixmap(rdcartslots_22x22_xpm);
-  setIcon(*lib_rivendell_map);
-
-  //
-  // Ensure that system daemons are running
-  //
-  RDInitializeDaemons();
-
-  //
-  // Open Database
-  //
-  QString err;
-  QSqlDatabase *db=RDInitDb(&schema,&err);
-  if(!db) {
-    QMessageBox::warning(this,tr("Can't Connect"),err);
-    exit(0);
-  }
-  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
-    fprintf(stderr,
-	    "rdcastmanager: database version mismatch, should be %u, is %u\n",
-	    RD_VERSION_DATABASE,schema);
-    exit(256);
-  }
-  new RDDbHeartbeat(panel_config->mysqlHeartbeatInterval(),this);
-
-  //
-  // Allocate Global Resources
-  //
-  panel_station=new RDStation(panel_config->stationName());
-  panel_system=new RDSystem();
-
-  //
-  // RDAirPlay Configuration
-  //
-  panel_airplay_conf=new RDAirPlayConf(panel_config->stationName(),"RDAIRPLAY");
+  setWindowIcon(*lib_rivendell_map);
 
   //
   // CAE Connection
   //
-  panel_cae=new RDCae(panel_station,panel_config,parent);
-  panel_cae->connectHost();
+  connect(rda->cae(),SIGNAL(isConnected(bool)),
+	  this,SLOT(caeConnectedData(bool)));
+  rda->cae()->connectHost();
 
   //
   // RIPC Connection
   //
-  panel_ripc=new RDRipc(panel_station,panel_config,this);
-  connect(panel_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
-  connect(panel_ripc,SIGNAL(rmlReceived(RDMacro *)),
+  connect(rda,SIGNAL(userChanged()),this,SLOT(userData()));
+  connect(rda->ripc(),SIGNAL(rmlReceived(RDMacro *)),
 	  this,SLOT(rmlReceivedData(RDMacro *)));
 
-  //
-  // User
-  //
-  panel_user=NULL;
-
   //
   // Service Picker
   //
@@ -141,32 +85,30 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Macro Player
   //
-  panel_player=new RDEventPlayer(panel_ripc,this);
+  panel_player=new RDEventPlayer(rda->ripc(),this);
 
   //
   // Dialogs
   //
-  panel_cart_dialog=new RDCartDialog(&panel_filter,&panel_group,
-				     &panel_schedcode,panel_cae,panel_ripc,
-				     panel_station,panel_system,panel_config,
-				     this);
+  panel_cart_dialog=
+    new RDCartDialog(&panel_filter,&panel_group,&panel_schedcode,this);
   panel_slot_dialog=new RDSlotDialog(tr("RDCartSlots"),this);
-  panel_cue_dialog=new RDCueEditDialog(panel_cae,panel_station->cueCard(),
-				       panel_station->cuePort(),
+  panel_cue_dialog=new RDCueEditDialog(rda->cae(),rda->station()->cueCard(),
+				       rda->station()->cuePort(),
 				       tr("RDCartSlots"),this);
 
   //
   // Cart Slots
   //
   QTimer *timer=new QTimer(this);
-  for(int i=0;i<panel_station->cartSlotColumns();i++) {
-    for(int j=0;j<panel_station->cartSlotRows();j++) {
+  for(int i=0;i<rda->station()->cartSlotColumns();i++) {
+    for(int j=0;j<rda->station()->cartSlotRows();j++) {
       panel_slots.
-	push_back(new RDCartSlot(panel_slots.size(),panel_ripc,panel_cae,
-				 panel_station,panel_config,panel_svcs_dialog,
+	push_back(new RDCartSlot(panel_slots.size(),rda->ripc(),rda->cae(),
+				 rda->station(),rda->config(),panel_svcs_dialog,
 				 panel_slot_dialog,panel_cart_dialog,
 				 panel_cue_dialog,tr("RDCartSlots"),
-				 panel_airplay_conf,this));
+				 rda->airplayConf(),this));
       panel_slots.back()->
 	setGeometry(10+i*(panel_slots.back()->sizeHint().width()+10),
 		    10+j*(panel_slots.back()->sizeHint().height()+5),
@@ -177,7 +119,7 @@ MainWidget::MainWidget(QWidget *parent)
     }
   }
   timer->start(METER_INTERVAL);
-  panel_ripc->connectHost("localhost",RIPCD_TCP_PORT,panel_config->password());
+  rda->ripc()->connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
 
   //
   // Fix the Window Size
@@ -193,13 +135,29 @@ MainWidget::MainWidget(QWidget *parent)
 
 QSize MainWidget::sizeHint() const
 {
-  return QSize(10+panel_station->cartSlotColumns()*
+  return QSize(10+rda->station()->cartSlotColumns()*
 	       (10+panel_slots[0]->size().width()),
-	       10+panel_station->cartSlotRows()*
+	       10+rda->station()->cartSlotRows()*
 	       (5+panel_slots[0]->size().height()));
 }
 
 
+void MainWidget::caeConnectedData(bool state)
+{
+  QList<int> cards;
+
+  QString sql=QString("select CARD from CARTSLOTS where ")+
+    "STATION_NAME=\""+RDEscapeString(rda->config()->stationName())+"\"";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+   cards.push_back(q->value(0).toInt());
+  }
+  delete q;
+
+  rda->cae()->enableMetering(&cards);
+}
+
+
 void MainWidget::rmlReceivedData(RDMacro *rml)
 {
   RunLocalMacros(rml);
@@ -214,15 +172,11 @@ QSizePolicy MainWidget::sizePolicy() const
 
 void MainWidget::userData()
 {
-  if(panel_user!=NULL) {
-    delete panel_user;
-  }
-  panel_user=new RDUser(panel_ripc->user());
   for(unsigned i=0;i<panel_slots.size();i++) {
-    panel_slots[i]->setUser(panel_user);
+    panel_slots[i]->setUser(rda->user());
   }
   SetCaption();
-  panel_ripc->sendOnairFlag();
+  rda->ripc()->sendOnairFlag();
 }
 
 
@@ -231,7 +185,7 @@ void MainWidget::paintEvent(QPaintEvent *e)
   QPainter *p=new QPainter(this);
   p->setPen(Qt::black);
   p->setBrush(Qt::black);
-  for(int i=1;i<panel_station->cartSlotColumns();i++) {
+  for(int i=1;i<rda->station()->cartSlotColumns();i++) {
     p->fillRect(i*(panel_slots[0]->size().width()+10),10,
 		5,size().height()-15,Qt::black);
   }
@@ -251,21 +205,22 @@ void MainWidget::closeEvent(QCloseEvent *e)
 void MainWidget::SetCaption()
 {
   QString service=tr("[None]");
-  setCaption(tr("RDCartSlots")+" v"+VERSION+" - "+tr("Station")+": "+
-	     panel_config->stationName()+"  "+tr("User")+": "+
-	     panel_ripc->user());
+  setWindowTitle(tr("RDCartSlots")+" v"+VERSION+" - "+tr("Station")+": "+
+		 rda->config()->stationName()+"  "+tr("User")+": "+
+		 rda->ripc()->user());
 }
 
 
 int main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
   // Load Translations
   //
   QTranslator qt(0);
-  qt.load(QString(QTDIR)+QString("/translations/qt_")+QTextCodec::locale(),".");
+  qt.load(QString("/usr/share/qt4/translations/qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
   QTranslator rd(0);
   rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
@@ -282,7 +237,9 @@ int main(int argc,char *argv[])
 	     QTextCodec::locale(),".");
   a.installTranslator(&tr);
 
-  MainWidget *w=new MainWidget();
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
   w->show();
