@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Cast
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,23 +21,20 @@
 #ifndef EDIT_CAST_H
 #define EDIT_CAST_H
 
-#include <vector>
 
-#include <qdialog.h>
-#include <qtextedit.h>
-#include <qspinbox.h>
-#include <qlineedit.h>
-#include <qsqldatabase.h>
+#include <qbuttongroup.h>
 #include <qcombobox.h>
 #include <qdatetimeedit.h>
 #include <qlabel.h>
+#include <qlineedit.h>
 #include <qpushbutton.h>
-#include <qbuttongroup.h>
+#include <qtextedit.h>
 
+#include <rddialog.h>
 #include <rdfeed.h>
 #include <rdpodcast.h>
 
-class EditCast : public QDialog
+class EditCast : public RDDialog
 {
  Q_OBJECT
  public:
@@ -73,8 +70,6 @@ class EditCast : public QDialog
   QDateEdit *cast_item_expiration_edit;
   QDateTimeEdit *cast_item_effective_edit;
   QButtonGroup *cast_item_status_group;
-  std::vector<QString> cast_aux_varnames;
-  std::vector<QLineEdit *> cast_aux_edits;
   int cast_ypos;
   RDPodcast::Status cast_status;
 };
