@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Download Event
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,59 +18,37 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
+#include <qgroupbox.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
 #include <qurl.h>
 
-#include <rdurl.h>
-#include <rddb.h>
-#include <rd.h>
 #include <rdcut_dialog.h>
 #include <rdcut_path.h>
+#include <rdescape_string.h>
 #include <rdtextvalidator.h>
-#include <rddeck.h>
 
-#include <edit_download.h>
-#include <globals.h>
+#include "edit_download.h"
+#include "globals.h"
 
 EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
 			   QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QString sql;
   RDSqlQuery *q;
   QString temp;
 
-  //
-  // Fix the Window Size
-  //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont day_font=QFont("Helvetica",10,QFont::Normal);
-  day_font.setPixelSize(10);
-
   edit_deck=NULL;
   edit_added_events=adds;
   edit_filter=filter;
 
-  setCaption(tr("Edit Download"));
+  setWindowTitle("RDCatch - "+tr("Edit Download"));
+
+  //
+  // Fix the Window Size
+  //
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Text Validator
@@ -89,8 +67,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_active_button->setGeometry(10,11,20,20);
   QLabel *label=new QLabel(edit_active_button,tr("Event Active"),this);
   label->setGeometry(30,11,125,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Station
@@ -99,18 +77,19 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_station_box->setGeometry(200,10,140,23);
   label=new QLabel(edit_station_box,tr("Location:"),this);
   label->setGeometry(125,10,70,23);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Start Time
   //
   edit_starttime_edit=new QTimeEdit(this);
   edit_starttime_edit->setGeometry(sizeHint().width()-90,12,80,20);
+  edit_starttime_edit->setDisplayFormat("hh:mm:ss");
   label=new QLabel(edit_starttime_edit,tr("Start Time:"),this);
   label->setGeometry(sizeHint().width()-175,12,80,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Description
@@ -120,8 +99,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_description_edit->setValidator(validator);
   label=new QLabel(edit_description_edit,tr("Description:"),this);
   label->setGeometry(10,43,100,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Url
@@ -134,8 +113,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
 	  this,SLOT(urlChangedData(const QString &)));
   label=new QLabel(edit_url_edit,tr("Url:"),this);
   label->setGeometry(10,70,100,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Username
@@ -146,8 +125,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_username_edit->setValidator(validator);
   edit_username_label=new QLabel(edit_username_edit,tr("Username:"),this);
   edit_username_label->setGeometry(10,97,100,20);
-  edit_username_label->setFont(label_font);
-  edit_username_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  edit_username_label->setFont(labelFont());
+  edit_username_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Password
@@ -159,8 +138,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_username_edit->setValidator(validator);
   edit_password_label=new QLabel(edit_password_edit,tr("Password:"),this);
   edit_password_label->setGeometry(275,97,80,20);
-  edit_password_label->setFont(label_font);
-  edit_password_label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  edit_password_label->setFont(labelFont());
+  edit_password_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Destination
@@ -170,11 +149,11 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_destination_edit->setReadOnly(true);
   label=new QLabel(edit_destination_edit,tr("Destination:"),this);
   label->setGeometry(10,127,100,19);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight);
   QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-70,122,60,24);
-  button->setFont(day_font);
+  button->setFont(subLabelFont());
   button->setText(tr("&Select"));
   connect(button,SIGNAL(clicked()),this,SLOT(selectCartData()));
 
@@ -187,8 +166,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_channels_box->insertItem("2");
   label=new QLabel(edit_channels_box,tr("Channels:"),this);
   label->setGeometry(120,149,70,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignLeft);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   //
   // Autotrim Controls
@@ -199,19 +178,19 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
 	  this,SLOT(autotrimToggledData(bool)));
   label=new QLabel(edit_autotrim_box,tr("Autotrim"),this);
   label->setGeometry(140,173,80,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignLeft);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
   edit_autotrim_spin=new QSpinBox(this);
   edit_autotrim_spin->setGeometry(265,173,40,20);
   edit_autotrim_spin->setRange(-99,-1);
   edit_autotrim_label=new QLabel(edit_autotrim_spin,tr("Level:"),this);
   edit_autotrim_label->setGeometry(220,173,40,20);
-  edit_autotrim_label->setFont(label_font);
-  edit_autotrim_label->setAlignment(AlignVCenter|AlignRight);
+  edit_autotrim_label->setFont(labelFont());
+  edit_autotrim_label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   edit_autotrim_unit=new QLabel(edit_autotrim_spin,tr("dBFS"),this);
   edit_autotrim_unit->setGeometry(310,173,40,20);
-  edit_autotrim_unit->setFont(label_font);
-  edit_autotrim_unit->setAlignment(AlignVCenter|AlignLeft);
+  edit_autotrim_unit->setFont(labelFont());
+  edit_autotrim_unit->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   //
   // Normalize Controls
@@ -222,19 +201,19 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
 	  this,SLOT(normalizeToggledData(bool)));
   label=new QLabel(edit_normalize_box,tr("Normalize"),this);
   label->setGeometry(140,197,80,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignLeft);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
   edit_normalize_spin=new QSpinBox(this);
   edit_normalize_spin->setGeometry(265,197,40,20);
   edit_normalize_spin->setRange(-99,-1);
   edit_normalize_label=new QLabel(edit_normalize_spin,tr("Level:"),this);
   edit_normalize_label->setGeometry(220,197,40,20);
-  edit_normalize_label->setFont(label_font);
-  edit_normalize_label->setAlignment(AlignVCenter|AlignRight);
+  edit_normalize_label->setFont(labelFont());
+  edit_normalize_label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   edit_normalize_unit=new QLabel(edit_normalize_spin,tr("dBFS"),this);
   edit_normalize_unit->setGeometry(310,197,40,20);
-  edit_normalize_unit->setFont(label_font);
-  edit_normalize_unit->setAlignment(AlignVCenter|AlignLeft);
+  edit_normalize_unit->setFont(labelFont());
+  edit_normalize_unit->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   //
   // Export Metadata Box
@@ -243,16 +222,15 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_metadata_box->setGeometry(120,222,15,15);
   label=new QLabel(edit_metadata_box,tr("Update Library Metadata"),this);
   label->setGeometry(140,222,160,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Button Label
   //
-  label=new QLabel(tr("Active Days"),this);
-  label->setGeometry(47,254,90,19);
-  label->setFont(label_font);
-  label->setAlignment(AlignHCenter|ShowPrefix);
+  QGroupBox *groupbox=new QGroupBox(tr("Active Days"),this);
+  groupbox->setFont(labelFont());
+  groupbox->setGeometry(10,257,sizeHint().width()-20,62);
 
   //
   // Monday Button
@@ -261,8 +239,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_mon_button->setGeometry(20,273,20,20);
   label=new QLabel(edit_mon_button,tr("Monday"),this);
   label->setGeometry(40,273,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Tuesday Button
@@ -271,8 +249,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_tue_button->setGeometry(115,273,20,20);
   label=new QLabel(edit_tue_button,tr("Tuesday"),this);
   label->setGeometry(135,273,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Wednesday Button
@@ -281,8 +259,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_wed_button->setGeometry(215,273,20,20);
   label=new QLabel(edit_wed_button,tr("Wednesday"),this);
   label->setGeometry(235,273,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Thursday Button
@@ -291,8 +269,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_thu_button->setGeometry(335,273,20,20);
   label=new QLabel(edit_thu_button,tr("Thursday"),this);
   label->setGeometry(355,273,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Friday Button
@@ -301,8 +279,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_fri_button->setGeometry(440,273,20,20);
   label=new QLabel(edit_fri_button,tr("Friday"),this);
   label->setGeometry(460,273,40,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Saturday Button
@@ -311,8 +289,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_sat_button->setGeometry(130,298,20,20);
   label=new QLabel(edit_sat_button,tr("Saturday"),this);
   label->setGeometry(150,298,60,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Sunday Button
@@ -321,8 +299,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_sun_button->setGeometry(300,298,20,20);
   label=new QLabel(edit_sun_button,tr("Sunday"),this);
   label->setGeometry(320,298,60,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // OneShot Button
@@ -331,8 +309,8 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_oneshot_box->setGeometry(20,335,15,15);
   label=new QLabel(edit_oneshot_box,tr("Make OneShot"),this);
   label->setGeometry(40,333,115,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Event Offset
@@ -342,19 +320,19 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   edit_eventoffset_spin->setRange(-30,30);
   label=new QLabel(edit_eventoffset_spin,tr("Event Offset:"),this);
   label->setGeometry(140,333,100,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignRight);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
   label=new QLabel(edit_eventoffset_spin,tr("days"),this);
   label->setGeometry(295,333,40,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignVCenter|AlignLeft);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   //
   //  Save As Button
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-300,sizeHint().height()-60,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Save As\nNew"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveasData()));
   if(adds==NULL) {
@@ -367,7 +345,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -376,7 +354,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -405,7 +383,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   }
   else {
     edit_autotrim_box->setChecked(false);
-    edit_autotrim_spin->setValue(rdlibrary_conf->trimThreshold()/100);
+    edit_autotrim_spin->setValue(rda->libraryConf()->trimThreshold()/100);
   }
   autotrimToggledData(edit_autotrim_box->isChecked());
   if(edit_recording->normalizationLevel()<0) {
@@ -414,7 +392,7 @@ EditDownload::EditDownload(int id,std::vector<int> *adds,QString *filter,
   }
   else {
     edit_normalize_box->setChecked(false);
-    edit_normalize_spin->setValue(rdlibrary_conf->ripperLevel()/100);
+    edit_normalize_spin->setValue(rda->libraryConf()->ripperLevel()/100);
   }
   normalizeToggledData(edit_normalize_box->isChecked());
   edit_metadata_box->setChecked(edit_recording->enableMetadata());
@@ -473,19 +451,13 @@ void EditDownload::urlChangedData(const QString &str)
 
 void EditDownload::selectCartData()
 {
-  QString str;
-
-  RDCutDialog *cut=new RDCutDialog(&edit_cutname,rdstation_conf,catch_system,
-				   edit_filter,NULL,NULL,catch_user->name(),
-				   false,true);
+  RDCutDialog *cut=
+    new RDCutDialog(&edit_cutname,"RDCatch",edit_filter,NULL,NULL,false,true);
   switch(cut->exec()) {
-      case 0:
-	edit_description_edit->setText(RDCutPath(edit_cutname));
-	str=QString(tr("Cut"));
-	edit_destination_edit->
-	  setText(QString().sprintf("%s %s",(const char *)str,
-				    (const char *)edit_cutname));
-	break;
+  case 0:
+    edit_description_edit->setText(RDCutPath(edit_cutname));
+    edit_destination_edit->setText(tr("Cut")+" "+edit_cutname);
+    break;
   }
   delete cut;
 }
@@ -528,7 +500,7 @@ void EditDownload::okData()
     QMessageBox::warning(this,tr("Invalid URL"),tr("The URL is invalid!"));
     return;
   }
-  RDUrl url(edit_url_edit->text());
+  QUrl url(edit_url_edit->text());
   QString protocol=url.protocol();
   if((protocol!="ftp")&&(protocol!="http")&&(protocol!="https")&&
      (protocol!="file")&&(protocol!="scp")&&(protocol!="sftp")) {
@@ -547,36 +519,27 @@ void EditDownload::okData()
     return;
   }
   Save();
-  done(0);
+  done(true);
 }
 
 
 void EditDownload::cancelData()
 {
-  done(-1);
-}
-
-
-void EditDownload::paintEvent(QPaintEvent *e)
-{
-  QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
-  p->drawRect(10,262,sizeHint().width()-20,62);
-  p->end();
+  done(false);
 }
 
 
 void EditDownload::keyPressEvent(QKeyEvent *e)
 {
   switch(e->key()) {
-      case Qt::Key_Escape:
-	e->accept();
-	cancelData();
-	break;
+  case Qt::Key_Escape:
+    e->accept();
+    cancelData();
+    break;
 
-      default:
-	QDialog::keyPressEvent(e);
-	break;
+  default:
+    QDialog::keyPressEvent(e);
+    break;
   }
 }
 
@@ -626,17 +589,13 @@ void EditDownload::Save()
 
 bool EditDownload::CheckEvent(bool include_myself)
 {
-  QString sql=
-    QString().sprintf("select ID from RECORDINGS \
-                       where (STATION_NAME=\"%s\")&&\
-                       (TYPE=%d)&&(START_TIME=\"%s\")&&\
-                       (URL=\"%s\")&&(CUT_NAME=\"%s\")",
-		      (const char *)edit_station_box->currentText(),
-		      RDRecording::Download,
-		      (const char *)edit_starttime_edit->time().
-		      toString("hh:mm:ss"),
-		      (const char *)edit_url_edit->text(),
-		      (const char *)edit_destination_edit->text().right(10));
+  QString sql=QString("select ID from RECORDINGS where ")+
+    "(STATION_NAME=\""+RDEscapeString(edit_station_box->currentText())+"\")&&"+
+    QString().sprintf("(TYPE=%d)&&",RDRecording::Download)+
+    "(START_TIME=\""+RDEscapeString(edit_starttime_edit->time().
+				    toString("hh:mm:ss"))+"\")&&"+
+    "(URL=\""+RDEscapeString(edit_url_edit->text())+"\")&&"+
+    "(CUT_NAME=\""+RDEscapeString(edit_destination_edit->text().right(10))+"\")";
   if(edit_sun_button->isChecked()) {
     sql+="&&(SUN=\"Y\")";
   }
