@@ -2,7 +2,7 @@
 //
 // Edit a Rivendell Netcatch Cart Event
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,28 +18,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
+#include <qgroupbox.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
 
-#include <rddb.h>
-#include <rd.h>
 #include <rdcart_dialog.h>
-#include <rdcut_path.h>
 #include <rdescape_string.h>
 #include <rdtextvalidator.h>
 
-#include <edit_switchevent.h>
-
+#include "edit_switchevent.h"
 
 EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QString sql;
   RDSqlQuery *q;
@@ -47,27 +36,15 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_matrix=NULL;
   edit_added_events=adds;
 
+  edit_deck=NULL;
+
+  setWindowTitle("RDCatch - "+tr("Edit Switcher Event"));
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont day_font=QFont("Helvetica",10,QFont::Normal);
-  day_font.setPixelSize(10);
-
-  edit_deck=NULL;
-
-  setCaption(tr("Edit Switcher Event"));
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Text Validator
@@ -86,8 +63,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_active_button->setGeometry(10,11,20,20);
   QLabel *label=new QLabel(edit_active_button,tr("Event Active"),this);
   label->setGeometry(30,11,125,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Station
@@ -96,8 +73,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_station_box->setGeometry(200,10,140,23);
   label=new QLabel(edit_station_box,tr("Location:"),this);
   label->setGeometry(125,10,70,23);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   connect(edit_station_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(activateStationData(const QString &)));
 
@@ -106,10 +83,11 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   //
   edit_starttime_edit=new QTimeEdit(this);
   edit_starttime_edit->setGeometry(sizeHint().width()-90,12,80,20);
+  edit_starttime_edit->setDisplayFormat("hh:mm:ss");
   label=new QLabel(edit_starttime_edit,tr("Start Time:"),this);
   label->setGeometry(sizeHint().width()-175,12,80,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Description
@@ -119,8 +97,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_description_edit->setValidator(validator);
   label=new QLabel(edit_description_edit,tr("Description:"),this);
   label->setGeometry(10,43,105,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Switch Matrix
@@ -129,8 +107,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_matrix_box->setGeometry(120,70,sizeHint().width()-130,20);
   label=new QLabel(edit_matrix_box,tr("Switch Matrix:"),this);
   label->setGeometry(10,70,105,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   connect(edit_matrix_box,SIGNAL(activated(const QString &)),
 	  this,SLOT(activateMatrixData(const QString &)));
 
@@ -141,8 +119,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_input_box->setGeometry(120,100,sizeHint().width()-130,20);
   label=new QLabel(edit_input_box,tr("Switch Input:"),this);
   label->setGeometry(10,100,105,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   edit_input_spin=new QSpinBox(this);
   edit_input_spin->setGeometry(140,125,50,20);
   connect(edit_input_box,SIGNAL(activated(const QString &)),
@@ -155,8 +133,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_output_box->setGeometry(120,155,sizeHint().width()-130,20);
   label=new QLabel(edit_output_box,tr("Switch Output:"),this);
   label->setGeometry(10,155,105,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter|Qt::TextShowMnemonic);
   edit_output_spin=new QSpinBox(this);
   edit_output_spin->setGeometry(140,180,50,20);
   connect(edit_output_box,SIGNAL(activated(const QString &)),
@@ -165,10 +143,9 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   //
   // Button Label
   //
-  label=new QLabel(tr("Active Days"),this);
-  label->setGeometry(47,210,80,19);
-  label->setFont(label_font);
-  label->setAlignment(AlignHCenter|ShowPrefix);
+  QGroupBox *groupbox=new QGroupBox(tr("Active Days"),this);
+  groupbox->setFont(labelFont());
+  groupbox->setGeometry(10,213,sizeHint().width()-20,62);
 
   //
   // Monday Button
@@ -177,8 +154,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_mon_button->setGeometry(20,228,20,20);
   label=new QLabel(edit_mon_button,tr("Monday"),this);
   label->setGeometry(40,228,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Tuesday Button
@@ -187,8 +164,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_tue_button->setGeometry(115,228,20,20);
   label=new QLabel(edit_tue_button,tr("Tuesday"),this);
   label->setGeometry(135,228,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Wednesday Button
@@ -197,8 +174,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_wed_button->setGeometry(215,228,20,20);
   label=new QLabel(edit_wed_button,tr("Wednesday"),this);
   label->setGeometry(235,228,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Thursday Button
@@ -207,8 +184,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_thu_button->setGeometry(335,228,20,20);
   label=new QLabel(edit_thu_button,tr("Thursday"),this);
   label->setGeometry(355,228,115,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Friday Button
@@ -217,8 +194,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_fri_button->setGeometry(440,228,20,20);
   label=new QLabel(edit_fri_button,tr("Friday"),this);
   label->setGeometry(460,228,40,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Saturday Button
@@ -227,8 +204,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_sat_button->setGeometry(130,253,20,20);
   label=new QLabel(edit_sat_button,tr("Saturday"),this);
   label->setGeometry(150,253,60,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // Sunday Button
@@ -237,8 +214,8 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_sun_button->setGeometry(300,253,20,20);
   label=new QLabel(edit_sun_button,tr("Sunday"),this);
   label->setGeometry(320,253,60,20);
-  label->setFont(day_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   // OneShot Button
@@ -247,15 +224,15 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   edit_oneshot_box->setGeometry(20,290,15,15);
   label=new QLabel(edit_oneshot_box,tr("Make OneShot"),this);
   label->setGeometry(40,288,115,20);
-  label->setFont(label_font);
-  label->setAlignment(AlignLeft|AlignVCenter|ShowPrefix);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter|Qt::TextShowMnemonic);
 
   //
   //  Save As Button
   //
   QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-300,sizeHint().height()-60,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Save As\nNew"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveasData()));
   if(adds==NULL) {
@@ -268,7 +245,7 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -277,7 +254,7 @@ EditSwitchEvent::EditSwitchEvent(int id,std::vector<int> *adds,QWidget *parent)
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(button_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -480,22 +457,13 @@ void EditSwitchEvent::okData()
     return;
   }
   Save();
-  done(0);
+  done(true);
 }
 
 
 void EditSwitchEvent::cancelData()
 {
-  done(-1);
-}
-
-
-void EditSwitchEvent::paintEvent(QPaintEvent *e)
-{
-  QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
-  p->drawRect(10,218,sizeHint().width()-20,62);
-  p->end();
+  done(false);
 }
 
 
