@@ -2,7 +2,7 @@
 //
 // The Event Schedule Manager for Rivendell.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,33 +21,17 @@
 #ifndef RDCATCH_H
 #define RDCATCH_H
 
-#include <vector>
-
-#include <qwidget.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qsqldatabase.h>
-#include <qpixmap.h>
-#include <qtimer.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
-#include <qpixmap.h>
-#include <qscrollview.h>
 
-#include <rdtransportbutton.h>
-#include <rdlistviewitem.h>
-#include <rd.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rdcae.h>
-#include <rddeck.h>
-#include <rdconfig.h>
 #include <rdcatch_connect.h>
+#include <rdtransportbutton.h>
+#include <rdwidget.h>
 
-#include <catch_listview.h>
-#include <deckmon.h>
-#include <catch_monitor.h>
-#include <vbox.h>
+#include "catch_listview.h"
+#include "catch_monitor.h"
+#include "deckmon.h"
+#include "vbox.h"
 
 /*
  * Widget Settings
@@ -72,16 +56,15 @@ class CatchConnector
 };
 
 
-class MainWidget : public QWidget
+class MainWidget : public RDWidget
 {
   Q_OBJECT
  public:
-  MainWidget(QWidget *parent=0);
+  MainWidget(RDConfig *c,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   
  private slots:
-  void log(RDConfig::LogPriority prio,const QString &msg);
   void resizeData();
   void connectedData(int serial,bool state);
   void nextEventData();
@@ -105,8 +88,8 @@ class MainWidget : public QWidget
   void meterLevelData(int,int,int,int);
   void abortData(int);
   void monitorData(int);
-  void selectionChangedData(QListViewItem *item);
-  void doubleClickedData(QListViewItem *,const QPoint &,int);
+  void selectionChangedData(Q3ListViewItem *item);
+  void doubleClickedData(Q3ListViewItem *,const QPoint &,int);
   void filterChangedData(bool state);
   void filterActivatedData(int id);
   void clockData();
@@ -127,6 +110,8 @@ class MainWidget : public QWidget
   void ProcessNewRecords(std::vector<int> *adds);
   void EnableScroll(bool state);
   void UpdateScroll();
+  QString RefreshSql() const;
+  void RefreshRow(RDSqlQuery *q,RDListViewItem *item);
   void RefreshList();
   void RefreshLine(RDListViewItem *item);
   void UpdateExitCode(RDListViewItem *item);
@@ -141,7 +126,7 @@ class MainWidget : public QWidget
   void LoadGeometry();
   void SaveGeometry();
   std::vector<CatchMonitor *> catch_monitor;
-  QScrollView *catch_monitor_view;
+  Q3ScrollView *catch_monitor_view;
   VBox *catch_monitor_vbox;
   std::vector<CatchConnector *> catch_connect;
   QSqlDatabase *catch_db;
@@ -181,6 +166,7 @@ class MainWidget : public QWidget
   int catch_time_offset;
   QPixmap *catch_rivendell_map;
   bool catch_host_warnings;
+  bool catch_resize;
 };
 
 
