@@ -1,8 +1,8 @@
 //   rdhpiplaystream.cpp
 //
-//   A class for playing Microsoft WAV files.
+//   A class for playing Microsoft WAV file on AudioScience HPI devices.
 //
-//   (C) Copyright 2002-2007,2016-2018 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,8 +31,9 @@
 #include <qdatetime.h>
 
 #include <rd.h>
-#include <rdhpiplaystream.h>
-#include <rdhpisoundcard.h>
+#include <rdapplication.h>
+#include "rdhpiplaystream.h"
+#include "rdhpisoundcard.h"
 
 #define RDHPIPLAYSTREAM_USE_LOCAL_MUTEX
 
@@ -188,7 +189,7 @@ bool RDHPIPlayStream::formatSupported(RDWaveFile::Format format)
     for(int i=0;i<sound_card->getCardOutputStreams(card_number);i++) {
       if(LogHpi(HPI_OutStreamOpen(NULL,card_index[card_number],i,&hostream),
 		__LINE__)==0) {
-	syslog(LOG_NOTICE,"buffer_size: %u\n",dma_buffer_size);
+	RDApplication::syslog(sound_card->config(),LOG_DEBUG,"buffer_size: %u\n",dma_buffer_size);
 	found=true;
 	break;
       }
@@ -196,11 +197,7 @@ bool RDHPIPlayStream::formatSupported(RDWaveFile::Format format)
     if(!found) {
       return false;
     }
-    if(LogHpi(HPI_OutStreamHostBufferAllocate(NULL,hostream,dma_buffer_size),
-	      __LINE__)!=0) {
-      LogHpi(HPI_OutStreamClose(NULL,hostream),__LINE__);
-      return false;
-    }
+    if(HPI_OutStreamHostBufferAllocate(NULL,hostream,dma_buffer_size));
   }
   else {
     hostream=hpi_stream;
@@ -246,7 +243,7 @@ bool RDHPIPlayStream::formatSupported(RDWaveFile::Format format)
     break;
   }
   if(!is_open) {
-    LogHpi(HPI_OutStreamHostBufferFree(NULL,hostream),__LINE__);
+    if(HPI_OutStreamHostBufferFree(NULL,hostream));
     LogHpi(HPI_OutStreamClose(NULL,hostream),__LINE__);
   }
   if(state!=0) {
@@ -412,14 +409,15 @@ bool RDHPIPlayStream::play()
 #ifdef RPLAYSTREAM_SHOW_SLOTS
   printf("play() -- Card: %d  Stream: %d\n",card_number,stream_number);
 #endif  // RPLAYSTREAM_SHOW_SLOTS
-  syslog(LOG_ERR,"Play - 1\n");
   if(!is_open) {
     return false;
   }
   if((!playing)&&(!is_paused)) {
-    LogHpi(HPI_OutStreamSetTimeScale(NULL,hpi_stream,
+    if(sound_card->haveTimescaling(card_number)) {
+      LogHpi(HPI_OutStreamSetTimeScale(NULL,hpi_stream,
 			(uint16_t)((RD_TIMESCALE_DIVISOR/(double)play_speed)*
 				   HPI_OSTREAM_TIMESCALE_UNITS)),__LINE__);
+    }
     if(LogHpi(HPI_OutStreamGetInfoEx(NULL,hpi_stream,
 				     &state,&buffer_size,&data_to_play,
 				     &samples_played,&reserved),__LINE__)!=0) {
@@ -759,7 +757,7 @@ void RDHPIPlayStream::tickClock()
   else {
     if(state==HPI_STATE_DRAINED) {
       LogHpi(HPI_OutStreamStop(NULL,hpi_stream),__LINE__);
-      LogHpi(HPI_OutStreamHostBufferFree(NULL,hpi_stream),__LINE__);
+      if(HPI_OutStreamHostBufferFree(NULL,hpi_stream));
       LogHpi(HPI_OutStreamClose(NULL,hpi_stream),__LINE__);
       hpi_err=LogHpi(HPI_AdapterClose(NULL,card_index[card_number]),__LINE__);
       clock->stop();
@@ -793,16 +791,14 @@ int RDHPIPlayStream::GetStream()
 #ifdef RDHPIPLAYSTREAM_USE_LOCAL_MUTEX
   for(int i=0;i<sound_card->getCardOutputStreams(card_number);i++) {
     if(++stream_mutex[card_number][i]==1) {
-      LogHpi(HPI_OutStreamOpen(NULL,card_index[card_number],i,&hpi_stream),
-	     __LINE__);
-      LogHpi(HPI_OutStreamHostBufferAllocate(NULL,hpi_stream,dma_buffer_size),
-	     __LINE__);
-      stream_number=i;
-      return stream_number;
-    }
-    else {
-      stream_mutex[card_number][i]--;
+      if(LogHpi(HPI_OutStreamOpen(NULL,card_index[card_number],i,&hpi_stream),
+		__LINE__)==0) {
+	if(HPI_OutStreamHostBufferAllocate(NULL,hpi_stream,dma_buffer_size));
+	stream_number=i;
+	return stream_number;
+      }
     }
+    stream_mutex[card_number][i]--;
   }
   return -1;
 #else
@@ -810,7 +806,7 @@ int RDHPIPlayStream::GetStream()
     if(LogHpi(HPI_OutStreamOpen(NULL,card_index[card_number],i,&hpi_stream),
 	      __LINE__)==0) {
       stream_number=i;
-//      syslog(LOG_ERR,"HPI allocating ostream: %d",stream_number);
+//      RDApplication::syslog(sound_card->config(),LOG_ERR,"HPI allocating ostream: %d",stream_number);
       return stream_number;
     }
   }
@@ -823,13 +819,12 @@ void RDHPIPlayStream::FreeStream()
 {
 #ifdef RDHPIPLAYSTREAM_USE_LOCAL_MUTEX
   stream_mutex[card_number][stream_number]--;
-  LogHpi(HPI_OutStreamHostBufferFree(NULL,hpi_stream),__LINE__);
+  if(HPI_OutStreamHostBufferFree(NULL,hpi_stream));
   LogHpi(HPI_OutStreamClose(NULL,hpi_stream),__LINE__);
   stream_number=-1;
 #else
-  LogHpi(HPI_OutStreamHostBufferFree(NULL,hpi_stream),__LINE__);
+  if(HPI_OutStreamHostBufferFree(NULL,hpi_stream));
   LogHpi(HPI_OutStreamClose(NULL,hpi_stream),__LINE__);
-//  syslog(LOG_ERR,"HPI closing ostream: %d",stream_number);
   stream_number=-1;
 #endif
 }
@@ -841,7 +836,8 @@ hpi_err_t RDHPIPlayStream::LogHpi(hpi_err_t err,int lineno)
 
   if(err!=0) {
     HPI_GetErrorText(err,err_txt);
-    syslog(LOG_NOTICE,"HPI Error: %s, %s line %d",err_txt,__FILE__,lineno);
+    RDApplication::syslog(sound_card->config(),LOG_WARNING,
+			  "HPI Error: %s, %s line %d",err_txt,__FILE__,lineno);
   }
   return err;
 }
