@@ -2,7 +2,7 @@
 //
 // The audio cart editor for RDLibrary.
 //
-//   (C) Copyright 2002-2004,2016-2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,45 +18,26 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qpixmap.h>
-#include <unistd.h>
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistview.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpainter.h>
-#include <qevent.h>
-#include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
 #include <qapplication.h>
+#include <qmessagebox.h>
 
-#include <rdcut.h>
-#include <rdcddbrecord.h>
-#include <rddb.h>
-#include <rdwavedata.h>
-#include <rd.h>
-#include <rdconf.h>
-#include <rdimport_audio.h>
 #include <rdaudio_exists.h>
+#include <rdconf.h>
 #include <rdedit_audio.h>
 #include <rdescape_string.h>
+#include <rdimport_audio.h>
 
-#include <cdripper.h>
-#include <audio_cart.h>
-#include <record_cut.h>
-#include <globals.h>
-
-#include <validate_cut.h>
+#include "audio_cart.h"
+#include "cdripper.h"
+#include "globals.h"
+#include "record_cut.h"
+#include "validate_cut.h"
 
 bool import_active=false;
 
-
 AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
 		     bool select_cut,bool profile_rip,QWidget *parent)
-  : QWidget(parent)
+  : RDWidget(parent)
 {
   rdcart_import_metadata=true;
   rdcart_controls=controls;
@@ -64,18 +45,8 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   rdcart_import_path=path;
   rdcart_select_cut=select_cut;
   rdcart_profile_rip=profile_rip;
-  rdcart_modification_allowed=lib_user->editAudio()&&cart->owner().isEmpty();
+  rdcart_modification_allowed=rda->user()->editAudio()&&cart->owner().isEmpty();
 
-  setCaption(QString().sprintf("%u",rdcart_cart->number())+" - "+
-    rdcart_cart->title());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont line_edit_font=QFont("Helvetica",12,QFont::Normal);
-  line_edit_font.setPixelSize(12);
   QColor system_button_text_color = palette().active().buttonText();
 
   //
@@ -84,7 +55,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   rdcart_progress_dialog=new QProgressDialog(this);
   rdcart_progress_dialog->setLabelText(tr("Copying audio..."));
   rdcart_progress_dialog->setCancelButton(NULL);
-  rdcart_progress_dialog->setTotalSteps(10);
+  rdcart_progress_dialog->setMaximum(10);
   rdcart_progress_dialog->setMinimumDuration(1000);
 
   //
@@ -92,7 +63,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   QPushButton *add_cut_button=new QPushButton(this);
   add_cut_button->setGeometry(10,0,80,50);
-  add_cut_button->setFont(button_font);
+  add_cut_button->setFont(buttonFont());
   add_cut_button->setText(tr("Add"));
   connect(add_cut_button,SIGNAL(clicked()),this,SLOT(addCutData()));
 
@@ -101,7 +72,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   QPushButton *delete_cut_button=new QPushButton(this);
   delete_cut_button->setGeometry(10,60,80,50);
-  delete_cut_button->setFont(button_font);
+  delete_cut_button->setFont(buttonFont());
   delete_cut_button->setText(tr("Delete"));
   connect(delete_cut_button,SIGNAL(clicked()),this,SLOT(deleteCutData()));
 
@@ -110,7 +81,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   QPushButton *copy_cut_button=new QPushButton(this);
   copy_cut_button->setGeometry(10,120,80,50);
-  copy_cut_button->setFont(button_font);
+  copy_cut_button->setFont(buttonFont());
   copy_cut_button->setText(tr("Copy"));
   connect(copy_cut_button,SIGNAL(clicked()),this,SLOT(copyCutData()));
 
@@ -119,7 +90,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   paste_cut_button=new QPushButton(this);
   paste_cut_button->setGeometry(10,180,80,50);
-  paste_cut_button->setFont(button_font);
+  paste_cut_button->setFont(buttonFont());
   paste_cut_button->setText(tr("Paste"));
   connect(paste_cut_button,SIGNAL(clicked()),this,SLOT(pasteCutData()));
 
@@ -129,54 +100,55 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   rdcart_cut_list=new RDListView(this);
   rdcart_cut_list->setGeometry(100,0,430,sizeHint().height());
   rdcart_cut_list->setAllColumnsShowFocus(true);
-  rdcart_cut_list->setSelectionMode(QListView::Extended);
+  rdcart_cut_list->setSelectionMode(Q3ListView::Extended);
   rdcart_cut_list->setItemMargin(5);
   rdcart_cut_list->setSorting(11);
   connect(rdcart_cut_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
-  rdcart_cut_list->addColumn(tr("WT"));
+  rdcart_cut_list->addColumn(tr("Wt"));
   rdcart_cut_list->setColumnAlignment(0,Qt::AlignHCenter);
+  rdcart_cut_list->setColumnSortType(0,RDListView::LineSort);
 
-  rdcart_cut_list->addColumn(tr("DESCRIPTION"));
+  rdcart_cut_list->addColumn(tr("Description"));
   rdcart_cut_list->setColumnAlignment(1,Qt::AlignLeft);
 
-  rdcart_cut_list->addColumn(tr("LENGTH"));
+  rdcart_cut_list->addColumn(tr("Length"));
   rdcart_cut_list->setColumnAlignment(2,Qt::AlignRight);
   rdcart_cut_list->setColumnSortType(2,RDListView::TimeSort);
 
-  rdcart_cut_list->addColumn(tr("LAST PLAYED"));
+  rdcart_cut_list->addColumn(tr("Last Played"));
   rdcart_cut_list->setColumnAlignment(3,Qt::AlignHCenter);
 
-  rdcart_cut_list->addColumn(tr("# OF PLAYS"));
+  rdcart_cut_list->addColumn(tr("# of Plays"));
   rdcart_cut_list->setColumnAlignment(4,Qt::AlignHCenter);
 
 
-  rdcart_cut_list->addColumn(tr("SOURCE"));
+  rdcart_cut_list->addColumn(tr("Source"));
   rdcart_cut_list->setColumnAlignment(5,Qt::AlignHCenter);
 
 
-  rdcart_cut_list->addColumn(tr("INGEST"));
+  rdcart_cut_list->addColumn(tr("Ingest"));
   rdcart_cut_list->setColumnAlignment(6,Qt::AlignHCenter);
 
-  rdcart_cut_list->addColumn(tr("OUTCUE"));
+  rdcart_cut_list->addColumn(tr("Outcue"));
   rdcart_cut_list->setColumnAlignment(7,Qt::AlignLeft);
 
-  rdcart_cut_list->addColumn(tr("START DATE"));
+  rdcart_cut_list->addColumn(tr("Start Date"));
   rdcart_cut_list->setColumnAlignment(8,Qt::AlignLeft);
 
-  rdcart_cut_list->addColumn(tr("END DATE"));
+  rdcart_cut_list->addColumn(tr("End Date"));
   rdcart_cut_list->setColumnAlignment(9,Qt::AlignLeft);
 
-  rdcart_cut_list->addColumn(tr("DAYPART START"));
+  rdcart_cut_list->addColumn(tr("Daypart Start"));
   rdcart_cut_list->setColumnAlignment(10,Qt::AlignLeft);
 
-  rdcart_cut_list->addColumn(tr("DAYPART END"));
+  rdcart_cut_list->addColumn(tr("Daypart End"));
   rdcart_cut_list->setColumnAlignment(11,Qt::AlignLeft);
 
-  rdcart_cut_list->addColumn(tr("NAME"));
+  rdcart_cut_list->addColumn(tr("Name"));
   rdcart_cut_list->setColumnAlignment(12,Qt::AlignLeft);
 
   rdcart_cut_list->addColumn(tr("SHA1"));
@@ -187,16 +159,15 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   // Record Cut Button
   //
-  QPixmap *pix=new QPixmap(QSize(80,50));
+  QPixmap *pix=new QPixmap(QSize(70,40));
   QPainter *p=new QPainter(pix);
-  QFontMetrics *m=new QFontMetrics(button_font);
-  p->fillRect(0,0,80,50,palette().color(QPalette::Active,QColorGroup::Button));
+  QFontMetrics *m=new QFontMetrics(buttonFont());
+  p->fillRect(0,0,70,40,palette().color(QPalette::Active,QColorGroup::Button));
   p->setPen(QColor(system_button_text_color));
-  p->setFont(button_font);
-  p->drawText((80-m->width(tr("Cut Info")))/2,20,tr("Cut Info"));
-  p->moveTo(10,24);
-  p->lineTo(70,24);
-  p->drawText((80-m->width(tr("Record")))/2,38,tr("Record"));
+  p->setFont(buttonFont());
+  p->drawText((70-m->width(tr("Cut Info")))/2,15,tr("Cut Info"));
+  p->drawLine(10,19,60,19);
+  p->drawText((70-m->width(tr("Record")))/2,33,tr("Record"));
   p->end();
   QPushButton *record_cut_button=new QPushButton(this);
   record_cut_button->setGeometry(550,0,80,50);
@@ -208,13 +179,13 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   QPushButton *ext_editor_cut_button=new QPushButton(this);
   ext_editor_cut_button->setGeometry(550,60,80,50);
-  ext_editor_cut_button->setFont(button_font);
+  ext_editor_cut_button->setFont(buttonFont());
   ext_editor_cut_button->setText(tr("Edit\nAudio"));
   connect(ext_editor_cut_button,SIGNAL(clicked()),
 	  this,SLOT(extEditorCutData()));
   int yoffset=60;
-  if((!rdlibrary_conf->enableEditor())||
-     rdstation_conf->editorPath().isEmpty()) {
+  if((!rda->libraryConf()->enableEditor())||
+     rda->station()->editorPath().isEmpty()) {
     ext_editor_cut_button->hide();
     yoffset=0;
   }
@@ -224,7 +195,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   QPushButton *edit_cut_button=new QPushButton(this);
   edit_cut_button->setGeometry(550,60+yoffset,80,50);
-  edit_cut_button->setFont(button_font);
+  edit_cut_button->setFont(buttonFont());
   edit_cut_button->setText(tr("Edit\nMarkers"));
   connect(edit_cut_button,SIGNAL(clicked()),this,SLOT(editCutData()));
 
@@ -232,14 +203,13 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   // Import Cut Button
   //
   p=new QPainter(pix);
-  m=new QFontMetrics(button_font);
-  p->fillRect(0,0,80,50,palette().color(QPalette::Active,QColorGroup::Button));
+  m=new QFontMetrics(buttonFont());
+  p->fillRect(0,0,70,40,palette().color(QPalette::Active,QColorGroup::Button));
   p->setPen(QColor(system_button_text_color));
-  p->setFont(button_font);
-  p->drawText((80-m->width(tr("Import")))/2,20,tr("Import"));
-  p->moveTo(10,24);
-  p->lineTo(70,24);
-  p->drawText((80-m->width(tr("Export")))/2,38,tr("Export"));
+  p->setFont(buttonFont());
+  p->drawText((70-m->width(tr("Import")))/2,15,tr("Import"));
+  p->drawLine(10,19,60,19);
+  p->drawText((70-m->width(tr("Export")))/2,33,tr("Export"));
   p->end();
   QPushButton *import_cut_button=new QPushButton(this);
   import_cut_button->setPixmap(*pix);
@@ -251,7 +221,7 @@ AudioCart::AudioCart(AudioControls *controls,RDCart *cart,QString *path,
   //
   QPushButton *rip_cut_button=new QPushButton(this);
   rip_cut_button->setGeometry(550,180+yoffset,80,50);
-  rip_cut_button->setFont(button_font);
+  rip_cut_button->setFont(buttonFont());
   rip_cut_button->setText(tr("Rip CD"));
   connect(rip_cut_button,SIGNAL(clicked()),this,SLOT(ripCutData()));
 
@@ -297,10 +267,10 @@ void AudioCart::changeCutScheduling(int sched)
     item=(RDListViewItem *)item->nextSibling();
   }
   if(sched) {
-    rdcart_cut_list->setColumnText(0,tr("WT"));
+    rdcart_cut_list->setColumnText(0,tr("Wt"));
   }
   else {
-    rdcart_cut_list->setColumnText(0,tr("ORD"));
+    rdcart_cut_list->setColumnText(0,tr("Ord"));
   }
   rdcart_use_weighting=sched!=0;
 }
@@ -309,9 +279,9 @@ void AudioCart::changeCutScheduling(int sched)
 void AudioCart::addCutData()
 {
   QString next_name=RDCut::cutName(rdcart_cart->number(),
-		 rdcart_cart->addCut(rdlibrary_conf->defaultFormat(),
-				     rdlibrary_conf->defaultBitrate(),
-				     rdlibrary_conf->defaultChannels()));
+		 rdcart_cart->addCut(rda->libraryConf()->defaultFormat(),
+				     rda->libraryConf()->defaultBitrate(),
+				     rda->libraryConf()->defaultChannels()));
   if(next_name.isEmpty()) {
     QMessageBox::warning(this,tr("RDLibrary - Edit Cart"),
 			 tr("This cart cannot contain any additional cuts!"));
@@ -350,7 +320,7 @@ void AudioCart::deleteCutData()
 				 QMessageBox::Yes,QMessageBox::No)) {
 
     case QMessageBox::No:
-    case QMessageBox::NoButton:
+    case Qt::NoButton:
       return;
       
     default:
@@ -404,8 +374,8 @@ void AudioCart::deleteCutData()
   // Delete Cuts
   //
   for(unsigned i=0;i<cutnames.size();i++) {
-    if(!rdcart_cart->removeCut(rdstation_conf,lib_user,cutnames[i],
-			       lib_config)) {
+    if(!rdcart_cart->removeCut(rda->station(),rda->user(),cutnames[i],
+			       rda->config())) {
       QMessageBox::warning(this,tr("RDLibrary"),
 			   tr("Unable to delete audio for cut")+
 			   QString().sprintf(" %d!",RDCut::cutNumber(cutnames[i])));
@@ -466,7 +436,7 @@ void AudioCart::extEditorCutData()
     return;
   }
 
-  QString cmd=rdstation_conf->editorPath();
+  QString cmd=rda->station()->editorPath();
   cmd.replace("%f",RDCut::pathName(rdcart_cut_list->currentItem()->text(12)));
   // FIXME: other replace commands to match: lib/rdcart_dialog.cpp editorData()
   //        These substitions should be documented (maybe a text file),
@@ -506,7 +476,7 @@ void AudioCart::pasteCutData()
     }
   }
   cut_clipboard->connect(this,SLOT(copyProgressData(const QVariant &)));
-  cut_clipboard->copyTo(rdstation_conf,lib_user,item->text(12),lib_config);
+  cut_clipboard->copyTo(rda->station(),rda->user(),item->text(12),rda->config());
   cut_clipboard->disconnect(this,SLOT(copyProgressData(const QVariant &)));
   rdcart_cart->updateLength(rdcart_controls->enforce_length_box->isChecked(),
 			    QTime().msecsTo(rdcart_controls->
@@ -532,10 +502,9 @@ void AudioCart::editCutData()
     return;
   }
   RDEditAudio *edit=
-    new RDEditAudio(rdcart_cart,cutname,rdcae,lib_user,rdstation_conf,
-		    lib_config,rdlibrary_conf->outputCard(),
-		    rdlibrary_conf->outputPort(),rdlibrary_conf->tailPreroll(),
-		    rdlibrary_conf->trimThreshold(),this);
+    new RDEditAudio(rdcart_cart,cutname,rda->libraryConf()->outputCard(),
+		    rda->libraryConf()->outputPort(),rda->libraryConf()->tailPreroll(),
+		    rda->libraryConf()->trimThreshold(),this);
   if(edit->exec()!=-1) {
     emit cartDataChanged();
     rdcart_cart->updateLength(rdcart_controls->enforce_length_box->isChecked(),
@@ -585,7 +554,7 @@ void AudioCart::ripCutData()
   }
   cutname=item->text(12);
   RDCddbRecord *rec=new RDCddbRecord();
-  CdRipper *ripper=new CdRipper(cutname,rec,rdlibrary_conf,rdcart_profile_rip);
+  CdRipper *ripper=new CdRipper(cutname,rec,rda->libraryConf(),rdcart_profile_rip);
   if((track=ripper->exec(&title,&artist,&album))>=0) {
     if((rdcart_controls->title_edit->text().isEmpty()||
 	(rdcart_controls->title_edit->text()==tr("[new cart]")))&&
@@ -623,16 +592,15 @@ void AudioCart::importCutData()
   }
   cutname=item->text(12);
   RDSettings settings;
-  rdlibrary_conf->getSettings(&settings);
+  rda->libraryConf()->getSettings(&settings);
   RDImportAudio *import=new RDImportAudio(cutname,rdcart_import_path,
 					  &settings,&rdcart_import_metadata,
 					  &wavedata,cut_clipboard,
-					  rdstation_conf,lib_user,
-					  &import_active,lib_config);
-  import->enableAutotrim(rdlibrary_conf->defaultTrimState());
-  import->setAutotrimLevel(rdlibrary_conf->trimThreshold());
-  import->enableNormalization(rdlibrary_conf->ripperLevel()!=0);
-  import->setNormalizationLevel(rdlibrary_conf->ripperLevel());
+					  &import_active);
+  import->enableAutotrim(rda->libraryConf()->defaultTrimState());
+  import->setAutotrimLevel(rda->libraryConf()->trimThreshold());
+  import->enableNormalization(rda->libraryConf()->ripperLevel()!=0);
+  import->setNormalizationLevel(rda->libraryConf()->ripperLevel());
   if(import->exec(true,true)==0) {
     if(rdcart_controls->title_edit->text().isEmpty()||
        (rdcart_controls->title_edit->text()==tr("[new cart]"))) {
@@ -688,7 +656,7 @@ void AudioCart::importCutData()
 }
 
 
-void AudioCart::doubleClickedData(QListViewItem *,const QPoint &,int)
+void AudioCart::doubleClickedData(Q3ListViewItem *,const QPoint &,int)
 {
   recordCutData();
 }
@@ -696,7 +664,7 @@ void AudioCart::doubleClickedData(QListViewItem *,const QPoint &,int)
 
 void AudioCart::copyProgressData(const QVariant &step)
 {
-  rdcart_progress_dialog->setProgress(step.toInt());
+  rdcart_progress_dialog->setValue(step.toInt());
   qApp->processEvents();
 }
 
