@@ -1,8 +1,8 @@
 // cdripper.cpp
 //
-// CD Ripper Dialog for Rivendell.
+// CD Track Ripper Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2003,2009,2016-2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,31 +18,16 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <signal.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <math.h>
-#include <linux/cdrom.h>
-#include <qpushbutton.h>
-#include <qfiledialog.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
-#include <qstringlist.h>
 
-#include <rd.h>
 #include <rdaudioimport.h>
-#include <rdconf.h>
 #include <rdcdripper.h>
-#include <rdcut.h>
+#include <rdconf.h>
 #include <rdtempdirectory.h>
-#include <rdwavefile.h>
 
-#include <cdripper.h>
-#include <globals.h>
-#include <rdconfig.h>
+#include "cdripper.h"
+#include "globals.h"
+#include "rdconfig.h"
 
 //
 // Global Variables
@@ -51,32 +36,22 @@ bool ripper_running;
 
 CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
 		   bool profile_rip,QWidget *parent) 
-  : QDialog(parent)
+  : RDDialog(parent)
 {
   rip_profile_rip=profile_rip;
   rip_isrc_read=false;
-
-  //
-  // Fix the Window Size
-  //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-
   rip_conf=conf;
   rip_cddb_record=rec;
   rip_track[0]=-1;
   rip_track[1]=-1;
   rip_title=NULL;
 
-  setCaption("Rip CD");
+  setWindowTitle("RDLibrary - "+tr("Rip CD"));
+
+  //
+  // Fix the Window Size
+  //
+  setMinimumSize(sizeHint());
 
   //
   // Create Temporary Directory
@@ -117,20 +92,20 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   // CDDB Stuff
   //
   if(rip_profile_rip) {
-    rip_cddb_lookup=new RDCddbLookup(stdout,this);
+    rip_cddb_lookup=new RDCddbLookup("RDLibrary",stdout,this);
   }
   else {
-    rip_cddb_lookup=new RDCddbLookup(NULL,this);
+    rip_cddb_lookup=new RDCddbLookup("RDLibrary",NULL,this);
   }
-  connect(rip_cddb_lookup,SIGNAL(done(RDCddbLookup::Result)),
+  connect(rip_cddb_lookup,SIGNAL(lookupDone(RDCddbLookup::Result)),
 	  this,SLOT(cddbDoneData(RDCddbLookup::Result)));
 
   //
   // Title Selector
   //
   rip_title_label=new QLabel(tr("Title:"),this);
-  rip_title_label->setFont(label_font);
-  rip_title_label->setAlignment(AlignRight|AlignVCenter);
+  rip_title_label->setFont(labelFont());
+  rip_title_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_title_box=new QComboBox(this);
   rip_title_box->insertItem(tr("[none]"));
 
@@ -138,25 +113,25 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   // Artist Label
   //
   rip_artist_label=new QLabel(tr("Artist:"),this);
-  rip_artist_label->setFont(label_font);
-  rip_artist_label->setAlignment(AlignRight|AlignVCenter);
+  rip_artist_label->setFont(labelFont());
+  rip_artist_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_artist_edit=new QLineEdit(this);
 
   //
   // Album Edit
   //
   rip_album_label=new QLabel(tr("Album:"),this);
-  rip_album_label->setFont(label_font);
-  rip_album_label->setAlignment(AlignRight|AlignVCenter);
+  rip_album_label->setFont(labelFont());
+  rip_album_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_album_edit=new QLineEdit(this);
 
   //
   // Other Edit
   //
   rip_other_label=new QLabel(tr("Other:"),this);
-  rip_other_label->setFont(label_font);
-  rip_other_label->setAlignment(AlignRight);
-  rip_other_edit=new QTextEdit(this);
+  rip_other_label->setFont(labelFont());
+  rip_other_label->setAlignment(Qt::AlignRight);
+  rip_other_edit=new Q3TextEdit(this);
   rip_other_edit->setReadOnly(true);
 
   //
@@ -167,8 +142,8 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_apply_box->setDisabled(true);
   rip_apply_label=
     new QLabel(rip_apply_box,tr("Apply FreeDB Values to Cart"),this);
-  rip_apply_label->setFont(label_font);
-  rip_apply_label->setAlignment(AlignLeft);
+  rip_apply_label->setFont(labelFont());
+  rip_apply_label->setAlignment(Qt::AlignLeft);
   rip_apply_box->setChecked(false);
   rip_apply_label->setDisabled(true);
 
@@ -177,13 +152,13 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   //
   rip_track_list=new RDListView(this);
   rip_track_list->setAllColumnsShowFocus(true);
-  rip_track_list->setSelectionMode(QListView::Extended);
+  rip_track_list->setSelectionMode(Q3ListView::Extended);
   rip_track_list->setItemMargin(5);
   rip_track_list->setSorting(-1);
   connect(rip_track_list,SIGNAL(selectionChanged()),
 	  this,SLOT(trackSelectionChangedData()));
   rip_track_label=new QLabel(rip_track_list,tr("Tracks"),this);
-  rip_track_label->setFont(label_font);
+  rip_track_label->setFont(labelFont());
   rip_track_list->addColumn(tr("TRACK"));
   rip_track_list->setColumnAlignment(0,Qt::AlignHCenter);
   rip_track_list->addColumn(tr("LENGTH"));
@@ -216,7 +191,7 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   // Stop Button
   //
   rip_stop_button=new RDTransportButton(RDTransportButton::Stop,this);
-  rip_stop_button->setOnColor(red);
+  rip_stop_button->setOnColor(Qt::red);
   rip_stop_button->on();
   connect(rip_stop_button,SIGNAL(clicked()),this,SLOT(stopButtonData()));
   
@@ -224,7 +199,7 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   // Rip Track Button
   //
   rip_rip_button=new QPushButton(tr("&Rip\nTrack"),this);
-  rip_rip_button->setFont(button_font);
+  rip_rip_button->setFont(buttonFont());
   rip_rip_button->setDisabled(true);
   connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripTrackButtonData()));
 
@@ -234,8 +209,8 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_normalize_box=new QCheckBox(this);
   rip_normalize_box->setChecked(true);
   rip_normalize_box_label=new QLabel(rip_normalize_box,tr("Normalize"),this);
-  rip_normalize_box_label->setFont(label_font);
-  rip_normalize_box_label->setAlignment(AlignLeft|AlignVCenter);
+  rip_normalize_box_label->setFont(labelFont());
+  rip_normalize_box_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(rip_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
@@ -245,11 +220,11 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_normalize_spin=new QSpinBox(this);
   rip_normalize_spin->setRange(-30,0);
   rip_normalize_label=new QLabel(rip_normalize_spin,tr("Level:"),this);
-  rip_normalize_label->setFont(label_font);
-  rip_normalize_label->setAlignment(AlignRight|AlignVCenter);
+  rip_normalize_label->setFont(labelFont());
+  rip_normalize_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_normalize_unit=new QLabel(tr("dBFS"),this);
-  rip_normalize_unit->setFont(label_font);
-  rip_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
+  rip_normalize_unit->setFont(labelFont());
+  rip_normalize_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Autotrim Check Box
@@ -257,8 +232,8 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_autotrim_box=new QCheckBox(this);
   rip_autotrim_box->setChecked(true);
   rip_autotrim_box_label=new QLabel(rip_autotrim_box,tr("Autotrim"),this);
-  rip_autotrim_box_label->setFont(label_font);
-  rip_autotrim_box_label->setAlignment(AlignLeft|AlignVCenter);
+  rip_autotrim_box_label->setFont(labelFont());
+  rip_autotrim_box_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(rip_autotrim_box,SIGNAL(toggled(bool)),
 	  this,SLOT(autotrimCheckData(bool)));
 
@@ -268,25 +243,25 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
   rip_autotrim_spin=new QSpinBox(this);
   rip_autotrim_spin->setRange(-99,0);
   rip_autotrim_label=new QLabel(rip_autotrim_spin,tr("Level:"),this);
-  rip_autotrim_label->setFont(label_font);
-  rip_autotrim_label->setAlignment(AlignRight|AlignVCenter);
+  rip_autotrim_label->setFont(labelFont());
+  rip_autotrim_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_autotrim_unit=new QLabel(tr("dBFS"),this);
-  rip_autotrim_unit->setFont(label_font);
-  rip_autotrim_unit->setAlignment(AlignLeft|AlignVCenter);
+  rip_autotrim_unit->setFont(labelFont());
+  rip_autotrim_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Channels
   //
   rip_channels_box=new QComboBox(this);
   rip_channels_label=new QLabel(rip_channels_box,tr("Channels:"),this);
-  rip_channels_label->setFont(label_font);
-  rip_channels_label->setAlignment(AlignRight|AlignVCenter);
+  rip_channels_label->setFont(labelFont());
+  rip_channels_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Close Button
   //
   rip_close_button=new QPushButton("&Close",this);
-  rip_close_button->setFont(button_font);
+  rip_close_button->setFont(buttonFont());
   connect(rip_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   //
@@ -304,7 +279,7 @@ CdRipper::CdRipper(QString cutname,RDCddbRecord *rec,RDLibraryConf *conf,
 CdRipper::~CdRipper()
 {
   QStringList files=rip_cdda_dir.entryList();
-  for(unsigned i=0;i<files.size();i++) {
+  for(int i=0;i<files.size();i++) {
     if((files[i]!=".")&&(files[i]!="..")) {
       rip_cdda_dir.remove(files[i]);
     }
@@ -346,11 +321,15 @@ int CdRipper::exec(QString *title,QString *artist,QString *album)
 
 void CdRipper::trackSelectionChangedData()
 {
-  QListViewItem *item=rip_track_list->firstChild();
+  Q3ListViewItem *item=rip_track_list->firstChild();
   QStringList titles;
 
   while(item!=NULL) {
     if(item->isSelected()) {
+      if(item->text(4)==tr("Data Track")) {
+	rip_rip_button->setDisabled(true);
+	return;
+      }
       titles.push_back(item->text(2));
     }
     item=item->nextSibling();
@@ -367,7 +346,7 @@ void CdRipper::trackSelectionChangedData()
 
   default:
     rip_title_box->insertItem(titles.join(" / "));
-    for(unsigned i=0;i<titles.size();i++) {
+    for(int i=0;i<titles.size();i++) {
       rip_title_box->insertItem(titles[i]);
     }
     break;
@@ -411,7 +390,7 @@ void CdRipper::ripTrackButtonData()
 				tr("This will overwrite the existing recording.\nDo you want to proceed?"),
 				QMessageBox::Yes,QMessageBox::No)) {
     case QMessageBox::No:
-    case QMessageBox::NoButton:
+    case Qt::NoButton:
       return;
       
     default:
@@ -425,7 +404,7 @@ void CdRipper::ripTrackButtonData()
 				  QMessageBox::Yes,
 				  QMessageBox::No)) {
       case QMessageBox::No:
-      case QMessageBox::NoButton:
+      case Qt::NoButton:
 	return;
 
       default:
@@ -454,7 +433,7 @@ void CdRipper::ripTrackButtonData()
   // Read ISRCs
   //
   if(!rip_isrc_read) {
-    if(rdlibrary_conf->readIsrc()) {
+    if(rda->libraryConf()->readIsrc()) {
       rip_cddb_lookup->readIsrc(rip_cdda_dir.path(),rip_conf->ripperDevice());
     }
     rip_isrc_read=true;
@@ -476,8 +455,8 @@ void CdRipper::ripTrackButtonData()
   }
   disconnect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripTrackButtonData()));
   connect(rip_rip_button,SIGNAL(clicked()),ripper,SLOT(abort()));
-  rip_bar->setTotalSteps(ripper->totalSteps()+1);
-  connect(ripper,SIGNAL(progressChanged(int)),rip_bar,SLOT(setProgress(int)));
+  rip_bar->setMaximum(ripper->totalSteps()+1);
+  connect(ripper,SIGNAL(progressChanged(int)),rip_bar,SLOT(setValue(int)));
   RDAudioImport *conv=NULL;
   RDSettings *settings=NULL;
   ripper->setDevice(rip_conf->ripperDevice());
@@ -486,7 +465,7 @@ void CdRipper::ripTrackButtonData()
 
   rip_track[0]=-1;
   rip_track[1]=-1;
-  QListViewItem *item=rip_track_list->firstChild();
+  Q3ListViewItem *item=rip_track_list->firstChild();
   while(item!=NULL) {
     if(item->isSelected()) {
       if(rip_track[0]<0) {
@@ -498,21 +477,21 @@ void CdRipper::ripTrackButtonData()
   }
   switch((ripper_err=ripper->rip(rip_track[0],rip_track[1]))) {
   case RDCdRipper::ErrorOk:
-    conv=new RDAudioImport(rdstation_conf,lib_config,this);
+    conv=new RDAudioImport(this);
     conv->setSourceFile(tmpfile);
     conv->setCartNumber(rip_cut->cartNumber());
     conv->setCutNumber(rip_cut->cutNumber());
     conv->setUseMetadata(false);
     settings=new RDSettings();
-    if(rdlibrary_conf->defaultFormat()==1) {
+    if(rda->libraryConf()->defaultFormat()==1) {
       settings->setFormat(RDSettings::MpegL2Wav);
     }
     else {
       settings->setFormat(RDSettings::Pcm16);
     }
     settings->setChannels(rip_channels_box->currentText().toInt());
-    settings->setSampleRate(lib_system->sampleRate());
-    settings->setBitRate(rdlibrary_conf->defaultBitrate());
+    settings->setSampleRate(rda->system()->sampleRate());
+    settings->setBitRate(rda->libraryConf()->defaultBitrate());
     if(rip_normalize_box->isChecked()) {
       settings->setNormalizationLevel(rip_normalize_spin->value());
     }
@@ -521,7 +500,7 @@ void CdRipper::ripTrackButtonData()
     }
     conv->setDestinationSettings(settings);
     switch((conv_err=conv->
-	  runImport(lib_user->name(),lib_user->password(),&audio_conv_err))) {
+	  runImport(rda->user()->name(),rda->user()->password(),&audio_conv_err))) {
     case RDAudioImport::ErrorOk:
       QMessageBox::information(this,tr("Rip Complete"),tr("Rip complete!"));
       break;
@@ -548,18 +527,16 @@ void CdRipper::ripTrackButtonData()
   delete ripper;
   unlink(tmpfile);
   rmdir(tmpdir);
-  rip_bar->setPercentageVisible(false);
   rip_bar->reset();
   rip_eject_button->setEnabled(true);
   rip_play_button->setEnabled(true);
   rip_stop_button->setEnabled(true);
-  rip_rip_button->setText(tr("Rip Track"));
+  rip_rip_button->setText(tr("Rip\nTrack"));
   connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripTrackButtonData()));
   rip_close_button->setEnabled(true);
   rip_cdrom->unlock();
   rip_done=true;
-  rip_bar->setProgress(0);
-  rip_bar->setPercentageVisible(true);
+  rip_bar->setValue(0);
 }
 
 
@@ -577,14 +554,14 @@ void CdRipper::ejectedData()
 
 void CdRipper::mediaChangedData()
 {
-  QListViewItem *l;
+  Q3ListViewItem *l;
 
   rip_isrc_read=false;
   rip_track_list->clear();
   rip_track[0]=-1;
   rip_track[1]=-1;
   for(int i=rip_cdrom->tracks();i>0;i--) {
-    l=new QListViewItem(rip_track_list);
+    l=new Q3ListViewItem(rip_track_list);
     l->setText(0,QString().sprintf("%d",i));
     if(rip_cdrom->isAudio(i)) {
       l->setText(4,tr("Audio Track"));
