@@ -1,8 +1,8 @@
 // disk_ripper.cpp
 //
-// CD Ripper Dialog for Rivendell.
+// CD Disk Ripper Dialog for Rivendell.
 //
-//   (C) Copyright 2002-2003,2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,39 +18,23 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <signal.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <math.h>
-#include <linux/cdrom.h>
-#include <qpushbutton.h>
-#include <qfiledialog.h>
+#include <qapplication.h>
 #include <qmessagebox.h>
-#include <qcheckbox.h>
 
-#include <rddb.h>
-#include <rd.h>
-#include <rdconf.h>
-#include <rdwavefile.h>
-#include <rdcart.h>
-#include <rdcut.h>
-#include <rdcut_dialog.h>
-#include <rdlist_groups.h>
-#include <rdgroup.h>
 #include <rdaudioimport.h>
 #include <rdcdripper.h>
-#include <rdescape_string.h>
-
-#include <disk_ripper.h>
-#include <globals.h>
+#include <rdconf.h>
+#include <rdcut_dialog.h>
+#include <rdgroup.h>
+#include <rdlist_groups.h>
+#include <rdtempdirectory.h>
 
+#include "disk_ripper.h"
+#include "globals.h"
 
 DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
 		       bool profile_rip,QWidget *parent) 
-  : QDialog(parent)
+  : RDDialog(parent)
 {
   rip_isrc_read=false;
   rip_filter_text=filter;
@@ -59,21 +43,12 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_profile_rip=profile_rip;
   rip_aborting=false;
 
+  setWindowTitle("RDLibrary - "+tr("Rip Disk"));
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-
-  setCaption(tr("Rip Disk"));
+  setMinimumSize(sizeHint());
 
   //
   // Create Dialogs
@@ -84,7 +59,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Create Temporary Directory
   //
   char path[PATH_MAX];
-  strncpy(path,RDTempDir(),PATH_MAX);
+  strncpy(path,RDTempDirectory::basePath(),PATH_MAX);
   strcat(path,"/XXXXXX");
   if(mkdtemp(path)==NULL) {
     QMessageBox::warning(this,"RDLibrary - "+tr("Ripper Error"),
@@ -107,19 +82,19 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   connect(rip_cdrom,SIGNAL(mediaChanged()),this,SLOT(mediaChangedData()));
   connect(rip_cdrom,SIGNAL(played(int)),this,SLOT(playedData(int)));
   connect(rip_cdrom,SIGNAL(stopped()),this,SLOT(stoppedData()));
-  rip_cdrom->setDevice(rdlibrary_conf->ripperDevice());
+  rip_cdrom->setDevice(rda->libraryConf()->ripperDevice());
   rip_cdrom->open();
 
   //
   // CDDB Stuff
   //
   if(rip_profile_rip) {
-    rip_cddb_lookup=new RDCddbLookup(stdout,this);
+    rip_cddb_lookup=new RDCddbLookup("RDLibrary",stdout,this);
   }
   else {
-    rip_cddb_lookup=new RDCddbLookup(NULL,this);
+    rip_cddb_lookup=new RDCddbLookup("RDLibrary",NULL,this);
   }
-  connect(rip_cddb_lookup,SIGNAL(done(RDCddbLookup::Result)),
+  connect(rip_cddb_lookup,SIGNAL(lookupDone(RDCddbLookup::Result)),
 	  this,SLOT(cddbDoneData(RDCddbLookup::Result)));
 
   //
@@ -127,8 +102,8 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   //
   QLabel *label=new QLabel(tr("Artist:"),this);
   label->setGeometry(10,10,50,18);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_artist_edit=new QLineEdit(this);
 
   //
@@ -136,8 +111,8 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   //
   label=new QLabel(tr("Album:"),this);
   label->setGeometry(10,32,50,18);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_album_edit=new QLineEdit(this);
 
   //
@@ -145,8 +120,8 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   //
   label=new QLabel(tr("Other:"),this);
   label->setGeometry(10,54,50,16);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight);
   rip_other_edit=new QTextEdit(this);
   rip_other_edit->setReadOnly(true);
 
@@ -158,27 +133,27 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_apply_box->setDisabled(true);
   rip_apply_label=
     new QLabel(rip_apply_box,tr("Apply FreeDB Values to Carts"),this);
-  rip_apply_label->setFont(label_font);
-  rip_apply_label->setAlignment(AlignLeft);
+  rip_apply_label->setFont(labelFont());
+  rip_apply_label->setAlignment(Qt::AlignLeft);
   rip_apply_box->setChecked(false);
   rip_apply_label->setDisabled(true);
 
   //
   // Track List
   //
-  rip_track_list=new QListView(this);
+  rip_track_list=new Q3ListView(this);
   rip_track_list->setAllColumnsShowFocus(true);
   rip_track_list->setItemMargin(5);
   rip_track_list->setSorting(-1);
-  rip_track_list->setSelectionMode(QListView::Extended);
+  rip_track_list->setSelectionMode(Q3ListView::Extended);
   connect(rip_track_list,SIGNAL(selectionChanged()),
 	  this,SLOT(selectionChangedData()));
   connect(rip_track_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
   rip_track_label=new QLabel(rip_track_list,tr("Tracks"),this);
-  rip_track_label->setFont(label_font);
+  rip_track_label->setFont(sectionLabelFont());
   rip_track_list->addColumn(tr("TRACK"));
   rip_track_list->setColumnAlignment(0,Qt::AlignHCenter);
   rip_track_list->addColumn(tr("LENGTH"));
@@ -197,13 +172,13 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   //
   rip_disk_bar=new QProgressBar(this);
   rip_diskbar_label=new QLabel(tr("Disk Progress"),this);
-  rip_diskbar_label->setFont(label_font);
-  rip_diskbar_label->setAlignment(AlignLeft|AlignVCenter);
+  rip_diskbar_label->setFont(labelFont());
+  rip_diskbar_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   rip_diskbar_label->setDisabled(true);
   rip_track_bar=new QProgressBar(this);
   rip_trackbar_label=new QLabel(tr("Track Progress"),this);
-  rip_trackbar_label->setFont(label_font);
-  rip_trackbar_label->setAlignment(AlignLeft|AlignVCenter);
+  rip_trackbar_label->setFont(labelFont());
+  rip_trackbar_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   rip_trackbar_label->setDisabled(true);
 
   //
@@ -222,7 +197,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Stop Button
   //
   rip_stop_button=new RDTransportButton(RDTransportButton::Stop,this);
-  rip_stop_button->setOnColor(red);
+  rip_stop_button->setOnColor(Qt::red);
   rip_stop_button->on();
   connect(rip_stop_button,SIGNAL(clicked()),this,SLOT(stopButtonData()));
   
@@ -230,7 +205,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Set Cut Button
   //
   rip_setcut_button=new QPushButton(tr("Set\n&Cart/Cut"),this);
-  rip_setcut_button->setFont(button_font);
+  rip_setcut_button->setFont(buttonFont());
   rip_setcut_button->setDisabled(true);
   connect(rip_setcut_button,SIGNAL(clicked()),this,SLOT(setCutButtonData()));
 
@@ -238,7 +213,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Set Multi Tracks Button
   //
   rip_setall_button=new QPushButton(tr("Add Cart\nPer Track"),this);
-  rip_setall_button->setFont(button_font);
+  rip_setall_button->setFont(buttonFont());
   rip_setall_button->setDisabled(true);
   connect(rip_setall_button,SIGNAL(clicked()),this,SLOT(setMultiButtonData()));
 
@@ -246,7 +221,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Set Single Button
   //
   rip_setsingle_button=new QPushButton(tr("Add Single\nCart"),this);
-  rip_setsingle_button->setFont(button_font);
+  rip_setsingle_button->setFont(buttonFont());
   rip_setsingle_button->setDisabled(true);
   connect(rip_setsingle_button,SIGNAL(clicked()),
 	  this,SLOT(setSingleButtonData()));
@@ -255,7 +230,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Set Cart Label Button
   //
   rip_cartlabel_button=new QPushButton(tr("Modify\nCart Label"),this);
-  rip_cartlabel_button->setFont(button_font);
+  rip_cartlabel_button->setFont(buttonFont());
   rip_cartlabel_button->setDisabled(true);
   connect(rip_cartlabel_button,SIGNAL(clicked()),
 	  this,SLOT(modifyCartLabelData()));
@@ -264,7 +239,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Clear Selection Button
   //
   rip_clear_button=new QPushButton(tr("Clear\nSelection"),this);
-  rip_clear_button->setFont(button_font);
+  rip_clear_button->setFont(buttonFont());
   rip_clear_button->setDisabled(true);
   connect(rip_clear_button,SIGNAL(clicked()),this,SLOT(clearSelectionData()));
 
@@ -274,8 +249,8 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_normalize_box=new QCheckBox(this);
   rip_normalize_box->setChecked(true);
   rip_normalizebox_label=new QLabel(rip_normalize_box,tr("Normalize"),this);
-  rip_normalizebox_label->setFont(label_font);
-  rip_normalizebox_label->setAlignment(AlignLeft|AlignVCenter);
+  rip_normalizebox_label->setFont(labelFont());
+  rip_normalizebox_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(rip_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
@@ -285,11 +260,11 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_normalize_spin=new QSpinBox(this);
   rip_normalize_spin->setRange(-30,0);
   rip_normalize_label=new QLabel(rip_normalize_spin,tr("Level:"),this);
-  rip_normalize_label->setFont(label_font);
-  rip_normalize_label->setAlignment(AlignRight|AlignVCenter);
+  rip_normalize_label->setFont(labelFont());
+  rip_normalize_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_normalize_unit=new QLabel(tr("dBFS"),this);
-  rip_normalize_unit->setFont(label_font);
-  rip_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
+  rip_normalize_unit->setFont(labelFont());
+  rip_normalize_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Autotrim Check Box
@@ -297,8 +272,8 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_autotrim_box=new QCheckBox(this);
   rip_autotrim_box->setChecked(true);
   rip_autotrimbox_label=new QLabel(rip_autotrim_box,tr("Autotrim"),this);
-  rip_autotrimbox_label->setFont(label_font);
-  rip_autotrimbox_label->setAlignment(AlignLeft|AlignVCenter);
+  rip_autotrimbox_label->setFont(labelFont());
+  rip_autotrimbox_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   connect(rip_autotrim_box,SIGNAL(toggled(bool)),
 	  this,SLOT(autotrimCheckData(bool)));
 
@@ -308,25 +283,25 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   rip_autotrim_spin=new QSpinBox(this);
   rip_autotrim_spin->setRange(-99,0);
   rip_autotrim_label=new QLabel(rip_autotrim_spin,tr("Level:"),this);
-  rip_autotrim_label->setFont(label_font);
-  rip_autotrim_label->setAlignment(AlignRight|AlignVCenter);
+  rip_autotrim_label->setFont(labelFont());
+  rip_autotrim_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   rip_autotrim_unit=new QLabel(tr("dBFS"),this);
-  rip_autotrim_unit->setFont(label_font);
-  rip_autotrim_unit->setAlignment(AlignLeft|AlignVCenter);
+  rip_autotrim_unit->setFont(labelFont());
+  rip_autotrim_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Channels
   //
   rip_channels_box=new QComboBox(this);
   rip_channels_label=new QLabel(rip_channels_box,tr("Channels:"),this);
-  rip_channels_label->setFont(label_font);
-  rip_channels_label->setAlignment(AlignRight|AlignVCenter);
+  rip_channels_label->setFont(labelFont());
+  rip_channels_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Rip Disc Button
   //
   rip_rip_button=new QPushButton(tr("&Rip\nDisc"),this);
-  rip_rip_button->setFont(button_font);
+  rip_rip_button->setFont(buttonFont());
   connect(rip_rip_button,SIGNAL(clicked()),this,SLOT(ripDiskButtonData()));
   rip_rip_button->setDisabled(true);
 
@@ -334,17 +309,17 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
   // Close Button
   //
   rip_close_button=new QPushButton(tr("&Close"),this);
-  rip_close_button->setFont(button_font);
+  rip_close_button->setFont(buttonFont());
   connect(rip_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   //
   // Populate Data
   //
-  rip_normalize_spin->setValue(rdlibrary_conf->ripperLevel()/100);
-  rip_autotrim_spin->setValue(rdlibrary_conf->trimThreshold()/100);
+  rip_normalize_spin->setValue(rda->libraryConf()->ripperLevel()/100);
+  rip_autotrim_spin->setValue(rda->libraryConf()->trimThreshold()/100);
   rip_channels_box->insertItem("1");
   rip_channels_box->insertItem("2");
-  rip_channels_box->setCurrentItem(rdlibrary_conf->defaultChannels()-1);
+  rip_channels_box->setCurrentItem(rda->libraryConf()->defaultChannels()-1);
   rip_done=false;
 }
 
@@ -352,7 +327,7 @@ DiskRipper::DiskRipper(QString *filter,QString *group,QString *schedcode,
 DiskRipper::~DiskRipper()
 {
   QStringList files=rip_cdda_dir.entryList();
-  for(unsigned i=0;i<files.size();i++) {
+  for(int i=0;i<files.size();i++) {
     if((files[i]!=".")&&(files[i]!="..")) {
       rip_cdda_dir.remove(files[i]);
     }
@@ -425,19 +400,24 @@ void DiskRipper::ripDiskButtonData()
       tracks++;
     }
   }
-  rip_disk_bar->setTotalSteps(tracks);
+  rip_disk_bar->setMaximum(tracks);
 
   //
   // Read ISRCs
   //
   if(!rip_isrc_read) {
-    if(rdlibrary_conf->readIsrc()) {
+    if(rda->libraryConf()->readIsrc()) {
       rip_cddb_lookup->
-	readIsrc(rip_cdda_dir.path(),rdlibrary_conf->ripperDevice());
+	readIsrc(rip_cdda_dir.path(),rda->libraryConf()->ripperDevice());
     }
     rip_isrc_read=true;
   }
 
+  //
+  // Set Artist and Album
+  //
+  SetArtistAlbum();
+
   //
   // Rip
   //
@@ -461,8 +441,7 @@ void DiskRipper::ripDiskButtonData()
       rip_channels_box->setDisabled(true);
       rip_autotrim_box->setDisabled(true);
       rip_autotrim_spin->setDisabled(true);
-      rip_disk_bar->setProgress(tracks++);
-      rip_disk_bar->setPercentageVisible(true);
+      rip_disk_bar->setValue(tracks++);
       int start_track=item->text(0).toInt();
       int end_track=rip_end_track[item->text(0).toInt()-1];
       RipTrack(start_track,end_track,rip_cutnames[item->text(0).toInt()-1],
@@ -487,7 +466,6 @@ void DiskRipper::ripDiskButtonData()
   rip_channels_box->setEnabled(true);
   rip_autotrim_box->setEnabled(true);
   rip_autotrim_spin->setEnabled(true);
-  rip_disk_bar->setPercentageVisible(false);
   rip_disk_bar->reset();
   rip_diskbar_label->setDisabled(true);
   rip_trackbar_label->setDisabled(true);
@@ -498,7 +476,9 @@ void DiskRipper::ripDiskButtonData()
     item->setText(5,"");
     item=(RDListViewItem *)item->nextSibling();
   }
-  rip_cdrom->eject();
+
+//  rip_cdrom->eject();
+
   if(rip_aborting) {
     QMessageBox::information(this,tr("Rip Complete"),tr("Rip aborted!"));
   }
@@ -534,10 +514,9 @@ void DiskRipper::setCutButtonData()
     return;
   }
   QString cutname=rip_cutnames[item->text(0).toUInt()-1];
-  RDCutDialog *dialog=new RDCutDialog(&cutname,rdstation_conf,lib_system,
-				      rip_filter_text,
-				      rip_group_text,rip_schedcode_text,
-				      lib_user->name(),true,true,true,this);
+  RDCutDialog *dialog=
+    new RDCutDialog(&cutname,"RDLibrary",rip_filter_text,rip_group_text,
+		    rip_schedcode_text,true,true,true,this);
   if(dialog->exec()==0) {
     if(cutname.isEmpty()) {
       rip_cutnames[item->text(0).toUInt()-1]="";
@@ -616,7 +595,7 @@ void DiskRipper::setMultiButtonData()
   //
   // Get Destination Group
   //
-  RDListGroups *list_groups=new RDListGroups(rip_group_text,lib_user->name(),
+  RDListGroups *list_groups=new RDListGroups(rip_group_text,rda->user()->name(),
 					     this);
   if(list_groups->exec()<0) {
     delete list_groups;
@@ -637,7 +616,7 @@ void DiskRipper::setMultiButtonData()
     }
     item=(RDListViewItem *)item->nextSibling();
   }
-  if(!group->reserveCarts(&cart_nums,rdstation_conf->name(),RDCart::Audio,
+  if(!group->reserveCarts(&cart_nums,rda->station()->name(),RDCart::Audio,
 			  count)) {
     QMessageBox::warning(this,"RDLibrary - "+tr("Error"),
 			 tr("Unable to allocate carts in group")+" \""+
@@ -676,7 +655,7 @@ void DiskRipper::setSingleButtonData()
   //
   // Get Destination Group
   //
-  RDListGroups *list_groups=new RDListGroups(rip_group_text,lib_user->name(),
+  RDListGroups *list_groups=new RDListGroups(rip_group_text,rda->user()->name(),
 					     this);
   if(list_groups->exec()<0) {
     delete list_groups;
@@ -691,7 +670,7 @@ void DiskRipper::setSingleButtonData()
   //
   // Reserve Cart
   //
-  if(!group->reserveCarts(&cart_nums,rdstation_conf->name(),RDCart::Audio,1)) {
+  if(!group->reserveCarts(&cart_nums,rda->station()->name(),RDCart::Audio,1)) {
     QMessageBox::warning(this,"RDLibrary - "+tr("Error"),
 			 tr("Unable to allocate cart in group")+" \""+
 			 group->name()+"\".");
@@ -733,7 +712,10 @@ void DiskRipper::setSingleButtonData()
 
 void DiskRipper::modifyCartLabelData()
 {
+  SetArtistAlbum();
+
   RDListViewItem *item=(RDListViewItem *)rip_track_list->firstChild();
+
   while(item!=NULL) {
     if(item->isSelected()) {
       int track=item->text(0).toInt()-1;
@@ -773,6 +755,8 @@ void DiskRipper::mediaChangedData()
 {
   RDListViewItem *l;
 
+  QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
   rip_isrc_read=false;
   rip_cutnames.clear();
   rip_end_track.clear();
@@ -806,9 +790,11 @@ void DiskRipper::mediaChangedData()
   rip_cdrom->setCddbRecord(&rip_cddb_record);
   rip_cddb_lookup->setCddbRecord(&rip_cddb_record);
   rip_cddb_lookup->
-    lookupRecord(rip_cdda_dir.path(),rdlibrary_conf->ripperDevice(),
-		 rdlibrary_conf->cddbServer(),8880,
+    lookupRecord(rip_cdda_dir.path(),rda->libraryConf()->ripperDevice(),
+		 rda->libraryConf()->cddbServer(),8880,
 		 RIPPER_CDDB_USER,PACKAGE_NAME,VERSION);
+
+  QApplication::restoreOverrideCursor();
 }
 
 
@@ -886,6 +872,14 @@ void DiskRipper::selectionChangedData()
   while(item!=NULL) {
     int track=item->text(0).toInt();
     if(item->isSelected()) {
+      if(item->text(4)==tr("Data Track")) {
+	rip_setcut_button->setEnabled(false);
+	rip_setall_button->setEnabled(false);
+	rip_setsingle_button->setEnabled(false);
+	rip_cartlabel_button->setEnabled(false);
+	rip_clear_button->setEnabled(true);
+	return;
+      }
       if(item->id()>0) {
 	FocusSelection(item->id());
 	rip_setcut_button->setEnabled(false);
@@ -911,7 +905,7 @@ void DiskRipper::selectionChangedData()
 }
 
 
-void DiskRipper::doubleClickedData(QListViewItem *item,const QPoint &pt,
+void DiskRipper::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
   setCutButtonData();
@@ -920,7 +914,7 @@ void DiskRipper::doubleClickedData(QListViewItem *item,const QPoint &pt,
 
 void DiskRipper::closeData()
 {
-  RDCart::removePending(rdstation_conf,lib_user,lib_config);
+  RDCart::removePending(rda->station(),rda->user(),rda->config());
   if(rip_done&&rip_apply_box->isChecked()) {
     done(0);
   }
@@ -991,19 +985,12 @@ void DiskRipper::RipTrack(int track,int end_track,QString cutname,QString title)
   RDCdRipper *ripper=NULL;
   RDCut *cut=new RDCut(cutname);
   RDCart *cart=new RDCart(cut->cartNumber());
-  QString sql;
-  RDSqlQuery *q;
 
   //
   // Create Cut
   //
-  sql=QString("insert into CUTS set ")+
-    "CUT_NAME=\""+RDEscapeString(cutname)+"\","+
-    QString().sprintf("CART_NUMBER=%u,",cut->cartNumber())+
-    "DESCRIPTION=\""+tr("Cut")+" 001\"";
-  q=new RDSqlQuery(sql);
-  delete q;
-  
+  RDCut::create(cutname);
+
   rip_done=false;
   rip_rip_aborted=false;
   rip_track_number=track;
@@ -1025,7 +1012,7 @@ void DiskRipper::RipTrack(int track,int end_track,QString cutname,QString title)
   RDAudioImport::ErrorCode conv_err;
   RDAudioConvert::ErrorCode audio_conv_err;
   RDCdRipper::ErrorCode ripper_err;
-  QString tmpdir=RDTempDir();
+  QString tmpdir=RDTempDirectory::basePath();
   QString tmpfile=tmpdir+"/"+RIPPER_TEMP_WAV;
   if(rip_profile_rip) {
     ripper=new RDCdRipper(stdout,this);
@@ -1033,31 +1020,31 @@ void DiskRipper::RipTrack(int track,int end_track,QString cutname,QString title)
   else {
     ripper=new RDCdRipper(NULL,this);
   }
-  rip_track_bar->setTotalSteps(ripper->totalSteps()+1);
+  rip_track_bar->setMaximum(ripper->totalSteps()+1);
   connect(ripper,SIGNAL(progressChanged(int)),
-	  rip_track_bar,SLOT(setProgress(int)));
+	  rip_track_bar,SLOT(setValue(int)));
   connect(rip_rip_button,SIGNAL(clicked()),ripper,SLOT(abort()));
   RDAudioImport *conv=NULL;
   RDSettings *settings=NULL;
-  ripper->setDevice(rdlibrary_conf->ripperDevice());
+  ripper->setDevice(rda->libraryConf()->ripperDevice());
   ripper->setDestinationFile(tmpfile);
   switch((ripper_err=ripper->rip(rip_track_number-1,end_track-1))) {
   case RDCdRipper::ErrorOk:
-    conv=new RDAudioImport(rdstation_conf,lib_config,this);
+    conv=new RDAudioImport(this);
     conv->setSourceFile(tmpfile);
     conv->setCartNumber(cut->cartNumber());
     conv->setCutNumber(cut->cutNumber());
     conv->setUseMetadata(false);
     settings=new RDSettings();
-    if(rdlibrary_conf->defaultFormat()==1) {
+    if(rda->libraryConf()->defaultFormat()==1) {
       settings->setFormat(RDSettings::MpegL2Wav);
     }
     else {
       settings->setFormat(RDSettings::Pcm16);
     }
     settings->setChannels(rip_channels_box->currentText().toInt());
-    settings->setSampleRate(lib_system->sampleRate());
-    settings->setBitRate(rdlibrary_conf->defaultBitrate());
+    settings->setSampleRate(rda->system()->sampleRate());
+    settings->setBitRate(rda->libraryConf()->defaultBitrate());
     if(rip_normalize_box->isChecked()) {
       settings->setNormalizationLevel(rip_normalize_spin->value());
     }
@@ -1066,17 +1053,18 @@ void DiskRipper::RipTrack(int track,int end_track,QString cutname,QString title)
     }
     conv->setDestinationSettings(settings);
     switch((conv_err=conv->
-	    runImport(lib_user->name(),lib_user->password(),
+	    runImport(rda->user()->name(),rda->user()->password(),
 		      &audio_conv_err))) {
     case RDAudioImport::ErrorOk:
       cart->setMetadata(rip_wave_datas[track-1]);
       cut->setDescription(rip_wave_datas[track-1]->title());
       cut->setIsrc(rip_cddb_record.isrc(rip_track_number-1));
       cart->clearPending();
+      SendNotification(RDNotification::AddAction,cart->number());
       break;
 
     default:
-      cart->remove(rdstation_conf,lib_user,lib_config);
+      cart->remove(rda->station(),rda->user(),rda->config());
       QMessageBox::warning(this,tr("RDLibrary - Importer Error"),
 			   RDAudioImport::errorText(conv_err,audio_conv_err));
       break;
@@ -1090,21 +1078,20 @@ void DiskRipper::RipTrack(int track,int end_track,QString cutname,QString title)
   case RDCdRipper::ErrorInternal:
   case RDCdRipper::ErrorNoDisc:
   case RDCdRipper::ErrorNoTrack:
-    cart->remove(rdstation_conf,lib_user,lib_config);
+    cart->remove(rda->station(),rda->user(),rda->config());
     QMessageBox::warning(this,tr("RDLibrary - Ripper Error"),
 			 RDCdRipper::errorText(ripper_err));
     break;
 
   case RDCdRipper::ErrorAborted:
     rip_aborting=true;
-    cart->remove(rdstation_conf,lib_user,lib_config);
+    cart->remove(rda->station(),rda->user(),rda->config());
     break;
   }
   delete ripper;
   unlink(tmpfile);
   rmdir(tmpdir);
-  rip_track_bar->setProgress(0);
-  rip_track_bar->setPercentageVisible(true);
+  rip_track_bar->setValue(0);
 
   delete cart;
   delete cut;
@@ -1149,3 +1136,31 @@ QString DiskRipper::BuildTrackName(int start_track,int end_track) const
   }
   return ret;
 }
+
+
+void DiskRipper::SetArtistAlbum()
+{
+  RDListViewItem *item=(RDListViewItem *)rip_track_list->firstChild();
+
+  while(item!=NULL) {
+    int track=item->text(0).toInt()-1;
+    if(rip_wave_datas[track]->artist().isEmpty()) {
+      rip_wave_datas[track]->setArtist(rip_artist_edit->text());
+    }
+    if(rip_wave_datas[track]->album().isEmpty()) {
+      rip_wave_datas[track]->setAlbum(rip_album_edit->text());
+    }
+    item=(RDListViewItem *)item->nextSibling();
+  }
+}
+
+
+void DiskRipper::SendNotification(RDNotification::Action action,
+				  unsigned cartnum)
+{
+  RDNotification *notify=
+    new RDNotification(RDNotification::CartType,action,QVariant(cartnum));
+  rda->ripc()->sendNotification(*notify);
+  qApp->processEvents();
+  delete notify;
+}
