@@ -1,10 +1,8 @@
 // disk_ripper.h
 //
-// CD Ripper Dialog for Rivendell
+// CD Disk Ripper Dialog for Rivendell
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: disk_ripper.h,v 1.8.4.2.2.3 2014/06/02 17:17:00 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,39 +21,24 @@
 #ifndef DISK_RIPPER_H
 #define DISK_RIPPER_H
 
-#include <vector>
-#include <sys/types.h>
-#include <unistd.h>
-#include <qdialog.h>
-#include <qdir.h>
-#include <qlistview.h>
-#include <qlabel.h>
-#include <qlineedit.h>
 #include <qprogressbar.h>
-#include <qtimer.h>
-#include <qfile.h>
-#include <qspinbox.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
 #include <qtextedit.h>
 
-#include <rdlistviewitem.h>
-#include <rdtransportbutton.h>
-#include <rdcdplayer.h>
-#include <rdcddbrecord.h>
+#include <qcheckbox.h>
+#include <qdir.h>
+
 #include <rdcddblookup.h>
+#include <rdcdplayer.h>
+#include <rddialog.h>
+#include <rdtransportbutton.h>
 #include <rdwavedata_dialog.h>
 
-#include <rdlibrary_conf.h>
-#include <rd.h>
-
-
-class DiskRipper : public QDialog
+class DiskRipper : public RDDialog
 {
   Q_OBJECT
  public:
   DiskRipper(QString *filter,QString *group,QString *schedcode,
-	     bool profile_rip,QWidget *parent=0,const char *name=0);
+	     bool profile_rip,QWidget *parent=0);
   ~DiskRipper();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -78,7 +61,7 @@ class DiskRipper : public QDialog
   void normalizeCheckData(bool);
   void autotrimCheckData(bool);
   void selectionChangedData();
-  void doubleClickedData(QListViewItem *item,const QPoint &pt,int col);
+  void doubleClickedData(Q3ListViewItem *item,const QPoint &pt,int col);
   void closeData();
   
  protected:
@@ -90,11 +73,13 @@ class DiskRipper : public QDialog
   void RipTrack(int track,int end_track,QString cutname,QString title);
   void UpdateRipButton();
   QString BuildTrackName(int start_track,int end_track) const;
+  void SetArtistAlbum();
+  void SendNotification(RDNotification::Action action,unsigned cartnum);
   RDCdPlayer *rip_cdrom;
   RDCddbRecord rip_cddb_record;
   RDCddbLookup *rip_cddb_lookup;
   QLabel *rip_track_label;
-  QListView *rip_track_list;
+  Q3ListView *rip_track_list;
   QPushButton *rip_rip_button;
   bool rip_rip_aborted;
   QPushButton *rip_close_button;
@@ -146,5 +131,4 @@ class DiskRipper : public QDialog
 };
 
 
-#endif
-
+#endif  // DISK_RIPPER_H
