@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AudioCart</name>
     <message>
@@ -23,51 +25,51 @@
     </message>
     <message>
         <source>WT</source>
-        <translation>WT</translation>
+        <translation type="obsolete">WT</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>POPIS</translation>
+        <translation type="obsolete">POPIS</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>LAST PLAYED</source>
-        <translation>NAPOSLEDY HRÁNO</translation>
+        <translation type="obsolete">NAPOSLEDY HRÁNO</translation>
     </message>
     <message>
         <source># OF PLAYS</source>
-        <translation># PŘEHRÁNÍ</translation>
+        <translation type="obsolete"># PŘEHRÁNÍ</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>PŮVOD</translation>
+        <translation type="obsolete">PŮVOD</translation>
     </message>
     <message>
         <source>OUTCUE</source>
-        <translation>OUTCUE</translation>
+        <translation type="obsolete">OUTCUE</translation>
     </message>
     <message>
         <source>START DATE</source>
-        <translation>POČÁTEČNÍ DATUM</translation>
+        <translation type="obsolete">POČÁTEČNÍ DATUM</translation>
     </message>
     <message>
         <source>END DATE</source>
-        <translation>KONCOVÉ DATUM</translation>
+        <translation type="obsolete">KONCOVÉ DATUM</translation>
     </message>
     <message>
         <source>DAYPART START</source>
-        <translation>ZAČÁTEK ČÁSTI DNE</translation>
+        <translation type="obsolete">ZAČÁTEK ČÁSTI DNE</translation>
     </message>
     <message>
         <source>DAYPART END</source>
-        <translation>KONEC ČÁSTI DNE</translation>
+        <translation type="obsolete">KONEC ČÁSTI DNE</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -220,6 +222,74 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>SHA1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>not available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Played</source>
+        <translation type="unfinished">Naposledy přehráno</translation>
+    </message>
+    <message>
+        <source># of Plays</source>
+        <translation type="unfinished"># přehrání</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Outcue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ord</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -371,7 +441,7 @@ vytahování</translation>
     </message>
     <message>
         <source>Rip Track</source>
-        <translation>Vytáhnout stopu</translation>
+        <translation type="obsolete">Vytáhnout stopu</translation>
     </message>
     <message>
         <source>Title:</source>
@@ -389,6 +459,22 @@ vytahování</translation>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rip CD</source>
+        <translation type="unfinished">Vytáhnout z CD</translation>
+    </message>
+    <message>
+        <source>Rip
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DiskGauge</name>
+    <message>
+        <source>Free</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -609,10 +695,6 @@ zrušeno!</translation>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -863,7 +945,35 @@ poznámky</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
+        <source>By Specified Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>By Weight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Schedule Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following cut order values are assigned more than once</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate Cut Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Carts [multiple]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use RDLogManager Length for PAD Updates</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -871,7 +981,7 @@ poznámky</translation>
     <name>EditMacro</name>
     <message>
         <source>Edit Macro</source>
-        <translation>Upravit makro</translation>
+        <translation type="obsolete">Upravit makro</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -932,31 +1042,27 @@ poznámky</translation>
     <name>Filter</name>
     <message>
         <source>Library Filter</source>
-        <translation>Filtr knihovny</translation>
+        <translation type="obsolete">Filtr knihovny</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>C&amp;lear</source>
-        <translation>&amp;Vyprázdnit</translation>
+        <translation type="obsolete">&amp;Vyprázdnit</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
     <message>
         <source>&amp;Filter:</source>
-        <translation>&amp;Filtr:</translation>
+        <translation type="obsolete">&amp;Filtr:</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
-    <message>
-        <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Report</source>
         <translation type="unfinished"></translation>
@@ -981,10 +1087,6 @@ poznámky</translation>
         <source>ALL</source>
         <translation type="unfinished">VŠE</translation>
     </message>
-    <message>
-        <source>Cart Data Dump (fixed width)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Data Dump (CSV)</source>
         <translation type="unfinished"></translation>
@@ -993,6 +1095,10 @@ poznámky</translation>
         <source>Prepend Field Names</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -1014,11 +1120,11 @@ poznámky</translation>
     </message>
     <message>
         <source>LINE</source>
-        <translation>ŘÁDEK</translation>
+        <translation type="obsolete">ŘÁDEK</translation>
     </message>
     <message>
         <source>COMMAND</source>
-        <translation>PŘÍKAZ</translation>
+        <translation type="obsolete">PŘÍKAZ</translation>
     </message>
     <message>
         <source>Macros</source>
@@ -1042,7 +1148,19 @@ vozík</translation>
     </message>
     <message>
         <source>--- End of cart ---</source>
-        <translation>--- Konec vozíku ---</translation>
+        <translation type="obsolete">--- Konec vozíku ---</translation>
+    </message>
+    <message>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- End of Cart ---</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1053,11 +1171,11 @@ vozík</translation>
     </message>
     <message>
         <source>rdlibrary : </source>
-        <translation>rdlibrary: </translation>
+        <translation type="obsolete">rdlibrary: </translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Nelze spojit</translation>
+        <translation type="obsolete">Nelze spojit</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1089,51 +1207,51 @@ vozík</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>VOZÍK</translation>
+        <translation type="obsolete">VOZÍK</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>UMĚLEC</translation>
+        <translation type="obsolete">UMĚLEC</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>ZAČÁTEK</translation>
+        <translation type="obsolete">ZAČÁTEK</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>KONEC</translation>
+        <translation type="obsolete">KONEC</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>ZÁKAZNÍK</translation>
+        <translation type="obsolete">ZÁKAZNÍK</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTURA</translation>
+        <translation type="obsolete">AGENTURA</translation>
     </message>
     <message>
         <source>USER DEFINED</source>
-        <translation>STANOVENO UŽIVATELEM</translation>
+        <translation type="obsolete">STANOVENO UŽIVATELEM</translation>
     </message>
     <message>
         <source>CUTS</source>
-        <translation>ZÁBĚRY</translation>
+        <translation type="obsolete">ZÁBĚRY</translation>
     </message>
     <message>
         <source>LAST CUT PLAYED</source>
-        <translation>NAPOSLEDY HRANÝ ZÁBĚR</translation>
+        <translation type="obsolete">NAPOSLEDY HRANÝ ZÁBĚR</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
@@ -1141,19 +1259,19 @@ vozík</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
-        <translation>VYNUTIT DÉLKU</translation>
+        <translation type="obsolete">VYNUTIT DÉLKU</translation>
     </message>
     <message>
         <source>PRESERVE PITCH</source>
-        <translation>ZACHOVAT VÝŠKU TÓNU</translation>
+        <translation type="obsolete">ZACHOVAT VÝŠKU TÓNU</translation>
     </message>
     <message>
         <source>LENGTH DEVIATION</source>
-        <translation>ODCHYLKA DÉLKY</translation>
+        <translation type="obsolete">ODCHYLKA DÉLKY</translation>
     </message>
     <message>
         <source>OWNED BY</source>
-        <translation>PATŘÍ</translation>
+        <translation type="obsolete">PATŘÍ</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -1220,9 +1338,9 @@ Přesto smazat?</translation>
     </message>
     <message>
         <source>Deleting cart %06u will also empty the clipboard.
-      <byte value="x9"/>Do you still want to proceed?</source>
+      	Do you still want to proceed?</source>
         <translation>Smazání vozíku %06u vyprázdní také schránku
-      <byte value="x9"/>Přesto pokračovat?</translation>
+      	Přesto pokračovat?</translation>
     </message>
     <message>
         <source>Empty Clipboard</source>
@@ -1276,18 +1394,6 @@ Přesto smazat?</translation>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>COMPOSER</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CONDUCTOR</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PUBLISHER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
@@ -1297,15 +1403,112 @@ Přesto smazat?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unknown command-line option</source>
+        <source>Unknown command option</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Konec</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publisher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Defined</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cuts</source>
+        <translation type="unfinished">Záběry</translation>
+    </message>
+    <message>
+        <source>Last Cut Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enforce Length</source>
+        <translation type="unfinished">Vynutit délku</translation>
+    </message>
+    <message>
+        <source>Preserve Pitch</source>
+        <translation type="unfinished">Zachovat výšku tónu</translation>
+    </message>
+    <message>
+        <source>Length Deviation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Owned By</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run
+&amp;Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>And Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matching Carts:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1313,7 +1516,7 @@ Přesto smazat?</translation>
     <name>RecordCut</name>
     <message>
         <source>RDLibrary - Record</source>
-        <translation>RDLibrary - Nahrávání</translation>
+        <translation type="obsolete">RDLibrary - Nahrávání</translation>
     </message>
     <message>
         <source>&amp;Description</source>
@@ -1325,7 +1528,7 @@ Přesto smazat?</translation>
     </message>
     <message>
         <source>Origin</source>
-        <translation>Původ</translation>
+        <translation type="obsolete">Původ</translation>
     </message>
     <message>
         <source>ISRC</source>
@@ -1545,5 +1748,25 @@ Přesto uložit?</translation>
         <source>AES ALARM</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut Info / Record</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
