@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AudioCart</name>
     <message>
@@ -23,51 +25,51 @@
     </message>
     <message>
         <source>WT</source>
-        <translation>WT</translation>
+        <translation type="obsolete">WT</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>BESCHREIBUNG</translation>
+        <translation type="obsolete">BESCHREIBUNG</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>LAST PLAYED</source>
-        <translation>ZUL. GESPIELT</translation>
+        <translation type="obsolete">ZUL. GESPIELT</translation>
     </message>
     <message>
         <source># OF PLAYS</source>
-        <translation># GESPIELT</translation>
+        <translation type="obsolete"># GESPIELT</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>HERKUNFT</translation>
+        <translation type="obsolete">HERKUNFT</translation>
     </message>
     <message>
         <source>OUTCUE</source>
-        <translation>OUTCUE</translation>
+        <translation type="obsolete">OUTCUE</translation>
     </message>
     <message>
         <source>START DATE</source>
-        <translation>STARTDATUM</translation>
+        <translation type="obsolete">STARTDATUM</translation>
     </message>
     <message>
         <source>END DATE</source>
-        <translation>ENDDATUM</translation>
+        <translation type="obsolete">ENDDATUM</translation>
     </message>
     <message>
         <source>DAYPART START</source>
-        <translation>TAGESTEIL START</translation>
+        <translation type="obsolete">TAGESTEIL START</translation>
     </message>
     <message>
         <source>DAYPART END</source>
-        <translation>TAGESTEIL ENDE</translation>
+        <translation type="obsolete">TAGESTEIL ENDE</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAME</translation>
+        <translation type="obsolete">NAME</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -220,10 +222,6 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ORD</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>SHA1</source>
         <translation type="unfinished"></translation>
@@ -232,6 +230,66 @@ Do you still want to delete?</source>
         <source>not available</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Played</source>
+        <translation type="unfinished">ZUL. GESPIELT</translation>
+    </message>
+    <message>
+        <source># of Plays</source>
+        <translation type="unfinished"># GESPIELT</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Outcue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ord</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -383,7 +441,7 @@ abbrechen</translation>
     </message>
     <message>
         <source>Rip Track</source>
-        <translation>Titel rippen</translation>
+        <translation type="obsolete">Titel rippen</translation>
     </message>
     <message>
         <source>Title:</source>
@@ -401,6 +459,22 @@ abbrechen</translation>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rip CD</source>
+        <translation type="unfinished">CD rippen</translation>
+    </message>
+    <message>
+        <source>Rip
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DiskGauge</name>
+    <message>
+        <source>Free</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -620,10 +694,6 @@ Rippen</translation>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -862,10 +932,6 @@ Notes</source>
         <source>&amp;Beats per Minute:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>By Specified Order</source>
         <translation type="unfinished"></translation>
@@ -886,12 +952,24 @@ Notes</source>
         <source>Duplicate Cut Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Carts [multiple]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use RDLogManager Length for PAD Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
     <message>
         <source>Edit Macro</source>
-        <translation>Makro editieren</translation>
+        <translation type="obsolete">Makro editieren</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -952,31 +1030,27 @@ Notes</source>
     <name>Filter</name>
     <message>
         <source>Library Filter</source>
-        <translation>Bibliotheksfilter</translation>
+        <translation type="obsolete">Bibliotheksfilter</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>C&amp;lear</source>
-        <translation>&amp;Löschen</translation>
+        <translation type="obsolete">&amp;Löschen</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Abbrechen</translation>
+        <translation type="obsolete">&amp;Abbrechen</translation>
     </message>
     <message>
         <source>&amp;Filter:</source>
-        <translation>&amp;Filter:</translation>
+        <translation type="obsolete">&amp;Filter:</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
-    <message>
-        <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Report</source>
         <translation type="unfinished"></translation>
@@ -1001,10 +1075,6 @@ Notes</source>
         <source>ALL</source>
         <translation type="unfinished">ALLE</translation>
     </message>
-    <message>
-        <source>Cart Data Dump (fixed width)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Data Dump (CSV)</source>
         <translation type="unfinished"></translation>
@@ -1013,6 +1083,10 @@ Notes</source>
         <source>Prepend Field Names</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -1034,11 +1108,11 @@ Notes</source>
     </message>
     <message>
         <source>LINE</source>
-        <translation>ZEILE</translation>
+        <translation type="obsolete">ZEILE</translation>
     </message>
     <message>
         <source>COMMAND</source>
-        <translation>KOMMANDO</translation>
+        <translation type="obsolete">KOMMANDO</translation>
     </message>
     <message>
         <source>Macros</source>
@@ -1062,7 +1136,19 @@ starten</translation>
     </message>
     <message>
         <source>--- End of cart ---</source>
-        <translation>--- Ende des Carts ---</translation>
+        <translation type="obsolete">--- Ende des Carts ---</translation>
+    </message>
+    <message>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- End of Cart ---</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1073,11 +1159,11 @@ starten</translation>
     </message>
     <message>
         <source>rdlibrary : </source>
-        <translation>rdlibrary : </translation>
+        <translation type="obsolete">rdlibrary : </translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Kann nicht verbinden</translation>
+        <translation type="obsolete">Kann nicht verbinden</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1109,51 +1195,51 @@ starten</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CART</translation>
+        <translation type="obsolete">CART</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>KÜNSTLER</translation>
+        <translation type="obsolete">KÜNSTLER</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>ENDE</translation>
+        <translation type="obsolete">ENDE</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KUNDE</translation>
+        <translation type="obsolete">KUNDE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENTUR</translation>
+        <translation type="obsolete">AGENTUR</translation>
     </message>
     <message>
         <source>USER DEFINED</source>
-        <translation>BENUTZERDEFINIERT</translation>
+        <translation type="obsolete">BENUTZERDEFINIERT</translation>
     </message>
     <message>
         <source>CUTS</source>
-        <translation>CUTS</translation>
+        <translation type="obsolete">CUTS</translation>
     </message>
     <message>
         <source>LAST CUT PLAYED</source>
-        <translation>LETZTER GESPIELTER CUT</translation>
+        <translation type="obsolete">LETZTER GESPIELTER CUT</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
@@ -1161,19 +1247,19 @@ starten</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
-        <translation>LÄNGE ERZWINGEN</translation>
+        <translation type="obsolete">LÄNGE ERZWINGEN</translation>
     </message>
     <message>
         <source>PRESERVE PITCH</source>
-        <translation>PITCH SCHÜTZEN</translation>
+        <translation type="obsolete">PITCH SCHÜTZEN</translation>
     </message>
     <message>
         <source>LENGTH DEVIATION</source>
-        <translation>LÄNGENABWEICHUNG</translation>
+        <translation type="obsolete">LÄNGENABWEICHUNG</translation>
     </message>
     <message>
         <source>OWNED BY</source>
-        <translation>GEHÖRT</translation>
+        <translation type="obsolete">GEHÖRT</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -1229,9 +1315,9 @@ verwendet. Trotzdem löschen?</translation>
     </message>
     <message>
         <source>Deleting cart %06u will also empty the clipboard.
-      <byte value="x9"/>Do you still want to proceed?</source>
+      	Do you still want to proceed?</source>
         <translation>Den Cart %06u zu löschen wird auch die Zwischenablage leeren
-      <byte value="x9"/>Trotzdem fortfahren?</translation>
+      	Trotzdem fortfahren?</translation>
     </message>
     <message>
         <source>Empty Clipboard</source>
@@ -1285,18 +1371,6 @@ verwendet. Trotzdem löschen?</translation>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>COMPOSER</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CONDUCTOR</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PUBLISHER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
@@ -1306,15 +1380,112 @@ verwendet. Trotzdem löschen?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unknown command-line option</source>
+        <source>Unknown command option</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Ende</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publisher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Defined</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cuts</source>
+        <translation type="unfinished">Cuts</translation>
+    </message>
+    <message>
+        <source>Last Cut Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enforce Length</source>
+        <translation type="unfinished">Länge erzwingen</translation>
+    </message>
+    <message>
+        <source>Preserve Pitch</source>
+        <translation type="unfinished">Pitch schützen</translation>
+    </message>
+    <message>
+        <source>Length Deviation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Owned By</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run
+&amp;Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>And Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matching Carts:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1322,7 +1493,7 @@ verwendet. Trotzdem löschen?</translation>
     <name>RecordCut</name>
     <message>
         <source>RDLibrary - Record</source>
-        <translation>RDLibrary - Aufnahme</translation>
+        <translation type="obsolete">RDLibrary - Aufnahme</translation>
     </message>
     <message>
         <source>&amp;Description</source>
@@ -1334,7 +1505,7 @@ verwendet. Trotzdem löschen?</translation>
     </message>
     <message>
         <source>Origin</source>
-        <translation>HERKUNFT</translation>
+        <translation type="obsolete">HERKUNFT</translation>
     </message>
     <message>
         <source>ISRC</source>
@@ -1558,5 +1729,21 @@ Trotzdem speichern?</translation>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut Info / Record</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
