@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AudioCart</name>
     <message>
@@ -23,51 +25,51 @@
     </message>
     <message>
         <source>WT</source>
-        <translation>WT</translation>
+        <translation type="obsolete">WT</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIPCIÓN</translation>
+        <translation type="obsolete">DESCRIPCIÓN</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURACIÓN</translation>
+        <translation type="obsolete">DURACIÓN</translation>
     </message>
     <message>
         <source>LAST PLAYED</source>
-        <translation>ÚLTIMA REPROD</translation>
+        <translation type="obsolete">ÚLTIMA REPROD</translation>
     </message>
     <message>
         <source># OF PLAYS</source>
-        <translation># DE REPROD</translation>
+        <translation type="obsolete"># DE REPROD</translation>
     </message>
     <message>
         <source>ORIGIN</source>
-        <translation>ORIGEN</translation>
+        <translation type="obsolete">ORIGEN</translation>
     </message>
     <message>
         <source>OUTCUE</source>
-        <translation>OUTCUE</translation>
+        <translation type="obsolete">OUTCUE</translation>
     </message>
     <message>
         <source>START DATE</source>
-        <translation>FECHA INICIO</translation>
+        <translation type="obsolete">FECHA INICIO</translation>
     </message>
     <message>
         <source>END DATE</source>
-        <translation>FECHA FIN</translation>
+        <translation type="obsolete">FECHA FIN</translation>
     </message>
     <message>
         <source>DAYPART START</source>
-        <translation>INICIO DE DAYPART</translation>
+        <translation type="obsolete">INICIO DE DAYPART</translation>
     </message>
     <message>
         <source>DAYPART END</source>
-        <translation>FIN DE DAYPART</translation>
+        <translation type="obsolete">FIN DE DAYPART</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOMBRE</translation>
+        <translation type="obsolete">NOMBRE</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -220,10 +222,6 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ORD</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>SHA1</source>
         <translation type="unfinished"></translation>
@@ -232,6 +230,66 @@ Do you still want to delete?</source>
         <source>not available</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Played</source>
+        <translation type="unfinished">Últ. Reprod</translation>
+    </message>
+    <message>
+        <source># of Plays</source>
+        <translation type="unfinished"># de reprod</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Outcue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ord</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -383,7 +441,7 @@ Lectura</translation>
     </message>
     <message>
         <source>Rip Track</source>
-        <translation>Leyendo pista</translation>
+        <translation type="obsolete">Leyendo pista</translation>
     </message>
     <message>
         <source>Title:</source>
@@ -401,6 +459,22 @@ Lectura</translation>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rip CD</source>
+        <translation type="unfinished">Leer CD</translation>
+    </message>
+    <message>
+        <source>Rip
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DiskGauge</name>
+    <message>
+        <source>Free</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -621,10 +695,6 @@ Abortada!</translation>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -863,10 +933,6 @@ Notas</translation>
         <source>&amp;Beats per Minute:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>By Specified Order</source>
         <translation type="unfinished"></translation>
@@ -887,12 +953,24 @@ Notas</translation>
         <source>Duplicate Cut Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Carts [multiple]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use RDLogManager Length for PAD Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
     <message>
         <source>Edit Macro</source>
-        <translation>Editar macro</translation>
+        <translation type="obsolete">Editar macro</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -953,30 +1031,30 @@ Notas</translation>
     <name>Filter</name>
     <message>
         <source>Library Filter</source>
-        <translation>Filtro de la biblioteca</translation>
+        <translation type="obsolete">Filtro de la biblioteca</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>Acepta&amp;r</translation>
+        <translation type="obsolete">Acepta&amp;r</translation>
     </message>
     <message>
         <source>C&amp;lear</source>
-        <translation>&amp;Limpiar</translation>
+        <translation type="obsolete">&amp;Limpiar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>&amp;Filter:</source>
-        <translation>&amp;Filtro:</translation>
+        <translation type="obsolete">&amp;Filtro:</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
     <message>
         <source>RDLibrary Reports</source>
-        <translation>Reportes de RDLibrary</translation>
+        <translation type="obsolete">Reportes de RDLibrary</translation>
     </message>
     <message>
         <source>Cart Report</source>
@@ -1006,10 +1084,6 @@ Notas</translation>
         <source>ALL</source>
         <translation type="unfinished">TODAS</translation>
     </message>
-    <message>
-        <source>Cart Data Dump (fixed width)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Data Dump (CSV)</source>
         <translation type="unfinished"></translation>
@@ -1018,6 +1092,10 @@ Notas</translation>
         <source>Prepend Field Names</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -1039,11 +1117,11 @@ Notas</translation>
     </message>
     <message>
         <source>LINE</source>
-        <translation>LÍNEA</translation>
+        <translation type="obsolete">LÍNEA</translation>
     </message>
     <message>
         <source>COMMAND</source>
-        <translation>COMANDO</translation>
+        <translation type="obsolete">COMANDO</translation>
     </message>
     <message>
         <source>Macros</source>
@@ -1067,14 +1145,26 @@ Cartucho</translation>
     </message>
     <message>
         <source>--- End of cart ---</source>
-        <translation>--- Fin del cartucho ---</translation>
+        <translation type="obsolete">--- Fin del cartucho ---</translation>
+    </message>
+    <message>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- End of Cart ---</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>No puedo conectar</translation>
+        <translation type="obsolete">No puedo conectar</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1098,51 +1188,51 @@ Cartucho</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTUCHO</translation>
+        <translation type="obsolete">CARTUCHO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURACIÓN</translation>
+        <translation type="obsolete">DURACIÓN</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>INICIO</translation>
+        <translation type="obsolete">INICIO</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>FIN</translation>
+        <translation type="obsolete">FIN</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENTE</translation>
+        <translation type="obsolete">CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENCIA</translation>
+        <translation type="obsolete">AGENCIA</translation>
     </message>
     <message>
         <source>USER DEFINED</source>
-        <translation>RESERVADO</translation>
+        <translation type="obsolete">RESERVADO</translation>
     </message>
     <message>
         <source>CUTS</source>
-        <translation>AUDIOS</translation>
+        <translation type="obsolete">AUDIOS</translation>
     </message>
     <message>
         <source>LAST CUT PLAYED</source>
-        <translation>ÚLT. AUDIO REPR.</translation>
+        <translation type="obsolete">ÚLT. AUDIO REPR.</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
@@ -1150,15 +1240,15 @@ Cartucho</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
-        <translation>OBLIGAR DURACIÓN</translation>
+        <translation type="obsolete">OBLIGAR DURACIÓN</translation>
     </message>
     <message>
         <source>PRESERVE PITCH</source>
-        <translation>PRESERVAR PITCH</translation>
+        <translation type="obsolete">PRESERVAR PITCH</translation>
     </message>
     <message>
         <source>LENGTH DEVIATION</source>
-        <translation>DESVIACIÓN DE LA DURACIÓN</translation>
+        <translation type="obsolete">DESVIACIÓN DE LA DURACIÓN</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -1212,7 +1302,7 @@ CD</translation>
     </message>
     <message>
         <source>OWNED BY</source>
-        <translation>PROPIEDAD DE</translation>
+        <translation type="obsolete">PROPIEDAD DE</translation>
     </message>
     <message>
         <source>RDCatch Event Exists</source>
@@ -1246,13 +1336,13 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>Deleting cart %06u will also empty the clipboard.
-      <byte value="x9"/>Do you still want to proceed?</source>
+      	Do you still want to proceed?</source>
         <translation>Al eliminar el cartucho %06u también se vaciará el portapapeles.
-      <byte value="x9"/>¿Desea continuar?</translation>
+      	¿Desea continuar?</translation>
     </message>
     <message>
         <source>rdlibrary : </source>
-        <translation>rdlibrary : </translation>
+        <translation type="obsolete">rdlibrary : </translation>
     </message>
     <message>
         <source>&amp;Search</source>
@@ -1290,18 +1380,6 @@ Do you still want to delete it?</source>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>COMPOSER</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CONDUCTOR</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PUBLISHER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
@@ -1311,15 +1389,112 @@ Do you still want to delete it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unknown command-line option</source>
+        <source>Unknown command option</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Fin</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publisher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Defined</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cuts</source>
+        <translation type="unfinished">Audios</translation>
+    </message>
+    <message>
+        <source>Last Cut Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enforce Length</source>
+        <translation type="unfinished">Forzar duración</translation>
+    </message>
+    <message>
+        <source>Preserve Pitch</source>
+        <translation type="unfinished">Preservar pitch</translation>
+    </message>
+    <message>
+        <source>Length Deviation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Owned By</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run
+&amp;Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>And Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matching Carts:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1327,7 +1502,7 @@ Do you still want to delete it?</source>
     <name>RecordCut</name>
     <message>
         <source>RDLibrary - Record</source>
-        <translation>RDLibrary - Grabar</translation>
+        <translation type="obsolete">RDLibrary - Grabar</translation>
     </message>
     <message>
         <source>&amp;Description</source>
@@ -1339,7 +1514,7 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>Origin</source>
-        <translation>Origen</translation>
+        <translation type="obsolete">Origen</translation>
     </message>
     <message>
         <source>Weight</source>
@@ -1563,5 +1738,21 @@ Do you still want to save?</source>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut Info / Record</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
