@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AudioCart</name>
     <message>
@@ -21,54 +23,6 @@
         <source>Paste</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>WT</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DESCRIPTION</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>LENGTH</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>LAST PLAYED</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source># OF PLAYS</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ORIGIN</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OUTCUE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>START DATE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>END DATE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DAYPART START</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>DAYPART END</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>NAME</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cut Info</source>
         <translation type="unfinished"></translation>
@@ -198,10 +152,6 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ORD</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>SHA1</source>
         <translation type="unfinished"></translation>
@@ -210,6 +160,66 @@ Do you still want to delete?</source>
         <source>not available</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Wt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source># of Plays</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Outcue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ord</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -325,10 +335,6 @@ Do you still want to proceed?</source>
 Rip</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Rip Track</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Title:</source>
         <translation type="unfinished"></translation>
@@ -345,6 +351,22 @@ Rip</source>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rip CD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rip
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DiskGauge</name>
+    <message>
+        <source>Free</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -509,10 +531,6 @@ Disk</source>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cut</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -680,7 +698,7 @@ Script</source>
     </message>
     <message>
         <source></source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>Missing Title</source>
@@ -736,10 +754,6 @@ Notes</source>
         <source>&amp;Beats per Minute:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>By Specified Order</source>
         <translation type="unfinished"></translation>
@@ -760,13 +774,21 @@ Notes</source>
         <source>Duplicate Cut Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Carts [multiple]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use RDLogManager Length for PAD Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
-    <message>
-        <source>Edit Macro</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;OK</source>
         <translation type="unfinished"></translation>
@@ -822,35 +844,8 @@ Notes</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>Filter</name>
-    <message>
-        <source>Library Filter</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>C&amp;lear</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Filter:</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>ListReports</name>
-    <message>
-        <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Report</source>
         <translation type="unfinished"></translation>
@@ -875,10 +870,6 @@ Notes</source>
         <source>ALL</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Cart Data Dump (fixed width)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Data Dump (CSV)</source>
         <translation type="unfinished"></translation>
@@ -887,6 +878,10 @@ Notes</source>
         <source>Prepend Field Names</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -906,14 +901,6 @@ Notes</source>
         <source>Paste</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>LINE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>COMMAND</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Macros</source>
         <translation type="unfinished"></translation>
@@ -933,7 +920,15 @@ Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>--- End of cart ---</source>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- End of Cart ---</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -943,14 +938,6 @@ Cart</source>
         <source>Please Wait...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>rdlibrary : </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Can&apos;t Connect</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Filter:</source>
         <translation type="unfinished"></translation>
@@ -979,70 +966,6 @@ Cart</source>
         <source>Show Macro Carts</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>CART</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>GROUP</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>LENGTH</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>TITLE</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ARTIST</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>START</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>END</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CLIENT</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>AGENCY</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>USER DEFINED</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CUTS</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>LAST CUT PLAYED</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ENFORCE LENGTH</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PRESERVE PITCH</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>LENGTH DEVIATION</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>OWNED BY</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Add</source>
         <translation type="unfinished"></translation>
@@ -1074,7 +997,7 @@ CD</source>
     </message>
     <message>
         <source></source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>Are you sure you want to delete cart(s)</source>
@@ -1095,7 +1018,7 @@ Do you still want to delete it?</source>
     </message>
     <message>
         <source>Deleting cart %06u will also empty the clipboard.
-      <byte value="x9"/>Do you still want to proceed?</source>
+      	Do you still want to proceed?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1134,18 +1057,6 @@ Do you still want to delete it?</source>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>COMPOSER</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CONDUCTOR</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PUBLISHER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
@@ -1155,24 +1066,117 @@ Do you still want to delete it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unknown command-line option</source>
+        <source>Unknown command option</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publisher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Defined</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Cut Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enforce Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preserve Pitch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length Deviation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Owned By</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run
+&amp;Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>And Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matching Carts:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>RecordCut</name>
-    <message>
-        <source>RDLibrary - Record</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Description</source>
         <translation type="unfinished"></translation>
@@ -1408,5 +1412,9 @@ Do you still want to save?</source>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut Info / Record</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
