@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AudioCart</name>
     <message>
@@ -23,23 +25,23 @@
     </message>
     <message>
         <source>WT</source>
-        <translation>WT</translation>
+        <translation type="obsolete">WT</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>DESCRIÇÃO</translation>
+        <translation type="obsolete">DESCRIÇÃO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURAÇÃO</translation>
+        <translation type="obsolete">DURAÇÃO</translation>
     </message>
     <message>
         <source>LAST PLAYED</source>
-        <translation>ÚLTIMO VEZ EXECUTADA</translation>
+        <translation type="obsolete">ÚLTIMO VEZ EXECUTADA</translation>
     </message>
     <message>
         <source># OF PLAYS</source>
-        <translation># AO AR</translation>
+        <translation type="obsolete"># AO AR</translation>
     </message>
     <message>
         <source>ORIGIN</source>
@@ -47,27 +49,27 @@
     </message>
     <message>
         <source>OUTCUE</source>
-        <translation>COMENTÁRIO</translation>
+        <translation type="obsolete">COMENTÁRIO</translation>
     </message>
     <message>
         <source>START DATE</source>
-        <translation>DATA DE INÍCIO</translation>
+        <translation type="obsolete">DATA DE INÍCIO</translation>
     </message>
     <message>
         <source>END DATE</source>
-        <translation>DATA DE TÉRMINO</translation>
+        <translation type="obsolete">DATA DE TÉRMINO</translation>
     </message>
     <message>
         <source>DAYPART START</source>
-        <translation>DIAS PERMITIDOS INÍCIO</translation>
+        <translation type="obsolete">DIAS PERMITIDOS INÍCIO</translation>
     </message>
     <message>
         <source>DAYPART END</source>
-        <translation>DIAS PERMITIDOS TÉRMINO</translation>
+        <translation type="obsolete">DIAS PERMITIDOS TÉRMINO</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NOME</translation>
+        <translation type="obsolete">NOME</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -216,10 +218,6 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ORD</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>SHA1</source>
         <translation type="unfinished"></translation>
@@ -228,18 +226,66 @@ Do you still want to delete?</source>
         <source>not available</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>INGEST</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SOURCE</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>unknown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Wt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Played</source>
+        <translation type="unfinished">Última vez Executada</translation>
+    </message>
+    <message>
+        <source># of Plays</source>
+        <translation type="unfinished"># Ao Ar</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Outcue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ord</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -388,10 +434,6 @@ Rip</source>
         <source>RDLibrary - Ripper Error</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Rip Track</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Title:</source>
         <translation type="unfinished"></translation>
@@ -408,6 +450,22 @@ Rip</source>
         <source>Unable to create temporary directory!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rip CD</source>
+        <translation type="unfinished">Extrair CD</translation>
+    </message>
+    <message>
+        <source>Rip
+Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DiskGauge</name>
+    <message>
+        <source>Free</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -868,10 +926,6 @@ limite do sistema!   Você ainda quer salvar?</translation>
         <source>&amp;Beats per Minute:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>By Specified Order</source>
         <translation type="unfinished"></translation>
@@ -892,12 +946,24 @@ limite do sistema!   Você ainda quer salvar?</translation>
         <source>Duplicate Cut Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Carts [multiple]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use RDLogManager Length for PAD Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
     <message>
         <source>Edit Macro</source>
-        <translation>Editar Macro</translation>
+        <translation type="obsolete">Editar Macro</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -958,31 +1024,27 @@ limite do sistema!   Você ainda quer salvar?</translation>
     <name>Filter</name>
     <message>
         <source>Library Filter</source>
-        <translation>Filtro </translation>
+        <translation type="obsolete">Filtro </translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>C&amp;lear</source>
-        <translation>&amp;Limpar</translation>
+        <translation type="obsolete">&amp;Limpar</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>&amp;Filter:</source>
-        <translation>&amp;Filtrar:</translation>
+        <translation type="obsolete">&amp;Filtrar:</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
-    <message>
-        <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Report</source>
         <translation type="unfinished"></translation>
@@ -1007,10 +1069,6 @@ limite do sistema!   Você ainda quer salvar?</translation>
         <source>ALL</source>
         <translation type="unfinished">TODOS</translation>
     </message>
-    <message>
-        <source>Cart Data Dump (fixed width)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Data Dump (CSV)</source>
         <translation type="unfinished"></translation>
@@ -1019,6 +1077,10 @@ limite do sistema!   Você ainda quer salvar?</translation>
         <source>Prepend Field Names</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -1040,11 +1102,11 @@ limite do sistema!   Você ainda quer salvar?</translation>
     </message>
     <message>
         <source>LINE</source>
-        <translation>LINHA</translation>
+        <translation type="obsolete">LINHA</translation>
     </message>
     <message>
         <source>COMMAND</source>
-        <translation>COMANDO</translation>
+        <translation type="obsolete">COMANDO</translation>
     </message>
     <message>
         <source>Macros</source>
@@ -1068,7 +1130,19 @@ Cartão</translation>
     </message>
     <message>
         <source>--- End of cart ---</source>
-        <translation>-- Fim do Cartão --</translation>
+        <translation type="obsolete">-- Fim do Cartão --</translation>
+    </message>
+    <message>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- End of Cart ---</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1079,11 +1153,11 @@ Cartão</translation>
     </message>
     <message>
         <source>rdlibrary : </source>
-        <translation>RDBiblio: </translation>
+        <translation type="obsolete">RDBiblio: </translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Sem conexão</translation>
+        <translation type="obsolete">Sem conexão</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1119,51 +1193,51 @@ Cartão</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTÃO</translation>
+        <translation type="obsolete">CARTÃO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURAÇÃO</translation>
+        <translation type="obsolete">DURAÇÃO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>INÍCIO</translation>
+        <translation type="obsolete">INÍCIO</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>FIM</translation>
+        <translation type="obsolete">FIM</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>CLIENTE</translation>
+        <translation type="obsolete">CLIENTE</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGÊNCIA</translation>
+        <translation type="obsolete">AGÊNCIA</translation>
     </message>
     <message>
         <source>USER DEFINED</source>
-        <translation>USO GENÉRICO</translation>
+        <translation type="obsolete">USO GENÉRICO</translation>
     </message>
     <message>
         <source>CUTS</source>
-        <translation>CONTEÚDOS</translation>
+        <translation type="obsolete">CONTEÚDOS</translation>
     </message>
     <message>
         <source>LAST CUT PLAYED</source>
-        <translation>ÚLTIMO CONTEÚDO EXECUTADO</translation>
+        <translation type="obsolete">ÚLTIMO CONTEÚDO EXECUTADO</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
@@ -1171,19 +1245,19 @@ Cartão</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
-        <translation>FORÇAR DURAÇÃO</translation>
+        <translation type="obsolete">FORÇAR DURAÇÃO</translation>
     </message>
     <message>
         <source>PRESERVE PITCH</source>
-        <translation>PRESERVAR PITCH</translation>
+        <translation type="obsolete">PRESERVAR PITCH</translation>
     </message>
     <message>
         <source>LENGTH DEVIATION</source>
-        <translation>DESVIO DE DURAÇÃO</translation>
+        <translation type="obsolete">DESVIO DE DURAÇÃO</translation>
     </message>
     <message>
         <source>OWNED BY</source>
-        <translation>DONO</translation>
+        <translation type="obsolete">DONO</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -1239,9 +1313,9 @@ Você ainda quer deletá-lo?</translation>
     </message>
     <message>
         <source>Deleting cart %06u will also empty the clipboard.
-      <byte value="x9"/>Do you still want to proceed?</source>
+      	Do you still want to proceed?</source>
         <translation>Deletar o Cartão %06u também esvaziará o clipboard.
-      <byte value="x9"/>Você ainda quer proceder?</translation>
+      	Você ainda quer proceder?</translation>
     </message>
     <message>
         <source>Empty Clipboard</source>
@@ -1291,18 +1365,6 @@ Você ainda quer deletá-lo?</translation>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>COMPOSER</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CONDUCTOR</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PUBLISHER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
@@ -1312,15 +1374,112 @@ Você ainda quer deletá-lo?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unknown command-line option</source>
+        <source>Unknown command option</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Término</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publisher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Defined</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cuts</source>
+        <translation type="unfinished">Conteúdos</translation>
+    </message>
+    <message>
+        <source>Last Cut Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enforce Length</source>
+        <translation type="unfinished">Forçar Duração</translation>
+    </message>
+    <message>
+        <source>Preserve Pitch</source>
+        <translation type="unfinished">Preservar Pitch</translation>
+    </message>
+    <message>
+        <source>Length Deviation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Owned By</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run
+&amp;Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>And Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matching Carts:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1328,7 +1487,7 @@ Você ainda quer deletá-lo?</translation>
     <name>RecordCut</name>
     <message>
         <source>RDLibrary - Record</source>
-        <translation>RDBiblio - Gravacão</translation>
+        <translation type="obsolete">RDBiblio - Gravacão</translation>
     </message>
     <message>
         <source>&amp;Description</source>
@@ -1576,5 +1735,9 @@ Você ainda quer salvar?</translation>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut Info / Record</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
