@@ -2,7 +2,7 @@
 //
 // Record a Rivendell Cut
 //
-//   (C) Copyright 2002-2004,2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,57 +18,23 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <math.h>
-#include <qnamespace.h>
-#include <qpushbutton.h>
-#include <qtimer.h>
 #include <qmessagebox.h>
-#include <qfile.h>
-#include <qbuttongroup.h>
 
-#include <rd.h>
 #include <rdconf.h>
 #include <rdmixer.h>
 #include <rdrehash.h>
 
-#include <record_cut.h>
-#include <globals.h>
-#include <rdconfig.h>
+#include "globals.h"
+#include "record_cut.h"
 
-RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
-		     QWidget *parent)
-  : QDialog(parent,"",true)
+RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,QWidget *parent)
+  : RDDialog(parent)
 {
   bool valid;
   bool is_track=cart->owner().isEmpty();
-  bool allow_modification=lib_user->modifyCarts()&&is_track;
-  bool allow_editing=lib_user->editAudio()&&is_track;
+  bool allow_modification=rda->user()->modifyCarts()&&is_track;
+  bool allow_editing=rda->user()->editAudio()&&is_track;
   rec_use_weighting=use_weight;
-
-  //
-  // Fix the Window Size
-  //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Bold);
-  small_font.setPixelSize(10);
-  QFont large_font=QFont("Helvetica",18,QFont::Bold);
-  large_font.setPixelSize(18);
-  QFont timer_font=QFont("Helvetica",20,QFont::Bold);
-  timer_font.setPixelSize(20);
-  QFont day_font=QFont("helvetica",10,QFont::Normal);
-  day_font.setPixelSize(10);
-
-  setCaption(tr("RDLibrary - Record"));
   rec_cut=new RDCut(cut);
   is_playing=false;
   is_ready=false;
@@ -76,49 +42,57 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   is_closing=false;
   rec_timer_value=0;
 
+  setWindowTitle("RDLibrary - "+tr("Cut Info / Record"));
+
+  //
+  // Fix the Window Size
+  //
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
+
   //
   // Load Audio Assignments
   //
-  rec_card_no[0]=rdlibrary_conf->inputCard();
-  rec_port_no[0]=rdlibrary_conf->inputPort();
-  rec_card_no[1]=rdlibrary_conf->outputCard();
-  rec_port_no[1]=rdlibrary_conf->outputPort();
+  rec_card_no[0]=rda->libraryConf()->inputCard();
+  rec_port_no[0]=rda->libraryConf()->inputPort();
+  rec_card_no[1]=rda->libraryConf()->outputCard();
+  rec_port_no[1]=rda->libraryConf()->outputPort();
   rec_play_handle=-1;
 
   //
   // CAE Connection
   //
-  connect(rdcae,SIGNAL(isConnected(bool)),this,SLOT(initData(bool)));
-  connect(rdcae,SIGNAL(playing(int)),this,SLOT(playedData(int)));
-  connect(rdcae,SIGNAL(playStopped(int)),this,SLOT(playStoppedData(int)));
-  connect(rdcae,SIGNAL(recordLoaded(int,int)),
+  connect(rda->cae(),SIGNAL(isConnected(bool)),this,SLOT(initData(bool)));
+  connect(rda->cae(),SIGNAL(playing(int)),this,SLOT(playedData(int)));
+  connect(rda->cae(),SIGNAL(playStopped(int)),this,SLOT(playStoppedData(int)));
+  connect(rda->cae(),SIGNAL(recordLoaded(int,int)),
 	  this,SLOT(recordLoadedData(int,int)));
-  connect(rdcae,SIGNAL(recordUnloaded(int,int,unsigned)),
+  connect(rda->cae(),SIGNAL(recordUnloaded(int,int,unsigned)),
 	  this,SLOT(recordUnloadedData(int,int,unsigned)));
-  connect(rdcae,SIGNAL(recording(int,int)),this,SLOT(recordedData(int,int)));
-  connect(rdcae,SIGNAL(recordStopped(int,int)),
+  connect(rda->cae(),SIGNAL(recording(int,int)),this,SLOT(recordedData(int,int)));
+  connect(rda->cae(),SIGNAL(recordStopped(int,int)),
 	  this,SLOT(recordStoppedData(int,int)));
-  connect(rdcae,SIGNAL(inputStatusChanged(int,int,bool)),
+  connect(rda->cae(),SIGNAL(inputStatusChanged(int,int,bool)),
 	  this,SLOT(aesAlarmData(int,int,bool)));
 
   //
   // Audio Parameters
   //
-  rec_card_no[0]=rdlibrary_conf->inputCard();
-  rec_card_no[1]=rdlibrary_conf->outputCard();
+  rec_card_no[0]=rda->libraryConf()->inputCard();
+  rec_card_no[1]=rda->libraryConf()->outputCard();
   rec_name=rec_cut->cutName();
   switch(rec_cut->codingFormat()) {
-      case 0:
-	rec_format=RDCae::Pcm16;
-	break;
+  case 0:
+    rec_format=RDCae::Pcm16;
+    break;
 	
-      case 1:
-	rec_format=RDCae::MpegL2;
-	break;
+  case 1:
+    rec_format=RDCae::MpegL2;
+    break;
 
-      default:
-	rec_format=RDCae::Pcm16;
-	break;
+  default:
+    rec_format=RDCae::Pcm16;
+    break;
   }	
   rec_channels=rec_cut->channels();
   rec_samprate=rec_cut->sampleRate();
@@ -132,7 +106,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_description_edit->setMaxLength(64);
   cut_description_label=
     new QLabel(cut_description_edit,tr("&Description")+":",this);
-  cut_description_label->setFont(font);
+  cut_description_label->setFont(labelFont());
   cut_description_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -141,7 +115,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_outcue_edit=new QLineEdit(this);
   cut_outcue_edit->setMaxLength(64);
   cut_outcue_label=new QLabel(cut_outcue_edit,tr("&Outcue")+":",this);
-  cut_outcue_label->setFont(font);
+  cut_outcue_label->setFont(labelFont());
   cut_outcue_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -150,7 +124,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_isci_edit=new QLineEdit(this);
   cut_isci_edit->setMaxLength(32);
   cut_isci_label=new QLabel(cut_isci_edit,tr("&ISCI Code")+":",this);
-  cut_isci_label->setFont(font);
+  cut_isci_label->setFont(labelFont());
   cut_isci_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -159,7 +133,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_isrc_edit=new QLineEdit(this);
   cut_isrc_edit->setMaxLength(64);
   cut_isrc_label=new QLabel(cut_isrc_edit,tr("ISRC")+":",this);
-  cut_isrc_label->setFont(font);
+  cut_isrc_label->setFont(labelFont());
   cut_isrc_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -168,7 +142,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_source_edit=new QLineEdit(this);
   cut_source_edit->setReadOnly(true);
   cut_source_label=new QLabel(cut_source_edit,tr("Source")+":",this);
-  cut_source_label->setFont(font);
+  cut_source_label->setFont(labelFont());
   cut_source_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -177,7 +151,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_ingest_edit=new QLineEdit(this);
   cut_ingest_edit->setReadOnly(true);
   cut_ingest_label=new QLabel(cut_ingest_edit,tr("Ingest")+":",this);
-  cut_ingest_label->setFont(font);
+  cut_ingest_label->setFont(labelFont());
   cut_ingest_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -187,19 +161,19 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_playdate_edit->setReadOnly(true);
   cut_playdate_edit->setMaxLength(64);
   cut_playdate_label=new QLabel(cut_playdate_edit,tr("Last Played")+":",this);
-  cut_playdate_label->setFont(font);
+  cut_playdate_label->setFont(labelFont());
   cut_playdate_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Cut Play Counter
   //
   cut_playcounter_edit=new QLineEdit(this);
-  cut_playcounter_edit->setAlignment(AlignRight);
+  cut_playcounter_edit->setAlignment(Qt::AlignRight);
   cut_playcounter_edit->setReadOnly(true);
   cut_playcounter_edit->setMaxLength(64);
   cut_playcounter_label=
     new QLabel(cut_playcounter_edit,tr("# of Plays")+":",this);
-  cut_playcounter_label->setFont(font);
+  cut_playcounter_label->setFont(labelFont());
   cut_playcounter_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
@@ -208,8 +182,8 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   rec_evergreen_box=new QCheckBox(this);
   rec_evergreen_label=new 
     QLabel(rec_evergreen_box,tr("Cut is EVERGREEN")+":",this);
-  rec_evergreen_label->setFont(font);
-  rec_evergreen_label->setAlignment(AlignVCenter|AlignLeft);
+  rec_evergreen_label->setFont(labelFont());
+  rec_evergreen_label->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
   connect(rec_evergreen_box,SIGNAL(toggled(bool)),
 	  this,SLOT(evergreenToggledData(bool)));
 
@@ -219,105 +193,104 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_weight_box=new QSpinBox(this);
   cut_weight_box->setRange(0,100);
   cut_weight_label=new QLabel(cut_weight_box,tr("Weight")+":",this);
-  cut_weight_label->setFont(font);
+  cut_weight_label->setFont(labelFont());
   cut_weight_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Cut Air Date Times
   //
-  cut_killdatetime_label=new QLabel(tr("Air Date/Time"),this);
-  cut_killdatetime_label->setAlignment(Qt::AlignHCenter);
-  cut_killdatetime_label->setFont(font);
-  QButtonGroup *button_group=new QButtonGroup(this);
-  button_group->hide();
-  connect(button_group,SIGNAL(clicked(int)),this,SLOT(airDateButtonData(int)));
-  cut_startdatetime_enable_button=new QRadioButton(tr("Enabled"),this,
-					       "air_date_enabled_button");
-  button_group->insert(cut_startdatetime_enable_button,true);
+  cut_killdatetime_groupbox=new QGroupBox(tr("Air Date/Time"),this);
+  cut_killdatetime_groupbox->setFont(labelFont());
+  cut_killdatetime_group=new QButtonGroup(this);
+  connect(cut_killdatetime_group,SIGNAL(buttonClicked(int)),
+	  this,SLOT(airDateButtonData(int)));
+  cut_startdatetime_enable_button=new QRadioButton(tr("Enabled"),this);
+  cut_killdatetime_group->addButton(cut_startdatetime_enable_button,true);
   cut_startdatetime_disable_button=new QRadioButton(tr("Disabled"),this);
-  button_group->insert(cut_startdatetime_disable_button,false);
+  cut_killdatetime_group->addButton(cut_startdatetime_disable_button,false);
 
   cut_startdatetime_edit=new QDateTimeEdit(this);
+  cut_startdatetime_edit->setDisplayFormat("MM/dd/yyyy - hh:mm:ss");
   cut_startdatetime_label=new QLabel(cut_startdatetime_edit,tr("&Start"),this);
-  cut_startdatetime_label->setFont(small_font);
-  cut_startdatetime_label->setAlignment(AlignRight|ShowPrefix);
-
+  cut_startdatetime_label->setFont(subLabelFont());
+  cut_startdatetime_label->setAlignment(Qt::AlignRight);
   cut_enddatetime_edit=new QDateTimeEdit(this);
+  cut_enddatetime_edit->setDisplayFormat("MM/dd/yyyy - hh:mm:ss");
   cut_enddatetime_label=new QLabel(cut_enddatetime_edit,tr("End"),this);
-  cut_enddatetime_label->setFont(small_font);
-  cut_enddatetime_label->setAlignment(AlignRight|ShowPrefix);
+  cut_enddatetime_label->setFont(subLabelFont());
+  cut_enddatetime_label->setAlignment(Qt::AlignRight);
 
   //
   // Cut Daypart
   //
-  cut_daypart_label=new QLabel(tr("Daypart"),this);
-  cut_daypart_label->setAlignment(Qt::AlignHCenter);
-  cut_daypart_label->setFont(font);
-  button_group=new QButtonGroup(this);
-  button_group->hide();
-  connect(button_group,SIGNAL(clicked(int)),this,SLOT(daypartButtonData(int)));
+  cut_daypart_groupbox=new QGroupBox(tr("Daypart"),this);
+  cut_daypart_groupbox->setFont(labelFont());
+  cut_daypart_group=new QButtonGroup(this);
+  connect(cut_daypart_group,SIGNAL(buttonClicked(int)),
+	  this,SLOT(daypartButtonData(int)));
   cut_starttime_enable_button=new QRadioButton(tr("Enabled"),this);
-  button_group->insert(cut_starttime_enable_button,true);
+  cut_daypart_group->addButton(cut_starttime_enable_button,true);
   cut_starttime_disable_button=new QRadioButton(tr("Disabled"),this);
-  button_group->insert(cut_starttime_disable_button,false);
+  cut_daypart_group->addButton(cut_starttime_disable_button,false);
 
-  cut_starttime_edit=new RDTimeEdit(this);
+  cut_starttime_edit=new QTimeEdit(this);
+  cut_starttime_edit->setDisplayFormat("hh:mm:ss");
   cut_starttime_label=new QLabel(cut_starttime_edit,tr("&Start Time"),this);
-  cut_starttime_label->setFont(small_font);
-  cut_starttime_label->setAlignment(AlignRight|ShowPrefix);
+  cut_starttime_label->setFont(subLabelFont());
+  cut_starttime_label->setAlignment(Qt::AlignRight);
 
-  cut_endtime_edit=new RDTimeEdit(this);
+  cut_endtime_edit=new QTimeEdit(this);
+  cut_endtime_edit->setDisplayFormat("hh:mm:ss");
   cut_endtime_label=new QLabel(cut_endtime_edit,tr("End Time"),this);
-  cut_endtime_label->setFont(small_font);
-  cut_endtime_label->setAlignment(AlignRight|ShowPrefix);
+  cut_endtime_label->setFont(subLabelFont());
+  cut_endtime_label->setAlignment(Qt::AlignRight);
 
   //
   // Days of the Week
   //
-  rec_dayofweek_label=new QLabel(tr("Day of the Week"),this);
-  rec_dayofweek_label->setAlignment(Qt::AlignHCenter);
-  rec_dayofweek_label->setFont(font);
+  rec_dayofweek_groupbox=new QGroupBox(tr("Day of the Week"),this);
+  rec_dayofweek_groupbox->setFont(labelFont());
   rec_weekpart_button[0]=new QCheckBox(this);
   rec_weekpart_label[0]=new QLabel(rec_weekpart_button[0],tr("Monday"),this);
-  rec_weekpart_label[0]->setFont(day_font);
-  rec_weekpart_label[0]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[0]->setFont(subLabelFont());
+  rec_weekpart_label[0]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_weekpart_button[1]=new QCheckBox(this);
   rec_weekpart_label[1]=new QLabel(rec_weekpart_button[1],tr("Tuesday"),this);
-  rec_weekpart_label[1]->setFont(day_font);
-  rec_weekpart_label[1]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[1]->setFont(subLabelFont());
+  rec_weekpart_label[1]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_weekpart_button[2]=new QCheckBox(this);
   rec_weekpart_label[2]=new QLabel(rec_weekpart_button[2],tr("Wednesday"),this);
-  rec_weekpart_label[2]->setFont(day_font);
-  rec_weekpart_label[2]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[2]->setFont(subLabelFont());
+  rec_weekpart_label[2]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_weekpart_button[3]=new QCheckBox(this);
   rec_weekpart_label[3]=new QLabel(rec_weekpart_button[3],tr("Thursday"),this);
-  rec_weekpart_label[3]->setFont(day_font);
-  rec_weekpart_label[3]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[3]->setFont(subLabelFont());
+  rec_weekpart_label[3]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_weekpart_button[4]=new QCheckBox(this);
   rec_weekpart_label[4]=new QLabel(rec_weekpart_button[4],tr("Friday"),this);
-  rec_weekpart_label[4]->setFont(day_font);
-  rec_weekpart_label[4]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[4]->setFont(subLabelFont());
+  rec_weekpart_label[4]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_weekpart_button[5]=new QCheckBox(this);
   rec_weekpart_label[5]=new QLabel(rec_weekpart_button[5],tr("Saturday"),this);
-  rec_weekpart_label[5]->setFont(day_font);
-  rec_weekpart_label[5]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[5]->setFont(subLabelFont());
+  rec_weekpart_label[5]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_weekpart_button[6]=new QCheckBox(this);
   rec_weekpart_label[6]=new QLabel(rec_weekpart_button[6],tr("Sunday"),this);
-  rec_weekpart_label[6]->setFont(day_font);
-  rec_weekpart_label[6]->setAlignment(AlignVCenter|AlignLeft);
+  rec_weekpart_label[6]->setFont(subLabelFont());
+  rec_weekpart_label[6]->setAlignment(Qt::AlignVCenter|Qt::AlignLeft);
 
   rec_set_button=new QPushButton(tr("Set All"),this);
-  rec_set_button->setFont(small_font);
+  rec_set_button->setFont(subButtonFont());
   connect(rec_set_button,SIGNAL(clicked()),this,SLOT(setAllData()));
 
   rec_clear_button=new QPushButton(tr("Clear All"),this);
-  rec_clear_button->setFont(small_font);
+  rec_clear_button->setFont(subButtonFont());
   connect(rec_clear_button,SIGNAL(clicked()),this,SLOT(clearAllData()));
 
   //
@@ -334,9 +307,9 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   // AES Alarm
   //
   rec_aes_alarm_label=new QLabel(this);
-  rec_aes_alarm_label->setAlignment(AlignHCenter|AlignVCenter);
-  rec_aes_alarm_label->setFont(large_font);
-  rec_aes_alarm_label->setPalette(QColor(red));
+  rec_aes_alarm_label->setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
+  rec_aes_alarm_label->setFont(progressFont());
+  rec_aes_alarm_label->setPalette(QColor(Qt::red));
   rec_aes_alarm_label->setText(tr("AES ALARM"));
   rec_aes_alarm_label->hide();
 
@@ -346,8 +319,8 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   rec_timer=new QTimer(this);
   connect(rec_timer,SIGNAL(timeout()),this,SLOT(recTimerData()));
   rec_timer_label=new QLabel(this);
-  rec_timer_label->setFont(timer_font);
-  rec_timer_label->setAlignment(AlignLeft|AlignVCenter);
+  rec_timer_label->setFont(timerFont());
+  rec_timer_label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   rec_timer_label->setText(RDGetTimeLength(rec_length,true));
 
   //
@@ -356,8 +329,8 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   rec_channels_box=new QComboBox(this);
   rec_channels_edit=new QLineEdit(this);
   rec_channels_box_label=new QLabel(rec_channels_box,tr("Channels"),this);
-  rec_channels_box_label->setAlignment(AlignHCenter);
-  rec_channels_box_label->setFont(font);
+  rec_channels_box_label->setAlignment(Qt::AlignHCenter);
+  rec_channels_box_label->setFont(labelFont());
   connect(rec_channels_box,SIGNAL(activated(int)),
 	  this,SLOT(channelsData(int)));
 
@@ -381,7 +354,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   rec_stop_button=new RDTransportButton(RDTransportButton::Stop,this);
   rec_stop_button->setDefault(true);
   rec_stop_button->setState(RDTransportButton::On);
-  rec_stop_button->setOnColor(QColor(red));
+  rec_stop_button->setOnColor(Qt::red);
   connect(rec_stop_button,SIGNAL(clicked()),this,SLOT(stopData()));
 
   //
@@ -389,23 +362,23 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   //
   rec_mode_box=new QComboBox(this);
   rec_mode_box_label=new QLabel(rec_mode_box,tr("Record Mode"),this);
-  rec_mode_box_label->setAlignment(AlignHCenter);
-  rec_mode_box_label->setFont(font);
+  rec_mode_box_label->setAlignment(Qt::AlignHCenter);
+  rec_mode_box_label->setFont(labelFont());
 
   //
   // AutoTrim Mode 
   //
   rec_trim_box=new QComboBox(this);
   rec_trim_box_label=new QLabel(rec_trim_box,tr("AutoTrim"),this);
-  rec_trim_box_label->setAlignment(AlignHCenter);
-  rec_trim_box_label->setFont(font);
+  rec_trim_box_label->setAlignment(Qt::AlignHCenter);
+  rec_trim_box_label->setFont(labelFont());
 
   //
   //  Close Button
   //
   close_button=new QPushButton(this);
   close_button->setDefault(true);
-  close_button->setFont(font);
+  close_button->setFont(buttonFont());
   close_button->setText(tr("&Close"));
   connect(close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -434,10 +407,12 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_isrc_edit->setText(rec_cut->isrc(RDCut::FormattedIsrc));
   if(use_weight) {
     cut_weight_label->setText(tr("Weight"));
+    cut_weight_box->setRange(0,100);
     cut_weight_box->setValue(rec_cut->weight());
   }
   else {
     cut_weight_label->setText(tr("Order"));
+    cut_weight_box->setRange(1,RD_MAX_CUT_NUMBER);
     cut_weight_box->setValue(rec_cut->playOrder());
   }
   if(rec_cut->playCounter()>0) {
@@ -457,9 +432,9 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   cut_startdatetime_disable_button->setChecked(!valid);
   airDateButtonData(valid);
   cut_starttime_edit->setTime(rec_cut->startDaypart(&valid));
-  cut_endtime_edit->setTime(rec_cut->endDaypart(&valid));
   cut_starttime_enable_button->setChecked(valid);
   cut_starttime_disable_button->setChecked(!valid);
+  cut_endtime_edit->setTime(rec_cut->endDaypart(&valid));
   daypartButtonData(valid);
   for(int i=0;i<7;i++) {
     if(rec_cut->weekPart(i+1)) {
@@ -472,7 +447,7 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   rec_channels_edit->setText(QString().sprintf("%d",rec_cut->channels()));
   rec_mode_box->insertItem(tr("Manual"));
   rec_mode_box->insertItem(tr("VOX"));
-  switch(rdlibrary_conf->defaultRecordMode()) {
+  switch(rda->libraryConf()->defaultRecordMode()) {
       case RDLibraryConf::Manual:
 	rec_mode_box->setCurrentItem(0);
 	break;
@@ -483,14 +458,14 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   }
   rec_trim_box->insertItem(tr("On"));
   rec_trim_box->insertItem(tr("Off"));
-  if(rdlibrary_conf->defaultTrimState()) {
+  if(rda->libraryConf()->defaultTrimState()) {
     rec_trim_box->setCurrentItem(0);
   }
   else {
     rec_trim_box->setCurrentItem(1);
   }
   aesAlarmData(rec_card_no[0],rec_port_no[0],
-	       rdcae->inputStatus(rec_card_no[0],rec_port_no[0]));
+	       rda->cae()->inputStatus(rec_card_no[0],rec_port_no[0]));
 
   //
   // Set Control Perms
@@ -503,20 +478,20 @@ RecordCut::RecordCut(RDCart *cart,QString cut,bool use_weight,
   if(!allow_modification) {
     cut_weight_box->setRange(cut_weight_box->value(),cut_weight_box->value());
     if(cut_startdatetime_enable_button->isChecked()) {
-      cut_startdatetime_edit->dateEdit()->
-	setRange(cut_startdatetime_edit->dateEdit()->date(),
-		 cut_startdatetime_edit->dateEdit()->date());
-      cut_startdatetime_edit->timeEdit()->
-	setRange(cut_startdatetime_edit->timeEdit()->time(),
-		 cut_startdatetime_edit->timeEdit()->time());
-      cut_enddatetime_edit->dateEdit()->
-	setRange(cut_enddatetime_edit->dateEdit()->date(),
-		 cut_enddatetime_edit->dateEdit()->date());
+      cut_startdatetime_edit->
+	setDateRange(cut_startdatetime_edit->date(),
+		     cut_startdatetime_edit->date());
+      cut_startdatetime_edit->
+	setTimeRange(cut_startdatetime_edit->time(),
+		     cut_startdatetime_edit->time());
+      cut_enddatetime_edit->
+	setDateRange(cut_enddatetime_edit->date(),
+		     cut_enddatetime_edit->date());
     }
     if(cut_starttime_enable_button->isChecked()) {
-      cut_enddatetime_edit->timeEdit()->
-	setRange(cut_enddatetime_edit->timeEdit()->time(),
-		 cut_enddatetime_edit->timeEdit()->time());
+      cut_enddatetime_edit->
+	setTimeRange(cut_enddatetime_edit->time(),
+		     cut_enddatetime_edit->time());
     }
   }
   rec_evergreen_box->setEnabled(allow_modification);
@@ -649,42 +624,42 @@ void RecordCut::recordData()
       }
     }
     RDCart *cart=new RDCart(rec_cut->cartNumber());
-    cart->removeCutAudio(rdstation_conf,lib_user,rec_cut->cutName(),lib_config);
+    cart->removeCutAudio(rda->station(),rda->user(),rec_cut->cutName(),rda->config());
     delete cart;
-    switch(rdlibrary_conf->defaultFormat()) {
-	case 0:
-	  rec_cut->setCodingFormat(0);
-	  rec_format=RDCae::Pcm16;
-	  break;
+    switch(rda->libraryConf()->defaultFormat()) {
+    case 0:
+      rec_cut->setCodingFormat(0);
+      rec_format=RDCae::Pcm16;
+      break;
 
-	case 1:
-	  rec_cut->setCodingFormat(1);
-	  rec_format=RDCae::MpegL2;
-	  break;
+    case 1:
+      rec_cut->setCodingFormat(1);
+      rec_format=RDCae::MpegL2;
+      break;
 
-	case 2:
-	  rec_cut->setCodingFormat(2);
-	  rec_format=RDCae::Pcm24;
-	  break;
+    case 2:
+      rec_cut->setCodingFormat(2);
+      rec_format=RDCae::Pcm24;
+      break;
 
-	default:
-	  rec_cut->setCodingFormat(0);
-	  rec_format=RDCae::Pcm16;
-	  break;
+    default:
+      rec_cut->setCodingFormat(0);
+      rec_format=RDCae::Pcm16;
+      break;
     }
-    rec_samprate=lib_system->sampleRate();
+    rec_samprate=rda->system()->sampleRate();
     rec_cut->setSampleRate(rec_samprate);
-    rec_bitrate=rdlibrary_conf->defaultBitrate();
+    rec_bitrate=rda->libraryConf()->defaultBitrate();
     rec_cut->setBitRate(rec_bitrate);
     rec_channels=rec_channels_box->currentItem()+1;
     rec_cut->setChannels(rec_channels);
     rec_cut->setOriginDatetime(QDateTime::currentDateTime());
-    rec_cut->setOriginName(rdstation_conf->name());
-    cut_origin_name=rdstation_conf->name();
+    rec_cut->setOriginName(rda->station()->name());
+    cut_origin_name=rda->station()->name();
     cut_origin_datetime=QDateTime::currentDateTime();
     cut_ingest_edit->setText(cut_origin_name+" - "+
 			    cut_origin_datetime.toString("M/d/yyyy hh:mm:ss"));
-    rdcae->loadRecord(rec_card_no[0],rec_port_no[0],rec_name,rec_format,
+    rda->cae()->loadRecord(rec_card_no[0],rec_port_no[0],rec_name,rec_format,
 			rec_channels,rec_samprate,rec_bitrate*rec_channels);
   }
 }
@@ -696,24 +671,24 @@ void RecordCut::playData()
   int end=rec_cut->endPoint(true);
 
   if((!is_recording)&&(!is_playing)&&(!is_ready)) {  // Start Play
-    rdcae->loadPlay(rec_card_no[1],rec_cut->cutName(),
+    rda->cae()->loadPlay(rec_card_no[1],rec_cut->cutName(),
 		    &rec_stream_no[1],&rec_play_handle);
-    RDSetMixerOutputPort(rdcae,rec_card_no[1],rec_stream_no[1],rec_port_no[1]);
-    rdcae->positionPlay(rec_play_handle,start);
-    rdcae->setPlayPortActive(rec_card_no[1],rec_port_no[1],rec_stream_no[1]);
-    rdcae->setOutputVolume(rec_card_no[1],rec_stream_no[1],rec_port_no[1],
+    RDSetMixerOutputPort(rda->cae(),rec_card_no[1],rec_stream_no[1],rec_port_no[1]);
+    rda->cae()->positionPlay(rec_play_handle,start);
+    rda->cae()->setPlayPortActive(rec_card_no[1],rec_port_no[1],rec_stream_no[1]);
+    rda->cae()->setOutputVolume(rec_card_no[1],rec_stream_no[1],rec_port_no[1],
            0+rec_cut->playGain());
-    rdcae->play(rec_play_handle,end-start,RD_TIMESCALE_DIVISOR,false);
+    rda->cae()->play(rec_play_handle,end-start,RD_TIMESCALE_DIVISOR,false);
   }
   if(is_ready&&(!is_recording)) {
     if(rec_mode_box->currentItem()==1) {
-      rdcae->
-	record(rec_card_no[0],rec_port_no[0],rdlibrary_conf->maxLength(),
-	       rdlibrary_conf->voxThreshold());
+      rda->cae()->
+	record(rec_card_no[0],rec_port_no[0],rda->libraryConf()->maxLength(),
+	       rda->libraryConf()->voxThreshold());
     }
     else {
-      rdcae->
-	record(rec_card_no[0],rec_port_no[0],rdlibrary_conf->maxLength(),0);
+      rda->cae()->
+	record(rec_card_no[0],rec_port_no[0],rda->libraryConf()->maxLength(),0);
     }
   }
 }
@@ -722,15 +697,15 @@ void RecordCut::playData()
 void RecordCut::stopData()
 {
   if(is_playing) {
-    rdcae->stopPlay(rec_play_handle);
+    rda->cae()->stopPlay(rec_play_handle);
     return;
   }
   if(is_recording) {
-    rdcae->stopRecord(rec_card_no[0],rec_port_no[0]);
+    rda->cae()->stopRecord(rec_card_no[0],rec_port_no[0]);
     return;
   }
   if(is_ready) {
-    rdcae->unloadRecord(rec_card_no[0],rec_port_no[0]);
+    rda->cae()->unloadRecord(rec_card_no[0],rec_port_no[0]);
     rec_record_button->off();
     rec_play_button->off();
     rec_stop_button->on();
@@ -774,7 +749,7 @@ void RecordCut::playedData(int handle)
 
 void RecordCut::playStoppedData(int handle)
 {
-  rdcae->unloadPlay(rec_play_handle);
+  rda->cae()->unloadPlay(rec_play_handle);
   rec_timer->stop();
   rec_play_button->off();
   rec_stop_button->on();
@@ -793,7 +768,7 @@ void RecordCut::playStoppedData(int handle)
 void RecordCut::recordStoppedData(int card,int stream)
 {
   //printf("recordStoppedData()\n");
-  rdcae->unloadRecord(rec_card_no[0],rec_port_no[0]);
+  rda->cae()->unloadRecord(rec_card_no[0],rec_port_no[0]);
   rec_timer->stop();
   rec_play_button->off();
   rec_stop_button->on();
@@ -817,12 +792,12 @@ void RecordCut::recordUnloadedData(int card,int stream,unsigned len)
   s->setBitRate(rec_bitrate);
   s->setChannels(rec_channels);
   s->setFormat((RDSettings::Format)rec_format);
-  rec_cut->checkInRecording(rdstation_conf->name(),lib_user->name(),
-			    rdstation_conf->name(),s,len);
-  RDRehash::rehash(rdstation_conf,lib_user,lib_config,rec_cut->cartNumber(),
+  rec_cut->checkInRecording(rda->station()->name(),rda->user()->name(),
+			    rda->station()->name(),s,len);
+  RDRehash::rehash(rda->station(),rda->user(),rda->config(),rec_cut->cartNumber(),
 		   rec_cut->cutNumber());
   if(rec_trim_box->currentItem()==0) {
-    rec_cut->autoTrim(RDCut::AudioBoth,rdlibrary_conf->trimThreshold());
+    rec_cut->autoTrim(RDCut::AudioBoth,rda->libraryConf()->trimThreshold());
   }
   rec_length=rec_cut->length();
   if(is_closing) {
@@ -867,17 +842,17 @@ void RecordCut::closeData()
 			   tr("The End Date is prior to the Start Date!"));
       return;
     }
-    if((cut_enddatetime_edit->dateTime()<QDate::currentDate())&&
+    if((cut_enddatetime_edit->dateTime()<QDateTime::currentDateTime())&&
        (!rec_evergreen_box->isChecked())) {
       switch(QMessageBox::warning(this,tr("Invalid Date"),
 				  tr("The End Date has already passed!\nDo you still want to save?"),
 				  QMessageBox::Yes,QMessageBox::No)) {
-	  case QMessageBox::No:
-	  case QMessageBox::NoButton:
-	    return;
+      case QMessageBox::No:
+      case QMessageBox::NoButton:
+	return;
 
-	  default:
-	    break;
+      default:
+	break;
       }
     }
   }
@@ -969,9 +944,9 @@ void RecordCut::recTimerData()
 
 void RecordCut::aesAlarmData(int card,int port,bool state)
 {
-  if((card==rdlibrary_conf->inputCard())&&
-     (port==rdlibrary_conf->inputPort())) {
-    if(rdaudioport_conf->inputPortType(rdlibrary_conf->inputPort())!=
+  if((card==rda->libraryConf()->inputCard())&&
+     (port==rda->libraryConf()->inputPort())) {
+    if(rdaudioport_conf->inputPortType(rda->libraryConf()->inputPort())!=
        RDAudioPort::Analog) {
       if(state) {
 	rec_aes_alarm_label->hide();
@@ -989,12 +964,12 @@ void RecordCut::meterData()
   short levels[2];
 
   if(is_ready||is_recording) {
-    rdcae->inputMeterUpdate(rec_card_no[0],rec_port_no[0],levels);
+    rda->cae()->inputMeterUpdate(rec_card_no[0],rec_port_no[0],levels);
     rec_meter->setLeftSolidBar(levels[0]);
     rec_meter->setRightSolidBar(levels[1]);
   }
   if(is_playing) {
-    rdcae->outputMeterUpdate(rec_card_no[1],rec_port_no[1],levels);
+    rda->cae()->outputMeterUpdate(rec_card_no[1],rec_port_no[1],levels);
     rec_meter->setLeftSolidBar(levels[0]);
     rec_meter->setRightSolidBar(levels[1]);
   }
@@ -1005,21 +980,21 @@ void RecordCut::evergreenToggledData(bool state)
 {
   cut_weight_label->setDisabled(state);
   cut_weight_box->setDisabled(state);
-  cut_killdatetime_label->setDisabled(state);
+  cut_killdatetime_groupbox->setDisabled(state);
   cut_startdatetime_enable_button->setDisabled(state);
   cut_startdatetime_disable_button->setDisabled(state);
   cut_startdatetime_label->setDisabled(state);
   cut_startdatetime_edit->setDisabled(state);
   cut_enddatetime_edit->setDisabled(state);
   cut_enddatetime_label->setDisabled(state);
-  cut_daypart_label->setDisabled(state);
+  cut_daypart_groupbox->setDisabled(state);
   cut_starttime_enable_button->setDisabled(state);
   cut_starttime_disable_button->setDisabled(state);
   cut_starttime_edit->setDisabled(state);
   cut_starttime_label->setDisabled(state);
   cut_endtime_edit->setDisabled(state);
   cut_endtime_label->setDisabled(state);
-  rec_dayofweek_label->setDisabled(state);
+  rec_dayofweek_groupbox->setDisabled(state);
   for(int i=0;i<7;i++) {
     rec_weekpart_button[i]->setDisabled(state);
     rec_weekpart_label[i]->setDisabled(state);
@@ -1071,7 +1046,8 @@ void RecordCut::resizeEvent(QResizeEvent *e)
 
   cut_startdatetime_enable_button->setGeometry(40,223,100,20);
   cut_startdatetime_disable_button->setGeometry(40,243,100,20);
-  cut_killdatetime_label->setGeometry(50,201,100,19);
+  cut_killdatetime_groupbox->setGeometry(30,203,size().width()-60,65);
+
   cut_startdatetime_label->setGeometry(120,226,40,12);
   cut_startdatetime_edit->setGeometry(165,222,170,19);
   cut_enddatetime_label->setGeometry(120,245,40,12);
@@ -1079,13 +1055,13 @@ void RecordCut::resizeEvent(QResizeEvent *e)
 
   cut_starttime_enable_button->setGeometry(57,303,100,20);
   cut_starttime_disable_button->setGeometry(57,323,100,20);
-  cut_daypart_label->setGeometry(50,281,65,19);
+  cut_daypart_groupbox->setGeometry(37,283,size().width()-64,62);
   cut_starttime_label->setGeometry(137,306,80,12);
   cut_starttime_edit->setGeometry(222,302,90,19);
   cut_endtime_label->setGeometry(137,326,80,12);
   cut_endtime_edit->setGeometry(222,322,90,19);
 
-  rec_dayofweek_label->setGeometry(50,361,125,19);
+  rec_dayofweek_groupbox->setGeometry(20,359,size().width()-35,85);
   rec_weekpart_label[0]->setGeometry(62,378,80,20);
   rec_weekpart_button[0]->setGeometry(40,380,15,15);
   rec_weekpart_label[1]->setGeometry(142,378,80,20);
@@ -1100,8 +1076,8 @@ void RecordCut::resizeEvent(QResizeEvent *e)
   rec_weekpart_button[5]->setGeometry(80,420,15,15);
   rec_weekpart_label[6]->setGeometry(202,418,80,20);
   rec_weekpart_button[6]->setGeometry(180,420,15,15);
-  rec_set_button->setGeometry(sizeHint().width()-80,371,55,30);
-  rec_clear_button->setGeometry(sizeHint().width()-80,409,55,30);
+  rec_set_button->setGeometry(size().width()-80,372,55,30);
+  rec_clear_button->setGeometry(size().width()-80,410,55,30);
 
   rec_meter->setGeometry(20,453,rec_meter->geometry().width(),
 			 rec_meter->geometry().height());
@@ -1127,28 +1103,6 @@ void RecordCut::resizeEvent(QResizeEvent *e)
 }
 
 
-void RecordCut::paintEvent(QPaintEvent *e)
-{
-  QPainter *p=new QPainter(this);
-  if(rec_evergreen_box->isChecked()) {
-    p->setPen(palette().color(QPalette::Disabled,QColorGroup::Foreground));
-  }
-  else {
-    p->setPen(palette().color(QPalette::Active,QColorGroup::Foreground));
-  }
-  p->drawRect(30,208,sizeHint().width()-60,60);
-  p->drawRect(37,288,sizeHint().width()-74,60);
-  p->drawRect(20,369,sizeHint().width()-40,75);
-
-  /*
-  p->drawRect(30,275,sizeHint().width()-60,60);
-  p->drawRect(37,355,sizeHint().width()-74,60);
-  p->drawRect(20,436,sizeHint().width()-40,75);
-  */
-  p->end();
-}
-
-
 void RecordCut::closeEvent(QCloseEvent *e)
 {
   closeData();
@@ -1158,7 +1112,7 @@ void RecordCut::closeEvent(QCloseEvent *e)
 void RecordCut::AutoTrim(RDWaveFile *name)
 {
   if(name->hasEnergy()) {
-    rec_cut->setStartPoint(name->startTrim(rdlibrary_conf->trimThreshold()));
-    rec_cut->setEndPoint(name->endTrim(rdlibrary_conf->trimThreshold()));
+    rec_cut->setStartPoint(name->startTrim(rda->libraryConf()->trimThreshold()));
+    rec_cut->setEndPoint(name->endTrim(rda->libraryConf()->trimThreshold()));
   }
 }
