@@ -2,7 +2,7 @@
 //
 //   The Clock Carts ListView widget for RDLogManager.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,13 +19,14 @@
 //
 //
 
-#include <qdragobject.h>
-#include <qheader.h>
+#include <q3dragobject.h>
+#include <q3header.h>
+#include <QMouseEvent>
 
 #include <rdcart.h>
 
-#include <edit_note.h>
-#include <clock_listview.h>
+#include "clock_listview.h"
+#include "edit_note.h"
 
 ClockListView::ClockListView(QWidget *parent)
   : RDListView(parent)
@@ -35,7 +36,7 @@ ClockListView::ClockListView(QWidget *parent)
   //
   // Right Button Menu
   //
-  clock_menu=new QPopupMenu(this);
+  clock_menu=new Q3PopupMenu(this);
   connect(clock_menu,SIGNAL(aboutToShow()),this,SLOT(aboutToShowData()));
   clock_menu->
     insertItem(tr("Edit Event"),this,SLOT(editEventData()),0,0);
@@ -57,10 +58,10 @@ void ClockListView::editEventData()
 
 void ClockListView::contentsMousePressEvent(QMouseEvent *e)
 {
-  QListView::contentsMousePressEvent(e);
+  Q3ListView::contentsMousePressEvent(e);
   clock_menu_item=(RDListViewItem *)selectedItem();
   switch(e->button()) {
-      case QMouseEvent::RightButton:
+      case Qt::RightButton:
 	clock_menu->setGeometry(clock_parent->geometry().x()+
 				geometry().x()+e->pos().x()+2,
 				clock_parent->geometry().y()+
