@@ -2,7 +2,7 @@
 //
 // Edit Rivendell Log Clock
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,65 +18,44 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <vector>
-
-#include <math.h>
-
-#include <qdialog.h>
-#include <qstring.h>
-#include <qtextedit.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
 #include <qcolordialog.h>
-#include <qspinbox.h>
-#include <qcombobox.h>
 
-#include <rddb.h>
-#include <rd.h>
 #include <rdconf.h>
-#include <rdevent.h>
-#include <rdcreate_log.h>
 #include <rdescape_string.h>
 
-#include "edit_clock.h"
 #include "add_clock.h"
+#include "edit_clock.h"
+#include "edit_event.h"
 #include "edit_eventline.h"
 #include "edit_perms.h"
-#include "edit_event.h"
+#include "edit_schedrules.h"
 #include "globals.h"
 #include "list_clocks.h"
-#include "edit_schedrules.h"
-
 
 EditClock::EditClock(QString clockname,bool new_clock,
 		     std::vector<QString> *new_clocks,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QString str;
 
-  str=QString(tr("Edit Clock:"));
-  setCaption(QString().sprintf("%s %s",(const char *)str,
-			       (const char *)clockname));
   edit_name=clockname;
   edit_new_clock=new_clock;
   edit_new_clocks=new_clocks;
 
+  setWindowTitle("RDLogManager - "+tr("Edit Clock")+": "+clockname);
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Create Fonts
   //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
-  edit_title_font=new QFont("Helvetica",24,QFont::Bold);
+  edit_title_font=new QFont(labelFont().family(),24,QFont::Bold);
   edit_title_font->setPixelSize(24);
   edit_title_metrics=new QFontMetrics(*edit_title_font);
 
@@ -85,14 +64,14 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //
   edit_clockname_label=new QLabel(clockname,this);
   edit_clockname_label->setGeometry(10,10,280,20);
-  edit_clockname_label->setFont(bold_font);
+  edit_clockname_label->setFont(labelFont());
   edit_shortname_edit=new QLineEdit(this);
   edit_shortname_edit->setGeometry(350,10,40,20);
   edit_shortname_edit->setMaxLength(3);
   QLabel *label=new QLabel(edit_shortname_edit,tr("Code:"),this);
   label->setGeometry(295,10,50,20);
-  label->setFont(bold_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Clock List
@@ -101,74 +80,77 @@ EditClock::EditClock(QString clockname,bool new_clock,
   edit_clocks_list->setGeometry(10,35,CENTER_LINE-20,sizeHint().height()-250);
   edit_clocks_list->setAllColumnsShowFocus(true);
   edit_clocks_list->setItemMargin(5);
+  edit_clocks_list->setSorting(-1);
   edit_clocks_list->addColumn(tr("Start"));
   edit_clocks_list->addColumn(tr("End"));
   edit_clocks_list->addColumn(tr("Event"));
   edit_clocks_list->addColumn(tr("Length"));
-  edit_clocks_list->setColumnAlignment(3,AlignRight);
+  edit_clocks_list->setColumnAlignment(3,Qt::AlignRight);
   edit_clocks_list->addColumn(tr("Count"));
-  edit_clocks_list->setColumnAlignment(4,AlignCenter);
+  edit_clocks_list->setColumnAlignment(4,Qt::AlignCenter);
+  edit_clocks_list->setColumnSortType(4,RDListView::LineSort);
+  edit_clocks_list->setHardSortColumn(4);
   connect(edit_clocks_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
-	  this,SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
-  connect(edit_clocks_list,SIGNAL(selectionChanged(QListViewItem *)),
-	  this,SLOT(selectionChangedData(QListViewItem *)));
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
+	  this,SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
+  connect(edit_clocks_list,SIGNAL(selectionChanged(Q3ListViewItem *)),
+	  this,SLOT(selectionChangedData(Q3ListViewItem *)));
   connect(edit_clocks_list,SIGNAL(editLine(int)),
 	  this,SLOT(editEventData(int)));
 
   //
   //  Add Button
   //
-  QPushButton *button=new QPushButton(this);
-  button->setGeometry(10,sizeHint().height()-210,80,50);
-  button->setFont(bold_font);
-  button->setText(tr("&Add"));
-  connect(button,SIGNAL(clicked()),this,SLOT(addData()));
+  edit_add_button=new QPushButton(this);
+  edit_add_button->setGeometry(10,sizeHint().height()-210,80,50);
+  edit_add_button->setFont(buttonFont());
+  edit_add_button->setText(tr("&Add"));
+  connect(edit_add_button,SIGNAL(clicked()),this,SLOT(addData()));
 
   //
   //  Clone Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(110,sizeHint().height()-210,80,50);
-  button->setFont(bold_font);
-  button->setText(tr("&Clone"));
-  connect(button,SIGNAL(clicked()),this,SLOT(cloneData()));
+  edit_clone_button=new QPushButton(this);
+  edit_clone_button->setGeometry(110,sizeHint().height()-210,80,50);
+  edit_clone_button->setFont(buttonFont());
+  edit_clone_button->setText(tr("&Clone"));
+  connect(edit_clone_button,SIGNAL(clicked()),this,SLOT(cloneData()));
   
   //
   //  Edit Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(210,sizeHint().height()-210,80,50);
-  button->setFont(bold_font);
-  button->setText(tr("&Edit"));
-  connect(button,SIGNAL(clicked()),this,SLOT(editData()));
+  edit_edit_button=new QPushButton(this);
+  edit_edit_button->setGeometry(210,sizeHint().height()-210,80,50);
+  edit_edit_button->setFont(buttonFont());
+  edit_edit_button->setText(tr("&Edit"));
+  connect(edit_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
 
   //
   //  Delete Button
   //
-  button=new QPushButton(this);
-  button->setGeometry(310,sizeHint().height()-210,80,50);
-  button->setFont(bold_font);
-  button->setText(tr("&Delete"));
-  connect(button,SIGNAL(clicked()),this,SLOT(deleteData()));
+  edit_delete_button=new QPushButton(this);
+  edit_delete_button->setGeometry(310,sizeHint().height()-210,80,50);
+  edit_delete_button->setFont(buttonFont());
+  edit_delete_button->setText(tr("&Delete"));
+  connect(edit_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
   //
   // Remarks
   //
   edit_remarks_edit=new QTextEdit(this);
   edit_remarks_edit->setGeometry(10,sizeHint().height()-140,CENTER_LINE-20,130);
-  edit_remarks_edit->setTextFormat(QTextEdit::PlainText);
+  edit_remarks_edit->setTextFormat(Qt::PlainText);
   label=new QLabel(edit_remarks_edit,tr("Remarks"),this);
   label->setGeometry(15,sizeHint().height()-155,CENTER_LINE-20,15);
-  label->setFont(bold_font);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   //  Scheduler-Rules button
   //
-  button=new QPushButton(this);
-  button->setGeometry(CENTER_LINE+20,sizeHint().height()-60,70,50);
-  button->setFont(bold_font);
+  QPushButton *button=new QPushButton(this);
+  button->setGeometry(CENTER_LINE+10,sizeHint().height()-60,80,50);
+  button->setFont(buttonFont());
   button->setText(tr("Scheduler\nRules"));
   connect(button,SIGNAL(clicked()),this,SLOT(schedRules()));
 
@@ -177,7 +159,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //
   button=new QPushButton(this);
   button->setGeometry(CENTER_LINE+110,sizeHint().height()-60,70,50);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Save"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveData()));
 
@@ -186,7 +168,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //
   button=new QPushButton(this);
   button->setGeometry(CENTER_LINE+190,sizeHint().height()-60,70,50);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("Save &As"));
   connect(button,SIGNAL(clicked()),this,SLOT(saveAsData()));
 
@@ -196,7 +178,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   button=new QPushButton(this);
   button->setGeometry(CENTER_LINE+(sizeHint().width()-CENTER_LINE)/2-25,
 		      sizeHint().height()-60,70,50);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Services\nList"));
   connect(button,SIGNAL(clicked()),this,SLOT(svcData()));
 
@@ -207,7 +189,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   edit_color_button->
     setGeometry(CENTER_LINE+(sizeHint().width()-CENTER_LINE)/2+55,
 		sizeHint().height()-60,70,50);
-  edit_color_button->setFont(bold_font);
+  edit_color_button->setFont(buttonFont());
   edit_color_button->setText(tr("Colo&r"));
   connect(edit_color_button,SIGNAL(clicked()),this,SLOT(colorData()));
 
@@ -225,7 +207,7 @@ EditClock::EditClock(QString clockname,bool new_clock,
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-160,sizeHint().height()-60,70,50);
   button->setDefault(true);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&OK"));
   connect(button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -234,15 +216,15 @@ EditClock::EditClock(QString clockname,bool new_clock,
   //
   button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-80,sizeHint().height()-60,70,50);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Cancel"));
   connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Populate Data
   //
-  sched_rules_list = new SchedRulesList(clockname,log_config);
-  edit_clock=new RDClock();
+  sched_rules_list = new RDSchedRulesList(clockname,rda->config());
+  edit_clock=new RDClock(rda->station());
   edit_clock->setName(clockname);
   edit_clock->load();
   edit_shortname_edit->setText(edit_clock->shortName());
@@ -268,7 +250,7 @@ QSizePolicy EditClock::sizePolicy() const
 }
 
 
-void EditClock::selectionChangedData(QListViewItem *l)
+void EditClock::selectionChangedData(Q3ListViewItem *l)
 {
   if(l==NULL) {
     UpdateClock();
@@ -286,27 +268,23 @@ void EditClock::selectionChangedData(QListViewItem *l)
 void EditClock::addData()
 {
   int line=0;
-  RDEventLine eventline;
-
-  RDListViewItem *item=(RDListViewItem *)edit_clocks_list->selectedItem();
-  if(item!=NULL) {
-    if(item->text(4).isEmpty()) {
-      line=edit_clock->size();
-    }
-    else {
-      line=item->text(4).toInt();
-    }
-  }
+  RDEventLine eventline(rda->station());
   EditEventLine *edit_eventline=
     new EditEventLine(&eventline,edit_clock,-1,this);
   if(edit_eventline->exec()<0) {
     return;
   }
   delete edit_eventline;
-  edit_clock->insert(eventline.name(),line);
-  edit_clock->eventLine(line)->setStartTime(eventline.startTime());
-  edit_clock->eventLine(line)->setLength(eventline.length());
-  edit_clock->eventLine(line)->load();
+  if(line<0) {
+    line=edit_clock->size();
+  }
+  line=edit_clock->
+    insert(eventline.name(),eventline.startTime(),eventline.length());
+  if(line<0) {
+    QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			 tr("That event does not exist."));
+    return;
+  }
   edit_modified=true;
   RefreshList(line);
 }
@@ -322,6 +300,9 @@ void EditClock::editData()
     return;
   }
   int line=item->text(4).toInt();
+  if(line<0) {
+    return;
+  }
   EditEventLine *edit_eventline=
     new EditEventLine(edit_clock->eventLine(line),edit_clock,line,this);
   if(edit_eventline->exec()<0) {
@@ -347,10 +328,13 @@ void EditClock::cloneData()
   
   RDEventLine *selectedEventLine = edit_clock->eventLine(line);
 
-  RDEventLine eventline;
+  RDEventLine eventline(rda->station());
   eventline.setName(selectedEventLine->name());
   eventline.setStartTime(selectedEventLine->startTime().addMSecs(selectedEventLine->length()));
   eventline.setLength(selectedEventLine->length());
+  if(eventline.startTime().addMSecs(eventline.length()).hour()) {
+    eventline.setLength(0);
+  }
   
   EditEventLine *edit_eventline=
     new EditEventLine(&eventline,edit_clock,-1,this);
@@ -359,14 +343,18 @@ void EditClock::cloneData()
     return;
   }
   delete edit_eventline;
-  edit_clock->insert(eventline.name(),line);
-  edit_clock->eventLine(line)->setStartTime(eventline.startTime());
-  edit_clock->eventLine(line)->setLength(eventline.length());
-  edit_clock->eventLine(line)->load();
+  line=edit_clock->
+    insert(eventline.name(),eventline.startTime(),eventline.length());
+  if(line<0) {
+    QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			 tr("That event does not exist."));
+    return;
+  }
   edit_modified=true;
   RefreshList(line);
 }
 
+
 void EditClock::deleteData()
 {
   QString str;
@@ -379,10 +367,9 @@ void EditClock::deleteData()
     return;
   }
   str=QString(tr("Are you sure you want to delete\n"));
-  if(QMessageBox::question(this,tr("Delete Event"),
-			   QString().sprintf("%s \'(%s) %s\'?",(const char *)str,
-			 (const char *)item->text(0),
-			 (const char *)item->text(2)),
+  if(QMessageBox::question(this,"RDLogManager - "+tr("Delete Event"),
+			   tr("Are you sure you want to delete")+
+			   "\n \"("+item->text(0)+") "+item->text(2)+"\"?",
 			  QMessageBox::Yes,QMessageBox::No)!=
      QMessageBox::Yes) {
     return;
@@ -443,7 +430,6 @@ void EditClock::saveAsData()
   QString clockname=edit_name;
   QString sql;
   RDSqlQuery *q;
-  QString str;
 
   if(!ValidateCode()) {
     return;
@@ -468,9 +454,8 @@ void EditClock::saveAsData()
     return;
   }
   sql=
-    QString().sprintf("select SHORT_NAME from CLOCKS where SHORT_NAME=\"%s\"",
-		      (const char *)
-		      RDEscapeString(edit_shortname_edit->text()));
+    QString("select SHORT_NAME from CLOCKS where ")+
+    "SHORT_NAME=\""+RDEscapeString(edit_shortname_edit->text())+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     QMessageBox::warning(this,tr("Code Exists"),
@@ -487,8 +472,8 @@ void EditClock::saveAsData()
   }
   delete addclock;
   edit_name=clockname;
-  sql=QString().sprintf("select NAME from CLOCKS where NAME=\"%s\"",
-			(const char *)clockname);
+  sql=QString("select NAME from CLOCKS where ")+
+    "NAME=\""+RDEscapeString(clockname)+"\"";
   q=new RDSqlQuery(sql);
   if(q->first()) {
     if(QMessageBox::question(this,tr("Clock Exists"),
@@ -499,10 +484,6 @@ void EditClock::saveAsData()
   }
   delete q;
   edit_clock->setName(clockname);
-  sql=RDCreateClockTableSql(RDClock::tableName(clockname),log_config);
-  q=new RDSqlQuery(sql);
-  delete q;
-
 
   Save();
   edit_new_clocks->push_back(clockname);
@@ -512,13 +493,11 @@ void EditClock::saveAsData()
   }
   edit_clockname_label->setText(clockname);
   UpdateClock();
-  str=QString(tr("Edit Clock:"));
-  setCaption(QString().sprintf("%s %s",(const char *)str,
-			       (const char *)edit_name));
+  setCaption("RDLogManager - "+tr("Edit Clock")+": "+edit_name);
 }
 
 
-void EditClock::doubleClickedData(QListViewItem *item,const QPoint &,int)
+void EditClock::doubleClickedData(Q3ListViewItem *item,const QPoint &,int)
 {
   editData();
 }
@@ -526,8 +505,8 @@ void EditClock::doubleClickedData(QListViewItem *item,const QPoint &,int)
 
 void EditClock::colorData()
 {
-  QColor color=QColorDialog::getColor(edit_color_button->backgroundColor(),
-				      this,"color_dialog");
+  QColor color=
+    QColorDialog::getColor(edit_color_button->backgroundColor(),this);
   if(color.isValid()) {
     edit_color_button->setPalette(QPalette(color,backgroundColor()));
   }
@@ -567,17 +546,17 @@ void EditClock::cancelData()
   if(edit_modified) {
     switch(QMessageBox::question(this,tr("Clock Modified"),
 				 tr("The clock has been modified.\nDo you want to save?"),QMessageBox::Yes,QMessageBox::No,QMessageBox::Cancel)) {
-	case QMessageBox::Yes:
-	  Save();
-	  done(0);
-	  break;
+    case QMessageBox::Yes:
+      Save();
+      done(0);
+      break;
 
-	case QMessageBox::No:
-	  done(-1);
-	  break;
+    case QMessageBox::No:
+      done(-1);
+      break;
 
-	case QMessageBox::NoButton:
-	  return;
+    case QMessageBox::NoButton:
+      return;
     }
   }
   else {
@@ -589,9 +568,8 @@ void EditClock::cancelData()
 void EditClock::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
-  p->moveTo(CENTER_LINE,10);
-  p->lineTo(CENTER_LINE,sizeHint().height()-10);
+  p->setPen(QColor(Qt::black));
+  p->drawLine(CENTER_LINE,10,CENTER_LINE,sizeHint().height()-10);
 
   p->end();
 }
@@ -621,17 +599,10 @@ void EditClock::Save()
 void EditClock::RefreshList(int select_line)
 {
   UpdateClock();
-  RDListViewItem *prev_item=(RDListViewItem *)edit_clocks_list->selectedItem();
-
-  if((prev_item!=NULL)&&(select_line>=0)) {
-    select_line=prev_item->text(4).toInt();
-  }
   RDListViewItem *item;
   RDEventLine *eventline;
 
   edit_clocks_list->clear();
-  item=new RDListViewItem(edit_clocks_list);
-  item->setText(2,tr("--- End of clock ---"));
   for(int i=edit_clock->size()-1;i>=0;i--) {
     if((eventline=edit_clock->eventLine(i))!=NULL) {
       item=new RDListViewItem(edit_clocks_list);
@@ -640,9 +611,7 @@ void EditClock::RefreshList(int select_line)
 		    addMSecs(eventline->length()).toString("mm:ss.zzz").
 		    left(7));
       item->setText(3,RDGetTimeLength(eventline->length(),false,true));
-      item->setText(2,QString().sprintf("%s [%s]",
-		    (const char *)eventline->name(),
-		    (const char *)eventline->properties()));
+      item->setText(2,eventline->name()+" ["+eventline->properties()+"]");
       item->setText(4,QString().sprintf("%d",i));
       if(eventline->color().isValid()) {
 	item->setBackgroundColor(eventline->color());
@@ -664,15 +633,11 @@ void EditClock::RefreshNames()
   while(item!=NULL) {
     if(!item->text(4).isEmpty()) {
       if((eventline=edit_clock->eventLine(item->text(4).toInt()))!=NULL) {
-	sql=QString().sprintf("select PROPERTIES from EVENTS\
-                               where NAME=\"%s\"",
-			      (const char *)RDEscapeString(eventline->name()));
+	sql=QString("select PROPERTIES from EVENTS where ")+
+	  "NAME=\""+RDEscapeString(eventline->name())+"\"";
 	q=new RDSqlQuery(sql);
 	if(q->next()) {
-	  item->
-	    setText(2,QString().sprintf("%s [%s]",
-					(const char *)eventline->name(),
-					(const char *)q->value(0).toString()));
+	  item->setText(2,eventline->name()+" ["+q->value(0).toString()+"]");
 	}
 	delete q;
       }
@@ -688,8 +653,8 @@ void EditClock::UpdateClock(int line)
   map->fill();
   QPainter *p=new QPainter();
   p->begin(map);
-  p->setPen(QColor(black));
-  p->setBrush(QColor(black));
+  p->setPen(Qt::black);
+  p->setBrush(Qt::black);
   p->setFont(*edit_title_font);
 
   //
@@ -736,6 +701,10 @@ void EditClock::UpdateClock(int line)
   delete p;
   edit_clock_label->setPixmap(*map);
   delete map;
+
+  edit_clone_button->setDisabled(line<0);
+  edit_edit_button->setDisabled(line<0);
+  edit_delete_button->setDisabled(line<0);
 }
 
 
@@ -745,15 +714,13 @@ void EditClock::CopyClockPerms(QString old_name,QString new_name)
   RDSqlQuery *q;
   RDSqlQuery *q1;
 
-  sql=QString().sprintf("select SERVICE_NAME from CLOCK_PERMS where\
-                         CLOCK_NAME=\"%s\"",
-			(const char *)RDEscapeString(old_name));
+  sql=QString("select SERVICE_NAME from CLOCK_PERMS where ")+
+    "CLOCK_NAME=\""+RDEscapeString(old_name)+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    sql=QString().sprintf("insert into CLOCK_PERMS set\
-                          CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			  (const char *)RDEscapeString(new_name),
-			  (const char *)RDEscapeString(q->value(0).toString()));
+    sql=QString("insert into CLOCK_PERMS set ")+
+      "CLOCK_NAME=\""+RDEscapeString(new_name)+"\","+
+      "SERVICE_NAME=\""+RDEscapeString(q->value(0).toString())+"\"";
     q1=new RDSqlQuery(sql);
     delete q1;
   }
@@ -766,34 +733,28 @@ void EditClock::AbandonClock(QString name)
   if(name==edit_name) {
     return;
   }
-  QString sql=QString().sprintf("delete from CLOCKS where NAME=\"%s\"",
-				(const char *)name);
-  RDSqlQuery *q=new RDSqlQuery(sql);
-  delete q;
-
-  sql=QString("drop table `")+RDClock::tableName(name)+"`";
-  q=new RDSqlQuery(sql);
-  delete q;
+  QString sql=QString("delete from CLOCKS where ")+
+    "NAME=\""+RDEscapeString(name)+"\"";
+  RDSqlQuery::apply(sql);
+  sql=QString("delete from CLOCK_LINES where ")+
+    "CLOCK_NAME=\""+RDEscapeString(name)+"\"";
+  RDSqlQuery::apply(sql);
 }
 
 
 bool EditClock::ValidateCode()
 {
   if(edit_shortname_edit->text().isEmpty()) {
-    QMessageBox::information(this,tr("Invalid Code"),
+    QMessageBox::information(this,"RDLogManager - "+tr("Invalid Code"),
 			     tr("You must provide a clock code!"));
     return false;
   }
-  RDSqlQuery *q=
-    new RDSqlQuery(QString().
-		  sprintf("select SHORT_NAME from CLOCKS\
-                                     where (SHORT_NAME=\"%s\")&&\
-                                     (NAME!=\"%s\")",
-			  (const char *)
-			  RDEscapeString(edit_shortname_edit->text()),
-			  (const char *)RDEscapeString(edit_name)));
+  QString sql=QString("select SHORT_NAME from CLOCKS where ")+
+    "(SHORT_NAME=\""+RDEscapeString(edit_shortname_edit->text())+"\")&&"+
+    "(NAME!=\""+RDEscapeString(edit_name)+"\")";
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->next()) {
-    QMessageBox::information(this,tr("Duplicate Code"),
+    QMessageBox::information(this,"RDLogManager - "+tr("Duplicate Code"),
 			     tr("That code is already in use!"));
     delete q;
     return false;
