@@ -2,7 +2,7 @@
 //
 // Edit Rivendell Log Grid
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,72 +18,44 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <vector>
-
-#include <math.h>
-
-#include <qdialog.h>
-#include <qstring.h>
-#include <qtextedit.h>
-#include <qpainter.h>
 #include <qmessagebox.h>
-#include <qcolordialog.h>
+#include <qpainter.h>
 #include <qsignalmapper.h>
 
-#include <rddb.h>
-#include <rd.h>
 #include <rdescape_string.h>
-#include <rdevent.h>
-#include <rdcreate_log.h>
 
-#include <edit_grid.h>
-#include <list_clocks.h>
-#include <edit_clock.h>
+#include "edit_clock.h"
+#include "edit_grid.h"
+#include "list_clocks.h"
 
 EditGrid::EditGrid(QString servicename,QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QString sql;
-  QString str;
-
-  str=QString(tr("Edit Grid:"));
-  setCaption(QString().sprintf("%s %s",(const char *)str,
-			       (const char *)servicename));
   edit_servicename=servicename;
 
+  setWindowTitle("RDLogManager - "+tr("Edit Grid")+": "+servicename);
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
-  QFont button_font("Helvetica",10,QFont::Normal);
-  button_font.setPixelSize(10);
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Hour Buttons
   //
-  QLabel *label;
+  //  QLabel *label;
   QSignalMapper *mapper=new QSignalMapper(this);
   connect(mapper,SIGNAL(mapped(int)),this,SLOT(hourButtonData(int)));
   for(int i=0;i<5;i++) {
-    label=new QLabel(QDate::longDayName(i+1),this);
-    label->setGeometry(20,14+75*i,90,16);
-    label->setFont(bold_font);
-    label->setAlignment(AlignCenter);
+    edit_day_boxes[i]=new QGroupBox(QDate::longDayName(i+1),this);
+    edit_day_boxes[i]->setFont(labelFont());
+    edit_day_boxes[i]->setGeometry(5,11+75*i,sizeHint().width()-5,65);
     for(int j=0;j<24;j++) {
       edit_hour_button[i][j]=new RDPushButton(this);
       edit_hour_button[i][j]->setGeometry(10+42*j,30+75*i,42,40);
-      edit_hour_button[i][j]->setFont(button_font);
+      edit_hour_button[i][j]->setFont(subButtonFont());
       edit_hour_button[i][j]->setId(24*i+j);
       LabelButton(i+1,j,"---");
       mapper->setMapping(edit_hour_button[i][j],24*i+j);
@@ -93,14 +65,13 @@ EditGrid::EditGrid(QString servicename,QWidget *parent)
     }
   }
   for(int i=5;i<7;i++) {
-    label=new QLabel(QDate::longDayName(i+1),this);
-    label->setGeometry(20,44+75*i,90,16);
-    label->setFont(bold_font);
-    label->setAlignment(AlignCenter);
+    edit_day_boxes[i]=new QGroupBox(QDate::longDayName(i+1),this);
+    edit_day_boxes[i]->setFont(labelFont());
+    edit_day_boxes[i]->setGeometry(5,41+75*i,sizeHint().width()-5,65);
     for(int j=0;j<24;j++) {
       edit_hour_button[i][j]=new RDPushButton(this);
       edit_hour_button[i][j]->setGeometry(10+42*j,60+75*i,42,40);
-      edit_hour_button[i][j]->setFont(button_font);
+      edit_hour_button[i][j]->setFont(subButtonFont());
       edit_hour_button[i][j]->setId(24*i+j);
       LabelButton(i+1,j,"---");
       mapper->setMapping(edit_hour_button[i][j],24*i+j);
@@ -113,7 +84,7 @@ EditGrid::EditGrid(QString servicename,QWidget *parent)
   //
   // Right Button Menu
   //
-  edit_right_menu=new QPopupMenu(this);
+  edit_right_menu=new Q3PopupMenu(this);
   connect(edit_right_menu,SIGNAL(aboutToShow()),this,SLOT(aboutToShowData()));
   edit_right_menu->
     insertItem(tr("Edit Clock"),this,SLOT(editClockData()),0,0);
@@ -126,7 +97,7 @@ EditGrid::EditGrid(QString servicename,QWidget *parent)
   QPushButton *all_button=new QPushButton(this);
   all_button->setGeometry(10,sizeHint().height()-60,80,50);
   all_button->setDefault(false);
-  all_button->setFont(bold_font);
+  all_button->setFont(buttonFont());
   all_button->setText(tr("Change\n&All"));
   connect(all_button,SIGNAL(clicked()),this,SLOT(allHourButtonData()));
                       
@@ -136,7 +107,7 @@ EditGrid::EditGrid(QString servicename,QWidget *parent)
   QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setDefault(true);
-  button->setFont(bold_font);
+  button->setFont(buttonFont());
   button->setText(tr("&Close"));
   connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -282,8 +253,9 @@ void EditGrid::closeData()
 
 void EditGrid::paintEvent(QPaintEvent *e)
 {
+  /*
   QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
+  p->setPen(Qt::black);
   for(int i=0;i<5;i++) {
     p->drawRect(5,21+75*i,sizeHint().width()-10,55);
   }
@@ -291,6 +263,7 @@ void EditGrid::paintEvent(QPaintEvent *e)
     p->drawRect(5,51+75*i,sizeHint().width()-10,55);
   }
   p->end();
+  */
 }
 
 
@@ -315,9 +288,11 @@ void EditGrid::LabelButton(int dayofweek,int hour,QString clockname)
   QString code=QString("---");
   QColor color=backgroundColor();
 
-  QString sql=QString().sprintf("select SHORT_NAME,COLOR from CLOCKS\
-                                 where NAME=\"%s\"",
-				(const char *)clockname);
+  QString sql=QString("select ")+
+    "SHORT_NAME,"+  // 00
+    "COLOR "+       // 01
+    "from CLOCKS where "+
+    "NAME=\""+RDEscapeString(clockname)+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     code=q->value(0).toString();
@@ -326,7 +301,7 @@ void EditGrid::LabelButton(int dayofweek,int hour,QString clockname)
     }
   }
   edit_hour_button[dayofweek-1][hour]->
-    setText(QString().sprintf("%02d-%02d\n%s",hour,hour+1,(const char *)code));
+    setText(QString().sprintf("%02d-%02d\n",hour,hour+1)+code);
   edit_hour_button[dayofweek-1][hour]->
     setPalette(QPalette(color,backgroundColor()));
 }
