@@ -2,7 +2,7 @@
 //
 // Generate a Rivendell Log
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,28 +18,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-
-#include <qdialog.h>
-#include <qstring.h>
-#include <qdatetimeedit.h>
 #include <qmessagebox.h>
-#include <qfile.h>
-#include <qtimer.h>
 
-#include <rddb.h>
-#include <rddatedialog.h>
-#include <rdsvc.h>
 #include <rddatedecode.h>
+#include <rddatedialog.h>
 #include <rdlog.h>
-#include <rd.h>
-#include <rdexception_dialog.h>
+#include <rdsvc.h>
 #include <rdtextfile.h>
-#include <rdcreate_log.h>
 
-#include <generate_log.h>
-#include <edit_grid.h>
-#include <globals.h>
+#include "edit_grid.h"
+#include "generate_log.h"
+#include "globals.h"
 
 //
 // Icons
@@ -48,10 +37,9 @@
 #include "../icons/greenball.xpm"
 #include "../icons/redball.xpm"
 
-
 GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
 			 QDate *cmd_date)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
   QStringList services_list;
   bool  cmdservicefit=false;
@@ -59,9 +47,7 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   cmdservice = cmd_service;
   cmddate = cmd_date;
 
-  QString str1=tr("Generate Log - User: ");
-  setCaption(QString().sprintf("%s%s",(const char *)str1,
-			       (const char *)rdripc->user()));
+  setWindowTitle("RDLogManager - "+tr("Generate Log"));
 
   gen_music_enabled=false;
   gen_traffic_enabled=false;
@@ -69,20 +55,8 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Bold);
-  small_font.setPixelSize(10);
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Create Icons
@@ -94,8 +68,8 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   //
   // Progress Dialog
   //
-  gen_progress_dialog=new QProgressDialog(tr("Generating Log..."),tr("Cancel"),
-					  24,this,"gen_progress_dialog",true);
+  gen_progress_dialog=
+    new QProgressDialog(tr("Generating Log..."),tr("Cancel"),0,24,this);
   gen_progress_dialog->setCaption("Progress");
   gen_progress_dialog->setCancelButton(NULL);
 
@@ -106,19 +80,15 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   connect(gen_service_box,SIGNAL(activated(int)),
 	  this,SLOT(serviceActivatedData(int)));
   gen_service_label=new QLabel(gen_service_box,tr("Service:"),this);
-  gen_service_label->setFont(bold_font);
-  gen_service_label->setAlignment(AlignRight|AlignVCenter);
+  gen_service_label->setFont(labelFont());
+  gen_service_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
-  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
-    services_list = rduser->services();
-  } else { // RDStation::HostSec
-    QString sql="select NAME from SERVICES";
-    RDSqlQuery *q=new RDSqlQuery(sql);
-    while(q->next()) {
-      services_list.append( q->value(0).toString() );
-    }
-    delete q;
+  QString sql="select NAME from SERVICES";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+    services_list.append( q->value(0).toString() );
   }
+  delete q;
   for ( QStringList::Iterator it = services_list.begin(); 
         it != services_list.end();
         ++it ) {
@@ -131,22 +101,23 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   // Date
   //
   gen_date_edit=new QDateEdit(this);
+  gen_date_edit->setDisplayFormat("MM/dd/yyyy");
   gen_date_label=new QLabel(gen_date_edit,tr("Date:"),this);
-  gen_date_label->setFont(bold_font);
-  gen_date_label->setAlignment(AlignRight|AlignVCenter);
+  gen_date_label->setFont(labelFont());
+  gen_date_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   if (cmdswitch==0)
   gen_date_edit->setDate(QDate::currentDate().addDays(1));
   else
     gen_date_edit->setDate(*cmddate);
 
-  connect(gen_date_edit,SIGNAL(valueChanged(const QDate &)),
+  connect(gen_date_edit,SIGNAL(dateChanged(const QDate &)),
 	  this,SLOT(dateChangedData(const QDate &)));
 
   //
   // Date Select Button
   //
   gen_select_button=new QPushButton(this);
-  gen_select_button->setFont(bold_font);
+  gen_select_button->setFont(subButtonFont());
   gen_select_button->setText(tr("&Select"));
   connect(gen_select_button,SIGNAL(clicked()),this,SLOT(selectDateData()));
 
@@ -154,7 +125,7 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   //  Create Log Button
   //
   gen_create_button=new QPushButton(this);
-  gen_create_button->setFont(bold_font);
+  gen_create_button->setFont(buttonFont());
   gen_create_button->setText(tr("&Create New Log"));
   connect(gen_create_button,SIGNAL(clicked()),this,SLOT(createData()));
 
@@ -162,7 +133,7 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   //  Merge Music Log Button
   //
   gen_music_button=new QPushButton(this);
-  gen_music_button->setFont(bold_font);
+  gen_music_button->setFont(buttonFont());
   gen_music_button->setText(tr("Merge &Music"));
   connect(gen_music_button,SIGNAL(clicked()),this,SLOT(musicData()));
 
@@ -170,7 +141,7 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   //  Merge Traffic Log Button
   //
   gen_traffic_button=new QPushButton(this);
-  gen_traffic_button->setFont(bold_font);
+  gen_traffic_button->setFont(buttonFont());
   gen_traffic_button->setText(tr("Merge &Traffic"));
   connect(gen_traffic_button,SIGNAL(clicked()),this,SLOT(trafficData()));
 
@@ -180,42 +151,42 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   // Headers
   //
   gen_import_label=new QLabel(tr("Import Data"),this);
-  gen_import_label->setFont(bold_font);
-  gen_import_label->setAlignment(AlignCenter);
+  gen_import_label->setFont(labelFont());
+  gen_import_label->setAlignment(Qt::AlignCenter);
 
   gen_available_label=new QLabel(tr("Available"),this);
-  gen_available_label->setFont(small_font);
-  gen_available_label->setAlignment(AlignCenter);
+  gen_available_label->setFont(subLabelFont());
+  gen_available_label->setAlignment(Qt::AlignCenter);
 
   gen_merged_label=new QLabel(tr("Merged"),this);
-  gen_merged_label->setFont(small_font);
-  gen_merged_label->setAlignment(AlignCenter);
+  gen_merged_label->setFont(subLabelFont());
+  gen_merged_label->setAlignment(Qt::AlignCenter);
 
   //
   // Music Indicators
   //
   gen_mus_avail_label=new QLabel(this);
   gen_mus_avail_label->setPixmap(*gen_whiteball_map);
-  gen_mus_avail_label->setFont(small_font);
-  gen_mus_avail_label->setAlignment(AlignCenter);
+  gen_mus_avail_label->setFont(subLabelFont());
+  gen_mus_avail_label->setAlignment(Qt::AlignCenter);
 
   gen_mus_merged_label=new QLabel(this);
   gen_mus_merged_label->setPixmap(*gen_whiteball_map);
-  gen_mus_merged_label->setFont(small_font);
-  gen_mus_merged_label->setAlignment(AlignCenter);
+  gen_mus_merged_label->setFont(subLabelFont());
+  gen_mus_merged_label->setAlignment(Qt::AlignCenter);
 
   //
   // Traffic Indicators
   //
   gen_tfc_avail_label=new QLabel(this);
   gen_tfc_avail_label->setPixmap(*gen_whiteball_map);
-  gen_tfc_avail_label->setFont(small_font);
-  gen_tfc_avail_label->setAlignment(AlignCenter);
+  gen_tfc_avail_label->setFont(subLabelFont());
+  gen_tfc_avail_label->setAlignment(Qt::AlignCenter);
 
   gen_tfc_merged_label=new QLabel(this);
   gen_tfc_merged_label->setPixmap(*gen_whiteball_map);
-  gen_tfc_merged_label->setFont(small_font);
-  gen_tfc_merged_label->setAlignment(AlignCenter);
+  gen_tfc_merged_label->setFont(subLabelFont());
+  gen_tfc_merged_label->setAlignment(Qt::AlignCenter);
 
 
   //
@@ -223,7 +194,7 @@ GenerateLog::GenerateLog(QWidget *parent,int cmd_switch,QString *cmd_service,
   //
   gen_close_button=new QPushButton(this);
   gen_close_button->setDefault(true);
-  gen_close_button->setFont(bold_font);
+  gen_close_button->setFont(buttonFont());
   gen_close_button->setText(tr("C&lose"));
   connect(gen_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -299,24 +270,24 @@ void GenerateLog::createData()
 {
   QString report;
   QString unused_report;
-  QString str1;
-  QString str2;
   unsigned tracks=0;
+  QString err_msg;
 
   //
   // Generate Log
   //
-  RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
+  RDSvc *svc=
+    new RDSvc(gen_service_box->currentText(),rda->station(),rda->config(),this);
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
-			       svc->name());
+			       rda->station(),rda->config(),svc->name());
   RDLog *log=new RDLog(logname);
   if(log->exists()) {
-    str1=QString(tr("The log for"));
-    str2=QString(tr("already exists.  Recreating it\nwill remove any merged Music or Traffic events.\n\nRecreate?"));
-    if(QMessageBox::question(this,tr("Log Exists"),
-			     QString().sprintf("%s %s %s",(const char *)str1,
-		 (const char *)gen_date_edit->date().toString("MM/dd/yyyy"),
-					       (const char *)str2),
+    if(QMessageBox::question(this,"RDLogManager - "+tr("Log Exists"),
+			     tr("The log for")+" "+
+			     gen_date_edit->date().toString("MM/dd/yyyy")+" "+
+			     tr("already exists.  Recreating it")+"\n"+
+			     tr("will remove any merged Music or Traffic events.")+
+			     "\n\n"+tr("Recreate?"),
 			     QMessageBox::Yes,QMessageBox::No)!=
        QMessageBox::Yes) {
       delete log;
@@ -324,13 +295,11 @@ void GenerateLog::createData()
       return;
     }
     if((tracks=log->completedTracks())>0) {
-      str1=QString(tr("This will also delete the"));
-      str2=QString(tr("voice tracks associated with this log.\nContinue?"));
-      if(QMessageBox::warning(this,tr("Tracks Exist"),
-			      QString().sprintf("%s %u %s",
-						(const char *)str1,
-						tracks,
-						(const char *)str2),
+      if(QMessageBox::warning(this,"RDLogManager - "+tr("Tracks Exist"),
+			      tr("This will also delete the")+
+			      QString().sprintf(" %u ",tracks)+
+			      tr("voice tracks associated with this log.")+
+			      "\n"+tr("Continue?"),
 			      QMessageBox::Yes,QMessageBox::No)!=
 	 QMessageBox::Yes) {
 	delete log;
@@ -339,49 +308,54 @@ void GenerateLog::createData()
       }
     }
   }
-  log->removeTracks(rdstation_conf,rduser,log_config);
+  SendNotification(RDNotification::DeleteAction,log->name());
+  log->removeTracks(rda->station(),rda->user(),rda->config());
 
   //
   // Scheduler
   //
-  QString sql;
-  RDSqlQuery *q;
-
   srand(QTime::currentTime().msec());
-  sql=RDCreateStackTableSql(gen_service_box->currentText().replace(" ","_")); 
-
-  q=new RDSqlQuery(sql);
-  if(!q->isActive()) {
-    fprintf(stderr,"SQL: %s\n",(const char *)sql);
-    fprintf(stderr,"SQL Error: %s\n",
-	    (const char *)q->lastError().databaseText());
-    delete q;
-  }
-  delete q;
-
   connect(svc,SIGNAL(generationProgress(int)),
-	  gen_progress_dialog,SLOT(setProgress(int)));
-  svc->generateLog(gen_date_edit->date(),
-		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
-				svc->name()),
-		   RDDateDecode(svc->nameTemplate(),gen_date_edit->date().
-				addDays(1),svc->name()),&unused_report);
+	  gen_progress_dialog,SLOT(setValue(int)));
+  if(!svc->generateLog(gen_date_edit->date(),
+		       RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
+				    rda->station(),rda->config(),svc->name()),
+		       RDDateDecode(svc->nameTemplate(),gen_date_edit->date().
+				    addDays(1),rda->station(),rda->config(),
+				    svc->name()),
+		       &unused_report,rda->user(),&err_msg)) {
+    QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			 tr("Unable to generate log")+": "+err_msg);
+    gen_progress_dialog->setValue(gen_progress_dialog->maximum());
+    delete svc;
+    delete log;
+    return;
+  }
   log->updateTracks();
+  SendNotification(RDNotification::AddAction,log->name());
   delete log;
   delete svc;
 
   //
   // Generate Exception Report
   //
-  RDLogEvent *event=
-    new RDLogEvent(QString().sprintf("%s_LOG",(const char *)logname));
+  RDLogEvent *event=new RDLogEvent(logname);
   event->load();
   if((event->validate(&report,gen_date_edit->date())==0)&&
      unused_report.isEmpty()) {
-    QMessageBox::information(this,tr("No Errors"),tr("No exceptions found."));
+    QMessageBox::information(this,tr("No Errors"),\
+      tr("No broken rules or validation exceptions found."));
   }
   else {
-    RDTextFile(report+"\n\n"+unused_report);
+    int errs=unused_report.count("\n"); 
+    if(errs==1) {
+      unused_report+=QString().sprintf("\n%d broken rule.\n",errs);
+    }
+    else {
+      unused_report+=QString().sprintf("\n%d broken rules.\n",errs);
+    }
+
+    RDTextFile(report+"\n"+unused_report);
   }
   delete event;
 
@@ -392,48 +366,77 @@ void GenerateLog::createData()
 void GenerateLog::musicData()
 {
   unsigned tracks=0;
+  QString err_msg;
 
-  RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
+  RDSvc *svc=
+    new RDSvc(gen_service_box->currentText(),rda->station(),rda->config(),this);
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
-			       svc->name());
+			       rda->station(),rda->config(),svc->name());
   RDLog *log=new RDLog(logname);
   if(((log->linkState(RDLog::SourceMusic)==RDLog::LinkDone)||
       (log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone))) {
-    QString str1=QString(tr("The log for"));
-    QString str2=QString(tr("already contains merged music and/or traffic data.\nRemerging it will remove this data.  Remerge?"));
-    if(QMessageBox::question(this,tr("Music Exists"),
-			     QString().sprintf("%s %s %s",(const char *)str1,
-		 (const char *)gen_date_edit->date().toString("MM/dd/yyyy"),
-					       (const char *)str2),
-			     QMessageBox::Yes,QMessageBox::No)!=
-       QMessageBox::Yes) {
-      delete log;
-      delete svc;
-      return;
-    }
-    if((tracks=log->completedTracks())>0) {
-      str1=QString(tr("This will also delete the"));
-      str2=QString(tr("voice tracks associated with this log.\nContinue?"));
-      if(QMessageBox::warning(this,tr("Tracks Exist"),
-			      QString().sprintf("%s %u %s",
-						(const char *)str1,
-						tracks,
-						(const char *)str2),
-			      QMessageBox::Yes,QMessageBox::No)!=
+    if(log->includeImportMarkers()) {
+      if(QMessageBox::question(this,"RDLogManager - "+tr("Music Exists"),
+			       tr("The log for")+" "+
+			       gen_date_edit->date().toString("MM/dd/yyyy")+" "+
+			       tr("already contains merged music and/or traffic data.")+"\n"+
+			       tr("Remerging it will remove this data.  Remerge?"),
+			       QMessageBox::Yes,QMessageBox::No)!=
 	 QMessageBox::Yes) {
 	delete log;
 	delete svc;
 	return;
       }
+      if((tracks=log->completedTracks())>0) {
+	if(QMessageBox::warning(this,"RDLogManager - "+tr("Tracks Exist"),
+				tr("This will also delete the")+
+				QString().sprintf(" %u ",tracks)+
+				tr("voice tracks associated with this log.")+
+				"\n"+tr("Continue?"),
+				QMessageBox::Yes,QMessageBox::No)!=
+	   QMessageBox::Yes) {
+	  delete log;
+	  delete svc;
+	  return;
+	}
+      }
+    }
+    else {
+      QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			   tr("The log for")+" "+
+			   gen_date_edit->date().toString("MM/dd/yyyy")+" "+
+			   tr("cannot be relinked."));
+      return;
+    }
+    log->removeTracks(rda->station(),rda->user(),rda->config());
+    if(!svc->clearLogLinks(RDSvc::Traffic,logname,rda->user(),&err_msg)) {
+      QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			   tr("Unable to clear traffic links")+": "+err_msg);
+      delete log;
+      delete svc;
+      return;
+    }
+    if(!svc->clearLogLinks(RDSvc::Music,logname,rda->user(),&err_msg)) {
+      QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			   tr("Unable to clear music links")+": "+err_msg);
+      delete log;
+      delete svc;
+      return;
     }
-    log->removeTracks(rdstation_conf,rduser,log_config);
-    svc->clearLogLinks(RDSvc::Traffic,gen_date_edit->date(),logname);
-    svc->clearLogLinks(RDSvc::Music,gen_date_edit->date(),logname);
   }
   connect(svc,SIGNAL(generationProgress(int)),
-	  gen_progress_dialog,SLOT(setProgress(int)));
+	  gen_progress_dialog,SLOT(setValue(int)));
   QString report;
-  svc->linkLog(RDSvc::Music,gen_date_edit->date(),logname,&report);
+  if(!svc->linkLog(RDSvc::Music,gen_date_edit->date(),logname,&report,rda->user(),
+		   &err_msg)) {
+    
+      QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			   tr("Unable to link music log")+": "+err_msg);
+      delete log;
+      delete svc;
+      return;
+  }
+  SendNotification(RDNotification::ModifyAction,log->name());
   delete log;
   delete svc;
   if(!report.isEmpty()) {
@@ -445,30 +448,54 @@ void GenerateLog::musicData()
 
 void GenerateLog::trafficData()
 {
-  RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
+  QString err_msg;
+  RDSvc *svc=
+    new RDSvc(gen_service_box->currentText(),rda->station(),rda->config(),this);
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
-			       svc->name());
+			       rda->station(),rda->config(),svc->name());
   RDLog *log=new RDLog(logname);
   if((log->linkState(RDLog::SourceTraffic)==RDLog::LinkDone)) {
-    QString str1=QString(tr("The log for"));
-    QString str2=QString(tr("already contains merged traffic data.  Remerging it\nwill remove this data.  Remerge?"));
-    if(QMessageBox::question(this,tr("Traffic Exists"),
-			     QString().sprintf("%s %s %s",(const char *)str1,
-		 (const char *)gen_date_edit->date().toString("MM/dd/yyyy"),
-					       (const char *)str2),
-			     QMessageBox::Yes,QMessageBox::No)!=
-       QMessageBox::Yes) {
+    if(log->includeImportMarkers()) {
+      if(QMessageBox::question(this,"RDLogManager - "+tr("Traffic Exists"),
+			       tr("The log for")+" "+
+			       gen_date_edit->date().toString("MM/dd/yyyy")+" "+
+			       tr("already contains merged traffic data.")+"\n"+
+			       tr("Remerging it will remove this data.  Remerge?"),
+			       QMessageBox::Yes,QMessageBox::No)!=
+	 QMessageBox::Yes) {
+	delete log;
+	delete svc;
+	return;
+      }
+    }
+    else {
+      QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			   tr("The log for")+" "+
+			   gen_date_edit->date().toString("MM/dd/yyyy")+" "+
+			   tr("cannot be relinked."));
+      return;
+    }
+    if(!svc->clearLogLinks(RDSvc::Traffic,logname,rda->user(),&err_msg)) {
+      QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			   tr("Unable to clear traffic links")+": "+err_msg);
       delete log;
       delete svc;
       return;
     }
-    svc->clearLogLinks(RDSvc::Traffic,gen_date_edit->date(),logname);
   }
   connect(svc,SIGNAL(generationProgress(int)),
-	  gen_progress_dialog,SLOT(setProgress(int)));
+	  gen_progress_dialog,SLOT(setValue(int)));
 
   QString report;
-  svc->linkLog(RDSvc::Traffic,gen_date_edit->date(),logname,&report);
+  if(!svc->linkLog(RDSvc::Traffic,gen_date_edit->date(),logname,&report,rda->user(),
+		   &err_msg)) {
+    QMessageBox::warning(this,"RDLogManager - "+tr("Error"),
+			 tr("Unable to link traffic log")+": "+err_msg);
+    delete log;
+    delete svc;
+    return;
+  }
+  SendNotification(RDNotification::ModifyAction,log->name());
   delete log;
   delete svc;
   if(!report.isEmpty()) {
@@ -480,14 +507,17 @@ void GenerateLog::trafficData()
 
 void GenerateLog::fileScanData()
 {
-  RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
+  RDSvc *svc=
+    new RDSvc(gen_service_box->currentText(),rda->station(),rda->config(),this);
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
-			       svc->name());
+			       rda->station(),rda->config(),svc->name());
   RDLog *log=new RDLog(logname);
   if(gen_music_enabled) {
     if(QFile::exists(svc->
 		     importFilename(RDSvc::Music,gen_date_edit->date()))) {
-      gen_music_button->setEnabled(true);
+      gen_music_button->setEnabled(log->includeImportMarkers()||
+				   (log->linkState(RDLog::SourceMusic)==
+				    RDLog::LinkMissing));
       gen_mus_avail_label->setPixmap(*gen_greenball_map);
     }
     else {
@@ -502,8 +532,11 @@ void GenerateLog::fileScanData()
     if(QFile::exists(svc->
 		     importFilename(RDSvc::Traffic,gen_date_edit->date()))) {
       gen_traffic_button->
-	setEnabled((!gen_music_enabled)||
-		   (log->linkState(RDLog::SourceMusic)==RDLog::LinkDone));
+	setEnabled(((!gen_music_enabled)||
+		    (log->linkState(RDLog::SourceMusic)==RDLog::LinkDone))&&
+		   (log->includeImportMarkers()||
+		    (log->linkState(RDLog::SourceTraffic)==
+		     RDLog::LinkMissing)));
       gen_tfc_avail_label->setPixmap(*gen_greenball_map);
     }
     else {
@@ -549,9 +582,10 @@ void GenerateLog::resizeEvent(QResizeEvent *e)
 
 void GenerateLog::UpdateControls()
 {
-  RDSvc *svc=new RDSvc(gen_service_box->currentText(),this);
+  RDSvc *svc=
+    new RDSvc(gen_service_box->currentText(),rda->station(),rda->config(),this);
   QString logname=RDDateDecode(svc->nameTemplate(),gen_date_edit->date(),
-			       svc->name());
+			       rda->station(),rda->config(),svc->name());
   RDLog *log=new RDLog(logname);
   if(log->exists()) {
     if(log->linkQuantity(RDLog::SourceMusic)>0) {
@@ -593,3 +627,13 @@ void GenerateLog::UpdateControls()
   delete svc;
   fileScanData();
 }
+
+
+void GenerateLog::SendNotification(RDNotification::Action action,
+				   const QString &logname)
+{
+  RDNotification *notify=new RDNotification(RDNotification::LogType,
+					    action,QVariant(logname));
+  rda->ripc()->sendNotification(*notify);
+  delete notify;
+}
