@@ -2,7 +2,7 @@
 //
 // List Rivendell Log Events
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,20 +21,15 @@
 #ifndef LIST_EVENTS_H
 #define LIST_EVENTS_H
 
-#include <vector>
+#include <q3listview.h>
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlistview.h>
 #include <qcombobox.h>
 
-#include <rduser.h>
-#include <rdmatrix.h>
 #include <rddb.h>
+#include <rddialog.h>
 
-class ListEvents : public QDialog
+class ListEvents : public RDDialog
 {
  Q_OBJECT
  public:
@@ -47,7 +42,7 @@ class ListEvents : public QDialog
   void editData();
   void deleteData();
   void renameData();
-  void doubleClickedData(QListViewItem *,const QPoint &,int);
+  void doubleClickedData(Q3ListViewItem *,const QPoint &,int);
   void filterActivatedData(int id);
   void closeData();
   void okData();
@@ -59,14 +54,14 @@ class ListEvents : public QDialog
 
  private:
   void RefreshList();
-  void RefreshItem(QListViewItem *item,std::vector<QString> *new_events=NULL);
-  void UpdateItem(QListViewItem *item,QString name);
-  void WriteItem(QListViewItem *item,RDSqlQuery *q);
+  void RefreshItem(Q3ListViewItem *item,std::vector<QString> *new_events=NULL);
+  void UpdateItem(Q3ListViewItem *item,QString name);
+  void WriteItem(Q3ListViewItem *item,RDSqlQuery *q);
   int ActiveEvents(QString event_name,QString *clock_list);
   void DeleteEvent(QString event_name);
   QString GetEventFilter(QString svc_name);
   QString GetNoneFilter();
-  QListView *edit_events_list;
+  Q3ListView *edit_events_list;
   QString *edit_eventname;
   QLabel *edit_filter_label;
   QComboBox *edit_filter_box;
