@@ -1,8 +1,8 @@
 // rdlogmanager.cpp
 //
-// The Log Editor Utility for Rivendell.
+// The Log Generator Utility for Rivendell.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,49 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef WIN32
-#include <stdlib.h>
-#include <unistd.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#endif  // WIN32
 #include <qapplication.h>
-#include <qwindowsstyle.h>
-#include <qwidget.h>
-#include <qpainter.h>
-#include <qsqldatabase.h>
-#include <qsqlpropertymap.h>
 #include <qmessagebox.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qsettings.h>
-#include <qlabel.h>
-#include <qlistview.h>
-#include <qtextcodec.h>
 #include <qtranslator.h>
 
-#include <rd.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rdstation.h>
-#include <rdsvc.h>
-#include <rdcheck_daemons.h>
-#include <rdcreate_log.h>
-#include <rdcmd_switch.h>
-#include <rddbheartbeat.h>
-#include <rddatedecode.h>
-#include <rdlog.h>
-#include <rdlog_event.h>
-#include <dbversion.h>
-
-#include <rdlogmanager.h>
-#include <globals.h>
-#include <list_events.h>
-#include <list_clocks.h>
-#include <list_grids.h>
-#include <generate_log.h>
-#include <list_svcs.h>
+#include "generate_log.h"
+#include "globals.h"
+#include "list_clocks.h"
+#include "list_events.h"
+#include "list_grids.h"
+#include "list_svcs.h"
+#include "rdlogmanager.h"
+#include "logobject.h"
 
 //
 // Icons
@@ -70,121 +39,42 @@
 //
 // Global Resources
 //
-RDStation *rdstation_conf;
-RDUser *rduser;
-RDRipc *rdripc;
-RDCae *rdcae;
-RDConfig *log_config;
 QString *event_filter;
 QString *clock_filter;
 bool skip_db_check=false;
 
-#ifndef WIN32
-void SigHandler(int signo)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
-  pid_t pLocalPid;
-
-  switch(signo) {
-      case SIGCHLD:
-	pLocalPid=waitpid(-1,NULL,WNOHANG);
-	while(pLocalPid>0) {
-	  pLocalPid=waitpid(-1,NULL,WNOHANG);
-	}
-	signal(SIGCHLD,SigHandler);
-	break;
-  }
-}
-#endif  // WIN32
-
-
-MainWidget::MainWidget(QWidget *parent)
-  :QWidget(parent)
-{
-  unsigned schema=0;
+  QString err_msg;
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
-  // Ensure that the system daemons are running
+  // Open the Database
   //
-#ifndef WIN32
-  RDInitializeDaemons();
-#endif  // WIN32
-
-  //
-  // Load Local Configs
-  //
-  log_config=new RDConfig();
-  log_config->load();
-  log_config->setModuleName("RDLogManager");
-
-  setCaption(tr("RDLogManager"));
-
-  //
-  // Open Database
-  //
-  QString err;
-  log_db=RDInitDb(&schema,&err);
-  if(!log_db) {
-    QMessageBox::warning(this,tr("Can't Connect"),err);
-    exit(0);
+  rda=new RDApplication("RDLogManager","rdlogmanager",RDLOGMANAGER_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    QMessageBox::critical(this,"RDLogManager - "+tr("Error"),err_msg);
+    exit(1);
   }
-  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
-#ifdef WIN32
-	    QMessageBox::warning(this,tr("RDLogEdit -- Database Skew"),
-				 tr("This version of RDLogManager is incompatible with the version installed on the server.\nSee your system administrator for an update!"));
-#else
-    fprintf(stderr,
-	    "rdlogmanager: database version mismatch, should be %u, is %u\n",
-	    RD_VERSION_DATABASE,schema);
-#endif  // WIN32
-    exit(256);
-  }
-  new RDDbHeartbeat(log_config->mysqlHeartbeatInterval(),this);
 
-  //
-  // Allocate Global Resources
-  //
-  rdstation_conf=new RDStation(log_config->stationName());
-   
+  setWindowTitle(tr("RDLogManager"));
+
   //
   // CAE Connection
   //
-#ifndef WIN32
-  rdcae=new RDCae(rdstation_conf,log_config,parent);
-  rdcae->connectHost();
-#endif  // WIN32
+  rda->cae()->connectHost();
 
   //
   // RIPC Connection
   //
-  rdripc=new RDRipc(rdstation_conf,log_config,this);
-  connect(rdripc,SIGNAL(userChanged()),this,SLOT(userData()));
-  rdripc->connectHost("localhost",RIPCD_TCP_PORT,log_config->password());
-
-  //
-  // User
-  //
-  rduser=NULL;
-
-  //
-  // Generate Fonts
-  //
-  QFont default_font("Helvetica",12,QFont::Normal);
-  default_font.setPixelSize(12);
-  qApp->setFont(default_font);
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  QFont day_font=QFont("Helvetica",12,QFont::Normal);
-  day_font.setPixelSize(12);
+  connect(rda,SIGNAL(userChanged()),this,SLOT(userData()));
+  rda->ripc()->connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
 
   //
   // Create And Set Icon
@@ -203,19 +93,19 @@ MainWidget::MainWidget(QWidget *parent)
   //
   QLabel *label=new QLabel(tr("RDLogManager"),this);
   label->setGeometry(0,5,sizeHint().width(),32);
-  label->setFont(label_font);
-  label->setAlignment(AlignHCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignHCenter);
   label=new QLabel(tr("Select an operation:"),this);
   label->setGeometry(0,25,sizeHint().width(),16);
-  label->setFont(day_font);
-  label->setAlignment(AlignCenter);
+  label->setFont(subLabelFont());
+  label->setAlignment(Qt::AlignCenter);
 
   //
   //  Edit Events Button
   //
   log_events_button=new QPushButton(this);
   log_events_button->setGeometry(10,45,sizeHint().width()-20,50);
-  log_events_button->setFont(button_font);
+  log_events_button->setFont(buttonFont());
   log_events_button->setText(tr("Edit &Events"));
   connect(log_events_button,SIGNAL(clicked()),this,SLOT(eventsData()));
 
@@ -224,7 +114,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   log_clocks_button=new QPushButton(this);
   log_clocks_button->setGeometry(10,95,sizeHint().width()-20,50);
-  log_clocks_button->setFont(button_font);
+  log_clocks_button->setFont(buttonFont());
   log_clocks_button->setText(tr("Edit C&locks"));
   connect(log_clocks_button,SIGNAL(clicked()),this,SLOT(clocksData()));
 
@@ -233,7 +123,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   log_grids_button=new QPushButton(this);
   log_grids_button->setGeometry(10,145,sizeHint().width()-20,50);
-  log_grids_button->setFont(button_font);
+  log_grids_button->setFont(buttonFont());
   log_grids_button->setText(tr("Edit G&rids"));
   connect(log_grids_button,SIGNAL(clicked()),this,SLOT(gridsData()));
 
@@ -242,7 +132,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   log_logs_button=new QPushButton(this);
   log_logs_button->setGeometry(10,195,sizeHint().width()-20,50);
-  log_logs_button->setFont(button_font);
+  log_logs_button->setFont(buttonFont());
   log_logs_button->setText(tr("&Generate Logs"));
   connect(log_logs_button,SIGNAL(clicked()),this,SLOT(generateData()));
 
@@ -251,7 +141,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   log_reports_button=new QPushButton(this);
   log_reports_button->setGeometry(10,245,sizeHint().width()-20,50);
-  log_reports_button->setFont(button_font);
+  log_reports_button->setFont(buttonFont());
   log_reports_button->setText(tr("Manage &Reports"));
   connect(log_reports_button,SIGNAL(clicked()),this,SLOT(reportsData()));
 
@@ -261,14 +151,10 @@ MainWidget::MainWidget(QWidget *parent)
   log_close_button=new QPushButton(this);
   log_close_button->setGeometry(10,sizeHint().height()-60,
 				sizeHint().width()-20,50);
-  log_close_button->setFont(button_font);
+  log_close_button->setFont(buttonFont());
   log_close_button->setText(tr("&Close"));
   log_close_button->setDefault(true);
   connect(log_close_button,SIGNAL(clicked()),this,SLOT(quitMainWidget()));
-
-#ifndef WIN32
-  signal(SIGCHLD,SigHandler);
-#endif  // WIN32
 }
 
 
@@ -286,21 +172,12 @@ QSizePolicy MainWidget::sizePolicy() const
 
 void MainWidget::userData()
 {
-  QString str1=tr("RDLogManager - User: ");
-  setCaption(QString().sprintf("%s%s",(const char *)str1,
-			       (const char *)rdripc->user()));
-
-  if(rduser!=NULL) {
-    delete rduser;
-  }
-  rduser=new RDUser(rdripc->user());
-
   //
   // Set Control Perms
   //
-  bool templates_allowed=rduser->modifyTemplate();
-  bool creation_allowed=rduser->createLog();
-  bool rec_allowed=rduser->deleteRec();
+  bool templates_allowed=rda->user()->modifyTemplate();
+  bool creation_allowed=rda->user()->createLog();
+  bool rec_allowed=rda->user()->deleteRec();
   log_events_button->setEnabled(templates_allowed);
   log_clocks_button->setEnabled(templates_allowed);
   log_grids_button->setEnabled(templates_allowed);
@@ -351,13 +228,13 @@ void MainWidget::reportsData()
 
 void MainWidget::quitMainWidget()
 {
-  log_db->removeDatabase(log_config->mysqlDbname());
   exit(0);
 }
 
 
 int gui_main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
@@ -365,17 +242,9 @@ int gui_main(int argc,char *argv[])
   //
   QString tr_path;
   QString qt_path;
-#ifdef WIN32
-  QSettings settings;
-  settings.insertSearchPath(QSettings::Windows,"/SalemRadioLabs");
-  tr_path=QString().sprintf("%s\\",
-			    (const char *)settings.
-			    readEntry("/Rivendell/InstallDir"));
-  qt_path=tr_path;
-#else
   tr_path=QString(PREFIX)+QString("/share/rivendell/");
-  qt_path=QString(QTDIR)+QString("/translation/");
-#endif  // WIN32
+  qt_path=QString("/usr/share/qt4/translation/");
+
   QTranslator qt(0);
   qt.load(qt_path+QString("qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
@@ -395,7 +264,9 @@ int gui_main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget();
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(w->geometry().x(),w->geometry().y()),
 		       w->sizeHint()));
@@ -423,40 +294,45 @@ int main(int argc,char *argv[])
   for(unsigned i=0;i<cmd->keys();i++) {
     if (cmd->key(i)=="-P") {
       cmd_protect_existing = true;
+      cmd->setProcessed(i,true);
     }
     if (cmd->key(i)=="-g") {
+      printf("generate\n");
       cmd_generate = true;
+      cmd->setProcessed(i,true);
     }
     if (cmd->key(i)=="-m") {
       cmd_merge_music = true;
+      cmd->setProcessed(i,true);
     }
     if (cmd->key(i)=="-t") {
       cmd_merge_traffic = true;
       cmd->setProcessed(i,true);
     }
     if(cmd->key(i)=="--skip-db-check") {
-      skip_db_check=true;
       cmd->setProcessed(i,true);
     }
-    if (cmd->key(i)=="-s") {
-      if (i+1<cmd->keys()) {
+    if(cmd->key(i)=="-s") {
+      if((i+1)<cmd->keys()) {
 	i++;
 	cmd_service = cmd->key(i);
       }
       else {
 	fprintf(stderr,"rdlogmanager: missing argument to \"-s\"\n");
-	exit(256);
+	exit(2);
       }
+      cmd->setProcessed(i,true);
     }
-    if (cmd->key(i)=="-r") {
-      if (i+1<cmd->keys()) {
+    if(cmd->key(i)=="-r") {
+      if(i+1<cmd->keys()) {
 	i++;
 	cmd_report = cmd->key(i);
       }
       else {
 	fprintf(stderr,"rdlogmanager: missing argument to \"-r\"\n");
-	exit(256);
+	exit(2);
       }
+      cmd->setProcessed(i,true);
     }
     if (cmd->key(i)=="-d") {
       if (i+1<cmd->keys()) {
@@ -465,8 +341,9 @@ int main(int argc,char *argv[])
       }
       else {
 	fprintf(stderr,"rdlogmanager: missing argument to \"-d\"\n");
-	exit(256);
+	exit(2);
       }
+      cmd->setProcessed(i,true);
     }
     if (cmd->key(i)=="-e") {
       if (i+1<cmd->keys()) {
@@ -475,8 +352,14 @@ int main(int argc,char *argv[])
       }
       else {
 	fprintf(stderr,"rdlogmanager: missing argument to \"-e\"\n");
-	exit(256);
+	exit(2);
       }
+      cmd->setProcessed(i,true);
+    }
+    if(!cmd->processed(i)) {
+      fprintf(stderr,"rdlogmanager: unknown command option \"%s\"\n",
+	      (const char *)cmd->key(i));
+      exit(2);
     }
   }
   delete cmd;
@@ -488,10 +371,11 @@ int main(int argc,char *argv[])
   }
 
   if(cmd_generate||cmd_merge_traffic||cmd_merge_music) {
-    return RunLogOperation(argc,argv,cmd_service,cmd_start_offset,
-			   cmd_protect_existing,cmd_generate,
-			   cmd_merge_music,cmd_merge_traffic);
-  }
+    QApplication a(argc,argv,false);
+    new LogObject(cmd_service,cmd_start_offset,cmd_protect_existing,
+		  cmd_generate,cmd_merge_music,cmd_merge_traffic);
+    return a.exec();
+ }
   if(!cmd_report.isEmpty()) {
     return RunReportOperation(argc,argv,cmd_report,cmd_protect_existing,
 			      cmd_start_offset,cmd_end_offset);
