@@ -1,9 +1,11 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddClock</name>
     <message>
         <source>Add Log Clock</source>
-        <translation>Přidat nové hodiny zápisu</translation>
+        <translation type="obsolete">Přidat nové hodiny zápisu</translation>
     </message>
     <message>
         <source>&amp;New Clock Name:</source>
@@ -17,6 +19,10 @@
         <source>&amp;Cancel</source>
         <translation>Z&amp;rušit</translation>
     </message>
+    <message>
+        <source>Add Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddEvent</name>
@@ -48,7 +54,7 @@
     <name>EditClock</name>
     <message>
         <source>Edit Clock:</source>
-        <translation>Upravit hodiny:</translation>
+        <translation type="obsolete">Upravit hodiny:</translation>
     </message>
     <message>
         <source>Code:</source>
@@ -121,7 +127,7 @@ List</source>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Jste si jistý, že chcete smazat</translation>
+        <translation type="obsolete">Jste si jistý, že chcete smazat</translation>
     </message>
     <message>
         <source>Delete Event</source>
@@ -163,7 +169,7 @@ Chcete je uložit?</translation>
     </message>
     <message>
         <source>--- End of clock ---</source>
-        <translation>--- Konec hodin ---</translation>
+        <translation type="obsolete">--- Konec hodin ---</translation>
     </message>
     <message>
         <source>Invalid Code</source>
@@ -189,6 +195,27 @@ Chcete je uložit?</translation>
         <source>&amp;Clone</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Are you sure you want to delete
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Clock</source>
+        <translation type="unfinished">Upravit hodiny</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>That event does not exist.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -218,35 +245,35 @@ Chcete je uložit?</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>VOZÍK</translation>
+        <translation type="obsolete">VOZÍK</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>SKUPINA</translation>
+        <translation type="obsolete">SKUPINA</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DÉLKA</translation>
+        <translation type="obsolete">DÉLKA</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>UMĚLEC</translation>
+        <translation type="obsolete">UMĚLEC</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>ZAČÁTEK</translation>
+        <translation type="obsolete">ZAČÁTEK</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>KONEC</translation>
+        <translation type="obsolete">KONEC</translation>
     </message>
     <message>
         <source>TYPE</source>
-        <translation>TYP</translation>
+        <translation type="obsolete">TYP</translation>
     </message>
     <message>
         <source>ALL</source>
@@ -330,11 +357,11 @@ Chcete je uložit?</translation>
     </message>
     <message>
         <source>TRANSITION</source>
-        <translation>PŘECHOD</translation>
+        <translation type="obsolete">PŘECHOD</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>POČÍTADLO</translation>
+        <translation type="obsolete">POČÍTADLO</translation>
     </message>
     <message>
         <source>None</source>
@@ -474,7 +501,7 @@ Chcete ji přepsat?</translation>
     </message>
     <message>
         <source>Timed(Wait</source>
-        <translation>Načasovaný (Čekat</translation>
+        <translation type="obsolete">Načasovaný (Čekat</translation>
     </message>
     <message>
         <source>, Post</source>
@@ -524,6 +551,58 @@ Chcete ji přepsat?</translation>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Délka</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Začátek</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Konec</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished">Počet</translation>
+    </message>
+    <message>
+        <source>Artist Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -582,7 +661,7 @@ existující událostí.</translation>
     <name>EditGrid</name>
     <message>
         <source>Edit Grid:</source>
-        <translation>Upravit mřížku:</translation>
+        <translation type="obsolete">Upravit mřížku:</translation>
     </message>
     <message>
         <source>Edit Clock</source>
@@ -613,6 +692,10 @@ existující událostí.</translation>
         <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -652,6 +735,41 @@ existující událostí.</translation>
         <translation>Z&amp;rušit</translation>
     </message>
 </context>
+<context>
+    <name>EditSchedCodeRules</name>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">Z&amp;rušit</translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished">Kód:</translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished">Nejvíce za sebou:</translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished">Nejmenší doba čekání:</translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished">Nezařazovat po:</translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished">nebo po:</translation>
+    </message>
+</context>
 <context>
     <name>EditSchedRules</name>
     <message>
@@ -720,6 +838,14 @@ Chcete je uložit?</translation>
         <source>Import Rules from Clock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>None</source>
+        <translation type="obsolete">Žádný</translation>
+    </message>
+    <message>
+        <source>(This setting is deprecated and has been moved to events)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -795,7 +921,7 @@ Chcete je uložit?</translation>
 will remove any merged Music or Traffic events.
 
 Recreate?</source>
-        <translation>již existuje. Jeho znovuvytvoření odstraní
+        <translation type="obsolete">již existuje. Jeho znovuvytvoření odstraní
 jakékoli události sloučené hudby nebo přenosu.
 
 Vytvořit znovu?</translation>
@@ -811,7 +937,7 @@ Vytvořit znovu?</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>stopy hlasů spojených s tímto zápisem.
+        <translation type="obsolete">stopy hlasů spojených s tímto zápisem.
 Pokračovat?</translation>
     </message>
     <message>
@@ -820,16 +946,16 @@ Pokračovat?</translation>
     </message>
     <message>
         <source>No Errors</source>
-        <translation>Žádné chyby</translation>
+        <translation type="unfinished">Žádné chyby</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation>Nenalezena žádná chyba.</translation>
+        <translation type="obsolete">Nenalezena žádná chyba.</translation>
     </message>
     <message>
         <source>already contains merged music and/or traffic data.
 Remerging it will remove this data.  Remerge?</source>
-        <translation>již obsahuje sloučená data hudby a/nebo přenosu.
+        <translation type="obsolete">již obsahuje sloučená data hudby a/nebo přenosu.
 Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
     </message>
     <message>
@@ -839,7 +965,7 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
     <message>
         <source>already contains merged traffic data.  Remerging it
 will remove this data.  Remerge?</source>
-        <translation>již obsahuje sloučená data přenosu.
+        <translation type="obsolete">již obsahuje sloučená data přenosu.
 Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
     </message>
     <message>
@@ -848,7 +974,75 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
     </message>
     <message>
         <source>Generate Log - User: </source>
-        <translation>Vytvořit zápis - Uživatel: </translation>
+        <translation type="obsolete">Vytvořit zápis - Uživatel: </translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to generate log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear traffic links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to clear music links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link music log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to link traffic log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Generate Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already exists.  Recreating it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>will remove any merged Music or Traffic events.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recreate?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged music and/or traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remerging it will remove this data.  Remerge?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cannot be relinked.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No broken rules or validation exceptions found.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -871,15 +1065,15 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
     </message>
     <message>
         <source>Set PLAY Transition</source>
-        <translation>Nastavit přechod PŘEHRÁT</translation>
+        <translation type="obsolete">Nastavit přechod PŘEHRÁT</translation>
     </message>
     <message>
         <source>Set SEGUE Transition</source>
-        <translation>Nastavit přechod PŘECHOD</translation>
+        <translation type="obsolete">Nastavit přechod PŘECHOD</translation>
     </message>
     <message>
         <source>Set STOP Transition</source>
-        <translation>Nastavit přechod ZASTAVIT</translation>
+        <translation type="obsolete">Nastavit přechod ZASTAVIT</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -913,6 +1107,18 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
         <source>STOP</source>
         <translation>ZASTAVIT</translation>
     </message>
+    <message>
+        <source>PLAY Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
@@ -983,7 +1189,7 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Jste si jistý, že chcete smazat</translation>
+        <translation type="obsolete">Jste si jistý, že chcete smazat</translation>
     </message>
     <message>
         <source>Delete Clock</source>
@@ -991,7 +1197,7 @@ delete</source>
     </message>
     <message>
         <source>is in use in the following grid(s):</source>
-        <translation>se používá následující mřížkou(ami):</translation>
+        <translation type="obsolete">se používá následující mřížkou(ami):</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1003,7 +1209,19 @@ delete</source>
     </message>
     <message>
         <source>Log Clocks - User: </source>
-        <translation>Zápis - Uživatel hodin:</translation>
+        <translation type="obsolete">Zápis - Uživatel hodin:</translation>
+    </message>
+    <message>
+        <source>Log Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following grid(s)</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1071,7 +1289,7 @@ delete</source>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Jste si jistý, že chcete smazat</translation>
+        <translation type="obsolete">Jste si jistý, že chcete smazat</translation>
     </message>
     <message>
         <source>Delete Event</source>
@@ -1079,7 +1297,7 @@ delete</source>
     </message>
     <message>
         <source>is in use in the following clocks:</source>
-        <translation>se používá následujícími hodinami:</translation>
+        <translation type="obsolete">se používá následujícími hodinami:</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1091,7 +1309,19 @@ delete</source>
     </message>
     <message>
         <source>Log Events - User: </source>
-        <translation>Zápis - Události - Uživatel:</translation>
+        <translation type="obsolete">Zápis - Události - Uživatel:</translation>
+    </message>
+    <message>
+        <source>Log Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following clocks</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1125,11 +1355,11 @@ delete</source>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SLUŽBA</translation>
+        <translation type="obsolete">SLUŽBA</translation>
     </message>
     <message>
         <source>OLDEST REPORT</source>
-        <translation>NEJSTARŠÍ ZPRÁVA</translation>
+        <translation type="obsolete">NEJSTARŠÍ ZPRÁVA</translation>
     </message>
     <message>
         <source>&amp;Generate
@@ -1151,12 +1381,20 @@ data</translation>
         <source>[none]</source>
         <translation>[žádný]</translation>
     </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Oldest Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Nelze spojit</translation>
+        <translation type="obsolete">Nelze spojit</translation>
     </message>
     <message>
         <source>RDLogManager</source>
@@ -1192,18 +1430,22 @@ data</translation>
     </message>
     <message>
         <source>RDLogManager - User: </source>
-        <translation>RDLogManager - Uživatel: </translation>
+        <translation type="obsolete">RDLogManager - Uživatel: </translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
-        <translation>RDLogEdit - Nesouměrnost v databázi</translation>
+        <translation type="obsolete">RDLogEdit - Nesouměrnost v databázi</translation>
     </message>
     <message>
         <source>This version of RDLogManager is incompatible with the version installed on the server.
 See your system administrator for an update!</source>
-        <translation>Tato verze RDLogManager je neslučitelná s verzí nainstalovanou na serveru.
+        <translation type="obsolete">Tato verze RDLogManager je neslučitelná s verzí nainstalovanou na serveru.
 Vyhledejte svého správce systému kvůli aktualizaci!</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PickReportDates</name>
@@ -1255,14 +1497,26 @@ zprávu</translation>
     </message>
     <message>
         <source>Report Complete</source>
-        <translation>Zpráva úplná</translation>
+        <translation type="obsolete">Zpráva úplná</translation>
     </message>
     <message>
         <source>Report complete!</source>
         <translation type="obsolete">Zpráva úplná!</translation>
     </message>
     <message>
-        <source>Report generated in</source>
+        <source>File Exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file at</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The report file already exists.  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1349,35 +1603,31 @@ data</translation>
     <name>editSchedCodeRules</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
     <message>
         <source>Code:</source>
-        <translation>Kód:</translation>
+        <translation type="obsolete">Kód:</translation>
     </message>
     <message>
         <source>Max. in a row:</source>
-        <translation>Nejvíce za sebou:</translation>
+        <translation type="obsolete">Nejvíce za sebou:</translation>
     </message>
     <message>
         <source>Min. wait:</source>
-        <translation>Nejmenší doba čekání:</translation>
+        <translation type="obsolete">Nejmenší doba čekání:</translation>
     </message>
     <message>
         <source>Do not schedule after:</source>
-        <translation>Nezařazovat po:</translation>
+        <translation type="obsolete">Nezařazovat po:</translation>
     </message>
     <message>
         <source>Or after:</source>
-        <translation>nebo po:</translation>
-    </message>
-    <message>
-        <source>Edit Rules for Code</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">nebo po:</translation>
     </message>
 </context>
 </TS>
