@@ -1,9 +1,11 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddClock</name>
     <message>
         <source>Add Log Clock</source>
-        <translation>Neue Loguhr hinzufügen</translation>
+        <translation type="obsolete">Neue Loguhr hinzufügen</translation>
     </message>
     <message>
         <source>&amp;New Clock Name:</source>
@@ -17,6 +19,10 @@
         <source>&amp;Cancel</source>
         <translation>Abbre&amp;chen</translation>
     </message>
+    <message>
+        <source>Add Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddEvent</name>
@@ -48,7 +54,7 @@
     <name>EditClock</name>
     <message>
         <source>Edit Clock:</source>
-        <translation>Uhr editieren:</translation>
+        <translation type="obsolete">Uhr editieren:</translation>
     </message>
     <message>
         <source>Code:</source>
@@ -163,7 +169,7 @@ Wollen Sie sie speichern?</translation>
     </message>
     <message>
         <source>--- End of clock ---</source>
-        <translation>--- Ende der Uhr ---</translation>
+        <translation type="obsolete">--- Ende der Uhr ---</translation>
     </message>
     <message>
         <source>Invalid Code</source>
@@ -194,6 +200,22 @@ Wollen Sie sie speichern?</translation>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Clock</source>
+        <translation type="unfinished">Uhr editieren</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>That event does not exist.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -223,35 +245,35 @@ Wollen Sie sie speichern?</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CART</translation>
+        <translation type="obsolete">CART</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LÄNGE</translation>
+        <translation type="obsolete">LÄNGE</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITEL</translation>
+        <translation type="obsolete">TITEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>KÜNSTLER</translation>
+        <translation type="obsolete">KÜNSTLER</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>ENDE</translation>
+        <translation type="obsolete">ENDE</translation>
     </message>
     <message>
         <source>TYPE</source>
-        <translation>TYP</translation>
+        <translation type="obsolete">TYP</translation>
     </message>
     <message>
         <source>ALL</source>
@@ -335,11 +357,11 @@ Wollen Sie sie speichern?</translation>
     </message>
     <message>
         <source>TRANSITION</source>
-        <translation>ÜBERGANG</translation>
+        <translation type="obsolete">ÜBERGANG</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>ZÄHLER</translation>
+        <translation type="obsolete">ZÄHLER</translation>
     </message>
     <message>
         <source>None</source>
@@ -479,7 +501,7 @@ Wollen Sie es überschreiben?</translation>
     </message>
     <message>
         <source>Timed(Wait</source>
-        <translation>Zeitstart(Warte</translation>
+        <translation type="obsolete">Zeitstart(Warte</translation>
     </message>
     <message>
         <source>, Post</source>
@@ -529,6 +551,58 @@ Wollen Sie es überschreiben?</translation>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Länge</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Start</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Ende</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished">Zähler</translation>
+    </message>
+    <message>
+        <source>Artist Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -587,7 +661,7 @@ einem bereits existierendem Event.</translation>
     <name>EditGrid</name>
     <message>
         <source>Edit Grid:</source>
-        <translation>Grid editieren:</translation>
+        <translation type="obsolete">Grid editieren:</translation>
     </message>
     <message>
         <source>Edit Clock</source>
@@ -618,6 +692,10 @@ einem bereits existierendem Event.</translation>
         <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -657,6 +735,41 @@ einem bereits existierendem Event.</translation>
         <translation>Abbre&amp;chen</translation>
     </message>
 </context>
+<context>
+    <name>EditSchedCodeRules</name>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">Abbre&amp;chen</translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished">Code:</translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished">Max. hintereinander:</translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished">Mindestwartezeit:</translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished">Plane nicht nach:</translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished">oder nach:</translation>
+    </message>
+</context>
 <context>
     <name>EditSchedRules</name>
     <message>
@@ -725,6 +838,14 @@ Wollen Sie sie speichern?</translation>
         <source>Import Rules from Clock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>None</source>
+        <translation type="obsolete">Keine</translation>
+    </message>
+    <message>
+        <source>(This setting is deprecated and has been moved to events)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -800,7 +921,7 @@ Wollen Sie sie speichern?</translation>
 will remove any merged Music or Traffic events.
 
 Recreate?</source>
-        <translation>existiert bereits. Es erneut zu erstellen
+        <translation type="obsolete">existiert bereits. Es erneut zu erstellen
 wird alle verbundene Musik oder Traffic Events entfernen.
 
 Neu erstellen?</translation>
@@ -816,7 +937,7 @@ Neu erstellen?</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>Voice Tracks die mit diesem Log verbunden sind.
+        <translation type="obsolete">Voice Tracks die mit diesem Log verbunden sind.
 Fortfahren?</translation>
     </message>
     <message>
@@ -825,16 +946,16 @@ Fortfahren?</translation>
     </message>
     <message>
         <source>No Errors</source>
-        <translation>Keine Fehler</translation>
+        <translation type="unfinished">Keine Fehler</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation>Keine Fehler gefunden.</translation>
+        <translation type="obsolete">Keine Fehler gefunden.</translation>
     </message>
     <message>
         <source>already contains merged music and/or traffic data.
 Remerging it will remove this data.  Remerge?</source>
-        <translation>enthält bereits eingebundene Musik- und/oder Trafficdaten.
+        <translation type="obsolete">enthält bereits eingebundene Musik- und/oder Trafficdaten.
 Erneutes einbinden wird diese löschen. Erneut einbinden?</translation>
     </message>
     <message>
@@ -844,7 +965,7 @@ Erneutes einbinden wird diese löschen. Erneut einbinden?</translation>
     <message>
         <source>already contains merged traffic data.  Remerging it
 will remove this data.  Remerge?</source>
-        <translation>enthält bereits verbundene Trafficdaten. Erneutes
+        <translation type="obsolete">enthält bereits verbundene Trafficdaten. Erneutes
 Einbinden wird diese entfernen. Fortfahren?</translation>
     </message>
     <message>
@@ -853,7 +974,7 @@ Einbinden wird diese entfernen. Fortfahren?</translation>
     </message>
     <message>
         <source>Generate Log - User: </source>
-        <translation>Generiere Log - User: </translation>
+        <translation type="obsolete">Generiere Log - User: </translation>
     </message>
     <message>
         <source>Error</source>
@@ -879,6 +1000,50 @@ Einbinden wird diese entfernen. Fortfahren?</translation>
         <source>Unable to link traffic log</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Generate Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already exists.  Recreating it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>will remove any merged Music or Traffic events.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recreate?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged music and/or traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remerging it will remove this data.  Remerge?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cannot be relinked.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No broken rules or validation exceptions found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
@@ -900,15 +1065,15 @@ Einbinden wird diese entfernen. Fortfahren?</translation>
     </message>
     <message>
         <source>Set PLAY Transition</source>
-        <translation>PLAY-Übergang setzen</translation>
+        <translation type="obsolete">PLAY-Übergang setzen</translation>
     </message>
     <message>
         <source>Set SEGUE Transition</source>
-        <translation>SEGUE-Übergang setzen</translation>
+        <translation type="obsolete">SEGUE-Übergang setzen</translation>
     </message>
     <message>
         <source>Set STOP Transition</source>
-        <translation>STOP-Übergang setzen</translation>
+        <translation type="obsolete">STOP-Übergang setzen</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -942,6 +1107,18 @@ Einbinden wird diese entfernen. Fortfahren?</translation>
         <source>STOP</source>
         <translation>STOP</translation>
     </message>
+    <message>
+        <source>PLAY Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
@@ -1012,7 +1189,7 @@ Einbinden wird diese entfernen. Fortfahren?</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Löschen von</translation>
+        <translation type="obsolete">Löschen von</translation>
     </message>
     <message>
         <source>Delete Clock</source>
@@ -1020,7 +1197,7 @@ delete</source>
     </message>
     <message>
         <source>is in use in the following grid(s):</source>
-        <translation>wird von folgenden grid(s) verwendet:</translation>
+        <translation type="obsolete">wird von folgenden grid(s) verwendet:</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1032,7 +1209,19 @@ delete</source>
     </message>
     <message>
         <source>Log Clocks - User: </source>
-        <translation>Log-Uhrenbenutzer: </translation>
+        <translation type="obsolete">Log-Uhrenbenutzer: </translation>
+    </message>
+    <message>
+        <source>Log Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following grid(s)</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1100,7 +1289,7 @@ delete</source>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Löschen von</translation>
+        <translation type="obsolete">Löschen von</translation>
     </message>
     <message>
         <source>Delete Event</source>
@@ -1108,7 +1297,7 @@ delete</source>
     </message>
     <message>
         <source>is in use in the following clocks:</source>
-        <translation>wird von folgenden Uhren verwendet:</translation>
+        <translation type="obsolete">wird von folgenden Uhren verwendet:</translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1120,7 +1309,19 @@ delete</source>
     </message>
     <message>
         <source>Log Events - User: </source>
-        <translation>Log-Events-Benutzer: </translation>
+        <translation type="obsolete">Log-Events-Benutzer: </translation>
+    </message>
+    <message>
+        <source>Log Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following clocks</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1154,11 +1355,11 @@ delete</source>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVICE</translation>
+        <translation type="obsolete">SERVICE</translation>
     </message>
     <message>
         <source>OLDEST REPORT</source>
-        <translation>ÄLTESTER REPORT</translation>
+        <translation type="obsolete">ÄLTESTER REPORT</translation>
     </message>
     <message>
         <source>&amp;Generate
@@ -1180,12 +1381,20 @@ Data</source>
         <source>[none]</source>
         <translation>[keine]</translation>
     </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Oldest Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Kann nicht verbinden</translation>
+        <translation type="obsolete">Kann nicht verbinden</translation>
     </message>
     <message>
         <source>RDLogManager</source>
@@ -1221,15 +1430,10 @@ Data</source>
     </message>
     <message>
         <source>RDLogManager - User: </source>
-        <translation>RDLogManager - Benutzer: </translation>
+        <translation type="obsolete">RDLogManager - Benutzer: </translation>
     </message>
     <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogManager is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
+        <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1283,14 +1487,26 @@ Report</translation>
     </message>
     <message>
         <source>Report Complete</source>
-        <translation>Report komplett</translation>
+        <translation type="obsolete">Report komplett</translation>
     </message>
     <message>
         <source>Report complete!</source>
         <translation type="obsolete">Report komplett!</translation>
     </message>
     <message>
-        <source>Report generated in</source>
+        <source>File Exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file at</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The report file already exists.  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1377,35 +1593,31 @@ Data</source>
     <name>editSchedCodeRules</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Abbre&amp;chen</translation>
+        <translation type="obsolete">Abbre&amp;chen</translation>
     </message>
     <message>
         <source>Code:</source>
-        <translation>Code:</translation>
+        <translation type="obsolete">Code:</translation>
     </message>
     <message>
         <source>Max. in a row:</source>
-        <translation>Max. hintereinander:</translation>
+        <translation type="obsolete">Max. hintereinander:</translation>
     </message>
     <message>
         <source>Min. wait:</source>
-        <translation>Mindestwartezeit:</translation>
+        <translation type="obsolete">Mindestwartezeit:</translation>
     </message>
     <message>
         <source>Do not schedule after:</source>
-        <translation>Plane nicht nach:</translation>
+        <translation type="obsolete">Plane nicht nach:</translation>
     </message>
     <message>
         <source>Or after:</source>
-        <translation>oder nach:</translation>
-    </message>
-    <message>
-        <source>Edit Rules for Code</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">oder nach:</translation>
     </message>
 </context>
 </TS>
