@@ -1,9 +1,11 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AddClock</name>
     <message>
         <source>Add Log Clock</source>
-        <translation>Adicionar Relógio </translation>
+        <translation type="obsolete">Adicionar Relógio </translation>
     </message>
     <message>
         <source>&amp;New Clock Name:</source>
@@ -17,6 +19,10 @@
         <source>&amp;Cancel</source>
         <translation>&amp;Cancelar</translation>
     </message>
+    <message>
+        <source>Add Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddEvent</name>
@@ -48,7 +54,7 @@
     <name>EditClock</name>
     <message>
         <source>Edit Clock:</source>
-        <translation>Editar Relogio:</translation>
+        <translation type="obsolete">Editar Relogio:</translation>
     </message>
     <message>
         <source>Code:</source>
@@ -169,7 +175,7 @@ Você quer salvar?</translation>
     </message>
     <message>
         <source>--- End of clock ---</source>
-        <translation>-- Fim do Relógio --</translation>
+        <translation type="obsolete">-- Fim do Relógio --</translation>
     </message>
     <message>
         <source>Invalid Code</source>
@@ -196,6 +202,22 @@ Você quer salvar?</translation>
 </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Clock</source>
+        <translation type="unfinished">Editar Relógio</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>That event does not exist.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEvent</name>
@@ -225,35 +247,35 @@ Você quer salvar?</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>CARTÃO</translation>
+        <translation type="obsolete">CARTÃO</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPO</translation>
+        <translation type="obsolete">GRUPO</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>DURAÇÃO</translation>
+        <translation type="obsolete">DURAÇÃO</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TÍTULO</translation>
+        <translation type="obsolete">TÍTULO</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTISTA</translation>
+        <translation type="obsolete">ARTISTA</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>INÍCIO</translation>
+        <translation type="obsolete">INÍCIO</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>TÉRMINO</translation>
+        <translation type="obsolete">TÉRMINO</translation>
     </message>
     <message>
         <source>TYPE</source>
-        <translation>TIPO</translation>
+        <translation type="obsolete">TIPO</translation>
     </message>
     <message>
         <source>REMARKS</source>
@@ -345,11 +367,11 @@ Você quer salvar?</translation>
     </message>
     <message>
         <source>TRANSITION</source>
-        <translation>TRANSIÇÃO</translation>
+        <translation type="obsolete">TRANSIÇÃO</translation>
     </message>
     <message>
         <source>COUNT</source>
-        <translation>CONTADOR</translation>
+        <translation type="obsolete">CONTADOR</translation>
     </message>
     <message>
         <source>None</source>
@@ -489,7 +511,7 @@ Você quer sobreescrêve-lo?</translation>
     </message>
     <message>
         <source>Timed(Wait</source>
-        <translation>Hora Certa(Esperar)</translation>
+        <translation type="obsolete">Hora Certa(Esperar)</translation>
     </message>
     <message>
         <source>, Post</source>
@@ -531,6 +553,58 @@ Você quer sobreescrêve-lo?</translation>
         <source>and code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Timed(Wait)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Duração</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Início</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Fim</translation>
+    </message>
+    <message>
+        <source>Type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Count</source>
+        <translation type="unfinished">Contador</translation>
+    </message>
+    <message>
+        <source>Artist Separation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditEventLine</name>
@@ -589,7 +663,7 @@ evento existente.</translation>
     <name>EditGrid</name>
     <message>
         <source>Edit Grid:</source>
-        <translation>Editar Grade:</translation>
+        <translation type="obsolete">Editar Grade:</translation>
     </message>
     <message>
         <source>Edit Clock</source>
@@ -620,6 +694,10 @@ evento existente.</translation>
         <source>This operation cannot be undone!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Grid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditNote</name>
@@ -659,6 +737,41 @@ evento existente.</translation>
         <translation>&amp;Cancelar</translation>
     </message>
 </context>
+<context>
+    <name>EditSchedCodeRules</name>
+    <message>
+        <source>Edit Rules for Code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Cancelar</translation>
+    </message>
+    <message>
+        <source>Code:</source>
+        <translation type="unfinished">Código:</translation>
+    </message>
+    <message>
+        <source>Max. in a row:</source>
+        <translation type="unfinished">Max. na Sequência:</translation>
+    </message>
+    <message>
+        <source>Min. wait:</source>
+        <translation type="unfinished">Min. Espera:</translation>
+    </message>
+    <message>
+        <source>Do not schedule after:</source>
+        <translation type="unfinished">Não agende depois de:</translation>
+    </message>
+    <message>
+        <source>Or after:</source>
+        <translation type="unfinished">Ou depois de:</translation>
+    </message>
+</context>
 <context>
     <name>EditSchedRules</name>
     <message>
@@ -727,6 +840,14 @@ Você quer salvar?</translation>
         <source>Import Rules from Clock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>None</source>
+        <translation type="obsolete">Nenhum</translation>
+    </message>
+    <message>
+        <source>(This setting is deprecated and has been moved to events)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTrack</name>
@@ -747,7 +868,7 @@ Você quer salvar?</translation>
     <name>GenerateLog</name>
     <message>
         <source>Generate Log - User: </source>
-        <translation>Gerar Lista - Usuário: </translation>
+        <translation type="obsolete">Gerar Lista - Usuário: </translation>
     </message>
     <message>
         <source>Generating Log...</source>
@@ -806,7 +927,7 @@ Você quer salvar?</translation>
 will remove any merged Music or Traffic events.
 
 Recreate?</source>
-        <translation>já Existe.  Recriando-a
+        <translation type="obsolete">já Existe.  Recriando-a
 removerá todos os Eventos de Tráfego e Música.
 
 Recriar?</translation>
@@ -822,7 +943,7 @@ Recriar?</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>Faixas de voz associadas a esta lista.
+        <translation type="obsolete">Faixas de voz associadas a esta lista.
 Continue</translation>
     </message>
     <message>
@@ -831,16 +952,16 @@ Continue</translation>
     </message>
     <message>
         <source>No Errors</source>
-        <translation>Sem Erros</translation>
+        <translation type="unfinished">Sem Erros</translation>
     </message>
     <message>
         <source>No exceptions found.</source>
-        <translation>Exceções não encontradas. Parabéns. </translation>
+        <translation type="obsolete">Exceções não encontradas. Parabéns. </translation>
     </message>
     <message>
         <source>already contains merged music and/or traffic data.
 Remerging it will remove this data.  Remerge?</source>
-        <translation>já contém dados de músicas e/ou tráfego agregados.
+        <translation type="obsolete">já contém dados de músicas e/ou tráfego agregados.
 Re-agregar removerá estes dados.  Re-agregar? </translation>
     </message>
     <message>
@@ -850,7 +971,7 @@ Re-agregar removerá estes dados.  Re-agregar? </translation>
     <message>
         <source>already contains merged traffic data.  Remerging it
 will remove this data.  Remerge?</source>
-        <translation>já contém dados de tráfego agregados.
+        <translation type="obsolete">já contém dados de tráfego agregados.
 Re-agregar removerá estes dados.  Re-agregar? </translation>
     </message>
     <message>
@@ -881,6 +1002,50 @@ Re-agregar removerá estes dados.  Re-agregar? </translation>
         <source>Unable to link traffic log</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Generate Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already exists.  Recreating it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>will remove any merged Music or Traffic events.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recreate?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with this log.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged music and/or traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remerging it will remove this data.  Remerge?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>already contains merged traffic data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>cannot be relinked.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No broken rules or validation exceptions found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
@@ -902,15 +1067,15 @@ Re-agregar removerá estes dados.  Re-agregar? </translation>
     </message>
     <message>
         <source>Set PLAY Transition</source>
-        <translation>Setar transição SIMPLES</translation>
+        <translation type="obsolete">Setar transição SIMPLES</translation>
     </message>
     <message>
         <source>Set SEGUE Transition</source>
-        <translation>Setar transição SOBRE</translation>
+        <translation type="obsolete">Setar transição SOBRE</translation>
     </message>
     <message>
         <source>Set STOP Transition</source>
-        <translation>Setar transição PARE</translation>
+        <translation type="obsolete">Setar transição PARE</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -944,12 +1109,24 @@ Re-agregar removerá estes dados.  Re-agregar? </translation>
         <source>STOP</source>
         <translation>PARE</translation>
     </message>
+    <message>
+        <source>PLAY Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SEGUE Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>STOP Transition</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListClocks</name>
     <message>
         <source>Log Clocks - User: </source>
-        <translation>Relógios - Usuário: </translation>
+        <translation type="obsolete">Relógios - Usuário: </translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1018,7 +1195,7 @@ Re-agregar removerá estes dados.  Re-agregar? </translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Tem certeza que quer 
+        <translation type="obsolete">Tem certeza que quer 
 deletar</translation>
     </message>
     <message>
@@ -1027,7 +1204,7 @@ deletar</translation>
     </message>
     <message>
         <source>is in use in the following grid(s):</source>
-        <translation>está em uso nas seguintes grade(s): </translation>
+        <translation type="obsolete">está em uso nas seguintes grade(s): </translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1037,12 +1214,24 @@ deletar</translation>
         <source>Clock In Use</source>
         <translation>Relógio em Uso</translation>
     </message>
+    <message>
+        <source>Log Clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following grid(s)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListEvents</name>
     <message>
         <source>Log Events - User: </source>
-        <translation>Eventos - Usuário: </translation>
+        <translation type="obsolete">Eventos - Usuário: </translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1107,7 +1296,7 @@ deletar</translation>
     <message>
         <source>Are you sure you want to
 delete</source>
-        <translation>Tem certeza que quer 
+        <translation type="obsolete">Tem certeza que quer 
 deletar</translation>
     </message>
     <message>
@@ -1116,7 +1305,7 @@ deletar</translation>
     </message>
     <message>
         <source>is in use in the following clocks:</source>
-        <translation>está em uso nas seguintes relógio(s): </translation>
+        <translation type="obsolete">está em uso nas seguintes relógio(s): </translation>
     </message>
     <message>
         <source>Do you still want to delete it?</source>
@@ -1126,6 +1315,18 @@ deletar</translation>
         <source>Event In Use</source>
         <translation>Evento em Uso</translation>
     </message>
+    <message>
+        <source>Log Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is in use in the following clocks</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListGrids</name>
@@ -1158,11 +1359,11 @@ deletar</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SERVIÇO</translation>
+        <translation type="obsolete">SERVIÇO</translation>
     </message>
     <message>
         <source>OLDEST REPORT</source>
-        <translation>RELATÓRIO MAIS VELHO</translation>
+        <translation type="obsolete">RELATÓRIO MAIS VELHO</translation>
     </message>
     <message>
         <source>&amp;Generate
@@ -1184,6 +1385,14 @@ Dados</translation>
         <source>[none]</source>
         <translation>[nenhum]</translation>
     </message>
+    <message>
+        <source>Service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Oldest Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
@@ -1193,7 +1402,7 @@ Dados</translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Não foi possível conectar</translation>
+        <translation type="obsolete">Não foi possível conectar</translation>
     </message>
     <message>
         <source>Select an operation:</source>
@@ -1225,15 +1434,10 @@ Dados</translation>
     </message>
     <message>
         <source>RDLogManager - User: </source>
-        <translation>RDControle - Usuario: </translation>
+        <translation type="obsolete">RDControle - Usuario: </translation>
     </message>
     <message>
-        <source>RDLogEdit -- Database Skew</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>This version of RDLogManager is incompatible with the version installed on the server.
-See your system administrator for an update!</source>
+        <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1287,14 +1491,26 @@ Relatório</translation>
     </message>
     <message>
         <source>Report Complete</source>
-        <translation>Relatório Completo</translation>
+        <translation type="obsolete">Relatório Completo</translation>
     </message>
     <message>
         <source>Report complete!</source>
         <translation type="obsolete">Relatório Completo!</translation>
     </message>
     <message>
-        <source>Report generated in</source>
+        <source>File Exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file at</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The report file already exists.  Overwrite?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1381,35 +1597,31 @@ Dados</translation>
     <name>editSchedCodeRules</name>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Cancelar</translation>
+        <translation type="obsolete">&amp;Cancelar</translation>
     </message>
     <message>
         <source>Code:</source>
-        <translation>Código:</translation>
+        <translation type="obsolete">Código:</translation>
     </message>
     <message>
         <source>Max. in a row:</source>
-        <translation>Max. na Sequência:</translation>
+        <translation type="obsolete">Max. na Sequência:</translation>
     </message>
     <message>
         <source>Min. wait:</source>
-        <translation>Min. Espera:</translation>
+        <translation type="obsolete">Min. Espera:</translation>
     </message>
     <message>
         <source>Do not schedule after:</source>
-        <translation>Não agende depois de:</translation>
+        <translation type="obsolete">Não agende depois de:</translation>
     </message>
     <message>
         <source>Or after:</source>
-        <translation>Ou depois de:</translation>
-    </message>
-    <message>
-        <source>Edit Rules for Code</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Ou depois de:</translation>
     </message>
 </context>
 </TS>
