@@ -2,7 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools SRC-8 III
 //
-//   (C) Copyright 2002-2005,2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,13 +18,14 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qtimer.h>
-
 #include <stdlib.h>
 
-#include <globals.h>
-#include <btsrc8iii.h>
+#include <qtimer.h>
 
+#include <rdapplication.h>
+
+#include "btsrc8iii.h"
+#include "globals.h"
 
 BtSrc8Iii::BtSrc8Iii(RDMatrix *matrix,QObject *parent)
   : Switcher(matrix,parent)
@@ -48,14 +49,14 @@ BtSrc8Iii::BtSrc8Iii(RDMatrix *matrix,QObject *parent)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   bt_device=new RDTTYDevice();
   if(tty->active()) {
     bt_device->setName(tty->port());
     bt_device->setSpeed(tty->baudRate());
     bt_device->setWordLength(tty->dataBits());
     bt_device->setParity(tty->parity());
-    bt_device->open(IO_Raw|IO_ReadWrite);
+    bt_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 
@@ -121,14 +122,14 @@ void BtSrc8Iii::processCommand(RDMacro *cmd)
   switch(cmd->command()) {
       case RDMacro::GO:
 	if((cmd->argQuantity()!=5)||
-	   ((cmd->arg(1).toString().lower()!="i")&&
-	    (cmd->arg(1).toString().lower()!="o"))||
+	   ((cmd->arg(1).lower()!="i")&&
+	    (cmd->arg(1).lower()!="o"))||
 	   (cmd->arg(2).toInt()<1)||(cmd->arg(3).toInt()>bt_gpos)||
 	   (cmd->arg(2).toInt()>bt_gpos)||
 	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
-	    (cmd->arg(1).toString().lower()!="i"))||
+	    (cmd->arg(1).lower()!="i"))||
 	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
-	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).toString().lower()=="i"))||
+	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).lower()=="i"))||
 	   (cmd->arg(4).toInt()<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
@@ -136,16 +137,16 @@ void BtSrc8Iii::processCommand(RDMacro *cmd)
 	}
 	if(cmd->arg(3).toInt()==0) {  // Turn OFF
 	  if(cmd->arg(4).toInt()==0) {
-	    if(cmd->arg(1).toString().lower()=="i") {
+	    if(cmd->arg(1).lower()=="i") {
 	      if(bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
 		bt_gpi_state[cmd->arg(2).toInt()-1]=false;
 	      }
 	      bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 	    }
-	    if(cmd->arg(1).toString().lower()=="o") {
+	    if(cmd->arg(1).lower()=="o") {
 	      sprintf(str,"*%dOR%dF\r\n",BTSRC8III_UNIT_ID,cmd->arg(2).toInt());
-	      bt_device->writeBlock(str,8);
+	      bt_device->write(str,8);
 	      emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
 	    }
 	  }
@@ -160,26 +161,26 @@ void BtSrc8Iii::processCommand(RDMacro *cmd)
 	else {
 	  if(cmd->arg(3).toInt()==-1) {  // Clear input
 	    bt_gpi_mask[cmd->arg(2).toInt()-1]=false;
-	    bt_device->writeBlock("*0SPA\r\n",7);
+	    bt_device->write("*0SPA\r\n",7);
 	  }
 	  else { 
 	    if(cmd->arg(4).toInt()==0) {  // Turn ON
-	      if(cmd->arg(1).toString().lower()=="i") {
+	      if(cmd->arg(1).lower()=="i") {
 		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
 		}
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 	      }
-	      if(cmd->arg(1).toString().lower()=="o") {
+	      if(cmd->arg(1).lower()=="o") {
 		sprintf(str,"*%dOR%dL\r\n",
 			BTSRC8III_UNIT_ID,cmd->arg(2).toInt());
-		bt_device->writeBlock(str,8);
+		bt_device->write(str,8);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 	      }
 	    }
 	    else {  // Pulse
-	      if(cmd->arg(1).toString().lower()=="i") {
+	      if(cmd->arg(1).lower()=="i") {
 		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
@@ -187,11 +188,11 @@ void BtSrc8Iii::processCommand(RDMacro *cmd)
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 		bt_gpi_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
-	      if(cmd->arg(1).toString().lower()=="o") {
+	      if(cmd->arg(1).lower()=="o") {
 		sprintf(str,"*%dOR%dP%02d\r\n",
 			BTSRC8III_UNIT_ID,cmd->arg(2).toInt(),
 			cmd->arg(4).toInt()/100+1);
-		bt_device->writeBlock(str,10);
+		bt_device->write(str,10);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		bt_gpo_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
@@ -218,7 +219,7 @@ void BtSrc8Iii::processStatus()
   int n;
   int gpi;
 
-  while((n=bt_device->readBlock(buffer,255))>0) {
+  while((n=bt_device->read(buffer,255))>0) {
     for(int i=0;i<n;i++) {
       switch(bt_istate) {
 	  case 0:
@@ -316,7 +317,7 @@ void BtSrc8Iii::processStatus()
 void BtSrc8Iii::gpiOneshotData(int value)
 {
   bt_gpi_mask[value]=false;
-  bt_device->writeBlock("*0SPA",5);
+  bt_device->write("*0SPA",5);
 }
 
 
