@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools SS 12.4
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: btss124.cpp,v 1.6 2007/11/09 18:51:19 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,16 +18,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qtimer.h>
-
 #include <stdlib.h>
 
-#include <globals.h>
-#include <btss124.h>
+#include <qtimer.h>
 
+#include <rdapplication.h>
 
-BtSs124::BtSs124(RDMatrix *matrix,QObject *parent,const char *name)
-  : QObject(parent,name)
+#include "btss124.h"
+#include "globals.h"
+
+BtSs124::BtSs124(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   //
   // Get Matrix Parameters
@@ -37,20 +36,18 @@ BtSs124::BtSs124(RDMatrix *matrix,QObject *parent,const char *name)
   bt_matrix=matrix->matrix();
   bt_inputs=matrix->inputs();
   bt_outputs=matrix->outputs();
-  bt_gpis=matrix->gpis();
-  bt_gpos=matrix->gpos();
 
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   bt_device=new RDTTYDevice();
   if(tty->active()) {
     bt_device->setName(tty->port());
     bt_device->setSpeed(tty->baudRate());
     bt_device->setWordLength(tty->dataBits());
     bt_device->setParity(tty->parity());
-    bt_device->open(IO_Raw|IO_ReadWrite);
+    bt_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 }
@@ -62,6 +59,36 @@ BtSs124::~BtSs124()
 }
 
 
+RDMatrix::Type BtSs124::type()
+{
+  return RDMatrix::BtSs124;
+}
+
+
+unsigned BtSs124::gpiQuantity()
+{
+  return 0;
+}
+
+
+unsigned BtSs124::gpoQuantity()
+{
+  return 0;
+}
+
+
+bool BtSs124::primaryTtyActive()
+{
+  return true;
+}
+
+
+bool BtSs124::secondaryTtyActive()
+{
+  return false;
+}
+
+
 void BtSs124::processCommand(RDMacro *cmd)
 {
   char str[9];
@@ -76,7 +103,7 @@ void BtSs124::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"*%d%02d%d",BTSS124_UNIT_ID,
 		cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	bt_device->writeBlock(str,5);
+	bt_device->write(str,5);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -90,7 +117,7 @@ void BtSs124::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"*%d%02dM%d",BTSS124_UNIT_ID,
 		cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	bt_device->writeBlock(str,6);
+	bt_device->write(str,6);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -104,21 +131,21 @@ void BtSs124::processCommand(RDMacro *cmd)
 	}
 	if(cmd->arg(1).toInt()==0) {
 	  sprintf(str,"*%dM%d",BTSS124_UNIT_ID,cmd->arg(2).toInt());
-	  bt_device->writeBlock(str,4);
+	  bt_device->write(str,4);
 	}
 	else {
 	  sprintf(str,"*%d%02d%d",BTSS124_UNIT_ID,
 		  cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	  bt_device->writeBlock(str,5);
+	  bt_device->write(str,5);
 	  for(int i=1;i<cmd->arg(1).toInt();i++) {
 	    sprintf(str,"*%d%02dM%d",BTSS124_UNIT_ID,
 		    i,cmd->arg(2).toInt());
-	    bt_device->writeBlock(str,6);
+	    bt_device->write(str,6);
 	  }
 	  for(int i=cmd->arg(1).toInt()+1;i<9;i++) {
 	    sprintf(str,"*%d%02dM%d",BTSS124_UNIT_ID,
 		    i,cmd->arg(2).toInt());
-	    bt_device->writeBlock(str,6);
+	    bt_device->write(str,6);
 	  }
 	}
 	cmd->acknowledge(true);
@@ -131,8 +158,3 @@ void BtSs124::processCommand(RDMacro *cmd)
 	break;
   }
 }
-
-
-void BtSs124::processStatus()
-{
-}
