@@ -2,7 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools SS 4.2
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,12 +18,14 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qtimer.h>
-
 #include <stdlib.h>
 
-#include <globals.h>
-#include <btss42.h>
+#include <qtimer.h>
+
+#include <rdapplication.h>
+
+#include "btss42.h"
+#include "globals.h"
 
 BtSs42::BtSs42(RDMatrix *matrix,QObject *parent)
   : Switcher(matrix,parent)
@@ -49,14 +51,14 @@ BtSs42::BtSs42(RDMatrix *matrix,QObject *parent)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   bt_device=new RDTTYDevice();
   if(tty->active()) {
     bt_device->setName(tty->port());
     bt_device->setSpeed(tty->baudRate());
     bt_device->setWordLength(tty->dataBits());
     bt_device->setParity(tty->parity());
-    bt_device->open(IO_Raw|IO_ReadWrite);
+    bt_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 
@@ -122,14 +124,14 @@ void BtSs42::processCommand(RDMacro *cmd)
   switch(cmd->command()) {
       case RDMacro::GO:
 	if((cmd->argQuantity()!=5)||
-	   ((cmd->arg(1).toString().lower()!="i")&&
-	    (cmd->arg(1).toString().lower()!="o"))||
+	   ((cmd->arg(1).lower()!="i")&&
+	    (cmd->arg(1).lower()!="o"))||
 	   (cmd->arg(2).toInt()<1)||(cmd->arg(3).toInt()>bt_gpos)||
 	   (cmd->arg(2).toInt()>bt_gpos)||
 	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
-	    (cmd->arg(1).toString().lower()!="i"))||
+	    (cmd->arg(1).lower()!="i"))||
 	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
-	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).toString().lower()=="i"))||
+	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).lower()=="i"))||
 	   (cmd->arg(4).toInt()<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
@@ -137,21 +139,21 @@ void BtSs42::processCommand(RDMacro *cmd)
 	}
 	if(cmd->arg(3).toInt()==0) {  // Turn OFF
 	  if(cmd->arg(4).toInt()==0) {
-	    if(cmd->arg(1).toString().lower()=="i") {
+	    if(cmd->arg(1).lower()=="i") {
 	      if(bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
 		bt_gpi_state[cmd->arg(2).toInt()-1]=false;
 	      }
 	      bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 	    }
-	    if(cmd->arg(1).toString().lower()=="o") {
+	    if(cmd->arg(1).lower()=="o") {
 	      if(cmd->arg(2).toInt()<=4) {
 		sprintf(str,"*%dOO%dF",BTSS42_UNIT_ID,cmd->arg(2).toInt());
 	      }
 	      else {
 		sprintf(str,"*%dOR%dF",BTSS42_UNIT_ID,cmd->arg(2).toInt()-4);
 	      }
-	      bt_device->writeBlock(str,6);
+	      bt_device->write(str,6);
 	      emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
 	    }
 	  }
@@ -166,30 +168,30 @@ void BtSs42::processCommand(RDMacro *cmd)
 	else {
 	  if(cmd->arg(3).toInt()==-1) {  // Clear input
 	    bt_gpi_mask[cmd->arg(2).toInt()-1]=false;
-	    bt_device->writeBlock("*0SPA",5);
+	    bt_device->write("*0SPA",5);
 	  }
 	  else { 
 	    if(cmd->arg(4).toInt()==0) {  // Turn ON
-	      if(cmd->arg(1).toString().lower()=="i") {
+	      if(cmd->arg(1).lower()=="i") {
 		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
 		}
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 	      }
-	      if(cmd->arg(1).toString().lower()=="o") {
+	      if(cmd->arg(1).lower()=="o") {
 		if(cmd->arg(2).toInt()<=4) {
 		  sprintf(str,"*%dOO%dL",BTSS42_UNIT_ID,cmd->arg(2).toInt());
 		}
 		else {
 		  sprintf(str,"*%dOR%dL",BTSS42_UNIT_ID,cmd->arg(2).toInt()-4);
 		}
-		bt_device->writeBlock(str,6);
+		bt_device->write(str,6);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 	      }
 	    }
 	    else {  // Pulse
-	      if(cmd->arg(1).toString().lower()=="i") {
+	      if(cmd->arg(1).lower()=="i") {
 		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
@@ -197,14 +199,14 @@ void BtSs42::processCommand(RDMacro *cmd)
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 		bt_gpi_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
-	      if(cmd->arg(1).toString().lower()=="o") {
+	      if(cmd->arg(1).lower()=="o") {
 		if(cmd->arg(2).toInt()<=4) {
 		  sprintf(str,"*%dOO%dP",BTSS42_UNIT_ID,cmd->arg(2).toInt());
 		}
 		else {
 		  sprintf(str,"*%dOR%dP",BTSS42_UNIT_ID,cmd->arg(2).toInt()-4);
 		}
-		bt_device->writeBlock(str,6);
+		bt_device->write(str,6);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		bt_gpo_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
@@ -226,7 +228,7 @@ void BtSs42::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"*%d%02d%d",BTSS42_UNIT_ID,
 		cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	bt_device->writeBlock(str,5);
+	bt_device->write(str,5);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -240,7 +242,7 @@ void BtSs42::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"*%d%02dM%d",BTSS42_UNIT_ID,
 		cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	bt_device->writeBlock(str,6);
+	bt_device->write(str,6);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -254,21 +256,21 @@ void BtSs42::processCommand(RDMacro *cmd)
 	}
 	if(cmd->arg(1).toInt()==0) {
 	  sprintf(str,"*%dM%d",BTSS42_UNIT_ID,cmd->arg(2).toInt());
-	  bt_device->writeBlock(str,4);
+	  bt_device->write(str,4);
 	}
 	else {
 	  sprintf(str,"*%d%02d%d",BTSS42_UNIT_ID,
 		  cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	  bt_device->writeBlock(str,5);
+	  bt_device->write(str,5);
 	  for(int i=1;i<cmd->arg(1).toInt();i++) {
 	    sprintf(str,"*%d%02dM%d",BTSS42_UNIT_ID,
 		    i,cmd->arg(2).toInt());
-	    bt_device->writeBlock(str,6);
+	    bt_device->write(str,6);
 	  }
 	  for(int i=cmd->arg(1).toInt()+1;i<5;i++) {
 	    sprintf(str,"*%d%02dM%d",BTSS42_UNIT_ID,
 		    i,cmd->arg(2).toInt());
-	    bt_device->writeBlock(str,6);
+	    bt_device->write(str,6);
 	  }
 	}
 	cmd->acknowledge(true);
@@ -289,7 +291,7 @@ void BtSs42::processStatus()
   int n;
   int gpi;
 
-  while((n=bt_device->readBlock(buffer,255))>0) {
+  while((n=bt_device->read(buffer,255))>0) {
     for(int i=0;i<n;i++) {
       switch(bt_istate) {
 	  case 0:
@@ -403,7 +405,7 @@ void BtSs42::processStatus()
 void BtSs42::gpiOneshotData(int value)
 {
   bt_gpi_mask[value]=false;
-  bt_device->writeBlock("*0SPA",5);
+  bt_device->write("*0SPA",5);
 }
 
 
