@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools SS 4.4
 //
-//   (C) Copyright 2002-2005,2009 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: btss44.cpp,v 1.3.8.1 2014/03/02 03:15:23 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,15 +18,17 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qtimer.h>
-
 #include <stdlib.h>
 
-#include <globals.h>
-#include <btss44.h>
+#include <qtimer.h>
 
-BtSs44::BtSs44(RDMatrix *matrix,QObject *parent,const char *name)
-  : Switcher(matrix,parent,name)
+#include <rdapplication.h>
+
+#include "btss44.h"
+#include "globals.h"
+
+BtSs44::BtSs44(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   //
   // Initialize Data Structures
@@ -51,14 +51,14 @@ BtSs44::BtSs44(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   bt_device=new RDTTYDevice();
   if(tty->active()) {
     bt_device->setName(tty->port());
     bt_device->setSpeed(tty->baudRate());
     bt_device->setWordLength(tty->dataBits());
     bt_device->setParity(tty->parity());
-    bt_device->open(IO_Raw|IO_ReadWrite);
+    bt_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 
@@ -66,11 +66,9 @@ BtSs44::BtSs44(RDMatrix *matrix,QObject *parent,const char *name)
   // Interval OneShots
   //
   bt_gpi_oneshot=new RDOneShot(this);
-  connect(bt_gpi_oneshot,SIGNAL(timeout(void *)),
-	  this,SLOT(gpiOneshotData(void*)));
+  connect(bt_gpi_oneshot,SIGNAL(timeout(int)),this,SLOT(gpiOneshotData(int)));
   bt_gpo_oneshot=new RDOneShot(this);
-  connect(bt_gpo_oneshot,SIGNAL(timeout(void *)),
-	  this,SLOT(gpoOneshotData(void*)));
+  connect(bt_gpo_oneshot,SIGNAL(timeout(int)),this,SLOT(gpoOneshotData(int)));
 
   //
   // The Poll Timer
@@ -127,14 +125,14 @@ void BtSs44::processCommand(RDMacro *cmd)
       case RDMacro::GO:
 // NEW
 	if((cmd->argQuantity()!=5)||
-	   ((cmd->arg(1).toString().lower()!="i")&&
-	    (cmd->arg(1).toString().lower()!="o"))||
+	   ((cmd->arg(1).lower()!="i")&&
+	    (cmd->arg(1).lower()!="o"))||
 	   (cmd->arg(2).toInt()<1)||(cmd->arg(3).toInt()>bt_gpos)||
 	   (cmd->arg(2).toInt()>bt_gpos)||
 	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
-	    (cmd->arg(1).toString().lower()!="i"))||
+	    (cmd->arg(1).lower()!="i"))||
 	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
-	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).toString().lower()=="i"))||
+	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).lower()=="i"))||
 	   (cmd->arg(4).toInt()<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
@@ -142,21 +140,21 @@ void BtSs44::processCommand(RDMacro *cmd)
 	}
 	if(cmd->arg(3).toInt()==0) {  // Turn OFF
 	  if(cmd->arg(4).toInt()==0) {
-	    if(cmd->arg(1).toString().lower()=="i") {
+	    if(cmd->arg(1).lower()=="i") {
 	      if(bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
 		bt_gpi_state[cmd->arg(2).toInt()-1]=false;
 	      }
 	      bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 	    }
-	    if(cmd->arg(1).toString().lower()=="o") {
+	    if(cmd->arg(1).lower()=="o") {
 	      if(cmd->arg(2).toInt()<=4) {
 		sprintf(str,"*%dOO%dF",BTSS44_UNIT_ID,cmd->arg(2).toInt());
 	      }
 	      else {
 		sprintf(str,"*%dOR%dF",BTSS44_UNIT_ID,cmd->arg(2).toInt()-4);
 	      }
-	      bt_device->writeBlock(str,6);
+	      bt_device->write(str,6);
 	      emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
 	    }
 	  }
@@ -171,47 +169,47 @@ void BtSs44::processCommand(RDMacro *cmd)
 	else {
 	  if(cmd->arg(3).toInt()==-1) {  // Clear input
 	    bt_gpi_mask[cmd->arg(2).toInt()-1]=false;
-	    bt_device->writeBlock("*0SPA",5);
+	    bt_device->write("*0SPA",5);
 	  }
 	  else { 
 	    if(cmd->arg(4).toInt()==0) {  // Turn ON
-	      if(cmd->arg(1).toString().lower()=="i") {
+	      if(cmd->arg(1).lower()=="i") {
 		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
 		}
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
 	      }
-	      if(cmd->arg(1).toString().lower()=="o") {
+	      if(cmd->arg(1).lower()=="o") {
 		if(cmd->arg(2).toInt()<=4) {
 		  sprintf(str,"*%dOO%dL",BTSS44_UNIT_ID,cmd->arg(2).toInt());
 		}
 		else {
 		  sprintf(str,"*%dOR%dL",BTSS44_UNIT_ID,cmd->arg(2).toInt()-4);
 		}
-		bt_device->writeBlock(str,6);
+		bt_device->write(str,6);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 	      }
 	    }
 	    else {  // Pulse
-	      if(cmd->arg(1).toString().lower()=="i") {
+	      if(cmd->arg(1).lower()=="i") {
 		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
 		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
 		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
 		}
 		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
-		bt_gpi_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+		bt_gpi_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
-	      if(cmd->arg(1).toString().lower()=="o") {
+	      if(cmd->arg(1).lower()=="o") {
 		if(cmd->arg(2).toInt()<=4) {
 		  sprintf(str,"*%dOO%dP",BTSS44_UNIT_ID,cmd->arg(2).toInt());
 		}
 		else {
 		  sprintf(str,"*%dOR%dP",BTSS44_UNIT_ID,cmd->arg(2).toInt()-4);
 		}
-		bt_device->writeBlock(str,6);
+		bt_device->write(str,6);
 		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
-		bt_gpo_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+		bt_gpo_oneshot->start(cmd->arg(2).toInt()-1,500);
 	      }
 	    }
 	  }
@@ -231,7 +229,7 @@ void BtSs44::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"*%d%02d%d",BTSS44_UNIT_ID,
 		cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	bt_device->writeBlock(str,5);
+	bt_device->write(str,5);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -245,7 +243,7 @@ void BtSs44::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"*%d%02dM%d",BTSS44_UNIT_ID,
 		cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	bt_device->writeBlock(str,6);
+	bt_device->write(str,6);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -259,21 +257,21 @@ void BtSs44::processCommand(RDMacro *cmd)
 	}
 	if(cmd->arg(1).toInt()==0) {
 	  sprintf(str,"*%dM%d",BTSS44_UNIT_ID,cmd->arg(2).toInt());
-	  bt_device->writeBlock(str,4);
+	  bt_device->write(str,4);
 	}
 	else {
 	  sprintf(str,"*%d%02d%d",BTSS44_UNIT_ID,
 		  cmd->arg(1).toInt(),cmd->arg(2).toInt());
-	  bt_device->writeBlock(str,5);
+	  bt_device->write(str,5);
 	  for(int i=1;i<cmd->arg(1).toInt();i++) {
 	    sprintf(str,"*%d%02dM%d",BTSS44_UNIT_ID,
 		    i,cmd->arg(2).toInt());
-	    bt_device->writeBlock(str,6);
+	    bt_device->write(str,6);
 	  }
 	  for(int i=cmd->arg(1).toInt()+1;i<5;i++) {
 	    sprintf(str,"*%d%02dM%d",BTSS44_UNIT_ID,
 		    i,cmd->arg(2).toInt());
-	    bt_device->writeBlock(str,6);
+	    bt_device->write(str,6);
 	  }
 	}
 	cmd->acknowledge(true);
@@ -294,7 +292,7 @@ void BtSs44::processStatus()
   int n;
   int gpi;
 
-  while((n=bt_device->readBlock(buffer,255))>0) {
+  while((n=bt_device->read(buffer,255))>0) {
     for(int i=0;i<n;i++) {
       switch(bt_istate) {
 	  case 0:
@@ -405,14 +403,14 @@ void BtSs44::processStatus()
 }
 
 
-void BtSs44::gpiOneshotData(void *data)
+void BtSs44::gpiOneshotData(int value)
 {
-  bt_gpi_mask[(long)data]=false;
-  bt_device->writeBlock("*0SPA",5);
+  bt_gpi_mask[value]=false;
+  bt_device->write("*0SPA",5);
 }
 
 
-void BtSs44::gpoOneshotData(void *data)
+void BtSs44::gpoOneshotData(int value)
 {
-  emit gpoChanged(bt_matrix,(long)data,false);
+  emit gpoChanged(bt_matrix,value,false);
 }
