@@ -2,7 +2,7 @@
 //
 // Local RML Macros for the Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,26 +18,29 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <errno.h>
 #include <stdlib.h>
+#include <syslog.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 
 #include <rd.h>
+#include <rdapplication.h>
 #include <rdconf.h>
-#include <rdmatrix.h>
-#include <rdtty.h>
-#include <rduser.h>
-#include <rddb.h>
-#include <ripcd.h>
 #include <rdescape_string.h>
+#include <rdmatrix.h>
+#include <rdpaths.h>
+#include <rdtty.h>
+
+#include "ripcd.h"
 
 void MainObject::gpiChangedData(int matrix,int line,bool state)
 {
   if(state) {
-    LogLine(RDConfig::LogInfo,QString().sprintf("GPI %d:%d ON",matrix,line+1));
+    rda->syslog(LOG_INFO,"GPI %d:%d ON",matrix,line+1);
   }
   else {
-    LogLine(RDConfig::LogInfo,QString().sprintf("GPI %d:%d OFF",matrix,line+1));
+    rda->syslog(LOG_INFO,"GPI %d:%d OFF",matrix,line+1);
   }
   ripcd_gpi_state[matrix][line]=state;
   BroadcastCommand(QString().sprintf("GI %d %d %d %d!",matrix,line,state,
@@ -55,10 +58,10 @@ void MainObject::gpiChangedData(int matrix,int line,bool state)
 void MainObject::gpoChangedData(int matrix,int line,bool state)
 {
   if(state) {
-    LogLine(RDConfig::LogInfo,QString().sprintf("GPO %d:%d ON",matrix,line+1));
+    rda->syslog(LOG_INFO,"GPO %d:%d ON",matrix,line+1);
   }
   else {
-    LogLine(RDConfig::LogInfo,QString().sprintf("GPO %d:%d OFF",matrix,line+1));
+    rda->syslog(LOG_INFO,"GPO %d:%d OFF",matrix,line+1);
   }
   ripcd_gpo_state[matrix][line]=state;
   BroadcastCommand(QString().sprintf("GO %d %d %d %d!",matrix,line,state,
@@ -104,7 +107,7 @@ void MainObject::ttyScanData()
 
   for(int i=0;i<MAX_TTYS;i++) {
     if(ripcd_tty_dev[i]!=NULL) {
-      while((n=ripcd_tty_dev[i]->readBlock(buf,255))>0) {
+      while((n=ripcd_tty_dev[i]->read(buf,255))>0) {
 	ripcd_tty_trap[i]->scan(buf,n);
       }
     }
@@ -117,10 +120,9 @@ void MainObject::ExecCart(int cartnum)
   RDMacro rml;
   rml.setRole(RDMacro::Cmd);
   rml.setCommand(RDMacro::EX);
-  rml.setAddress(rdstation->address());
+  rml.setAddress(rda->station()->address());
   rml.setEchoRequested(false);
-  rml.setArgQuantity(1);
-  rml.setArg(0,cartnum);
+  rml.addArg(cartnum);
   sendRml(&rml);
 }
 
@@ -132,7 +134,7 @@ void MainObject::LogGpioEvent(int matrix,int line,RDMatrix::GpioType type,
   RDSqlQuery *q;
 
   sql=QString("insert into GPIO_EVENTS set ")+
-    "STATION_NAME=\""+RDEscapeString(rdstation->name())+"\","+
+    "STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\","+
     QString().sprintf("MATRIX=%d,",matrix)+
     QString().sprintf("NUMBER=%d,",line+1)+
     QString().sprintf("TYPE=%d,",type)+
@@ -148,6 +150,7 @@ void MainObject::LoadLocalMacros()
   QString sql;
   RDSqlQuery *q;
   unsigned tty_port;
+  QString cmd;
 
   for(int i=0;i<MAX_MATRICES;i++) {
     ripcd_switcher_tty[i][0]=-1;
@@ -161,15 +164,20 @@ void MainObject::LoadLocalMacros()
   //
   // Initialize Matrices
   //
-  sql=QString().sprintf("select MATRIX,TYPE,PORT,INPUTS,OUTPUTS from MATRICES \
-                         where STATION_NAME=\"%s\"",
-			(const char *)rdstation->name());
+  sql=QString("select ")+
+    "MATRIX,"+   // 00
+    "TYPE,"+     // 01
+    "PORT,"+     // 02
+    "INPUTS,"+   // 03
+    "OUTPUTS "+  // 04
+    "from MATRICES where "+
+    "STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     if(!LoadSwitchDriver(q->value(0).toInt())) {
-      LogLine(RDConfig::LogErr,QString().
-	      sprintf("attempted to load unknown switcher driver for matrix %d",
-		      q->value(0).toInt()));
+      rda->syslog(LOG_WARNING,
+		  "attempted to load unknown switcher driver for matrix %d",
+		  q->value(0).toInt());
     }
   }
   delete q;
@@ -177,10 +185,16 @@ void MainObject::LoadLocalMacros()
   //
   // Initialize TTYs
   //
-  sql=QString().sprintf("select PORT_ID,PORT,BAUD_RATE,DATA_BITS,PARITY,\
-                         TERMINATION from TTYS where (STATION_NAME=\"%s\")&&\
-                         (ACTIVE=\"Y\")",
-			(const char *)rdstation->name());
+  sql=QString("select ")+
+    "PORT_ID,"+      // 00
+    "PORT,"+         // 01
+    "BAUD_RATE,"+    // 02
+    "DATA_BITS,"+    // 03
+    "PARITY,"+       // 04
+    "TERMINATION "+  // 05
+    "from TTYS where "+
+    "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+    "(ACTIVE=\"Y\")";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     tty_port=q->value(0).toUInt();
@@ -191,7 +205,7 @@ void MainObject::LoadLocalMacros()
       ripcd_tty_dev[tty_port]->setWordLength(q->value(3).toInt());
       ripcd_tty_dev[tty_port]->
 	setParity((RDTTYDevice::Parity)q->value(4).toInt());
-      if(ripcd_tty_dev[tty_port]->open(IO_ReadWrite)) {
+      if(ripcd_tty_dev[tty_port]->open(QIODevice::ReadWrite)) {
 	ripcd_tty_term[tty_port]=(RDTty::Termination)q->value(5).toInt();
 	ripcd_tty_inuse[tty_port]=true;
 	ripcd_tty_trap[tty_port]=new RDCodeTrap(this);
@@ -211,7 +225,7 @@ void MainObject::LoadLocalMacros()
 }
 
 
-void MainObject::RunLocalMacros(RDMacro *rml)
+void MainObject::RunLocalMacros(RDMacro *rml_in)
 {
   int matrix_num;
   int gpi;
@@ -223,17 +237,19 @@ void MainObject::RunLocalMacros(RDMacro *rml)
   RDSqlQuery *q;
   QHostAddress addr;
   RDUser *rduser;
-  char logstr[RD_RML_MAX_LENGTH];
+  QString logstr;
   char bin_buf[RD_RML_MAX_LENGTH];
   int d;
   RDMatrix::GpioType gpio_type;
   QByteArray data;
+  int err;
 
-  rml->generateString(logstr,RD_RML_MAX_LENGTH-1);
-  LogLine(RDConfig::LogInfo,QString().sprintf("received rml: \'%s\' from %s",
-	  (const char *)logstr,(const char *)rml->address().toString()));
+  rda->syslog(LOG_INFO,"received rml: \"%s\" from %s",
+	      (const char *)rml_in->toString().toUtf8(),
+	      (const char *)rml_in->address().toString().toUtf8());
 
-  ForwardConvert(rml);
+  RDMacro *rml=new RDMacro();
+  *rml=ForwardConvert(*rml_in);
 
   switch(rml->command()) {
   case RDMacro::BO:
@@ -251,38 +267,15 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     for(int i=1;i<(rml->argQuantity());i++) {
-      sscanf((const char *)rml->arg(i).toString(),"%x",&d);
+      sscanf((const char *)rml->arg(i),"%x",&d);
       bin_buf[i-1]=0xFF&d;
     }
-    ripcd_tty_dev[tty_port]->writeBlock(bin_buf,rml->argQuantity()-1);
+    ripcd_tty_dev[tty_port]->write(bin_buf,rml->argQuantity()-1);
     rml->acknowledge(true);
     sendRml(rml);
     return;
     break;
       
-  case RDMacro::DB:
-    if(rml->argQuantity()!=1) {
-      if(rml->echoRequested()) {
-	rml->acknowledge(false);
-	sendRml(rml);
-      }
-      return;
-    }
-    if(fork()==0) {
-      cmd=QString().sprintf("mysqldump -c Rivendell -h %s -u %s -p%s > %s",
-			    (const char *)ripcd_config->mysqlHostname(),
-			    (const char *)ripcd_config->mysqlUsername(),
-			    (const char *)ripcd_config->mysqlPassword(),
-			    (const char *)rml->arg(0).toString());
-      system((const char *)cmd);
-      exit(0);
-    }
-    if(rml->echoRequested()) {
-      rml->acknowledge(true);
-      sendRml(rml);
-    }
-    break;
-      
   case RDMacro::GI:
     if(rml->argQuantity()!=5) {
       if(rml->echoRequested()) {
@@ -292,11 +285,11 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     matrix_num=rml->arg(0).toInt();
-    if(rml->arg(1).toString().lower()=="i") {
+    if(rml->arg(1).lower()=="i") {
       gpio_type=RDMatrix::GpioInput;
     }
     else {
-      if(rml->arg(1).toString().lower()=="o") {
+      if(rml->arg(1).lower()=="o") {
 	gpio_type=RDMatrix::GpioOutput;
       }
       else {
@@ -326,8 +319,6 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       BroadcastCommand(QString().sprintf("GC %d %d %d %d!",matrix_num,gpi,
 					 ripcd_gpi_macro[matrix_num][gpi][0],
 					 ripcd_gpi_macro[matrix_num][gpi][1]));
-      LogLine(RDConfig::LogWarning,QString().sprintf("cart: %u",
-		       ripcd_gpi_macro[matrix_num][gpi][rml->arg(3).toInt()]));
       break;
 
     case RDMatrix::GpioOutput:
@@ -353,11 +344,11 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     matrix_num=rml->arg(0).toInt();
-    if(rml->arg(1).toString().lower()=="i") {
+    if(rml->arg(1).lower()=="i") {
       gpio_type=RDMatrix::GpioInput;
     }
     else {
-      if(rml->arg(1).toString().lower()=="o") {
+      if(rml->arg(1).lower()=="o") {
 	gpio_type=RDMatrix::GpioOutput;
       }
       else {
@@ -409,6 +400,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     break;
 
   case RDMacro::JC:
+#ifdef JACK
     if(rml->argQuantity()!=2) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
@@ -416,14 +408,45 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       return;
     }
-    rdcae->connectJackPorts(rml->arg(0).toString(),rml->arg(1).toString());
+    if(ripcd_jack_client!=NULL) {
+      if((err=jack_connect(ripcd_jack_client,rml->arg(1).toUtf8(),
+			   rml->arg(0).toUtf8()))==0) {
+	rda->syslog(LOG_DEBUG,
+		    "executed JACK port connection \"%s %s\"",
+		    (const char *)rml->arg(0).toUtf8(),
+		    (const char *)rml->arg(1).toUtf8());
+      }
+      else {
+	if(err!=EEXIST) {
+	  rda->syslog(LOG_WARNING,
+		      "JACK port connection \"%s %s\" failed, err: %d",
+		      (const char *)rml->arg(0).toUtf8(),
+		      (const char *)rml->arg(1).toUtf8(),
+		      err);
+	}
+      }
+    }
+    else {
+      if(rml->echoRequested()) {
+	rml->acknowledge(false);
+	sendRml(rml);
+      }
+      return;
+    }
     if(rml->echoRequested()) {
       rml->acknowledge(true);
       sendRml(rml);
     }
+#else
+    if(rml->echoRequested()) {
+      rml->acknowledge(false);
+      sendRml(rml);
+    }
+#endif  // JACK
     break;
 
   case RDMacro::JD:
+#ifdef JACK
     if(rml->argQuantity()!=2) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
@@ -431,11 +454,39 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       return;
     }
-    rdcae->disconnectJackPorts(rml->arg(0).toString(),rml->arg(1).toString());
+    if(ripcd_jack_client!=NULL) {
+      if((err=jack_disconnect(ripcd_jack_client,rml->arg(1).toUtf8(),
+			   rml->arg(0).toUtf8()))==0) {
+	rda->syslog(LOG_DEBUG,
+		    "executed JACK port disconnection \"%s %s\"",
+		    (const char *)rml->arg(0).toUtf8(),
+		    (const char *)rml->arg(1).toUtf8());
+      }
+      else {
+	rda->syslog(LOG_WARNING,
+		    "JACK port disconnection \"%s %s\" failed, err: %d",
+		    (const char *)rml->arg(0).toUtf8(),
+		    (const char *)rml->arg(1).toUtf8(),
+		    err);
+      }
+    }
+    else {
+      if(rml->echoRequested()) {
+	rml->acknowledge(false);
+	sendRml(rml);
+      }
+      return;
+    }
     if(rml->echoRequested()) {
       rml->acknowledge(true);
       sendRml(rml);
     }
+#else
+    if(rml->echoRequested()) {
+      rml->acknowledge(false);
+      sendRml(rml);
+    }
+#endif  // JACK
     break;
       
   case RDMacro::LO:
@@ -447,10 +498,10 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     if(rml->argQuantity()==0) {
-      rduser=new RDUser(rdstation->defaultName());
+      rduser=new RDUser(rda->station()->defaultName());
     }
     else {
-      rduser=new RDUser(rml->arg(0).toString());
+      rduser=new RDUser(rml->arg(0));
       if(!rduser->exists()) {
 	if(rml->echoRequested()) {
 	  rml->acknowledge(false);
@@ -459,7 +510,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	delete rduser;
 	return;
       }
-      if(!rduser->checkPassword(rml->arg(1).toString(),false)) {
+      if(!rduser->checkPassword(rml->arg(1),false)) {
 	if(rml->echoRequested()) {
 	  rml->acknowledge(false);
 	  sendRml(rml);
@@ -494,19 +545,17 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     }
     if(fork()==0) {
       if(getuid()==0) {
-	if(setegid(ripcd_config->gid())<0) {
-	  LogLine(RDConfig::LogWarning,QString().
-		  sprintf("unable to set group id %d for RDPopup",
-			  ripcd_config->gid()));
+	if(setegid(rda->config()->gid())<0) {
+	  rda->syslog(LOG_WARNING,"unable to set group id %d for RDPopup",
+		      rda->config()->gid());
 	  if(rml->echoRequested()) {
 	    rml->acknowledge(false);
 	    sendRml(rml);
 	  }
 	}
-	if(seteuid(ripcd_config->uid())<0) {
-	  LogLine(RDConfig::LogWarning,QString().
-		  sprintf("unable to set user id %d for RDPopup",
-			  ripcd_config->uid()));
+	if(seteuid(rda->config()->uid())<0) {
+	  rda->syslog(LOG_WARNING,"unable to set user id %d for RDPopup",
+		      rda->config()->uid());
 	  if(rml->echoRequested()) {
 	    rml->acknowledge(false);
 	    sendRml(rml);
@@ -515,10 +564,10 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       if(system(QString().
 		sprintf("rdpopup -display %s %s %s",
-			(const char *)rml->arg(0).toString(),
-			(const char *)rml->arg(1).toString(),
+			(const char *)rml->arg(0),
+			(const char *)rml->arg(1),
 			(const char *)RDEscapeString(rml->rollupArgs(2))))<0) {
-	LogLine(RDConfig::LogWarning,"RDPopup returned an error");
+	rda->syslog(LOG_WARNING,"RDPopup returned an error");
       }
       exit(0);
     }
@@ -573,34 +622,10 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       return;
     }
-    if(fork()==0) {
-      QString cmd=rml->arg(0).toString();
-      for(int i=1;i<=rml->argQuantity();i++) {
-	cmd+=" "+rml->arg(i).toString();
-      }
-      if(getuid()==0) {
-	if(setgid(ripcd_config->gid())<0) {
-	  LogLine(RDConfig::LogWarning,QString().
-		  sprintf("unable to set group id %d for RN",
-			  ripcd_config->gid()));
-	  if(rml->echoRequested()) {
-	    rml->acknowledge(false);
-	    sendRml(rml);
-	  }
-	}
-	if(setuid(ripcd_config->uid())<0) {
-	  LogLine(RDConfig::LogWarning,QString().
-		  sprintf("unable to set user id %d for RN",
-			  ripcd_config->uid()));
-	  if(rml->echoRequested()) {
-	    rml->acknowledge(false);
-	    sendRml(rml);
-	  }
-	}
-      }
-      system((const char *)cmd);
-      exit(0);
+    for(int i=0;i<rml->argQuantity();i++) {
+      cmd+=rml->arg(i)+" ";
     }
+    RunCommand(rda->config()->rnRmlOwner(),rda->config()->rnRmlGroup(),cmd.trimmed());
     if(rml->echoRequested()) {
       rml->acknowledge(true);
       sendRml(rml);
@@ -622,9 +647,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     for(int i=2;i<(rml->argQuantity()-1);i++) {
-      str+=(rml->arg(i).toString()+" ");
+      str+=(rml->arg(i)+" ");
     }
-    str+=rml->arg(rml->argQuantity()-1).toString();
+    str+=rml->arg(rml->argQuantity()-1);
     ripcd_tty_trap[tty_port]->addTrap(rml->arg(1).toInt(),
 				      str,str.length());
     rml->acknowledge(true);
@@ -667,8 +692,8 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	  
     case 3:
       ripcd_tty_trap[tty_port]->removeTrap(rml->arg(1).toInt(),
-					   (const char *)rml->arg(2).toString(),
-					   rml->arg(2).toString().length());
+					   (const char *)rml->arg(2),
+					   rml->arg(2).length());
       if(rml->echoRequested()) {
 	rml->acknowledge(true);
 	sendRml(rml);
@@ -684,7 +709,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       break;
     }
     break;
-      
+
   case RDMacro::SO:
     tty_port=rml->arg(0).toInt();
     if((tty_port<0)||(tty_port>MAX_TTYS)) {
@@ -700,9 +725,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     for(int i=1;i<(rml->argQuantity()-1);i++) {
-      str+=(rml->arg(i).toString()+" ");
+      str+=(rml->arg(i)+" ");
     }
-    str+=rml->arg(rml->argQuantity()-1).toString();
+    str+=rml->arg(rml->argQuantity()-1);
     switch(ripcd_tty_term[tty_port]) {
     case RDTty::CrTerm:
       str+=QString().sprintf("\x0d");
@@ -720,12 +745,12 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       break;
     }
     data=RDStringToData(str);
-    ripcd_tty_dev[tty_port]->writeBlock((const char *)data,data.size());
+    ripcd_tty_dev[tty_port]->write(data);
     rml->acknowledge(true);
     sendRml(rml);
     return;
     break;
-      
+
   case RDMacro::CL:
   case RDMacro::FS:
   case RDMacro::GO:
@@ -778,10 +803,17 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     //
     // Try to Restart
     //
-    sql=QString().sprintf("select PORT_ID,PORT,BAUD_RATE,DATA_BITS,PARITY,\
-                         TERMINATION from TTYS where (STATION_NAME=\"%s\")&& \
-                         (ACTIVE=\"Y\")&&(PORT_ID=%d)",
-			  (const char *)rdstation->name(),tty_port);
+    sql=QString("select ")+
+      "PORT_ID,"+      // 00
+      "PORT,"+         // 01
+      "BAUD_RATE,"+    // 02
+      "DATA_BITS,"+    // 03
+      "PARITY,"+       // 04
+      "TERMINATION "+  // 05
+      "from TTYS where "+
+      "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+      "(ACTIVE=\"Y\")&&"+
+      QString().sprintf("(PORT_ID=%d)",tty_port);
     q=new RDSqlQuery(sql);
     if(q->first()) {
       if(!ripcd_tty_inuse[tty_port]) {
@@ -791,7 +823,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
 	ripcd_tty_dev[tty_port]->setWordLength(q->value(3).toInt());
 	ripcd_tty_dev[tty_port]->
 	  setParity((RDTTYDevice::Parity)q->value(4).toInt());
-	if(ripcd_tty_dev[tty_port]->open(IO_ReadWrite)) {
+	if(ripcd_tty_dev[tty_port]->open(QIODevice::ReadWrite)) {
 	  ripcd_tty_term[tty_port]=(RDTty::Termination)q->value(5).toInt();
 	  ripcd_tty_inuse[tty_port]=true;
 	  ripcd_tty_trap[tty_port]=new RDCodeTrap(this);
@@ -832,9 +864,9 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     // Startup the new
     //
     if(!LoadSwitchDriver(matrix_num)) {
-      LogLine(RDConfig::LogErr,QString().
-            sprintf("attempted to load unknown switcher driver for matrix %d",
-		      matrix_num));
+      rda->syslog(LOG_WARNING,
+		  "attempted to load unknown switcher driver for matrix %d",
+		  matrix_num);
     }
     break;
     
@@ -849,11 +881,11 @@ void MainObject::RunLocalMacros(RDMacro *rml)
     }
     if((rml->arg(0).toInt()==0)&&ripc_onair_flag) {
       BroadcastCommand("TA 0!");
-      LogLine(RDConfig::LogInfo,"onair flag OFF");
+      rda->syslog(LOG_INFO,"onair flag OFF");
     }
     if((rml->arg(0).toInt()==1)&&(!ripc_onair_flag)) {
       BroadcastCommand("TA 1!");
-      LogLine(RDConfig::LogInfo,"onair flag ON");
+      rda->syslog(LOG_INFO,"onair flag ON");
     }
     ripc_onair_flag=rml->arg(0).toInt();
     if(rml->echoRequested()) {
@@ -870,7 +902,7 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       return;
     }
-    if(!addr.setAddress(rml->arg(0).toString())) {
+    if(!addr.setAddress(rml->arg(0))) {
       if(rml->echoRequested()) {
 	rml->acknowledge(false);
 	sendRml(rml);
@@ -885,95 +917,111 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       return;
     }
     for(int i=2;i<(rml->argQuantity()-1);i++) {
-      str+=(rml->arg(i).toString()+" ");
+      str+=(rml->arg(i)+" ");
     }
-    str+=rml->arg(rml->argQuantity()-1).toString();
-    LogLine(RDConfig::LogDebug,QString().
-	    sprintf("Sending \"%s\" to %s:%d",(const char *)str,
-		    (const char *)addr.toString(),rml->arg(1).toInt()));
+    str+=rml->arg(rml->argQuantity()-1);
+    rda->syslog(LOG_INFO,"sending \"%s\" to %s:%d",(const char *)str.toUtf8(),
+		(const char *)addr.toString().toUtf8(),rml->arg(1).toInt());
     data=RDStringToData(str);
-    ripcd_rml_send->writeBlock((const char *)data,data.size(),addr,
-			       (Q_UINT16)(rml->arg(1).toInt()));
+    ripcd_rml_send->writeDatagram(data,addr,(Q_UINT16)(rml->arg(1).toInt()));
     if(rml->echoRequested()) {
       rml->acknowledge(true);
       sendRml(rml);
     }
     break;
- 
+
   default:
-//	LogLine(RDConfig::LogDebug,QString().sprintf("unhandled rml: \'%s\' from %s",
-//	       (const char *)logstr,(const char *)rml->address().toString()));
     break;
   }
 }
 
 
-bool MainObject::CheckAirGate(RDMacro *rml)
+RDMacro MainObject::ForwardConvert(const RDMacro &rml) const
 {
-  char buffer[RD_RML_MAX_LENGTH];
+  RDMacro ret;
 
-  if(rml->command()==RDMacro::AG) {
-    if(ripc_onair_flag) {
-      rml->generateString(buffer,RD_RML_MAX_LENGTH-1);
-      QStringList f0=f0.split(" ",buffer);
-      f0.pop_front();
-      QString rmlstr=f0.join(" ");
-      if(!rml->parseString(rmlstr,rmlstr.length())) {
-	return false;
-      }
-    }
-    else {
-      LogLine(RDConfig::LogDebug,
-	      QString("rejected rml: \"")+buffer+
-	      "\": on-air flag not active");
-      return false;
-    }
-  }
-  return true;
-}
+  ret.setCommand(rml.command());
+  ret.setRole(rml.role());
+  ret.setAddress(rml.address());
+  ret.setEchoRequested(rml.echoRequested());
 
-
-void MainObject::ForwardConvert(RDMacro *rml) const
-{
   //
   // Convert old RML syntax to current forms
   //
-  switch(rml->command()) {
-    case RDMacro::GE:
-      if(rml->argQuantity()==3) {
-	rml->setArgQuantity(4);
-	for(int i=2;i>=1;i--) {
-	  rml->setArg(i+1,rml->arg(i));
-	}
-	rml->setArg(1,"I");
-      }
-      break;
+  switch(rml.command()) {
+  case RDMacro::GE:
+    if(rml.argQuantity()==3) {
+      ret.addArg(rml.arg(0));
+      ret.addArg("I");
+      ret.addArg(rml.arg(1));
+      ret.addArg(rml.arg(2));
+    }
+    else {
+      ret=rml;
+    }
+    break;
 
-    case RDMacro::GI:
-      if(rml->argQuantity()==3) {
-	rml->setArgQuantity(4);
-	rml->setArg(3,0);
+  case RDMacro::GI:
+    if(rml.argQuantity()==3) {
+      ret.addArg(rml.arg(0));
+      ret.addArg("I");
+      ret.addArg(rml.arg(1));
+      ret.addArg(rml.arg(2));
+      ret.addArg(0);
+    }
+    else {
+      if(rml.argQuantity()==4) {
+	ret.addArg(rml.arg(0));
+	ret.addArg("I");
+	ret.addArg(rml.arg(1));
+	ret.addArg(rml.arg(2));
+	ret.addArg(rml.arg(3));
       }
-      if(rml->argQuantity()==4) {
-	rml->setArgQuantity(5);
-	for(int i=3;i>=1;i--) {
-	  rml->setArg(i+1,rml->arg(i));
-	}
-	rml->setArg(1,"I");
+      else {
+	ret=rml;
       }
-      break;
+    }
+    break;
 
-    case RDMacro::GO:
-      if(rml->argQuantity()==4) {
-	rml->setArgQuantity(5);
-	for(int i=3;i>=1;i--) {
-	  rml->setArg(i+1,rml->arg(i));
-	}
-	rml->setArg(1,"O");
-      }
-      break;
+  case RDMacro::GO:
+    if(rml.argQuantity()==4) {
+      ret.addArg(rml.arg(0));
+      ret.addArg("O");
+      ret.addArg(rml.arg(1));
+      ret.addArg(rml.arg(2));
+      ret.addArg(rml.arg(3));
+    }
+    else {
+      ret=rml;
+    }
+    break;
 
-    default:
-      break;
+  default:
+    ret=rml;
+    break;
+  }
+
+  return ret;
+}
+
+
+void MainObject::RunCommand(const QString &user,const QString &group,
+			    const QString &cmd) const
+{
+  QStringList f0=cmd.split(" ",QString::SkipEmptyParts);
+  const char *args[f0.size()+6];
+  args[0]=RD_RUNUSER;
+  args[1]="-u";
+  args[2]=user.toUtf8();
+  args[3]="-g";
+  args[4]=group.toUtf8();
+  for(int i=0;i<f0.size();i++) {
+    args[5+i]=f0.at(i).toUtf8();
+  }
+  args[5+f0.size()]=(char *)NULL;
+  if(vfork()==0) {
+    execv(RD_RUNUSER,(char * const *)args);
+    exit(0);
   }
 }
+
