@@ -2,7 +2,7 @@
 //
 // Rivendell Interprocess Communication Daemon
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,17 +27,23 @@
 
 #include <qobject.h>
 #include <qstring.h>
-#include <qserversocket.h>
-#include <qsqldatabase.h>
-#include <qsocketdevice.h>
+#include <qsignalmapper.h>
+#include <qtcpserver.h>
 #include <qtimer.h>
+#include <qudpsocket.h>
 
+#ifdef JACK
+#include <jack/jack.h>
+#endif  // JACK
+
+#include <rdnotification.h>
 #include <rdsocket.h>
 #include <rdttydevice.h>
 #include <rdcodetrap.h>
 #include <rdstation.h>
 #include <rdmatrix.h>
 #include <rdmacro.h>
+#include <rdmulticaster.h>
 #include <rdtty.h>
 
 #include <ripcd_connection.h>
@@ -59,41 +65,38 @@ class MainObject : public QObject
   MainObject(QObject *parent=0);
   ~MainObject();
 
- public slots:
-  void newConnection(int fd);
-
  private slots:
-  void log(RDConfig::LogPriority prio,const QString &msg);
+  void newConnectionData();
+  void notificationReceivedData(const QString &msg,const QHostAddress &addr);
   void sendRml(RDMacro *rml);
-  void readRml();
+  void rmlEchoData();
+  void rmlNoechoData();
+  void rmlReplyData();
   void gpiChangedData(int matrix,int line,bool state);
   void gpoChangedData(int matrix,int line,bool state);
   void gpiStateData(int matrix,unsigned line,bool state);
   void gpoStateData(int matrix,unsigned line,bool state);
   void ttyTrapData(int cartnum);
   void ttyScanData();
-  void databaseBackup();
   void macroTimerData(int num);
-  void socketData(int);
-  void socketKill(int);
-  void checkMaintData();
+  void readyReadData(int conn_id);
+  void killData(int conn_id);
   void exitTimerData();
+  void garbageData();
+  void startJackData();
   
  private:
   void SetUser(QString username);
   void ExecCart(int cartnum);
   void LogGpioEvent(int matrix,int line,RDMatrix::GpioType type,bool state);
-  void ParseCommand(int);
-  void DispatchCommand(int);
-  void KillSocket(int);
-  void EchoCommand(int,const char *);
-  void BroadcastCommand(const char *);
-  void EchoArgs(int,const char);
-  void ReadRmlSocket(QSocketDevice *dev,RDMacro::Role role,bool echo);
+  bool DispatchCommand(RipcdConnection *conn);
+  void EchoCommand(int,const QString &cmd);
+  void BroadcastCommand(const QString &cmd,int except_ch=-1);
+  void ReadRmlSocket(QUdpSocket *sock,RDMacro::Role role,bool echo);
   QString StripPoint(QString);
   void LoadLocalMacros();
+  void RunLocalNotifications(RDNotification *notify);
   void RunLocalMacros(RDMacro *rml);
-  bool CheckAirGate(RDMacro *rml);
   void LoadGpiTable();
   void SendGpi(int ch,int matrix);
   void SendGpo(int ch,int matrix);
@@ -101,20 +104,21 @@ class MainObject : public QObject
   void SendGpoMask(int ch,int matrix);
   void SendGpiCart(int ch,int matrix);
   void SendGpoCart(int ch,int matrix);
-  void RunSystemMaintRoutine();
-  void RunLocalMaintRoutine();
-  int GetMaintInterval() const;
-  void ForwardConvert(RDMacro *rml) const;
+  RDMacro ForwardConvert(const RDMacro &rml) const;
   bool LoadSwitchDriver(int matrix_num);
+  void RunCommand(const QString &user,const QString &group,
+		  const QString &cmd) const;
   QSqlDatabase *ripcd_db;
   QString ripcd_host;
   bool debug;
-  QServerSocket *server;
+  QTcpServer *server;
   std::vector<RipcdConnection *> ripcd_conns;
-  QSocketDevice *ripcd_rml_send;
-  QSocketDevice *ripcd_rml_echo;
-  QSocketDevice *ripcd_rml_noecho;
-  QSocketDevice *ripcd_rml_reply;
+  QSignalMapper *ripcd_ready_mapper;
+  QSignalMapper *ripcd_kill_mapper;
+  QUdpSocket *ripcd_rml_send;
+  QUdpSocket *ripcd_rml_echo;
+  QUdpSocket *ripcd_rml_noecho;
+  QUdpSocket *ripcd_rml_reply;
   QHostAddress ripcd_host_addr;
   Switcher *ripcd_switcher[MAX_MATRICES];
   bool ripcd_gpi_state[MAX_MATRICES][MAX_GPIO_PINS];
@@ -128,11 +132,15 @@ class MainObject : public QObject
   RDTTYDevice *ripcd_tty_dev[MAX_TTYS];
   RDTty::Termination ripcd_tty_term[MAX_TTYS];
   RDCodeTrap *ripcd_tty_trap[MAX_TTYS];
-  QTimer *ripcd_backup_timer;
   bool ripc_onair_flag;
   QTimer *ripc_macro_timer[RD_MAX_MACRO_TIMERS];
   unsigned ripc_macro_cart[RD_MAX_MACRO_TIMERS];
-  QTimer *ripcd_maint_timer;
+  RDMulticaster *ripcd_notification_mcaster;
+  QTimer *ripcd_garbage_timer;
+#ifdef JACK
+  jack_client_t *ripcd_jack_client;
+  QTimer *ripcd_start_jack_timer;
+#endif  // JACK
 };
 
 
