@@ -22,22 +22,29 @@
 #define RIPCD_CONNECTION_H
 
 #include <qobject.h>
+#include <qtcpsocket.h>
 #include <qstring.h>
 
-#include <rdsocket.h>
 #include <rd.h>
 
 class RipcdConnection
 {
   public:
-  RipcdConnection(int id,int fd);
+   RipcdConnection(int id,QTcpSocket *sock);
    ~RipcdConnection();
-   RDSocket *socket;
-   char args[RD_RML_MAX_ARGS][RD_RML_MAX_LENGTH];
-   int istate;
-   int argnum;
-   int argptr;
-   bool auth;
+   int id() const;
+   QTcpSocket *socket() const;
+   bool isAuthenticated() const;
+   void setAuthenticated(bool state);
+   bool isClosing() const;
+   void close();
+   QString accum;
+
+ private:
+   int ripcd_id;
+   bool ripcd_authenticated;
+   QTcpSocket *ripcd_socket;
+   bool ripcd_closing;
 };
 
 
