@@ -2,7 +2,7 @@
 //
 // A Rivendell switcher driver for the Ross NK switchers via the SCP/A
 //
-//   (C) Copyright 2002-2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,10 +19,12 @@
 //
 
 #include <stdlib.h>
+#include <syslog.h>
 
-#include <globals.h>
-#include <rossnkscp.h>
+#include <rdapplication.h>
 
+#include "globals.h"
+#include "rossnkscp.h"
 
 RossNkScp::RossNkScp(RDMatrix *matrix,QObject *parent)
   : Switcher(matrix,parent)
@@ -37,14 +39,14 @@ RossNkScp::RossNkScp(RDMatrix *matrix,QObject *parent)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   ross_device=new RDTTYDevice();
   if(tty->active()) {
     ross_device->setName(tty->port());
     ross_device->setSpeed(tty->baudRate());
     ross_device->setWordLength(tty->dataBits());
     ross_device->setParity(tty->parity());
-    ross_device->open(IO_Raw|IO_ReadWrite);
+    ross_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 }
@@ -101,7 +103,7 @@ void RossNkScp::processCommand(RDMacro *cmd)
 	sprintf(str,"X%03d,%03d,%d\x0d",cmd->arg(2).toInt()-1,
 		cmd->arg(1).toInt()-1,ross_breakaway);
 	syslog(LOG_WARNING,"sent: %s\n",str);
-	ross_device->writeBlock(str,11);
+	ross_device->write(str,11);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
