@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the SAS32000
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: sas32000.cpp,v 1.14.8.1 2013/03/03 22:58:22 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,12 +20,13 @@
 
 #include <stdlib.h>
 
-#include <globals.h>
-#include <sas32000.h>
+#include <rdapplication.h>
 
+#include "globals.h"
+#include "sas32000.h"
 
-Sas32000::Sas32000(RDMatrix *matrix,QObject *parent,const char *name)
-  : Switcher(matrix,parent,name)
+Sas32000::Sas32000(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   //
   // Get Matrix Parameters
@@ -38,14 +37,14 @@ Sas32000::Sas32000(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   sas_device=new RDTTYDevice();
   if(tty->active()) {
     sas_device->setName(tty->port());
     sas_device->setSpeed(tty->baudRate());
     sas_device->setWordLength(tty->dataBits());
     sas_device->setParity(tty->parity());
-    sas_device->open(IO_Raw|IO_ReadWrite);
+    sas_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 
@@ -123,7 +122,7 @@ void Sas32000::processCommand(RDMacro *cmd)
 	}
 	sprintf(str,"DL%02d%c%03d",cmd->arg(1).toInt(),sign,
 		10*abs(cmd->arg(2).toInt()));
-	sas_device->writeBlock(str,8);
+	sas_device->write(str,8);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
@@ -141,7 +140,7 @@ void Sas32000::runQueue()
   if(sas_commands.size()==0) {
     return;
   }
-  sas_device->writeBlock((const char *)sas_commands.front(),7);
+  sas_device->write((const char *)sas_commands.front(),7);
   sas_commands.pop();
   if(sas_commands.size()==0) {
     sas_timer->stop();
