@@ -3,9 +3,7 @@
 // A Rivendell switcher driver for the SAS64000 connected via 
 //   a GPI-1600
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: sas64000gpi.cpp,v 1.13 2010/08/03 23:39:26 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,12 +21,13 @@
 
 #include <stdlib.h>
 
-#include <globals.h>
-#include <sas64000gpi.h>
+#include <rdapplication.h>
 
+#include "globals.h"
+#include "sas64000gpi.h"
 
-Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent,const char *name)
-  : Switcher(matrix,parent,name)
+Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   //
   // Get Matrix Parameters
@@ -42,14 +41,14 @@ Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Initialize the TTY Port
   //
-  RDTty *tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+  RDTty *tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
   sas_device=new RDTTYDevice();
   if(tty->active()) {
     sas_device->setName(tty->port());
     sas_device->setSpeed(tty->baudRate());
     sas_device->setWordLength(tty->dataBits());
     sas_device->setParity(tty->parity());
-    sas_device->open(IO_Raw|IO_ReadWrite);
+    sas_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
   }
   delete tty;
 
@@ -118,13 +117,13 @@ void Sas64000Gpi::processCommand(RDMacro *cmd)
 		(char)((cmd->arg(1).toInt()-1)/128),
 		(char)(((cmd->arg(1).toInt()-1)%128)+
 		((cmd->arg(1).toInt()-1)/128))&0x7F);
-	sas_device->writeBlock(str,7);
+	sas_device->write(str,7);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
 
       case RDMacro::GO:
-	if((cmd->arg(1).toString().lower()!="o")||
+	if((cmd->arg(1).lower()!="o")||
 	   (cmd->arg(2).toInt()<1)||(cmd->arg(2).toInt()>sas_gpos)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
@@ -151,7 +150,7 @@ void Sas64000Gpi::processCommand(RDMacro *cmd)
 	  emit gpoChanged(sas_matrix,cmd->arg(2).toInt()-1,true);
 	}
 	sprintf(str,"%c%c\xFF",cmd_byte,cmd->arg(2).toInt()-1);
-	sas_device->writeBlock(str,3);
+	sas_device->write(str,3);
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
 	break;
