@@ -2,7 +2,7 @@
 //
 // A Rivendell switcher driver for the SAS USI Protocol
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,12 +19,17 @@
 //
 
 #include <stdlib.h>
-#include <rddb.h>
-#include <globals.h>
-#include <sasusi.h>
+#include <syslog.h>
 
-SasUsi::SasUsi(RDMatrix *matrix,QObject *parent,const char *name)
-  : Switcher(matrix,parent,name)
+#include <rdapplication.h>
+#include <rddb.h>
+#include <rdescape_string.h>
+
+#include "globals.h"
+#include "sasusi.h"
+
+SasUsi::SasUsi(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   QString sql;
   RDSqlQuery *q;
@@ -49,12 +54,14 @@ SasUsi::SasUsi(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Load Switch Table
   //
-  sql=QString().
-    sprintf("select ENGINE_NUM,DEVICE_NUM,RELAY_NUM \
-             from VGUEST_RESOURCES where (STATION_NAME=\"%s\")&&\
-             (MATRIX_NUM=%d) order by NUMBER",
-	    (const char *)ripcd_config->stationName(),
-	    matrix->matrix());
+  sql=QString("select ")+
+    "ENGINE_NUM,"+  // 00
+    "DEVICE_NUM,"+  // 01
+    "RELAY_NUM "+   // 02
+    "from VGUEST_RESOURCES where "+
+    "(STATION_NAME=\""+RDEscapeString(rda->config()->stationName())+"\")&&"+
+    QString().sprintf("(MATRIX_NUM=%d) ",matrix->matrix())+
+    "order by NUMBER";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     sas_console_numbers.push_back(q->value(0).toInt());
@@ -66,7 +73,7 @@ SasUsi::SasUsi(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Reconnection Timer
   //
-  sas_reconnect_timer=new QTimer(this,"sas_reconnect_timer");
+  sas_reconnect_timer=new QTimer(this);
   connect(sas_reconnect_timer,SIGNAL(timeout()),this,SLOT(ipConnect()));
 
   //
@@ -74,19 +81,19 @@ SasUsi::SasUsi(RDMatrix *matrix,QObject *parent,const char *name)
   //
   switch(sas_porttype) {
   case RDMatrix::TtyPort:
-    tty=new RDTty(rdstation->name(),matrix->port(RDMatrix::Primary));
+    tty=new RDTty(rda->station()->name(),matrix->port(RDMatrix::Primary));
     sas_device=new RDTTYDevice();
     if(tty->active()) {
       sas_device->setName(tty->port());
       sas_device->setSpeed(tty->baudRate());
       sas_device->setWordLength(tty->dataBits());
       sas_device->setParity(tty->parity());
-      sas_device->open(IO_Raw|IO_ReadWrite);
+      sas_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
     }
     delete tty;
 
   case RDMatrix::TcpPort:
-    sas_socket=new QSocket(this,"sas_socket");
+    sas_socket=new Q3Socket(this);
     connect(sas_socket,SIGNAL(connected()),this,SLOT(connectedData()));
     connect(sas_socket,SIGNAL(connectionClosed()),
 	    this,SLOT(connectionClosedData()));
@@ -148,9 +155,9 @@ void SasUsi::processCommand(RDMacro *cmd)
 	  return;
 	}
 	for(int i=3;i<(cmd->argQuantity()-1);i++) {
-	  label+=(cmd->arg(i).toString()+" ");
+	  label+=(cmd->arg(i)+" ");
 	}
-	label+=cmd->arg(cmd->argQuantity()-1).toString();
+	label+=cmd->arg(cmd->argQuantity()-1);
 	if(label.length()>8) {
 	  label=label.left(8);
 	}
@@ -266,7 +273,7 @@ void SasUsi::processCommand(RDMacro *cmd)
 	break;
 
       case RDMacro::GO:
-	if((cmd->arg(1).toString().lower()!="o")||
+	if((cmd->arg(1).lower()!="o")||
 	   (cmd->arg(2).toInt()<1)||(cmd->arg(2).toInt()>sas_gpos)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
@@ -292,7 +299,8 @@ void SasUsi::processCommand(RDMacro *cmd)
 	  if(sas_relay_numbers[cmd->arg(2).toUInt()-1]>=0) {
 	    snprintf(str,256,"\x05R%d%04d\x0D\x0A",cmd_byte,
 		    sas_relay_numbers[cmd->arg(2).toUInt()-1]);
-	    syslog(LOG_NOTICE,"USI: %s",(const char *)PrettifyCommand(str));
+	    rda->syslog(LOG_DEBUG,"USI: %s",
+			(const char *)PrettifyCommand(str));
 	    SendCommand(str);
 	    cmd->acknowledge(true);
 	    emit rmlEcho(cmd);
@@ -333,10 +341,10 @@ void SasUsi::ipConnect()
 
 void SasUsi::connectedData()
 {
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("Connection to SasUsi device at %s:%d established",
-		  (const char *)sas_ipaddress.toString(),
-		  sas_ipport));
+  rda->syslog(LOG_INFO,
+	      "connection to SasUsi device at %s:%d established",
+	      (const char *)sas_ipaddress.toString().toUtf8(),
+	 sas_ipport);
   if(sas_start_cart>0) {
     ExecuteMacroCart(sas_start_cart);
   }
@@ -345,10 +353,10 @@ void SasUsi::connectedData()
 
 void SasUsi::connectionClosedData()
 {
-  LogLine(RDConfig::LogNotice,QString().
-	  sprintf("Connection to SasUsi device at %s:%d closed unexpectedly, attempting reconnect",
-		  (const char *)sas_ipaddress.toString(),
-		  sas_ipport));
+  rda->syslog(LOG_WARNING,
+	      "connection to SasUsi device at %s:%d closed unexpectedly, attempting reconnect",
+	      (const char *)sas_ipaddress.toString().toUtf8(),
+	 sas_ipport);
   if(sas_stop_cart>0) {
     ExecuteMacroCart(sas_stop_cart);
   }
@@ -382,27 +390,27 @@ void SasUsi::readyReadData()
 
 void SasUsi::errorData(int err)
 {
-  switch((QSocket::Error)err) {
-      case QSocket::ErrConnectionRefused:
-	LogLine(RDConfig::LogNotice,QString().sprintf(
-	  "Connection to SasUsi device at %s:%d refused, attempting reconnect",
-		  (const char *)sas_ipaddress.toString(),
-		  sas_ipport));
+  switch((Q3Socket::Error)err) {
+      case Q3Socket::ErrConnectionRefused:
+	rda->syslog(LOG_WARNING,
+	  "connection to SasUsi device at %s:%d refused, attempting reconnect",
+		    (const char *)sas_ipaddress.toString().toUtf8(),
+	  sas_ipport);
 	sas_reconnect_timer->start(SASUSI_RECONNECT_INTERVAL,true);
 	break;
 
-      case QSocket::ErrHostNotFound:
-	LogLine(RDConfig::LogWarning,QString().sprintf(
-	  "Error on connection to SasUsi device at %s:%d: Host Not Found",
-		  (const char *)sas_ipaddress.toString(),
-		  sas_ipport));
+      case Q3Socket::ErrHostNotFound:
+	rda->syslog(LOG_WARNING,
+	       "error on connection to SasUsi device at %s:%d: Host Not Found",
+		    (const char *)sas_ipaddress.toString().toUtf8(),
+		    sas_ipport);
 	break;
 
-      case QSocket::ErrSocketRead:
-	LogLine(RDConfig::LogWarning,QString().sprintf(
-	  "Error on connection to SasUsi device at %s:%d: Socket Read Error",
-				  (const char *)sas_ipaddress.toString(),
-				  sas_ipport));
+      case Q3Socket::ErrSocketRead:
+	rda->syslog(LOG_WARNING,
+	     "error on connection to SasUsi device at %s:%d: Socket Read Error",
+		    (const char *)sas_ipaddress.toString().toUtf8(),
+		    sas_ipport);
 	break;
   }
 }
@@ -410,10 +418,11 @@ void SasUsi::errorData(int err)
 
 void SasUsi::SendCommand(char *str)
 {
-  LogLine(RDConfig::LogDebug,QString().sprintf("sending USI cmd: %s",(const char *)PrettifyCommand(str)));
+  rda->syslog(LOG_INFO,"sending USI cmd: %s",
+	      (const char *)PrettifyCommand(str));
   switch(sas_porttype) {
   case RDMatrix::TtyPort:
-    sas_device->writeBlock(str,strlen(str));
+    sas_device->write(str,strlen(str));
     break;
 
   case RDMatrix::TcpPort:
@@ -467,7 +476,8 @@ void SasUsi::DispatchCommand()
     }
   }
 
-  LogLine(RDConfig::LogDebug,QString().sprintf("received USI cmd: %s",(const char *)PrettifyCommand(sas_buffer)));
+  rda->syslog(LOG_INFO,"received USI cmd: %s",
+	      (const char *)PrettifyCommand(sas_buffer));
 
 
   //
@@ -483,26 +493,24 @@ void SasUsi::DispatchCommand()
     if(sscanf(sas_buffer+1,"%u",&input)!=1) {
       return;
     }
-    sql=QString().sprintf("select NUMBER from INPUTS where \
-                           (STATION_NAME=\"%s\")&&	   \
-                           (MATRIX=%d)&&(NUMBER=%d)",
-			  (const char *)rdstation->name(),
-			  sas_matrix,input);
+    sql=QString("select NUMBER from INPUTS where ")+
+      "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+      QString().sprintf("(MATRIX=%d)&&",sas_matrix)+
+      QString().sprintf("(NUMBER=%d)",input);
     q=new RDSqlQuery(sql);
     if(q->first()) {
-      sql=QString().sprintf("update INPUTS set NAME=\"%s\" where \
-                            (STATION_NAME=\"%s\")&&\
-                            (MATRIX=%d)&&(NUMBER=%d)",
-			    (const char *)label,
-			    (const char *)rdstation->name(),
-			    sas_matrix,input);
+      sql=QString("update INPUTS set ")+
+	"NAME=\""+RDEscapeString(label)+"\" where "+
+	"(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+	QString().sprintf("(MATRIX=%d)&&",sas_matrix)+
+	QString().sprintf("(NUMBER=%d)",input);
     }
     else {
-      sql=QString().sprintf("insert into INPUTS set NAME=\"%s\",\
-                            STATION_NAME=\"%s\",MATRIX=%d,NUMBER=%d",
-			    (const char *)label,
-			    (const char *)rdstation->name(),
-				sas_matrix,input);
+      sql=QString("insert into INPUTS set ")+
+	"NAME=\""+RDEscapeString(label)+"\","+
+	"STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\","+
+	QString().sprintf("MATRIX=%d,",sas_matrix)+
+	QString().sprintf("NUMBER=%d",input);
     }
     delete q;
     q=new RDSqlQuery(sql);
@@ -518,26 +526,24 @@ void SasUsi::DispatchCommand()
     if(sscanf(sas_buffer+1,"%u",&output)!=1) {
       return;
     }
-    sql=QString().sprintf("select NUMBER from OUTPUTS where \
-                           (STATION_NAME=\"%s\")&&\
-                           (MATRIX=%d)&&(NUMBER=%d)",
-			  (const char *)rdstation->name(),
-			  sas_matrix,output);
+    sql=QString("select NUMBER from OUTPUTS where ")+
+      "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+      QString().sprintf("(MATRIX=%d)&&",sas_matrix)+
+      QString().sprintf("(NUMBER=%d)",output);
     q=new RDSqlQuery(sql);
     if(q->first()) {
-      sql=QString().sprintf("update OUTPUTS set NAME=\"%s\" where \
-                             (STATION_NAME=\"%s\")&&\
-                             (MATRIX=%d)&&(NUMBER=%d)",
-			    (const char *)label,
-			    (const char *)rdstation->name(),
-			    sas_matrix,output);
+      sql=QString("update OUTPUTS set ")+
+	"NAME=\""+RDEscapeString(label)+"\" where "+
+	"(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+	QString().sprintf("(MATRIX=%d)&&",sas_matrix)+
+	QString().sprintf("(NUMBER=%d)",output);
     }
     else {
-      sql=QString().sprintf("insert into OUTPUTS set NAME=\"%s\",\
-                             STATION_NAME=\"%s\",MATRIX=%d,NUMBER=%d",
-			    (const char *)label,
-			    (const char *)rdstation->name(),
-			    sas_matrix,output);
+      sql=QString("insert into OUTPUTS set ")+
+	"NAME=\""+RDEscapeString(label)+"\","+
+	"STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\","+
+	QString().sprintf("MATRIX=%d,",sas_matrix)+
+	QString().sprintf("NUMBER=%d",output);
     }
     delete q;
     q=new RDSqlQuery(sql);
@@ -560,7 +566,6 @@ void SasUsi::DispatchCommand()
     for(unsigned i=0;i<sas_console_numbers.size();i++) {
       if((console==sas_console_numbers[i])&&(source==sas_source_numbers[i])) {
 	action=cmd.mid(1,1).toUInt(&ok);
-	LogLine(RDConfig::LogNotice,QString().sprintf("action: %u",action));
 	if(!ok) {
 	  return;
 	}
@@ -619,10 +624,9 @@ void SasUsi::ExecuteMacroCart(unsigned cartnum)
   RDMacro rml;
   rml.setRole(RDMacro::Cmd);
   rml.setCommand(RDMacro::EX);
-  rml.setAddress(rdstation->address());
+  rml.setAddress(rda->station()->address());
   rml.setEchoRequested(false);
-  rml.setArgQuantity(1);
-  rml.setArg(0,cartnum);
+  rml.addArg(cartnum);
   emit rmlEcho(&rml);
 }
 
