@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the Logitek vGuest Protocol
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: vguest.cpp,v 1.36 2010/08/03 23:39:26 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,22 +19,30 @@
 //
 
 #include <stdlib.h>
+#include <syslog.h>
 
 #include <qsignalmapper.h>
 
-#include <rddb.h>
-#include <globals.h>
-#include <vguest.h>
+#include <rdapplication.h>
+#include <rdescape_string.h>
 
+#include "globals.h"
+#include "vguest.h"
 
-VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
-  : Switcher(matrix,parent,name)
+VGuest::VGuest(RDMatrix *matrix,QObject *parent)
+  : Switcher(matrix,parent)
 {
   RDTty *tty;
   QString sql;
   RDSqlQuery *q;
   int n;
 
+  for(int i=0;i<2;i++) {
+    vguest_device[i]=NULL;
+    vguest_socket[i]=NULL;
+    vguest_error_notified[i]=false;
+  }
+
   //
   // Get Matrix Parameters
   //
@@ -67,9 +73,14 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Load Engine Data - Inputs
   //
-  sql=QString().sprintf("select NUMBER,ENGINE_NUM,DEVICE_NUM from INPUTS where\
-                         (STATION_NAME=\"%s\")&&(MATRIX=%d) order by NUMBER",
-			(const char *)matrix->station(),matrix->matrix());
+  sql=QString("select ")+
+    "NUMBER,"+      // 00
+    "ENGINE_NUM,"+  // 01
+    "DEVICE_NUM "+  // 02
+    "from INPUTS where "+
+    "(STATION_NAME=\""+RDEscapeString(matrix->station())+"\")&&"+
+    QString().sprintf("(MATRIX=%d) ",matrix->matrix())+
+    "order by NUMBER";
   q=new RDSqlQuery(sql);
   n=1;
   while(q->next()) {
@@ -88,9 +99,14 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   // Load Engine Data - Outputs
   //
   sql=
-    QString().sprintf("select NUMBER,ENGINE_NUM,DEVICE_NUM from OUTPUTS where\
-                       (STATION_NAME=\"%s\")&&(MATRIX=%d) order by NUMBER",
-		      (const char *)matrix->station(),matrix->matrix());
+    QString("select ")+
+    "NUMBER,"+      // 00
+    "ENGINE_NUM,"+  // 01
+    "DEVICE_NUM "+  // 02
+    "from OUTPUTS where "+
+    "(STATION_NAME=\""+RDEscapeString(matrix->station())+"\")&&"+
+    QString().sprintf("(MATRIX=%d) ",matrix->matrix())+
+    "order by NUMBER";
   q=new RDSqlQuery(sql);
   n=1;
   while(q->next()) {
@@ -109,12 +125,17 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   // Load Engine Data - Relays
   //
   sql=
-    QString().sprintf("select NUMBER,ENGINE_NUM,DEVICE_NUM,SURFACE_NUM,\
-                       RELAY_NUM from VGUEST_RESOURCES where\
-                       (STATION_NAME=\"%s\")&&(MATRIX_NUM=%d)&&\
-                       (VGUEST_TYPE=%d) order by NUMBER",
-		      (const char *)matrix->station(),matrix->matrix(),
-		      RDMatrix::VguestTypeRelay);
+    QString("select ")+
+    "NUMBER,"+       // 00
+    "ENGINE_NUM,"+   // 01
+    "DEVICE_NUM,"+   // 02
+    "SURFACE_NUM,"+  // 03
+    "RELAY_NUM "+    // 04
+    "from VGUEST_RESOURCES where "+
+    "(STATION_NAME=\""+RDEscapeString(matrix->station())+"\")&&"+
+    QString().sprintf("(MATRIX_NUM=%d)&&",matrix->matrix())+
+    QString().sprintf("(VGUEST_TYPE=%d) ",RDMatrix::VguestTypeRelay)+
+    "order by NUMBER";
   q=new RDSqlQuery(sql);
   n=1;
   while(q->next()) {
@@ -136,13 +157,16 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   //
   // Load Engine Data - Displays
   //
-  sql=
-    QString().sprintf("select NUMBER,ENGINE_NUM,DEVICE_NUM,SURFACE_NUM\
-                       from VGUEST_RESOURCES where\
-                       (STATION_NAME=\"%s\")&&(MATRIX_NUM=%d)&&\
-                       (VGUEST_TYPE=%d) order by NUMBER",
-		      (const char *)matrix->station(),matrix->matrix(),
-		      RDMatrix::VguestTypeDisplay);
+  sql=QString("select ")+
+    "NUMBER,"+       // 00
+    "ENGINE_NUM,"+   // 01
+    "DEVICE_NUM,"+   // 02
+    "SURFACE_NUM "+  // 03
+    "from VGUEST_RESOURCES where "+
+    "(STATION_NAME=\""+RDEscapeString(matrix->station())+"\")&&"+
+    QString().sprintf("(MATRIX_NUM=%d)&&",matrix->matrix())+
+    QString().sprintf("(VGUEST_TYPE=%d) ",RDMatrix::VguestTypeDisplay)+
+    "order by NUMBER";
   q=new RDSqlQuery(sql);
   n=1;
   while(q->next()) {
@@ -159,6 +183,26 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   }
   delete q;
 
+  //
+  // Ping Timers
+  //
+  vguest_ping_mapper=new QSignalMapper(this);
+  connect(vguest_ping_mapper,SIGNAL(mapped(int)),this,SLOT(pingData(int)));
+  vguest_ping_response_mapper=new QSignalMapper(this);
+  connect(vguest_ping_response_mapper,SIGNAL(mapped(int)),
+	  this,SLOT(pingResponseData(int)));
+  for(int i=0;i<2;i++) {
+    vguest_ping_timer[i]=new QTimer(this);
+    vguest_ping_mapper->setMapping(vguest_ping_timer[i],i);
+    connect(vguest_ping_timer[i],SIGNAL(timeout()),
+	    vguest_ping_mapper,SLOT(map()));
+
+    vguest_ping_response_timer[i]=new QTimer(this);
+    vguest_ping_response_mapper->setMapping(vguest_ping_timer[i],i);
+    connect(vguest_ping_response_timer[i],SIGNAL(timeout()),
+	    vguest_ping_response_mapper,SLOT(map()));
+  }
+
   //
   // Reconnection Timer
   //
@@ -176,22 +220,22 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
   // Interval OneShots
   //
   vguest_gpio_oneshot=new RDOneShot(this);
-  connect(vguest_gpio_oneshot,SIGNAL(timeout(void *)),
-	  this,SLOT(gpioOneshotData(void*)));
+  connect(vguest_gpio_oneshot,SIGNAL(timeout(int)),
+	  this,SLOT(gpioOneshotData(int)));
 
   //
   // Initialize the connection
   //
   for(int i=0;i<2;i++) {
     if(vguest_porttype[i]==RDMatrix::TtyPort) {
-      tty=new RDTty(rdstation->name(),matrix->port((RDMatrix::Role)i));
+      tty=new RDTty(rda->station()->name(),matrix->port((RDMatrix::Role)i));
       vguest_device[i]=new RDTTYDevice();
       if(tty->active()) {
 	vguest_device[i]->setName(tty->port());
 	vguest_device[i]->setSpeed(tty->baudRate());
 	vguest_device[i]->setWordLength(tty->dataBits());
 	vguest_device[i]->setParity(tty->parity());
-	vguest_device[i]->open(IO_Raw|IO_ReadWrite);
+	vguest_device[i]->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
       }
       delete tty;
     }
@@ -213,6 +257,23 @@ VGuest::VGuest(RDMatrix *matrix,QObject *parent,const char *name)
 }
 
 
+VGuest::~VGuest()
+{
+  delete vguest_gpio_oneshot;
+  for(int i=0;i<2;i++) {
+    delete vguest_reconnect_timer[i];
+    delete vguest_ping_response_timer[i];
+    delete vguest_ping_timer[i];
+    if(vguest_device[i]!=NULL) {
+      delete vguest_device[i];
+    }
+    if(vguest_socket[i]!=NULL) {
+      delete vguest_socket[i];
+    }
+  }
+}
+
+
 RDMatrix::Type VGuest::type()
 {
   return RDMatrix::LogitekVguest;
@@ -255,7 +316,7 @@ void VGuest::processCommand(RDMacro *cmd)
 	   (cmd->arg(1).toUInt()>vguest_displays_engine_nums.size())) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
-	  LogLine(RDConfig::LogWarning,"*** not enough vGuest arguments ***");
+	  rda->syslog(LOG_WARNING,"*** not enough vGuest arguments ***");
 	  return;
 	}
 	if((vguest_displays_engine_nums[cmd->arg(1).toInt()-1]<0)||
@@ -263,7 +324,7 @@ void VGuest::processCommand(RDMacro *cmd)
 	   (vguest_displays_surface_nums[cmd->arg(1).toInt()-1]<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
-	  LogLine(RDConfig::LogWarning,"*** invalid vGuest hex parameters ***");
+	  rda->syslog(LOG_WARNING,"*** invalid vGuest hex parameters ***");
 	  return;
 	}
 	label=cmd->rollupArgs(5).left(VGUEST_MAX_TEXT_LENGTH);
@@ -308,8 +369,8 @@ void VGuest::processCommand(RDMacro *cmd)
 	break;
 
       case RDMacro::GO:
-	if(((cmd->arg(1).toString().lower()!="i")&&
-	    (cmd->arg(1).toString().lower()!="o"))||
+	if(((cmd->arg(1).lower()!="i")&&
+	    (cmd->arg(1).lower()!="o"))||
 	   (cmd->arg(2).toInt()<1)||(cmd->arg(2).toInt()>vguest_gpos)||
 	   (cmd->arg(3).toInt()<0)||(cmd->arg(3).toInt()>1)||
 	   (cmd->arg(4).toInt()<0)) {
@@ -351,7 +412,7 @@ void VGuest::processCommand(RDMacro *cmd)
 	      SendCommand(buffer,9);
 	      emit gpiChanged(vguest_matrix,cmd->arg(2).toInt()-1,true);
 	      emit gpoChanged(vguest_matrix,cmd->arg(2).toInt()-1,true);
-	      vguest_gpio_oneshot->start((void *)(cmd->arg(2).toInt()-1),2000);
+	      vguest_gpio_oneshot->start(cmd->arg(2).toInt()-1,2000);
 	      break;
 
 	    case 0x52:
@@ -399,13 +460,18 @@ void VGuest::connectedData(int id)
 void VGuest::connectionClosedData(int id)
 {
   int interval=GetHoldoff();
-  LogLine(RDConfig::LogNotice,QString().
-	  sprintf("Connection to vGuest device at %s:%d closed, attempting reconnect, holdoff = %d mS",
-			    (const char *)vguest_ipaddress[id].toString(),
-			    vguest_ipport[id],interval));
+  if(!vguest_error_notified[id]) {
+    rda->syslog(LOG_WARNING,
+	   "connection to vGuest device at %s:%d closed, attempting reconnect",
+		(const char *)vguest_ipaddress[id].toString().toUtf8(),
+		vguest_ipport[id]);
+    vguest_error_notified[id]=true;
+  }
   if(vguest_stop_cart[id]>0) {
     ExecuteMacroCart(vguest_stop_cart[id]);
   }
+  vguest_ping_timer[id]->stop();
+  vguest_ping_response_timer[id]->stop();
   vguest_reconnect_timer[id]->start(interval,true);
 }
 
@@ -418,29 +484,49 @@ void VGuest::readyReadData(int id)
   while((n=vguest_socket[id]->readBlock(buffer,255))>0) {
     for(int i=0;i<n;i++) {
       switch(vguest_istate[id]) {
-	  case 0:   // STX Command Start
-	    if(buffer[i]==0x02) {
-	      vguest_istate[id]=1;
-	    }
-	    break;
+      case 0:   // STX Command Start
+	switch(buffer[i]) {
+	case 0x02:
+	  vguest_istate[id]=1;
+	  break;
 
-	  case 1:   // Command Length
-	    vguest_cmd_length[id]=buffer[i];
-	    vguest_cmd_buffer[id][0]=2;
-	    vguest_cmd_buffer[id][1]=buffer[i];
-	    vguest_cmd_ptr[id]=2;
-	    vguest_istate[id]=2;
-	    break;
+	case 0x04:
+	  vguest_istate[id]=11;
+	  break;
+	}
+	break;
 
-	  case 2:   // Command Body
-	    vguest_cmd_buffer[id][vguest_cmd_ptr[id]++]=buffer[i];
-	    if(vguest_cmd_ptr[id]==(vguest_cmd_length[id]+2)) {
-	      DispatchCommand(vguest_cmd_buffer[id],vguest_cmd_length[id]+2,
-			      id);
-	      vguest_istate[id]=0;
-	    }
-	    break;
+      case 1:   // LP2 Command Length
+	vguest_cmd_length[id]=buffer[i];
+	vguest_cmd_buffer[id][0]=2;
+	vguest_cmd_buffer[id][1]=buffer[i];
+	vguest_cmd_ptr[id]=2;
+	vguest_istate[id]=2;
+	break;
 
+      case 2:   // LP2 Command Body
+	vguest_cmd_buffer[id][vguest_cmd_ptr[id]++]=buffer[i];
+	if(vguest_cmd_ptr[id]==(vguest_cmd_length[id]+2)) {
+	  DispatchCommand(vguest_cmd_buffer[id],vguest_cmd_length[id]+2,id);
+	  vguest_istate[id]=0;
+	}
+	break;
+
+      case 11:   // Metadata Command Length
+	vguest_cmd_length[id]=buffer[i];
+	vguest_cmd_buffer[id][0]=2;
+	vguest_cmd_buffer[id][1]=buffer[i];
+	vguest_cmd_ptr[id]=2;
+	vguest_istate[id]=12;
+	break;
+
+      case 12:   // LP2 Command Body
+	vguest_cmd_buffer[id][vguest_cmd_ptr[id]++]=buffer[i];
+	if(vguest_cmd_ptr[id]==(vguest_cmd_length[id]+2)) {
+	  MetadataCommand(vguest_cmd_buffer[id],vguest_cmd_length[id]+2,id);
+	  vguest_istate[id]=0;
+	}
+	break;
       }
     }
   }
@@ -451,37 +537,68 @@ void VGuest::errorData(int err,int id)
 {
   int interval=VGUEST_RECONNECT_MIN_INTERVAL;
 
-  switch((QSocket::Error)err) {
-      case QSocket::ErrConnectionRefused:
+  switch((Q3Socket::Error)err) {
+      case Q3Socket::ErrConnectionRefused:
 	interval=GetHoldoff();
-	LogLine(RDConfig::LogNotice,QString().sprintf(
-	 "Connection to vGuest device at %s:%d refused, attempting reconnect, holdoff = %d mS",
-	 (const char *)vguest_ipaddress[id].toString(),
-	 vguest_ipport[id],interval));
+	if(!vguest_error_notified[id]) {
+	  rda->syslog(LOG_WARNING,
+	   "connection to vGuest device at %s:%d refused, attempting reconnect",
+		      (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		      vguest_ipport[id]);
+	  vguest_error_notified[id]=true;
+	}
 	vguest_reconnect_timer[id]->start(interval,true);
 	break;
 
-      case QSocket::ErrHostNotFound:
-	LogLine(RDConfig::LogWarning,QString().sprintf(
-	  "Error on connection to vGuest device at %s:%d: Host Not Found",
-	  (const char *)vguest_ipaddress[id].toString(),
-	  vguest_ipport[id]));
+      case Q3Socket::ErrHostNotFound:
+	if(!vguest_error_notified[id]) {
+	  rda->syslog(LOG_WARNING,
+		"error on connection to vGuest device at %s:%d: Host Not Found",
+		      (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		      vguest_ipport[id]);
+	  vguest_error_notified[id]=true;
+	}
 	break;
 
-      case QSocket::ErrSocketRead:
-	LogLine(RDConfig::LogWarning,QString().sprintf(
-	  "Error on connection to vGuest device at %s:%d: Socket Read Error",
-	  (const char *)vguest_ipaddress[id].toString(),
-	  vguest_ipport[id]));
+      case Q3Socket::ErrSocketRead:
+	if(!vguest_error_notified[id]) {
+	  rda->syslog(LOG_WARNING,
+	     "error on connection to vGuest device at %s:%d: Socket Read Error",
+		      (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		      vguest_ipport[id]);
+	  vguest_error_notified[id]=true;
+	}
 	break;
   }
 }
 
 
-void VGuest::gpioOneshotData(void *data)
+void VGuest::gpioOneshotData(int value)
 {
-  emit gpiChanged(vguest_matrix,(long)data,false);
-  emit gpoChanged(vguest_matrix,(long)data,false);
+  emit gpiChanged(vguest_matrix,value,false);
+  emit gpoChanged(vguest_matrix,value,false);
+}
+
+
+void VGuest::pingData(int id)
+{
+  char buffer[VGUEST_MAX_COMMAND_LENGTH];
+
+  buffer[0]=0x04;
+  buffer[1]=0x01;
+  buffer[2]=0x03;   // LPCore Connection Ping
+  vguest_socket[id]->writeBlock(buffer,3);
+  vguest_ping_response_timer[id]->start(VGUEST_PING_INTERVAL,true);
+}
+
+
+void VGuest::pingResponseData(int id)
+{
+  vguest_socket[id]->clearPendingData();
+  vguest_socket[id]->close();
+  rda->syslog(LOG_WARNING,"vGuest connection to "+
+	      vguest_ipaddress[id].toString()+
+	      " timed out, restarting connection");
 }
 
 
@@ -492,7 +609,7 @@ void VGuest::SendCommand(char *str,int len)
     switch(vguest_porttype[i]) {
       case RDMatrix::TtyPort:
 	if(vguest_device[i]!=NULL) {
-	  vguest_device[i]->writeBlock(str,len);
+	  vguest_device[i]->write(str,len);
 	}
 	break;
 	
@@ -515,121 +632,145 @@ void VGuest::DispatchCommand(char *cmd,int len,int id)
   QString str;
   int linenum;
 
-  // LogLine(RDConfig::LogNotice,
-  //QString().sprintf("RCVD: %s",(const char *)RenderCommand(cmd,len)));
+  //  LogLine(RDConfig::LogNotice,
+  //  QString().sprintf("RCVD: %s",(const char *)RenderCommand(cmd,len)));
 
   switch(0xFF&cmd[2]) {
-      case 0xF9:   // Username/Password Query
-	buffer[0]=0x02;
-	buffer[1]=0x22;
-	buffer[2]=0xF9;
-	buffer[3]=VGUEST_ID_BYTE;
-	sprintf(buffer+4,"%s%s",
-		(const char *)vguest_username[id],
-		(const char *)vguest_password[id]);
-	SendCommand(buffer,36);
-	break;
+  case 0xF9:   // Username/Password Query
+    buffer[0]=0x02;
+    buffer[1]=0x22;
+    buffer[2]=0xF9;
+    buffer[3]=VGUEST_ID_BYTE;
+    sprintf(buffer+4,"%s%s",
+	    (const char *)vguest_username[id],
+	    (const char *)vguest_password[id]);
+    SendCommand(buffer,36);
+    break;
 
-      case 0xF0:   // Connect Status
-	switch(0xFF&cmd[3]) {
-	    case 0x0A:  // Valid connection
-	    case 0x14:
-	      LogLine(RDConfig::LogInfo,QString().sprintf(
-			"connection to vGuest device at %s:%d established",
-			(const char *)vguest_ipaddress[id].toString(),
-			vguest_ipport[id]));
-	      if(vguest_start_cart[id]>0) {
-		ExecuteMacroCart(vguest_start_cart[id]);
-	      }
-	      break;
+  case 0xF0:   // Connect Status
+    switch(0xFF&cmd[3]) {
+    case 0x0A:  // Valid connection
+    case 0x14:
+      rda->syslog(LOG_INFO,
+		  "connection to vGuest device at %s:%d established",
+		  (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		  vguest_ipport[id]);
+      vguest_error_notified[id]=false;
+      if(vguest_start_cart[id]>0) {
+	ExecuteMacroCart(vguest_start_cart[id]);
+      }
+      if(vguest_socket[id]!=NULL) {
+	buffer[0]=0x04;
+	buffer[1]=0x01;
+	buffer[2]=0x03;   // LPCore Connection Ping
+	vguest_socket[id]->writeBlock(buffer,3);
+      }
+      break;
 
-	    case 0x0B:  // Invalid Username
-	    case 0x15:
-	      LogLine(RDConfig::LogWarning,QString().sprintf(
-	      "connection to vGuest device at %s:%d refused: username invalid",
-			(const char *)vguest_ipaddress[id].toString(),
-			vguest_ipport[id]));
-	      vguest_socket[id]->close();
-	      connectionClosedData(id);
-	      break;
+    case 0x0B:  // Invalid Username
+    case 0x15:
+      rda->syslog(LOG_WARNING,
+	     "connection to vGuest device at %s:%d refused: username invalid",
+		  (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		  vguest_ipport[id]);
+      vguest_socket[id]->close();
+      connectionClosedData(id);
+      break;
+      
+    case 0x0C:  // Invalid Password
+    case 0x16:
+      rda->syslog(LOG_WARNING,
+	     "connection to vGuest device at %s:%d refused: password invalid",
+		  (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		  vguest_ipport[id]);
+      vguest_socket[id]->close();
+      connectionClosedData(id);
+      break;
 
-	    case 0x0C:  // Invalid Password
-	    case 0x16:
-	      LogLine(RDConfig::LogWarning,QString().sprintf(
-	      "connection to vGuest device at %s:%d refused: password invalid",
-			(const char *)vguest_ipaddress[id].toString(),
-			vguest_ipport[id]));
-	      vguest_socket[id]->close();
-	      connectionClosedData(id);
-	      break;
+    case 0x0D:  // No vGuest Permission
+    case 0x17:
+      rda->syslog(LOG_WARNING,
+	   "connection to vGuest device at %s:%d refused: no vGuest permission",
+		  (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		  vguest_ipport[id]);
+      vguest_socket[id]->close();
+      connectionClosedData(id);
+      break;
 
-	    case 0x0D:  // No vGuest Permission
-	    case 0x17:
-	      LogLine(RDConfig::LogWarning,QString().sprintf(
-	  "connection to vGuest device at %s:%d refused: no vGuest permission",
-			(const char *)vguest_ipaddress[id].toString(),
-			vguest_ipport[id]));
-	      vguest_socket[id]->close();
-	      connectionClosedData(id);
-	      break;
+    case 0x0E:  // No Profile
+    case 0x18:
+      rda->syslog(LOG_WARNING,
+	    "connection to vGuest device at %s:%d refused: no profile assigned",
+		  (const char *)vguest_ipaddress[id].toString().toUtf8(),
+		  vguest_ipport[id]);
+      vguest_socket[id]->close();
+      connectionClosedData(id);
+      break;
+    }
+    break;
 
-	    case 0x0E:  // No Profile
-	    case 0x18:
-	      LogLine(RDConfig::LogWarning,QString().sprintf(
-	   "connection to vGuest device at %s:%d refused: no profile assigned",
-			(const char *)vguest_ipaddress[id].toString(),
-			vguest_ipport[id]));
-	      vguest_socket[id]->close();
-	      connectionClosedData(id);
-	      break;
-	}
-	break;
+  case 0x52:   // Turn On
+    if((linenum=GetRelay(0xFF&cmd[3],256*(0xFF&cmd[4])+(0xFF&cmd[5]),
+			 0xFF&cmd[6],0xFF&cmd[7]))>=0) {
+      emit gpiChanged(vguest_matrix,linenum,true);
+      emit gpoChanged(vguest_matrix,linenum,true);
+    }
+    else {
+      rda->syslog(LOG_DEBUG,
+		  "unhandled vGuest command received: %s",
+		  (const char *)RenderCommand(cmd,len).toUtf8());
+    }
+    break;
 
-      case 0x52:   // Turn On
-	if((linenum=GetRelay(0xFF&cmd[3],256*(0xFF&cmd[4])+(0xFF&cmd[5]),
-			     0xFF&cmd[6],0xFF&cmd[7]))>=0) {
-	  emit gpiChanged(vguest_matrix,linenum,true);
-	  emit gpoChanged(vguest_matrix,linenum,true);
-	}
-	else {
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("unhandled vGuest command received: %s",
-			  (const char *)RenderCommand(cmd,len)));
-	}
-	break;
+  case 0x53:   // Turn Off
+    if((linenum=GetRelay(0xFF&cmd[3],256*(0xFF&cmd[4])+(0xFF&cmd[5]),
+			 0xFF&cmd[6],0xFF&cmd[7]))>=0) {
+      emit gpiChanged(vguest_matrix,linenum,false);
+      emit gpoChanged(vguest_matrix,linenum,false);
+    }
+    else {
+      rda->syslog(LOG_DEBUG,
+		  "unhandled vGuest command received: %s",
+		  (const char *)RenderCommand(cmd,len).toUtf8());
+    }
+    break;
 
-      case 0x53:   // Turn Off
-	if((linenum=GetRelay(0xFF&cmd[3],256*(0xFF&cmd[4])+(0xFF&cmd[5]),
-			     0xFF&cmd[6],0xFF&cmd[7]))>=0) {
-	  emit gpiChanged(vguest_matrix,linenum,false);
-	  emit gpoChanged(vguest_matrix,linenum,false);
-	}
-	else {
-	  LogLine(RDConfig::LogDebug,QString().
-		  sprintf("unhandled vGuest command received: %s",
-			  (const char *)RenderCommand(cmd,len)));
-	}
-	break;
-
-      case 0x54:   // Input Assign
-	break;
-
-      case 0x55:   // Input Mode
-	break;
-
-      case 0x56:   // Fader Level
-	break;
-
-      default:
-	LogLine(RDConfig::LogDebug,QString().
-		sprintf("unrecognized vGuest command received: %s",
-			(const char *)RenderCommand(cmd,len)));
-	break;
+  case 0x54:   // Input Assign
+    break;
+    
+  case 0x55:   // Input Mode
+    break;
+    
+  case 0x56:   // Fader Level
+    break;
+    
+  default:
+    rda->syslog(LOG_DEBUG,"unrecognized vGuest command received: %s",
+		(const char *)RenderCommand(cmd,len).toUtf8());
+    break;
   }
 }
 
 
-QString VGuest::PadString(QString str,unsigned len)
+void VGuest::MetadataCommand(char *cmd,int len,int id)
+{
+  switch(0xFF&cmd[2]) {
+  case 0x03:   // Connection Ping
+    if(vguest_ping_response_timer[id]->isActive()) {
+      vguest_ping_response_timer[id]->stop();
+    }
+    else {
+      rda->syslog(LOG_INFO,
+	  "vGuest system at %s understands ping, activating timeout monitoring",
+		  (const char *)vguest_ipaddress[id].toString().toUtf8());
+    }
+    vguest_ping_timer[id]->start(VGUEST_PING_INTERVAL,true);
+    break;
+  }
+}
+
+
+QString VGuest::PadString(QString str,int len)
 {
   QString out;
   out=str.left(len);
@@ -685,9 +826,8 @@ void VGuest::ExecuteMacroCart(unsigned cartnum)
   RDMacro rml;
   rml.setRole(RDMacro::Cmd);
   rml.setCommand(RDMacro::EX);
-  rml.setAddress(rdstation->address());
+  rml.setAddress(rda->station()->address());
   rml.setEchoRequested(false);
-  rml.setArgQuantity(1);
-  rml.setArg(0,cartnum);
+  rml.addArg(cartnum);
   emit rmlEcho(&rml);
 }
