@@ -26,6 +26,7 @@
 
 #include <rdcmd_switch.h>
 #include <rddatedecode.h>
+#include <rddb.h>
 
 #include "datedecode_test.h"
 
@@ -34,6 +35,8 @@ MainObject::MainObject(QObject *parent)
 {
   QString date="";
   QString datetime="";
+  QString service="";
+  int schema=0;
 
   //
   // Read Command Options
@@ -50,6 +53,10 @@ MainObject::MainObject(QObject *parent)
       datetime=cmd->value(i);
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--service") {
+      service=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
     if(!cmd->processed(i)) {
       fprintf(stderr,"datedecode_test: unknown option \"%s\"\n",
 	      (const char *)cmd->value(i));
@@ -67,15 +74,35 @@ MainObject::MainObject(QObject *parent)
     exit(256);
   }
 
+  //
+  // Open Config
+  //
+  RDConfig *config=new RDConfig();
+  config->load();
+
+  //
+  // Open Database
+  //
+  QString err (tr("datedecode_test: "));
+  if(!RDOpenDb(&schema,&err,config)) {
+    fprintf(stderr,err.ascii());
+    delete cmd;
+    exit(256);
+  }
+  RDStation *station=new RDStation(config->stationName());
+
   //
   // Process Code
   //
   if(!date.isEmpty()) {
     printf("%s\n",
-	   (const char *)RDDateDecode(date,QDate::currentDate()));
+	   (const char *)RDDateDecode(date,QDate::currentDate(),station,config,
+				      service));
   }
   if(!datetime.isEmpty()) {
-    printf("%s\n",(const char *)RDDateTimeDecode(datetime,QDateTime(QDate::currentDate(),QTime::currentTime())));
+    printf("%s\n",(const char *)RDDateTimeDecode(datetime,
+		  QDateTime(QDate::currentDate(),QTime::currentTime()),station,
+						 config,service));
   }
   exit(0);
 }
