@@ -2,9 +2,7 @@
 //
 // QListBoxItem for ALSA PCM devices. 
 //
-//   (C) Copyright 2009 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: alsaitem.h,v 1.1.2.1 2009/08/03 10:57:54 cvs Exp $
+//   (C) Copyright 2009-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,22 +22,21 @@
 #ifndef ALSAITEM_H
 #define ALSAITEM_H
 
-#include <qlistbox.h>
+#include <q3listbox.h>
 
-class AlsaItem : public QListBoxText
+class AlsaItem : public Q3ListBoxText
 {
  public:
-  AlsaItem(QListBox *listbox,const QString &text=QString::null);
+  AlsaItem(Q3ListBox *listbox,const QString &text=QString::null);
   AlsaItem(const QString &text=QString::null);
   AlsaItem(const AlsaItem &item);
-  int card() const;
-  void setCard(int card);
-  int device() const;
-  void setDevice(int device);
-
+  int cardNumber() const;
+  void setCardNumber(int cardnum);
+  int pcmNumber() const;
+  void setPcmNumber(int pcmnum);
  private:
-  int alsa_card;
-  int alsa_device;
+  int alsa_card_number;
+  int alsa_pcm_number;
 };
 
 
