@@ -2,7 +2,7 @@
 //
 // A Qt-based application for importing TM Century GoldDisc CDs
 //
-//   (C) Copyright 2013,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2013-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,108 +18,65 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
+#include <q3filedialog.h>
 
 #include <qapplication.h>
-#include <qwindowsstyle.h>
-#include <qtextcodec.h>
-#include <qfiledialog.h>
 #include <qmessagebox.h>
-#include <qstringlist.h>
-#include <qfiledialog.h>
+#include <qtranslator.h>
 
-#include <rdescape_string.h>
-#include <rdcmd_switch.h>
 #include <rdconf.h>
-#include <rddatedialog.h>
-#include <rdgroup.h>
-#include <rdcart.h>
-#include <rdcut.h>
-#include <rdaudioimport.h>
-#include <rddatedecode.h>
 #include <rdlistviewitem.h>
 #include <rdprofile.h>
-#include <rdcart.h>
-#include <rdcut.h>
 #include <rdwavedata.h>
-#include <rdsystem.h>
 
-#include <rddiscimport.h>
+#include "rddiscimport.h"
 
-MainWidget::MainWidget(QWidget *parent)
-  : QWidget(parent)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
-  dg_user=NULL;
+  QString err_msg;
+
+  dg_resize=false;
   dg_group=NULL;
 
+  //
+  // Open the Database
+  //
+  rda=new RDApplication("RDDiscImport","rddiscimport",RDDISCIMPORT_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    QMessageBox::critical(this,"RDDiscImport - "+tr("Error"),err_msg);
+    exit(1);
+  }
+
   //
   // Read Command Options
   //
-  RDCmdSwitch *cmd=
-    new RDCmdSwitch(qApp->argc(),qApp->argv(),"RDDiscImport","\n");
-  delete cmd;
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      QMessageBox::critical(this,"RDDiscImport - "+tr("Error"),
+			    tr("Unknown command option")+": "+
+			    rda->cmdSwitch()->key(i));
+      exit(2);
+    }
+  }
 
   //
   // Set Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
 
   SetCaption();
 
-  //
-  // Load Local Configs
-  //
-  dg_config=new RDConfig();
-  dg_config->load();
-  dg_config->setModuleName("RDDiscImport");
-
   //
   // Get Temporary File
   //
   dg_tempfile=RDTempFile();
 
-  //
-  // Open Database
-  //
-  dg_db=QSqlDatabase::addDatabase(dg_config->mysqlDriver());
-  if(!dg_db) {
-    QMessageBox::warning(this,tr("Database Error"),
-		    tr("Can't Connect","Unable to connect to mySQL Server!"));
-    exit(0);
-  }
-  dg_db->setDatabaseName(dg_config->mysqlDbname());
-  dg_db->setUserName(dg_config->mysqlUsername());
-  dg_db->setPassword(dg_config->mysqlPassword());
-  dg_db->setHostName(dg_config->mysqlHostname());
-  if(!dg_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    dg_db->removeDatabase(dg_config->mysqlDbname());
-    exit(0);
-  }
-
-  //
-  // Fonts
-  //
-  QFont main_font("helvetica",12,QFont::Normal);
-  main_font.setPixelSize(12);
-  setFont(main_font);
-  QFont label_font("helvetica",12,QFont::Bold);
-  label_font.setPixelSize(12);
-  setFont(main_font);
-
   //
   // Configuration Elements
   //
-  dg_system=new RDSystem();
-  dg_station=new RDStation(dg_config->stationName(),this);
-  dg_library_conf=new RDLibraryConf(dg_config->stationName(),0);
-  dg_ripc=new RDRipc(dg_station,dg_config,this);
-  connect(dg_ripc,SIGNAL(userChanged()),this,SLOT(userChangedData()));
-  dg_ripc->connectHost("localhost",RIPCD_TCP_PORT,dg_config->password());
+  connect(rda,SIGNAL(userChanged()),this,SLOT(userChangedData()));
+  rda->ripc()->connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
 
   //
   // Metadata Index Library
@@ -132,11 +89,11 @@ MainWidget::MainWidget(QWidget *parent)
   dg_player=new RDCdPlayer(NULL,this);
   connect(dg_player,SIGNAL(mediaChanged()),this,SLOT(mediaChangedData()));
   connect(dg_player,SIGNAL(ejected()),this,SLOT(ejectData()));
-  dg_player->setDevice(dg_library_conf->ripperDevice());
+  dg_player->setDevice(rda->libraryConf()->ripperDevice());
   dg_ripper=new RDCdRipper(NULL,this);
-  dg_ripper->setDevice(dg_library_conf->ripperDevice());
+  dg_ripper->setDevice(rda->libraryConf()->ripperDevice());
   dg_ripper->setDestinationFile(dg_tempfile);
-  dg_importer=new RDAudioImport(dg_station,dg_config,this);
+  dg_importer=new RDAudioImport(this);
   dg_importer->setSourceFile(dg_tempfile);
   dg_importer->setUseMetadata(false);
   
@@ -145,10 +102,10 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_indexfile_edit=new QLineEdit(this);
   dg_indexfile_label=new QLabel(dg_indexfile_edit,tr("Index File")+":",this);
-  dg_indexfile_label->setFont(label_font);
+  dg_indexfile_label->setFont(labelFont());
   dg_indexfile_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   dg_indexfile_button=new QPushButton(tr("Select"),this);
-  dg_indexfile_button->setFont(main_font);
+  dg_indexfile_button->setFont(buttonFont());
   connect(dg_indexfile_button,SIGNAL(clicked()),
 	  this,SLOT(indexFileSelectedData()));
 
@@ -157,7 +114,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_group_box=new QComboBox(this);
   dg_group_label=new QLabel(dg_group_box,tr("Destination Group")+":",this);
-  dg_group_label->setFont(label_font);
+  dg_group_label->setFont(labelFont());
   dg_group_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(dg_group_box,SIGNAL(activated(int)),
 	  this,SLOT(groupActivatedData(int)));
@@ -167,22 +124,21 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_userdef_edit=new QLineEdit(this);
   dg_userdef_label=new QLabel(dg_userdef_edit,tr("User Defined")+":",this);
-  dg_userdef_label->setFont(label_font);
+  dg_userdef_label->setFont(labelFont());
   dg_userdef_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Track List
   //
   dg_track_list=new RDListView(this);
-  //db_track_list->setFont(default_font);
   dg_track_list->setAllColumnsShowFocus(true);
   dg_track_list->setItemMargin(5);
-  dg_track_list->setSelectionMode(QListView::Single);
+  dg_track_list->setSelectionMode(Q3ListView::Single);
   dg_track_list->setSortColumn(-1);
   connect(dg_track_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(trackDoubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(trackDoubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   dg_track_list->addColumn("#");
   dg_track_list->setColumnAlignment(0,Qt::AlignHCenter);
@@ -200,15 +156,15 @@ MainWidget::MainWidget(QWidget *parent)
   // Progress Bars
   //
   dg_disc_label=new QLabel(tr("Disk Progress"),this);
-  dg_disc_label->setFont(label_font);
+  dg_disc_label->setFont(labelFont());
   dg_disc_label->setDisabled(true);
-  dg_disc_bar=new QProgressBar(this);
+  dg_disc_bar=new Q3ProgressBar(this);
   dg_disc_bar->setDisabled(true);
 
   dg_track_label=new QLabel(tr("Track Progress"),this);
-  dg_track_label->setFont(label_font);
+  dg_track_label->setFont(labelFont());
   dg_track_label->setDisabled(true);
-  dg_track_bar=new QProgressBar(this);
+  dg_track_bar=new Q3ProgressBar(this);
   dg_track_bar->setTotalSteps(dg_ripper->totalSteps()+1);
   dg_track_bar->setDisabled(true);
   connect(dg_ripper,SIGNAL(progressChanged(int)),
@@ -219,7 +175,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_discid_edit=new QLineEdit(this);
   dg_discid_label=new QLabel(dg_discid_edit,tr("Disc ID")+":",this);
-  dg_discid_label->setFont(label_font);
+  dg_discid_label->setFont(labelFont());
   dg_discid_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(dg_discid_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(discIdChangedData(const QString &)));
@@ -228,7 +184,7 @@ MainWidget::MainWidget(QWidget *parent)
   // Rip Button
   //
   dg_rip_button=new QPushButton(tr("Rip Disc"),this);
-  dg_rip_button->setFont(label_font);
+  dg_rip_button->setFont(buttonFont());
   connect(dg_rip_button,SIGNAL(clicked()),this,SLOT(ripData()));
 
   //
@@ -237,18 +193,18 @@ MainWidget::MainWidget(QWidget *parent)
   dg_channels_box=new QComboBox(this);
   dg_channels_box->insertItem("1");
   dg_channels_box->insertItem("2");
-  dg_channels_box->setCurrentItem(dg_library_conf->defaultChannels()-1);
+  dg_channels_box->setCurrentItem(rda->libraryConf()->defaultChannels()-1);
   dg_channels_label=new QLabel(dg_channels_box,tr("Channels")+":",this);
-  dg_channels_label->setFont(label_font);
-  dg_channels_label->setAlignment(AlignRight|AlignVCenter);
+  dg_channels_label->setFont(labelFont());
+  dg_channels_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   //
   // Autotrim Check Box
   //
   dg_autotrim_box=new QCheckBox(tr("Autotrim"),this);
+  dg_autotrim_box->setFont(labelFont());
   dg_autotrim_box->setChecked(true);
-  dg_autotrim_box->setFont(label_font);
-  dg_autotrim_box->setChecked(dg_library_conf->trimThreshold()!=0);
+  dg_autotrim_box->setChecked(rda->libraryConf()->trimThreshold()!=0);
   connect(dg_autotrim_box,SIGNAL(toggled(bool)),
 	  this,SLOT(autotrimCheckData(bool)));
 
@@ -257,21 +213,21 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_autotrim_spin=new QSpinBox(this);
   dg_autotrim_spin->setRange(-99,0);
-  dg_autotrim_spin->setValue(dg_library_conf->trimThreshold()/100);
+  dg_autotrim_spin->setValue(rda->libraryConf()->trimThreshold()/100);
   dg_autotrim_label=new QLabel(dg_autotrim_spin,tr("Level")+":",this);
-  dg_autotrim_label->setFont(label_font);
-  dg_autotrim_label->setAlignment(AlignRight|AlignVCenter);
+  dg_autotrim_label->setFont(labelFont());
+  dg_autotrim_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   dg_autotrim_unit=new QLabel(tr("dBFS"),this);
-  dg_autotrim_unit->setFont(label_font);
-  dg_autotrim_unit->setAlignment(AlignLeft|AlignVCenter);
+  dg_autotrim_unit->setFont(labelFont());
+  dg_autotrim_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Normalize Check Box
   //
   dg_normalize_box=new QCheckBox(tr("Normalize"),this);
+  dg_normalize_box->setFont(labelFont());
   dg_normalize_box->setChecked(true);
-  dg_normalize_box->setFont(label_font);
-  dg_normalize_box->setChecked(dg_library_conf->ripperLevel()!=0);
+  dg_normalize_box->setChecked(rda->libraryConf()->ripperLevel()!=0);
   connect(dg_normalize_box,SIGNAL(toggled(bool)),
 	  this,SLOT(normalizeCheckData(bool)));
 
@@ -280,13 +236,13 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_normalize_spin=new QSpinBox(this);
   dg_normalize_spin->setRange(-30,0);
-  dg_normalize_spin->setValue(dg_library_conf->ripperLevel()/100);
+  dg_normalize_spin->setValue(rda->libraryConf()->ripperLevel()/100);
   dg_normalize_label=new QLabel(dg_normalize_spin,tr("Level:"),this);
-  dg_normalize_label->setFont(label_font);
-  dg_normalize_label->setAlignment(AlignRight|AlignVCenter);
+  dg_normalize_label->setFont(labelFont());
+  dg_normalize_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   dg_normalize_unit=new QLabel(tr("dBFS"),this);
-  dg_normalize_unit->setFont(label_font);
-  dg_normalize_unit->setAlignment(AlignLeft|AlignVCenter);
+  dg_normalize_unit->setFont(labelFont());
+  dg_normalize_unit->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
 
   //
   // Eject Button
@@ -298,7 +254,7 @@ MainWidget::MainWidget(QWidget *parent)
   // Close Button
   //
   dg_close_button=new QPushButton(tr("Close"),this);
-  dg_close_button->setFont(label_font);
+  dg_close_button->setFont(buttonFont());
   connect(dg_close_button,SIGNAL(clicked()),this,SLOT(quitMainWidget()));
 
   LoadConfig();
@@ -306,7 +262,7 @@ MainWidget::MainWidget(QWidget *parent)
   if(!dg_player->open()) {
     QMessageBox::warning(this,"RDDiscImport - "+tr("Ripper Error"),
 			 tr("Unable to open CD-ROM device at")+" "+
-			 " \""+dg_library_conf->ripperDevice()+"\".");
+			 " \""+rda->libraryConf()->ripperDevice()+"\".");
     exit(256);
   }
   if(dg_metalibrary->load(dg_indexfile_edit->text())&&
@@ -315,6 +271,8 @@ MainWidget::MainWidget(QWidget *parent)
 			 tr("Unable to read index file!"));
     return;
   }
+
+  dg_resize=true;
 }
 
 
@@ -329,7 +287,7 @@ void MainWidget::indexFileSelectedData()
   QString filename;
   int lines;
 
-  filename=QFileDialog::getOpenFileName(dg_indexfile_edit->text(),
+  filename=Q3FileDialog::getOpenFileName(dg_indexfile_edit->text(),
 					"CSV Files *.csv",this,"",
 					tr("RDDiscImport - Open Index File"));
   dg_metalibrary->clear();
@@ -366,7 +324,7 @@ void MainWidget::autotrimCheckData(bool state)
 }
 
 
-void MainWidget::trackDoubleClickedData(QListViewItem *it,const QPoint &pt,
+void MainWidget::trackDoubleClickedData(Q3ListViewItem *it,const QPoint &pt,
 					int row)
 {
   RDListViewItem *item=(RDListViewItem *)it;
@@ -468,15 +426,15 @@ void MainWidget::ripData()
   // Load Importer Settings
   //
   RDSettings *s=new RDSettings();
-  if(dg_library_conf->defaultFormat()==1) {
+  if(rda->libraryConf()->defaultFormat()==1) {
     s->setFormat(RDSettings::MpegL2Wav);
   }
   else {
     s->setFormat(RDSettings::Pcm16);
   }
   s->setChannels(dg_channels_box->currentItem()+1);
-  s->setSampleRate(dg_system->sampleRate());
-  s->setBitRate(dg_library_conf->defaultBitrate());
+  s->setSampleRate(rda->system()->sampleRate());
+  s->setBitRate(rda->libraryConf()->defaultBitrate());
   if(dg_normalize_box->isChecked()) {
     s->setNormalizationLevel(dg_normalize_spin->value());
   }
@@ -503,14 +461,14 @@ void MainWidget::ripData()
 	  return;
 	}
 	cart=new RDCart(cartnum);
-	cart->addCut(dg_library_conf->defaultFormat(),
-		     dg_library_conf->defaultBitrate(),
+	cart->addCut(rda->libraryConf()->defaultFormat(),
+		     rda->libraryConf()->defaultBitrate(),
 		     dg_channels_box->currentItem()+1,"",r->discId());
 	cut=new RDCut(cartnum,1);
 	dg_importer->setCartNumber(cartnum);
 	dg_importer->setCutNumber(1);
 	if((import_err=dg_importer->
-	    runImport(dg_user->name(),dg_user->password(),&conv_err))==
+	    runImport(rda->user()->name(),rda->user()->password(),&conv_err))==
 	   RDAudioImport::ErrorOk) {
 	  data=new RDWaveData();
 	  r->getMetadata(data,dg_player->trackLength(i+1));
@@ -573,15 +531,9 @@ void MainWidget::userChangedData()
 {
   QStringList groups;
 
-  if(dg_user!=NULL) {
-    delete dg_user;
-  }
   dg_group_box->clear();
-
-  dg_user=new RDUser(dg_ripc->user());
-  
-  groups=dg_user->groups();
-  for(unsigned i=0;i<groups.size();i++) {
+  groups=rda->user()->groups();
+  for(int i=0;i<groups.size();i++) {
     dg_group_box->insertItem(groups[i]);
     if(dg_group_name==groups[i]) {
       dg_group_box->setCurrentItem(i);
@@ -604,45 +556,47 @@ void MainWidget::quitMainWidget()
 
 void MainWidget::resizeEvent(QResizeEvent *e)
 {
-  dg_indexfile_label->setGeometry(10,10,115,20);
-  dg_indexfile_edit->setGeometry(130,10,size().width()-220,20);
-  dg_indexfile_button->setGeometry(size().width()-70,7,60,26);
+  if(dg_resize) {
+    dg_indexfile_label->setGeometry(10,10,115,20);
+    dg_indexfile_edit->setGeometry(130,10,size().width()-220,20);
+    dg_indexfile_button->setGeometry(size().width()-70,7,60,26);
 
-  dg_group_label->setGeometry(10,40,115,20);
-  dg_group_box->setGeometry(130,40,200,20);
+    dg_group_label->setGeometry(10,40,115,20);
+    dg_group_box->setGeometry(130,40,200,20);
 
-  dg_userdef_label->setGeometry(350,40,95,20);
-  dg_userdef_edit->setGeometry(450,40,size().width()-460,20);
+    dg_userdef_label->setGeometry(350,40,95,20);
+    dg_userdef_edit->setGeometry(450,40,size().width()-460,20);
 
-  dg_track_list->setGeometry(10,72,size().width()-20,size().height()-232);
+    dg_track_list->setGeometry(10,72,size().width()-20,size().height()-232);
 
-  dg_disc_label->setGeometry(15,size().height()-157,size().width()-20,20);
-  dg_disc_bar->setGeometry(10,size().height()-140,size().width()-20,20);
+    dg_disc_label->setGeometry(15,size().height()-157,size().width()-20,20);
+    dg_disc_bar->setGeometry(10,size().height()-140,size().width()-20,20);
 
-  dg_track_label->setGeometry(15,size().height()-117,size().width()-20,20);
-  dg_track_bar->setGeometry(10,size().height()-100,size().width()-20,20);
+    dg_track_label->setGeometry(15,size().height()-117,size().width()-20,20);
+    dg_track_bar->setGeometry(10,size().height()-100,size().width()-20,20);
 
-  dg_discid_label->setGeometry(10,size().height()-70,60,20);
-  dg_discid_edit->setGeometry(75,size().height()-70,60,20);
+    dg_discid_label->setGeometry(10,size().height()-70,60,20);
+    dg_discid_edit->setGeometry(75,size().height()-70,60,20);
 
-  dg_rip_button->setGeometry(10,size().height()-43,130,30);
+    dg_rip_button->setGeometry(10,size().height()-43,130,30);
 
-  dg_channels_box->setGeometry(340,size().height()-75,50,20);
-  dg_channels_label->setGeometry(250,size().height()-75,75,20);
+    dg_channels_box->setGeometry(340,size().height()-75,50,20);
+    dg_channels_label->setGeometry(250,size().height()-75,75,20);
 
-  dg_autotrim_box->setGeometry(200,size().height()-48,80,15);
-  dg_autotrim_spin->setGeometry(340,size().height()-50,40,20);
-  dg_autotrim_label->setGeometry(290,size().height()-50,45,20);
-  dg_autotrim_unit->setGeometry(385,size().height()-50,40,20);
+    dg_autotrim_box->setGeometry(200,size().height()-48,80,15);
+    dg_autotrim_spin->setGeometry(340,size().height()-50,40,20);
+    dg_autotrim_label->setGeometry(290,size().height()-50,45,20);
+    dg_autotrim_unit->setGeometry(385,size().height()-50,40,20);
 
-  dg_normalize_box->setGeometry(200,size().height()-21,113,15);
-  dg_normalize_spin->setGeometry(340,size().height()-23,40,20);
-  dg_normalize_label->setGeometry(290,size().height()-23,45,20);
-  dg_normalize_unit->setGeometry(385,size().height()-23,40,20);
+    dg_normalize_box->setGeometry(200,size().height()-21,113,15);
+    dg_normalize_spin->setGeometry(340,size().height()-23,40,20);
+    dg_normalize_label->setGeometry(290,size().height()-23,45,20);
+    dg_normalize_unit->setGeometry(385,size().height()-23,40,20);
 
-  dg_eject_button->setGeometry(size().width()-200,size().height()-60,80,50);
+    dg_eject_button->setGeometry(size().width()-200,size().height()-60,80,50);
 
-  dg_close_button->setGeometry(size().width()-90,size().height()-60,80,50);
+    dg_close_button->setGeometry(size().width()-90,size().height()-60,80,50);
+  }
 }
 
 
@@ -689,9 +643,8 @@ void MainWidget::LockGui(bool state)
 void MainWidget::SetCaption()
 {
   QString username=tr("[unknown]");
-  if(dg_user!=NULL) {
-    username=dg_user->name();
-  }
+
+  username=rda->user()->name();
   setCaption(tr("RDDiscImport")+" v"+VERSION+" "+tr("User")+": "+username);
 }
 
@@ -727,13 +680,14 @@ void MainWidget::SaveConfig()
 
 int main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
   // Load Translations
   //
   QTranslator qt(0);
-  qt.load(QString(QTDIR)+QString("/translations/qt_")+QTextCodec::locale(),
+  qt.load(QString("/usr/share/qt4/translations/qt_")+QTextCodec::locale(),
 	  ".");
   a.installTranslator(&qt);
 
@@ -755,7 +709,9 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget();
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
   w->show();
