@@ -2,7 +2,7 @@
 //
 // A Qt-based application for testing General Purpose Input (GPI) devices.
 //
-//   (C) Copyright 2002-2014 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,124 +18,79 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-
 #include <qapplication.h>
-#include <qwindowsstyle.h>
-#include <qwidget.h>
-#include <qpushbutton.h>
-#include <qrect.h>
-#include <qpoint.h>
-#include <qpainter.h>
-#include <qstring.h>
 #include <qmessagebox.h>
-#include <qlineedit.h>
-#include <qtextcodec.h>
 #include <qtranslator.h>
 
-#include <rddb.h>
-#include <rdgpimon.h>
-#include <rdcmd_switch.h>
-#include <rddbheartbeat.h>
 #include <rdescape_string.h>
-#include <rdlistviewitem.h>
+#include <rdreport.h>
 #include <rdtextfile.h>
 
+#include "rdgpimon.h"
+
 //
 // Icons
 //
 #include "../icons/rivendell-22x22.xpm"
 
-
-MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QWidget(parent,name)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
+  QString err_msg;
+
   gpi_scroll_mode=false;
   
+  //
+  // Open the Database
+  //
+  rda=new RDApplication("RDGpiMon","rdgpimon",RDGPIMON_USAGE,this);
+  if(!rda->open(&err_msg)) {
+    QMessageBox::critical(this,"RDGpiMon - "+tr("Error"),err_msg);
+    exit(1);
+  }
+
   //
   // Read Command Options
   //
-  RDCmdSwitch *cmd=new RDCmdSwitch(qApp->argc(),qApp->argv(),"rdgpimon","\n");
-  delete cmd;
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      QMessageBox::critical(this,"RDGpiMon - "+tr("Error"),
+			    tr("Unknown command option")+": "+
+			    rda->cmdSwitch()->key(i));
+      exit(2);
+    }
+  }
 
   //
   // Set Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMaximumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-  setMaximumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont font("helvetica",10,QFont::Normal);
-  font.setPixelSize(10);
-  setFont(font);
-  QFont list_font("helvetica",12,QFont::Normal);
-  list_font.setPixelSize(12);
-  QFont main_font("helvetica",12,QFont::Bold);
-  main_font.setPixelSize(12);
-  QFont title_font("helvetica",14,QFont::Bold);
-  title_font.setPixelSize(14);
+  setMinimumSize(sizeHint());
+  setMaximumSize(sizeHint());
 
   //
   // Create And Set Icon
   //
-  gpi_rivendell_map=new QPixmap(rivendell_xpm);
-  setIcon(*gpi_rivendell_map);
-
-  //
-  // Load Local Configs
-  //
-  gpi_config=new RDConfig();
-  gpi_config->load();
-
-  //
-  // Open Database
-  //
-  gpi_db=QSqlDatabase::addDatabase(gpi_config->mysqlDriver());
-  if(!gpi_db) {
-    QMessageBox::warning(this,tr("Database Error"),
-		    tr("Can't Connect","Unable to connect to mySQL Server!"));
-    exit(0);
-  }
-  gpi_db->setDatabaseName(gpi_config->mysqlDbname());
-  gpi_db->setUserName(gpi_config->mysqlUsername());
-  gpi_db->setPassword(gpi_config->mysqlPassword());
-  gpi_db->setHostName(gpi_config->mysqlHostname());
-  if(!gpi_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    gpi_db->removeDatabase(gpi_config->mysqlDbname());
-    exit(0);
-  }
-  new RDDbHeartbeat(gpi_config->mysqlHeartbeatInterval(),this);
+  gpi_rivendell_map=new QPixmap(rivendell_22x22_xpm);
+  setWindowIcon(*gpi_rivendell_map);
 
   //
   // RIPC Connection
   //
-  gpi_ripc=new RDRipc(gpi_config->stationName());
-  gpi_ripc->setIgnoreMask(true);
-  connect(gpi_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
-  connect(gpi_ripc,SIGNAL(gpiStateChanged(int,int,bool)),
+  rda->ripc()->setIgnoreMask(true);
+  connect(rda,SIGNAL(userChanged()),this,SLOT(userData()));
+  connect(rda->ripc(),SIGNAL(gpiStateChanged(int,int,bool)),
 	  this,SLOT(gpiStateChangedData(int,int,bool)));
-  connect(gpi_ripc,SIGNAL(gpoStateChanged(int,int,bool)),
+  connect(rda->ripc(),SIGNAL(gpoStateChanged(int,int,bool)),
 	  this,SLOT(gpoStateChangedData(int,int,bool)));
-  connect(gpi_ripc,SIGNAL(gpiMaskChanged(int,int,bool)),
+  connect(rda->ripc(),SIGNAL(gpiMaskChanged(int,int,bool)),
 	  this,SLOT(gpiMaskChangedData(int,int,bool)));
-  connect(gpi_ripc,SIGNAL(gpoMaskChanged(int,int,bool)),
+  connect(rda->ripc(),SIGNAL(gpoMaskChanged(int,int,bool)),
 	  this,SLOT(gpoMaskChangedData(int,int,bool)));
-  connect(gpi_ripc,SIGNAL(gpiCartChanged(int,int,int,int)),
+  connect(rda->ripc(),SIGNAL(gpiCartChanged(int,int,int,int)),
 	  this,SLOT(gpiCartChangedData(int,int,int,int)));
-  connect(gpi_ripc,SIGNAL(gpoCartChanged(int,int,int,int)),
+  connect(rda->ripc(),SIGNAL(gpoCartChanged(int,int,int,int)),
 	  this,SLOT(gpoCartChangedData(int,int,int,int)));
-  gpi_ripc->connectHost("localhost",RIPCD_TCP_PORT,gpi_config->password());
-
-  //
-  // RDStation
-  //
-  gpi_station=new RDStation(gpi_config->stationName());
+  rda->ripc()->connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
 
   //
   // RDMatrix;
@@ -151,8 +106,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   gpi_type_box->insertItem(tr("GPO (Outputs)"));
   QLabel *label=new QLabel(gpi_type_box,tr("Show:"),this);
   label->setGeometry(20,10,55,21);
-  label->setFont(main_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(gpi_type_box,SIGNAL(activated(int)),
 	  this,SLOT(matrixActivatedData(int)));
 
@@ -166,8 +121,8 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   }
   label=new QLabel(gpi_matrix_box,tr("Matrix:"),this);
   label->setGeometry(220,10,55,21);
-  label->setFont(main_font);
-  label->setAlignment(AlignRight|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
   connect(gpi_matrix_box,SIGNAL(activated(int)),
 	  this,SLOT(matrixActivatedData(int)));
 
@@ -206,58 +161,57 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   label=new QLabel(tr("Green = ON Cart"),this);
   label->setGeometry(200,370,300,12);
-  label->setFont(main_font);
-  label->setAlignment(AlignLeft|AlignVCenter);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
   QPalette p=palette();
-  p.setColor(QPalette::Active,QColorGroup::Foreground,darkGreen);
-  p.setColor(QPalette::Inactive,QColorGroup::Foreground,darkGreen);
-  p.setColor(QPalette::Disabled,QColorGroup::Foreground,darkGreen);
+  p.setColor(QPalette::Active,QColorGroup::Foreground,Qt::darkGreen);
+  p.setColor(QPalette::Inactive,QColorGroup::Foreground,Qt::darkGreen);
+  p.setColor(QPalette::Disabled,QColorGroup::Foreground,Qt::darkGreen);
   label->setPalette(p);
 
   label=new QLabel(tr("Red = OFF Cart"),this);
   label->setGeometry(200,392,300,12);
-  label->setFont(main_font);
-  label->setAlignment(AlignLeft|AlignVCenter);
-  p.setColor(QPalette::Active,QColorGroup::Foreground,darkRed);
-  p.setColor(QPalette::Inactive,QColorGroup::Foreground,darkRed);
-  p.setColor(QPalette::Disabled,QColorGroup::Foreground,darkRed);
+  label->setFont(labelFont());
+  label->setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
+  p.setColor(QPalette::Active,QColorGroup::Foreground,Qt::darkRed);
+  p.setColor(QPalette::Inactive,QColorGroup::Foreground,Qt::darkRed);
+  p.setColor(QPalette::Disabled,QColorGroup::Foreground,Qt::darkRed);
   label->setPalette(p);
 
   //
   // Events Log
   //
   label=new QLabel(tr("Events Log"),this);
-  label->setFont(title_font);
+  label->setFont(sectionLabelFont());
   label->setAlignment(Qt::AlignCenter);
   label->setGeometry(110,423,sizeHint().width()-220,30);
 
-  gpi_events_date_edit=new QDateEdit(this);
-  gpi_events_date_edit->setGeometry(155,453,90,20);
+  gpi_events_date_edit=new Q3DateEdit(this);
+  gpi_events_date_edit->setGeometry(155,453,100,20);
   gpi_events_date_edit->setDate(QDate::currentDate());
   connect(gpi_events_date_edit,SIGNAL(valueChanged(const QDate &)),
 	  this,SLOT(eventsDateChangedData(const QDate &)));
   gpi_events_date_label=new QLabel(gpi_events_date_edit,tr("Date")+":",this);
   gpi_events_date_label->setGeometry(100,453,50,20);
-  gpi_events_date_label->setFont(main_font);
+  gpi_events_date_label->setFont(labelFont());
   gpi_events_date_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   gpi_events_state_box=new QComboBox(this);
-  gpi_events_state_box->setGeometry(280,453,55,20);
+  gpi_events_state_box->setGeometry(330,453,55,20);
   gpi_events_state_box->insertItem(tr("On"));
   gpi_events_state_box->insertItem(tr("Off"));
   gpi_events_state_box->insertItem(tr("Both"));
   connect(gpi_events_state_box,SIGNAL(activated(int)),
 	  this,SLOT(eventsStateChangedData(int)));
   gpi_events_state_label=new QLabel(gpi_events_state_box,tr("State")+":",this);
-  gpi_events_state_label->setGeometry(225,453,50,20);
-  gpi_events_state_label->setFont(main_font);
+  gpi_events_state_label->setGeometry(275,453,50,20);
+  gpi_events_state_label->setFont(labelFont());
   gpi_events_state_label->setAlignment(Qt::AlignRight|Qt::AlignVCenter);
 
   gpi_events_list=new RDListView(this);
-  gpi_events_list->setFont(main_font);
   gpi_events_list->setGeometry(110,480,sizeHint().width()-220,230);
   gpi_events_list->setItemMargin(5);
-  gpi_events_list->setSelectionMode(QListView::NoSelection);
+  gpi_events_list->setSelectionMode(Q3ListView::NoSelection);
 
   gpi_events_list->addColumn("Time");
   gpi_events_list->setColumnAlignment(0,Qt::AlignHCenter);
@@ -272,7 +226,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 
   gpi_events_scroll_button=new QPushButton(tr("Scroll"),this);
   gpi_events_scroll_button->setGeometry(sizeHint().width()-100,510,80,50);
-  gpi_events_scroll_button->setFont(main_font);
+  gpi_events_scroll_button->setFont(buttonFont());
   connect(gpi_events_scroll_button,SIGNAL(clicked()),
 	  this,SLOT(eventsScrollData()));
   gpi_scroll_color=palette();
@@ -281,17 +235,17 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   gpi_scroll_color.setColor(QPalette::Active,QColorGroup::Button,
 			    Qt::blue);
   gpi_scroll_color.setColor(QPalette::Active,QColorGroup::Background,
-			    lightGray);
+			    Qt::lightGray);
   gpi_scroll_color.setColor(QPalette::Inactive,QColorGroup::ButtonText,
 			    Qt::white);
   gpi_scroll_color.setColor(QPalette::Inactive,QColorGroup::Button,
 			    Qt::blue);
   gpi_scroll_color.setColor(QPalette::Inactive,QColorGroup::Background,
-			    lightGray);
+			    Qt::lightGray);
 
   gpi_events_report_button=new QPushButton(tr("Report"),this);
   gpi_events_report_button->setGeometry(sizeHint().width()-100,570,80,50);
-  gpi_events_report_button->setFont(main_font);
+  gpi_events_report_button->setFont(buttonFont());
   connect(gpi_events_report_button,SIGNAL(clicked()),
 	  this,SLOT(eventsReportData()));
 
@@ -326,7 +280,7 @@ void MainWidget::userData()
   QString str;
 
   str=QString("RDGpiMon")+" v"+VERSION+" - "+tr("User")+":";
-  setCaption(str+" "+gpi_ripc->user());
+  setWindowTitle(str+" "+rda->ripc()->user());
 }
 
 
@@ -341,20 +295,20 @@ void MainWidget::matrixActivatedData(int index)
     delete gpi_matrix;
   }
   gpi_matrix=
-    new RDMatrix(gpi_config->stationName(),gpi_matrix_box->currentItem());
+    new RDMatrix(rda->config()->stationName(),gpi_matrix_box->currentItem());
   UpdateLabelsDown(0);
   gpi_up_button->setDisabled(true);
   switch((RDMatrix::GpioType)gpi_type_box->currentItem()) {
     case RDMatrix::GpioInput:
-      gpi_ripc->sendGpiStatus(gpi_matrix_box->currentItem());
-      gpi_ripc->sendGpiMask(gpi_matrix_box->currentItem());
-      gpi_ripc->sendGpiCart(gpi_matrix_box->currentItem());
+      rda->ripc()->sendGpiStatus(gpi_matrix_box->currentItem());
+      rda->ripc()->sendGpiMask(gpi_matrix_box->currentItem());
+      rda->ripc()->sendGpiCart(gpi_matrix_box->currentItem());
       break;
 
     case RDMatrix::GpioOutput:
-      gpi_ripc->sendGpoStatus(gpi_matrix_box->currentItem());
-      gpi_ripc->sendGpoMask(gpi_matrix_box->currentItem());
-      gpi_ripc->sendGpoCart(gpi_matrix_box->currentItem());
+      rda->ripc()->sendGpoStatus(gpi_matrix_box->currentItem());
+      rda->ripc()->sendGpoMask(gpi_matrix_box->currentItem());
+      rda->ripc()->sendGpoCart(gpi_matrix_box->currentItem());
       break;
   }
   RefreshEventsList();
@@ -402,15 +356,22 @@ void MainWidget::eventsReportData()
   QString sql;
   RDSqlQuery *q;
 
-  report="                          Rivendell GPIO Event Report\n";
-  report+="     Date: "+gpi_events_date_edit->date().toString("MM/dd/yyyy")+
-    "       Station/Matrix: "+gpi_station->name()+":"+
-    QString().sprintf("%d     ",gpi_matrix_box->currentItem())+
-    " State Filter: "+gpi_events_state_box->currentText()+"\n";
+  report=RDReport::center("Rivendell GPIO Event Report",78)+"\n";
+  report+=
+    RDReport::center(QString("Date: ")+
+		     gpi_events_date_edit->date().toString("MM/dd/yyyy")+
+		     "       "+rda->station()->name()+":"+
+		     QString().sprintf("%d     ",gpi_matrix_box->currentItem())+
+		     " State Filter: "+
+		     gpi_events_state_box->currentText(),78)+"\n";
   report+="\n";
 
-  sql=QString("select EVENT_DATETIME,NUMBER,EDGE from GPIO_EVENTS where ")+
-    "(STATION_NAME=\""+RDEscapeString(gpi_station->name())+"\")&&"+
+  sql=QString("select ")+
+    "EVENT_DATETIME,"+  // 00
+    "NUMBER,"+          // 01
+    "EDGE "+            // 02
+    "from GPIO_EVENTS where "+
+    "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
     QString().sprintf("(MATRIX=%d)&&",gpi_matrix_box->currentItem())+
     QString().sprintf("(TYPE=%d)&&",gpi_type_box->currentItem())+
     "(EVENT_DATETIME>=\""+gpi_events_date_edit->date().toString("yyyy-MM-dd")+
@@ -444,7 +405,7 @@ void MainWidget::eventsReportData()
 
 void MainWidget::gpiStateChangedData(int matrix,int line,bool state)
 {
-  // printf("gpiStateChanged(%d,%d,%d)\n",matrix,line,state);
+  //  printf("gpiStateChanged(%d,%d,%d)\n",matrix,line,state);
 
   if(gpi_type_box->currentItem()!=RDMatrix::GpioInput) {
     return;
@@ -463,7 +424,7 @@ void MainWidget::gpiStateChangedData(int matrix,int line,bool state)
 
 void MainWidget::gpoStateChangedData(int matrix,int line,bool state)
 {
-  // printf("gpoStateChanged(%d,%d,%d)\n",matrix,line,state);
+  //  printf("gpoStateChanged(%d,%d,%d)\n",matrix,line,state);
 
   if(gpi_type_box->currentItem()!=RDMatrix::GpioOutput) {
     return;
@@ -609,13 +570,15 @@ void MainWidget::UpdateLabelsUp(int last_line)
       tablename="GPOS";
       break;
   }
-  sql=QString().sprintf("select NUMBER,OFF_MACRO_CART,MACRO_CART from %s \
-                         where (STATION_NAME=\"%s\")&&\
-                         (MATRIX=%d)&&\
-                         (NUMBER<=%d) order by NUMBER desc",
-			(const char *)tablename,
-			(const char *)gpi_station->name(),
-			gpi_matrix->matrix(),last_line);
+  sql=QString("select ")+
+    "NUMBER,"+          // 00
+    "OFF_MACRO_CART,"+  // 01
+    "MACRO_CART "+      // 02
+    "from "+tablename+" where "+
+    "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+    QString().sprintf("(MATRIX=%d)&&",gpi_matrix->matrix())+
+    QString().sprintf("(NUMBER<=%d) ",last_line)+
+    "order by NUMBER desc";
   q=new RDSqlQuery(sql);
   if(q->size()<count_limit) {
     count_limit=q->size();
@@ -634,6 +597,8 @@ void MainWidget::UpdateLabelsUp(int last_line)
   }
   gpi_up_button->setEnabled(q->next());
   delete q;
+
+  RefreshGpioStates();
 }
 
 
@@ -657,13 +622,15 @@ void MainWidget::UpdateLabelsDown(int first_line)
       tablename="GPOS";
       break;
   }
-  sql=QString().sprintf("select NUMBER,OFF_MACRO_CART,MACRO_CART from %s \
-                         where (STATION_NAME=\"%s\")&&\
-                         (MATRIX=%d)&&\
-                         (NUMBER>=%d) order by NUMBER",
-			(const char *)tablename,
-			(const char *)gpi_station->name(),
-			gpi_matrix->matrix(),first_line);
+  sql=QString("select ")+
+    "NUMBER,"+          // 00
+    "OFF_MACRO_CART,"+  // 01
+    "MACRO_CART "+      // 02
+    "from "+tablename+" where "+
+    "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
+    QString().sprintf("(MATRIX=%d)&&",gpi_matrix->matrix())+
+    QString().sprintf("(NUMBER>=%d) ",first_line)+
+    "order by NUMBER";
   q=new RDSqlQuery(sql);
   while(q->next()&&(count<(GPIMON_ROWS*GPIMON_COLS))) {
     gpi_labels[count]->setLine(q->value(0).toInt()-1);
@@ -678,6 +645,23 @@ void MainWidget::UpdateLabelsDown(int first_line)
   }
   gpi_down_button->setEnabled(q->next());
   delete q;
+
+  RefreshGpioStates();
+}
+
+
+void MainWidget::RefreshGpioStates()
+{
+  if(gpi_type_box->currentIndex()==0) {
+    rda->ripc()->sendGpiStatus(gpi_matrix_box->currentIndex());
+    rda->ripc()->sendGpiCart(gpi_matrix_box->currentIndex());
+    rda->ripc()->sendGpiMask(gpi_matrix_box->currentIndex());
+  }
+  else {
+    rda->ripc()->sendGpoStatus(gpi_matrix_box->currentIndex());
+    rda->ripc()->sendGpoCart(gpi_matrix_box->currentIndex());
+    rda->ripc()->sendGpoMask(gpi_matrix_box->currentIndex());
+  }
 }
 
 
@@ -687,7 +671,7 @@ void MainWidget::RefreshEventsList()
   RDSqlQuery *q;
 
   sql=QString("select EVENT_DATETIME,NUMBER,EDGE from GPIO_EVENTS where ")+
-    "(STATION_NAME=\""+RDEscapeString(gpi_station->name())+"\")&&"+
+    "(STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\")&&"+
     QString().sprintf("(MATRIX=%d)&&",gpi_matrix_box->currentItem())+
     QString().sprintf("(TYPE=%d)&&",gpi_type_box->currentItem())+
     "(EVENT_DATETIME>=\""+gpi_events_date_edit->date().toString("yyyy-MM-dd")+
@@ -753,14 +737,14 @@ void MainWidget::AddEventsItem(int line,bool state)
 
 int main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
   // Load Translations
   //
   QTranslator qt(0);
-  qt.load(QString(QTDIR)+QString("/translations/qt_")+QTextCodec::locale(),
-	  ".");
+  qt.load(QString("/usr/share/qt4/translations/qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
 
   QTranslator rd(0);
@@ -781,7 +765,9 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget(NULL,"main");
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->setGeometry(QRect(QPoint(0,0),w->sizeHint()));
   w->show();
