@@ -2,7 +2,7 @@
 //
 // A Batch Importer for Rivendell.
 //
-//   (C) Copyright 2002-2009,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,17 +29,12 @@
 #include <qfileinfo.h>
 #include <qdatetime.h>
 
-#include <rdwavedata.h>
-#include <rdwavefile.h>
-#include <rdconfig.h>
-#include <rdcmd_switch.h>
-#include <rdgroup.h>
 #include <rdcart.h>
 #include <rdcut.h>
-#include <rdripc.h>
-#include <rduser.h>
-#include <rdsystem.h>
-#include <rdstation.h>
+#include <rdgroup.h>
+#include <rdnotification.h>
+#include <rdwavedata.h>
+#include <rdwavefile.h>
 
 #include "markerset.h"
 
@@ -62,7 +57,6 @@ class MainObject : public QObject
  private:
   enum Result {Success=0,FileBad=1,NoCart=2,NoCut=3};
   void RunDropBox();
-  void ProcessFileList(const QString &flist);
   void ProcessFileEntry(const QString &entry);
   MainObject::Result ImportFile(const QString &filename,unsigned *cartnum);
   void VerifyFile(const QString &filename,unsigned *cartnum);
@@ -73,20 +67,20 @@ class MainObject : public QObject
   bool RunPattern(const QString &pattern,const QString &filename,
 		  RDWaveData *wavedata,QString *groupname);
   bool VerifyPattern(const QString &pattern);
-  void PrintLogDateTime(FILE *f=stdout);
   void DeleteCuts(unsigned cartnum);
   QDateTime GetCachedTimestamp(const QString &filename);
   void WriteTimestampCache(const QString &filename,const QDateTime &dt);
   bool SchedulerCodeExists(const QString &code) const;
   void ReadXmlFile(const QString &basename,RDWaveData *wavedata) const;
-  RDConfig *import_config;
-  RDCmdSwitch *import_cmd;
+  void Log(int prio,const QString &msg) const;
+  void SendNotification(RDNotification::Action action,unsigned cartnum);
   unsigned import_file_key;
   RDGroup *import_group;
-  RDRipc *import_ripc;
-  RDUser *import_user;
   bool import_verbose;
-  bool import_log_mode;
+  bool import_log_syslog;
+  bool import_log_file;
+  //  QString import_log_directory;
+  QString import_log_filename;
   bool import_to_mono;
   bool import_use_cartchunk_cutid;
   int import_cart_number_offset;
@@ -145,8 +139,6 @@ class MainObject : public QObject
   };
   std::list<DropboxList *> import_dropbox_list;
   QString import_temp_fix_filename;
-  RDSystem *import_system;
-  RDStation *import_station;
   MarkerSet *import_cut_markers;
   MarkerSet *import_talk_markers;
   MarkerSet *import_hook_markers;
