@@ -2,7 +2,7 @@
 //
 // Rivendell web service portal
 //
-//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,14 +18,15 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <ctype.h>
+#include <fcntl.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <syslog.h>
+#include <openssl/sha.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <openssl/sha.h>
 
 #include <map>
 
@@ -33,6 +34,7 @@
 #include <qdatetime.h>
 #include <qstringlist.h>
 
+#include <rdapplication.h>
 #include <rddb.h>
 #include <rdescape_string.h>
 #include <rdweb.h>
@@ -40,27 +42,46 @@
 #include <rdxport_interface.h>
 #include <dbversion.h>
 
-#include <rdxport.h>
+#include "rdxport.h"
 
 Xport::Xport(QObject *parent)
   :QObject(parent)
 {
-  xport_user=NULL;
+  QString err_msg;
 
   //
-  // Read Configuration
+  // Open the Database
   //
-  xport_config=new RDConfig();
-  xport_config->load();
-  xport_config->setModuleName("rdxport.cgi");
+  rda=new RDApplication("rdxport.cgi","rdxport.cgi",RDXPORT_CGI_USAGE,this);
+  if(!rda->open(&err_msg,NULL,false)) {
+    printf("Content-type: text/html\n");
+    printf("Status: 500\n");
+    printf("\n");
+    printf("rdxport.cgi: %s\n",(const char *)err_msg.utf8());
+    Exit(0);
+  }
+
+  //
+  // Read Command Options
+  //
+  for(unsigned i=0;i<rda->cmdSwitch()->keys();i++) {
+    if(!rda->cmdSwitch()->processed(i)) {
+      printf("Content-type: text/html\n");
+      printf("Status: 500\n");
+      printf("\n");
+      printf("rdxport.cgi: unknown command option \"%s\"\n",
+	     (const char *)rda->cmdSwitch()->key(i).utf8());
+      Exit(0);
+    }
+  }
 
   //
   // Drop root permissions
   //
-  if(setgid(xport_config->gid())<0) {
+  if(setgid(rda->config()->gid())<0) {
     XmlExit("Unable to set Rivendell group",500,"rdxport.cpp",LINE_NUMBER);
   }
-  if(setuid(xport_config->uid())<0) {
+  if(setuid(rda->config()->uid())<0) {
     XmlExit("Unable to set Rivendell user",500,"rdxport.cpp",LINE_NUMBER);
   }
   if(getuid()==0) {
@@ -68,63 +89,28 @@ Xport::Xport(QObject *parent)
 	    LINE_NUMBER);
   }
 
-  //
-  // Open Database
-  //
-  QSqlDatabase *db=QSqlDatabase::addDatabase(xport_config->mysqlDriver());
-  if(!db) {
-    printf("Content-type: text/html\n\n");
-    printf("rdfeed: unable to initialize connection to database\n");
-    Exit(0);
-  }
-  db->setDatabaseName(xport_config->mysqlDbname());
-  db->setUserName(xport_config->mysqlUsername());
-  db->setPassword(xport_config->mysqlPassword());
-  db->setHostName(xport_config->mysqlHostname());
-  if(!db->open()) {
-    printf("Content-type: text/html\n\n");
-    printf("rdxport: unable to connect to database\n");
-    db->removeDatabase(xport_config->mysqlDbname());
-    Exit(0);
-  }
-  RDSqlQuery *q=new RDSqlQuery("select DB from VERSION");
-  if(!q->first()) {
-    printf("Content-type: text/html\n");
-    printf("Status: 500\n\n");
-    printf("rdxport: missing/invalid database version!\n");
-    db->removeDatabase(xport_config->mysqlDbname());
-    Exit(0);
-  }
-  if(q->value(0).toUInt()!=RD_VERSION_DATABASE) {
-    printf("Content-type: text/html\n");
-    printf("Status: 500\n\n");
-    printf("rdxport: skewed database version!\n");
-    db->removeDatabase(xport_config->mysqlDbname());
-    Exit(0);
-  }
-  delete q;
-
   //
   // Determine Connection Type
   //
   if(getenv("REQUEST_METHOD")==NULL) {
     printf("Content-type: text/html\n\n");
     printf("rdxport: missing REQUEST_METHOD\n");
-    db->removeDatabase(xport_config->mysqlDbname());
     Exit(0);
   }
   if(QString(getenv("REQUEST_METHOD")).lower()!="post") {
     printf("Content-type: text/html\n\n");
     printf("rdxport: invalid web method\n");
-    db->removeDatabase(xport_config->mysqlDbname());
     Exit(0);
   }
-
-  //
-  // Load System Settings
-  //
-  xport_system=new RDSystem();
-  xport_station=new RDStation(xport_config->stationName());
+  if(getenv("REMOTE_ADDR")!=NULL) {
+    xport_remote_address.setAddress(getenv("REMOTE_ADDR"));
+  }
+  if(getenv("REMOTE_HOST")!=NULL) {
+    xport_remote_hostname=getenv("REMOTE_HOST");
+  }
+  if(xport_remote_hostname.isEmpty()) {
+    xport_remote_hostname=xport_remote_address.toString();
+  }
 
   //
   // Generate Post
@@ -135,7 +121,11 @@ Xport::Xport(QObject *parent)
 	    LINE_NUMBER);
     Exit(0);
   }
-
+  /*
+  printf("Content-type: text/html; charset=UTF-8\n\n");
+  xport_post->dump();
+  exit(0);
+  */
   //
   // Authenticate Connection
   //
@@ -143,6 +133,23 @@ Xport::Xport(QObject *parent)
     XmlExit("Invalid User",403,"rdxport.cpp",LINE_NUMBER);
   }
 
+  //
+  // Connect to ripcd(8)
+  //
+  connect(rda->ripc(),SIGNAL(connected(bool)),
+	  this,SLOT(ripcConnectedData(bool)));
+  rda->ripc()->
+    connectHost("localhost",RIPCD_TCP_PORT,rda->config()->password());
+}
+
+
+void Xport::ripcConnectedData(bool state)
+{
+  if(!state) {
+    XmlExit("unable to connect to ripc service",500,"rdxport.cpp",LINE_NUMBER);
+    Exit(0);
+  }
+
   //
   // Read Command Variable and Dispatch 
   //
@@ -272,14 +279,25 @@ Xport::Xport(QObject *parent)
     ListSystemSettings();
     break;
 
+  case RDXPORT_COMMAND_LOCKLOG:
+    LockLog();
+    break;
+
   case RDXPORT_COMMAND_REHASH:
     Rehash();
     break;
 
+  case RDXPORT_COMMAND_SAVESTRING:
+    SaveString();
+    break;
+
+  case RDXPORT_COMMAND_SAVEFILE:
+    SaveFile();
+    break;
+
   default:
     printf("Content-type: text/html\n\n");
     printf("rdxport: missing/invalid command\n");
-    db->removeDatabase(xport_config->mysqlDbname());
     Exit(0);
     break;
   }
@@ -306,7 +324,7 @@ bool Xport::Authenticate()
       "(EXPIRATION_DATETIME>now())";
     q=new RDSqlQuery(sql);
     if(q->first()) {
-      xport_user=new RDUser(q->value(0).toString());
+      rda->user()->setName(q->value(0).toString());
       delete q;
       return true;
     }
@@ -322,8 +340,8 @@ bool Xport::Authenticate()
   if(!xport_post->getValue("PASSWORD",&passwd)) {
     return false;
   }
-  xport_user=new RDUser(name);
-  if(!xport_user->exists()) {
+  rda->user()->setName(name);
+  if(!rda->user()->exists()) {
     return false;
   }
   if((xport_post->clientAddress().toIPv4Address()>>24)==127) {  // Localhost
@@ -343,7 +361,7 @@ bool Xport::Authenticate()
   //
   // Finally, try password
   //
-  if(!xport_user->checkPassword(passwd,false)) {
+  if(!rda->user()->checkPassword(passwd,false)) {
     return false;
   }
   TryCreateTicket(name);
@@ -388,16 +406,16 @@ void Xport::TryCreateTicket(const QString &name)
 	"LOGIN_NAME=\""+RDEscapeString(name)+"\","+
 	"IPV4_ADDRESS=\""+xport_post->clientAddress().toString()+"\","+
 	"EXPIRATION_DATETIME=\""+
-	now.addSecs(xport_user->webapiAuthTimeout()).
+	now.addSecs(rda->user()->webapiAuthTimeout()).
 	toString("yyyy-MM-dd hh:mm:ss")+"\"";
       q=new RDSqlQuery(sql);
       delete q;
       printf("Content-type: application/xml\n\n");
       printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
       printf("<ticketInfo>\n");
-      printf("  %s\n",(const char *)RDXmlField("ticket",ticket));
+      printf("  %s\n",(const char *)RDXmlField("ticket",ticket).utf8());
       printf("  %s\n",(const char *)
-	  RDXmlField("expires",now.addSecs(xport_user->webapiAuthTimeout())));
+	     RDXmlField("expires",now.addSecs(rda->user()->webapiAuthTimeout())).utf8());
       printf("</ticketInfo>\n");
       exit(0);
     }
@@ -405,6 +423,16 @@ void Xport::TryCreateTicket(const QString &name)
 }
 
 
+void Xport::SendNotification(RDNotification::Type type,
+			     RDNotification::Action action,const QVariant &id)
+{
+  RDNotification *notify=new RDNotification(type,action,id);
+  rda->ripc()->sendNotification(*notify);
+  qApp->processEvents();
+  delete notify;
+}
+
+
 void Xport::Exit(int code)
 {
   if(xport_post!=NULL) {
@@ -420,6 +448,12 @@ void Xport::XmlExit(const QString &str,int code,const QString &srcfile,
   if(xport_post!=NULL) {
     delete xport_post;
   }
+  if(code>=400) {
+    rda->syslog(LOG_WARNING,"%s '%s' %s",
+		(const char *)str.toUtf8(),(const char *)srcfile.toUtf8(),
+		(srcline>0)?(const char *)QString().sprintf("line %d",srcline).
+		toUtf8():"");
+  }
 #ifdef RDXPORT_DEBUG
   if(srcline>0) {
     RDXMLResult(str+" \""+srcfile+"\" "+QString().sprintf("line %d",srcline),
