@@ -2,7 +2,7 @@
 //
 // Rivendell web service portal
 //
-//   (C) Copyright 2010,2014 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,25 +18,34 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-
 #ifndef RDXPORT_H
 #define RDXPORT_H
 
 #include <qobject.h>
 
 #include <rdaudioconvert.h>
-#include <rdconfig.h>
 #include <rdformpost.h>
-#include <rduser.h>
-#include <rdsystem.h>
+#include <rdnotification.h>
+#include <rdsvc.h>
+
+#define RDXPORT_CGI_USAGE "\n"
+#define STRINGIZE(x) STRINGIZE2(x)
+#define STRINGIZE2(x) #x
+#define LINE_NUMBER QString(STRINGIZE(__LINE__)).toInt()
 
 class Xport : public QObject
 {
+  Q_OBJECT;
  public:
-  Xport(QObject *parent=0,const char *name=0);
+  enum LockLogOperation {LockLogCreate=0,LockLogUpdate=1,LockLogClear=2};
+  Xport(QObject *parent=0);
+
+ private slots:
+  void ripcConnectedData(bool state);
 
  private:
   bool Authenticate();
+  void TryCreateTicket(const QString &name);
   void Export();
   void Import();
   void DeleteAudio();
@@ -59,20 +68,35 @@ class Xport : public QObject
   void CopyAudio();
   void AudioInfo();
   void AudioStore();
+  void AddLog();
+  void DeleteLog();
   void ListLogs();
   void ListLog();
+  RDSvc *GetLogService(const QString &svc_name);
+  bool ServiceUserValid(const QString &svc_name);
+  void Rehash();
+  void SaveLog();
   void ListSchedCodes();
   void AssignSchedCode();
   void UnassignSchedCode();
   void ListCartSchedCodes();
   void ListServices();
+  void ListSystemSettings();
+  void LockLog();
+  QString LogLockXml(bool result,const QString &log_name,const QString &guid,
+		     const QString &username,const QString &stationname,
+		     const QHostAddress addr) const;
+  void SaveString();
+  void SaveFile();
+  void SendNotification(RDNotification::Type type,RDNotification::Action action,
+			const QVariant &id);
   void Exit(int code);
-  void XmlExit(const QString &str,int code,
+  void XmlExit(const QString &msg,int code,
+	       const QString &srcfile="",int line=-1,
 	       RDAudioConvert::ErrorCode err=RDAudioConvert::ErrorOk);
   RDFormPost *xport_post;
-  RDUser *xport_user;
-  RDConfig *xport_config;
-  RDSystem *xport_system;
+  QString xport_remote_hostname;
+  QHostAddress xport_remote_address;
 };
 
 
